"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { memo, useMemo, useContext, useCallback } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { getIsInclude, mapToKeyArray } from '../../libs/map.js';
import { Heading } from '../Heading/Heading.js';
import { FaCaretRightIcon, FaCaretDownIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { AccordionPanelContext } from './AccordionPanel.js';
import { AccordionPanelItemContext } from './AccordionPanelItem.js';
import { getNewExpandedItems, focusNextSibling, focusPreviousSibling, focusLastSibling, focusFirstSibling } from './accordionPanelHelper.js';

const classNameGenerator = ce({
    slots: {
        title: 'shr-grow shr-leading-tight',
        titleWrapper: 'shr-flex-nowrap',
        button: [
            'smarthr-ui-AccordionPanel-trigger',
            'shr-group shr-w-full shr-cursor-pointer shr-appearance-none shr-border-none shr-bg-transparent shr-px-1 shr-py-0.75 shr-text-left shr-text-inherit shr-text-color-inherit',
            'disabled:shr-cursor-not-allowed disabled:shr-bg-white-darken disabled:shr-text-disabled',
            'hover:shr-bg-white-darken',
            'focus-visible:shr-focus-indicator',
            // Base 直下に AccordionPanel がある場合、背景が付き抜けないように角丸を指定（Base に overflow: hidden を与えるとフォーカスリングが表示されなくなる）
            '[.smarthr-ui-Base_>_.smarthr-ui-AccordionPanel_.smarthr-ui-AccordionPanel-item:first-child_&]:shr-rounded-t-l [.smarthr-ui-Base_>_.smarthr-ui-AccordionPanel_.smarthr-ui-AccordionPanel-item:last-child_&]:shr-rounded-b-l',
        ],
        leftIcon: 'shr-transition-transform shr-duration-100 group-aria-expanded:shr-rotate-90',
        rightIcon: 'group-aria-expanded:-shr-rotate-180',
    },
    compoundSlots: [
        {
            slots: ['leftIcon', 'rightIcon'],
            className: 'shr-shrink-0',
        },
    ],
});
const AccordionPanelTrigger = ({ children, className, headingType = 'blockTitle', headingTag, ...props }) => {
    const classNames = useMemo(() => {
        const { title, titleWrapper, button, leftIcon, rightIcon } = classNameGenerator();
        return {
            title: title(),
            titleWrapper: titleWrapper(),
            button: button({ className }),
            leftIcon: leftIcon(),
            rightIcon: rightIcon(),
        };
    }, [className]);
    const { name } = useContext(AccordionPanelItemContext);
    const { iconPosition, expandedItems, onClickTrigger, onClickProps, expandableMultiply, parentRef, } = useContext(AccordionPanelContext);
    const isExpanded = useMemo(() => getIsInclude(expandedItems, name), [expandedItems, name]);
    const actualOnClickTrigger = useMemo(() => onClickTrigger
        ? (e) => onClickTrigger(e.currentTarget.value, !isExpanded)
        : undefined, [isExpanded, onClickTrigger]);
    const actualOnClickProps = useMemo(() => onClickProps
        ? (e) => {
            const newExpandedItems = getNewExpandedItems(expandedItems, e.currentTarget.value, !isExpanded, expandableMultiply);
            onClickProps(mapToKeyArray(newExpandedItems));
        }
        : undefined, [isExpanded, expandedItems, expandableMultiply, onClickProps]);
    const handleClick = useMemo(() => {
        if (actualOnClickTrigger) {
            if (actualOnClickProps) {
                return (e) => {
                    actualOnClickTrigger(e);
                    actualOnClickProps(e);
                };
            }
            return actualOnClickTrigger;
        }
        else if (actualOnClickProps) {
            return actualOnClickProps;
        }
        return undefined;
    }, [actualOnClickProps, actualOnClickTrigger]);
    const handleKeyDown = useCallback((e) => {
        if (!parentRef?.current) {
            return;
        }
        const item = e.target;
        switch (e.key) {
            case 'Home': {
                e.preventDefault();
                focusFirstSibling(parentRef.current);
                break;
            }
            case 'End': {
                e.preventDefault();
                focusLastSibling(parentRef.current);
                break;
            }
            case 'ArrowLeft':
            case 'ArrowUp': {
                e.preventDefault();
                focusPreviousSibling(item, parentRef.current);
                break;
            }
            case 'ArrowRight':
            case 'ArrowDown': {
                e.preventDefault();
                focusNextSibling(item, parentRef.current);
                break;
            }
        }
    }, [parentRef]);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    jsx(Heading, { tag: headingTag, type: headingType, children: jsx("button", { ...props, type: "button", value: name, id: `${name}-trigger`, "aria-expanded": isExpanded, "aria-controls": `${name}-content`, onClick: handleClick, onKeyDown: handleKeyDown, className: classNames.button, "data-component": "AccordionHeaderButton", children: jsx(MemoizedTitle, { iconPosition: iconPosition, classNames: classNames, children: children }) }) }));
};
const MemoizedTitle = memo(({ classNames, iconPosition, children }) => (jsxs(Cluster, { className: classNames.titleWrapper, align: "center", as: "span", children: [iconPosition === 'left' && jsx(FaCaretRightIcon, { className: classNames.leftIcon }), jsx("span", { className: classNames.title, children: children }), iconPosition === 'right' && jsx(FaCaretDownIcon, { className: classNames.rightIcon })] })));

export { AccordionPanelTrigger };
//# sourceMappingURL=AccordionPanelTrigger.js.map
