"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { DesktopHeader } from './components/desktop/DesktopHeader.js';
import { MobileHeader } from './components/mobile/MobileHeader.js';
import { LocaleContextProvider } from './hooks/useLocale.js';
import { useMediaQuery, mediaQuery } from './hooks/useMediaQuery.js';

const AppHeader = ({ locale, children, ...props }) => {
    // NOTE: ヘッダーの出し分けは CSS によって行われているので、useMediaQuery による children の出し分けは本来不要ですが、
    //  wovn の言語切替カスタム UI の挿入対象となる DOM ("wovn-embedded-widget-anchor" クラスを持った div) が複数描画されていると、
    //  wovn のスクリプトの仕様上1つ目の DOM にしか UI が挿入されないため、やむを得ず children のみ React のレンダリングレベルでの出し分けをしています。
    const isDesktop = useMediaQuery(mediaQuery.desktop);
    // HINT: Desktop,Mobileの両ヘッダーは常にHTML上に存在し、cssでvisibleを切り替えることでSSR環境でのレイアウトシフトが発生しないようにしています
    // 表示切替は画面幅によって決まり、SSR環境では判定出来ないためです
    return (jsxs(LocaleContextProvider, { locale: locale, children: [jsx(DesktopHeader, { ...props, children: isDesktop ? children : undefined }), jsx(MobileHeader, { ...props, children: isDesktop ? undefined : children })] }));
};

export { AppHeader };
//# sourceMappingURL=AppHeader.js.map
