import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useRef, useMemo, useCallback } from 'react';
import { tv as ce } from './../../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { textColor } from '../../../../themes/tailwind/TailwindConfig.js';
import { Button } from '../../../Button/Button.js';
import '../../../Button/AnchorButton.js';
import '../../../Button/UnstyledButton.js';
import { Dropdown } from '../../../Dropdown/Dropdown.js';
import { DropdownTrigger } from '../../../Dropdown/DropdownTrigger.js';
import { DropdownContent } from '../../../Dropdown/DropdownContent.js';
import '../../../Dropdown/DropdownCloser.js';
import '../../../Dropdown/FilterDropdown/FilterDropdown.js';
import '../../../Dropdown/DropdownMenuButton/DropdownMenuButton.js';
import '../../../Dropdown/DropdownMenuButton/DropdownMenuGroup.js';
import '../../../Dropdown/SortDropdown/SortDropdown.js';
import { FaCaretDownIcon, FaCheckIcon } from '../../../Icon/Icon.js';
import '../../../Icon/generateIcon.js';
import { useTranslate } from '../../hooks/useTranslate.js';
import { Translate } from './Translate.js';

const classNameGenerator = ce({
    slots: {
        trigger: [
            'smarthr-ui-AppLauncher-SortDropdown-trigger',
            'shr-gap-0.25 shr-text-grey',
            '[&[aria-expanded="true"]_.smarthr-ui-Icon]:shr-rotate-180',
        ],
        contentBody: ['shr-px-0.25 shr-py-0.5', 'shr-flex shr-flex-col shr-items-stretch'],
        contentButton: [
            'shr-justify-start shr-border-none shr-py-0.75 shr-pl-2.5 shr-font-normal',
            'aria-selected:shr-pl-1',
        ],
    },
});
const AppLauncherSortDropdown = ({ sortType, onSelectSortType }) => {
    const triggerRef = useRef(null);
    const classNames = useMemo(() => {
        const { trigger, contentBody, contentButton } = classNameGenerator();
        return {
            trigger: trigger(),
            contentBody: contentBody(),
            contentButton: contentButton(),
        };
    }, []);
    const translate = useTranslate();
    const translated = useMemo(() => ({
        label: translate('Launcher/sortDropdownLabel'),
        selected: translate('Launcher/sortDropdownSelected'),
        default: translate('Launcher/sortDropdownOrderDefault'),
        asc: translate('Launcher/sortDropdownOrderNameAsc'),
        desc: translate('Launcher/sortDropdownOrderNameDesc'),
    }), [translate]);
    const options = useMemo(() => [
        ['default', translated.default],
        ['name/asc', translated.asc],
        ['name/desc', translated.desc],
    ], [translated]);
    const onClickOption = useCallback((e) => {
        onSelectSortType(e.currentTarget.value);
        // Dropdown がネストしており、この Dropdown のみ閉じて親の Dropdown は開いたままというのができない
        // そのため、無理矢理クリックイベントを発生させて実現している
        setTimeout(() => {
            if (triggerRef.current) {
                triggerRef.current.click();
                triggerRef.current.focus();
            }
        }, 0);
    }, [onSelectSortType]);
    return (jsxs(Dropdown, { children: [jsx(TriggerButton, { triggerRef: triggerRef, className: classNames.trigger, children: translated.label }), jsx(DropdownContent, { controllable: true, children: jsx("div", { role: "listbox", className: classNames.contentBody, children: options.map(([value, children], i) => (jsx(OptionButton, { value: value, selected: value === sortType, selectedAlt: translated.selected, onClick: onClickOption, className: classNames.contentButton, children: children }, i))) }) })] }));
};
const TriggerButton = memo(({ triggerRef, children, className }) => (jsx(DropdownTrigger, { children: jsx(Button, { ref: triggerRef, size: "s", variant: "text", suffix: jsx(FaCaretDownIcon, {}), className: className, children: jsx(Translate, { children: children }) }) })));
const OptionButton = memo(({ value, selected, selectedAlt, onClick, children, className }) => (jsx(Button, { value: value, role: "option", "aria-selected": selected, className: className, prefix: selected && jsx(FaCheckIcon, { color: textColor.main, alt: jsx(Translate, { children: selectedAlt }) }), onClick: onClick, children: jsx(Translate, { children: children }) })));

export { AppLauncherSortDropdown };
//# sourceMappingURL=AppLauncherSortDropdown.js.map
