import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Button } from '../../../Button/Button.js';
import { AnchorButton as ForwardedAnchorButton } from '../../../Button/AnchorButton.js';
import '../../../Button/UnstyledButton.js';
import { Dropdown } from '../../../Dropdown/Dropdown.js';
import { DropdownTrigger } from '../../../Dropdown/DropdownTrigger.js';
import { DropdownContent } from '../../../Dropdown/DropdownContent.js';
import '../../../Dropdown/DropdownCloser.js';
import '../../../Dropdown/FilterDropdown/FilterDropdown.js';
import { DropdownMenuButton } from '../../../Dropdown/DropdownMenuButton/DropdownMenuButton.js';
import '../../../Dropdown/DropdownMenuButton/DropdownMenuGroup.js';
import '../../../Dropdown/SortDropdown/SortDropdown.js';
import { FaUserIcon, FaGearIcon, FaCaretDownIcon } from '../../../Icon/Icon.js';
import '../../../Icon/generateIcon.js';
import { Stack } from '../../../Layout/Stack/Stack.js';
import { Cluster } from '../../../Layout/Cluster/Cluster.js';
import '../../../Layout/Reel/Reel.js';
import '../../../Layout/Sidebar/Sidebar.js';
import '../../../Layout/Center/Center.js';
import { Text } from '../../../Text/Text.js';
import { useTranslate } from '../../hooks/useTranslate.js';
import { buildDisplayName } from '../../utils.js';
import { CommonButton } from '../common/CommonButton.js';
import { Translate } from '../common/Translate.js';

// HeaderDropdownMenuButton と同じスタイルを適用
const classNameGenerator = ce({
    slots: {
        userSummary: [
            'shr-relative -shr-mx-0.25 -shr-mt-0.5 shr-p-1',
            // FIXME: smarthr-ui で DropdownMenuButton のグルーピングができるようになったら修正しましょう
            'after:shr-absolute after:shr-inset-x-0.5 after:shr-bottom-0 after:shr-block after:shr-h-px after:shr-bg-border after:shr-content-[""]',
        ],
        dropdownMenuButton: [
            '[&_.smarthr-ui-DropdownMenuButton-trigger]:shr-border-transparent [&_.smarthr-ui-DropdownMenuButton-trigger]:shr-px-0.5 [&_.smarthr-ui-DropdownMenuButton-trigger]:shr-font-normal',
        ],
        dropdownContentButton: [
            '[&&.smarthr-ui-AnchorButton]:shr-p-0.75 [&&.smarthr-ui-AnchorButton]:shr-py-0.75',
            '[&&.smarthr-ui-Button]:shr-p-0.75 [&&.smarthr-ui-Button]:shr-py-0.75',
        ],
        button: [
            '[&&]:shr-border-transparent [&&]:shr-font-normal [&&]:last-of-type:-shr-me-0.25',
            '[&&]:focus-visible:shr-bg-transparent',
            "[&[aria-expanded='true']_.smarthr-ui-Icon:last-child]:shr-rotate-180",
        ],
        dropdownContent: '[&&]:shr-whitespace-pre [&&]:shr-p-0.5',
        accountImage: '',
        placeholderImage: 'shr-p-0.5',
    },
    variants: {
        enableNew: {
            true: {
                button: '[&&]:shr-px-0.5',
            },
            false: {
                button: '[&&]:shr-bg-transparent [&&]:shr-px-0.25 [&&]:shr-text-white [&&]:hover:shr-bg-transparent',
            },
        },
    },
    compoundSlots: [
        {
            slots: ['accountImage', 'placeholderImage'],
            className: 'shr-border-shorthand -shr-my-1 shr-box-border shr-flex shr-size-2 shr-items-center shr-justify-center shr-rounded-full shr-bg-white',
        },
    ],
});
const UserInfo = ({ arbitraryDisplayName, email, empCode, firstName, lastName, accountUrl, desktopAdditionalContent, ...rest }) => {
    const displayName = useMemo(() => arbitraryDisplayName ??
        buildDisplayName({
            email,
            empCode,
            firstName,
            lastName,
        }), [arbitraryDisplayName, email, empCode, firstName, lastName]);
    if (!displayName) {
        return null;
    }
    if (!accountUrl && !desktopAdditionalContent) {
        return jsx("span", { className: "shr-text-white", children: displayName });
    }
    return (jsx(ActualUserInfo, { ...rest, email: email, empCode: empCode, firstName: firstName, lastName: lastName, accountUrl: accountUrl, desktopAdditionalContent: desktopAdditionalContent, displayName: displayName }));
};
const ActualUserInfo = ({ email, empCode, firstName, lastName, tenants, currentTenantId, accountUrl, accountImageUrl, desktopAdditionalContent, enableNew, displayName, }) => {
    const classNames = useMemo(() => {
        const { userSummary, dropdownMenuButton, dropdownContentButton, button, dropdownContent, accountImage, placeholderImage, } = classNameGenerator({
            enableNew,
        });
        return {
            userSummary: userSummary(),
            dropdownMenuButton: dropdownMenuButton(),
            dropdownContentButton: dropdownContentButton(),
            button: button(),
            dropdownContent: dropdownContent(),
            accountImage: accountImage(),
            placeholderImage: placeholderImage(),
        };
    }, [enableNew]);
    const translate = useTranslate();
    const translated = useMemo(() => ({
        userSetting: translate('common/userSetting'),
    }), [translate]);
    const currentTenantName = useMemo(() => tenants?.find((tenant) => tenant.id === currentTenantId)?.name, [tenants, currentTenantId]);
    if (enableNew) {
        return (jsxs(DropdownMenuButton, { className: classNames.dropdownMenuButton, label: jsx(DropdownMenuLabel, { firstName: firstName, lastName: lastName, email: email, accountImageUrl: accountImageUrl, currentTenantName: currentTenantName, accountImageClassName: classNames.accountImage, placeHolderImageClassName: classNames.placeholderImage }), children: [jsx(UserSummaryStack, { currentTenantName: currentTenantName, empCode: empCode, firstName: firstName, lastName: lastName, email: email, className: classNames.userSummary }), jsx(DropdownContentButton, { href: accountUrl, className: classNames.dropdownContentButton, children: translated.userSetting }), desktopAdditionalContent] }));
    }
    return (jsxs(Dropdown, { children: [jsx(DisplayNameDropdownTrigger, { className: classNames.button, children: displayName }), jsxs(DropdownContent, { className: classNames.dropdownContent, children: [jsx(AccountLink, { href: accountUrl, children: translated.userSetting }), desktopAdditionalContent] })] }));
};
const DropdownMenuLabel = memo(({ firstName, lastName, email, accountImageUrl, currentTenantName, accountImageClassName, placeHolderImageClassName, }) => {
    const body = [];
    if (currentTenantName) {
        body.push(currentTenantName);
    }
    if (firstName && lastName) {
        body.push(`${firstName} ${lastName}`);
    }
    else if (email) {
        body.push(email);
    }
    if (body.length === 2) {
        body.splice(1, 0, jsx("br", {}));
    }
    return (jsxs(Cluster, { as: "span", align: "flex-start", children: [accountImageUrl ? (
            // eslint-disable-next-line smarthr/a11y-image-has-alt-attribute, jsx-a11y/alt-text
            jsx("img", { src: accountImageUrl, className: accountImageClassName, "aria-hidden": true })) : (jsx("span", { className: placeHolderImageClassName, children: jsx(FaUserIcon, { color: "TEXT_GREY" }) })), jsx(Text, { size: "XS", leading: "NORMAL", className: "-shr-my-1 shr-text-left", children: body })] }));
});
const UserSummaryStack = memo(({ currentTenantName, empCode, firstName, lastName, email, className }) => (jsxs(Stack, { gap: 0.5, className: className, children: [jsx(Text, { size: "S", color: "TEXT_GREY", weight: "bold", leading: "TIGHT", children: currentTenantName }), empCode || (firstName && lastName) ? (jsxs(Cluster, { align: "center", children: [empCode && (jsx(Text, { size: "S", color: "TEXT_GREY", leading: "TIGHT", children: empCode })), firstName && lastName && jsx(Text, { leading: "TIGHT", children: `${lastName} ${firstName}` })] })) : (jsx(Text, { leading: "TIGHT", children: email }))] })));
const DropdownContentButton = memo(({ href, children, className }) => href && (jsx(ForwardedAnchorButton, { href: href, target: "_blank", rel: "noopener noreferrer", prefix: jsx(FaGearIcon, {}), className: className, children: jsx(Translate, { children: children }) })));
const DisplayNameDropdownTrigger = memo(({ children, className }) => (jsx(DropdownTrigger, { children: jsx(Button, { variant: "text", suffix: jsx(FaCaretDownIcon, {}), className: className, children: jsx(Translate, { children: children }) }) })));
const AccountLink = memo(({ href, children }) => href && (jsx(CommonButton, { elementAs: "a", href: href, target: "_blank", rel: "noopener noreferrer", prefix: jsx(FaGearIcon, {}), children: jsx(Translate, { children: children }) })));

export { ActualUserInfo, UserInfo };
//# sourceMappingURL=UserInfo.js.map
