import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { memo, useContext, useCallback, useState, useEffect, useMemo } from 'react';
import { tv as ce } from './../../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useHandleEscape } from '../../../../hooks/useHandleEscape.js';
import { usePortal } from '../../../../hooks/usePortal.js';
import { Button } from '../../../Button/Button.js';
import '../../../Button/AnchorButton.js';
import '../../../Button/UnstyledButton.js';
import { FaBarsIcon, FaAngleRightIcon, FaToolboxIcon } from '../../../Icon/Icon.js';
import '../../../Icon/generateIcon.js';
import { useTranslate } from '../../hooks/useTranslate.js';
import { Translate } from '../common/Translate.js';
import { AppLauncherContext } from './AppLauncherContext.js';
import { MenuAccordion } from './MenuAccordion.js';
import { MenuButton } from './MenuButton.js';
import { MenuDialog } from './MenuDialog.js';
import { Navigation } from './Navigation.js';
import { NavigationContext } from './NavigationContext.js';
import { ReleaseNoteContext } from './ReleaseNoteContext.js';

const classNameGenerator = ce({
    base: ['shr-border-t-shorthand shr-py-1', 'first:shr-border-t-0 first:shr-pt-0'],
});
let scrollPosition = 0;
const Menu = ({ appName, tenantSelector, additionalContent }) => {
    const [isOpen, setIsOpen] = useState(false);
    const open = useCallback(() => setIsOpen(true), []);
    const close = useCallback(() => setIsOpen(false), []);
    const { createPortal } = usePortal();
    useEffect(() => {
        if (isOpen) {
            scrollPosition = window.scrollY;
            document.body.style.overflow = 'hidden';
        }
        else {
            document.body.style.overflow = 'auto';
            setTimeout(() => window.scrollTo(0, scrollPosition), 0);
        }
    }, [isOpen]);
    useHandleEscape(close);
    const className = useMemo(() => classNameGenerator(), []);
    const translate = useTranslate();
    const translated = useMemo(() => ({
        open: translate('MobileHeader/Menu/openMenu'),
        launcherListText: translate('Launcher/listText'),
        management: translate('MobileHeader/Menu/managementMenu'),
        releaseNote: translate('common/releaseNote'),
    }), [translate]);
    return (jsxs(Fragment, { children: [jsx(OpenButton, { onClick: open, alt: translated.open }), createPortal(jsxs(MenuDialog, { isOpen: isOpen, setIsOpen: setIsOpen, tenantSelector: tenantSelector, children: [jsx(FeatureButton, { className: className, children: translated.launcherListText }), jsx(NavigationAccordion, { appName: appName, menuClose: close, className: className }), additionalContent && (jsx(AdditionalContent, { title: translated.management, className: className, children: additionalContent })), jsx(ReleaseNoteButton, { className: className, children: translated.releaseNote })] }))] }));
};
const OpenButton = memo(({ onClick, alt }) => (jsx(Button, { size: "s", onClick: onClick, "aria-haspopup": "true", children: jsx(FaBarsIcon, { alt: alt }) })));
const FeatureButton = memo(({ children, className }) => {
    const { features, setIsAppLauncherSelected } = useContext(AppLauncherContext);
    return (features &&
        features.length > 0 && (jsx(ActualFeatureButton, { setIsAppLauncherSelected: setIsAppLauncherSelected, className: className, children: children })));
});
const ActualFeatureButton = ({ setIsAppLauncherSelected, children, className }) => {
    const onClick = useCallback(() => setIsAppLauncherSelected(true), [setIsAppLauncherSelected]);
    return (jsx("div", { className: className, children: jsx(Button, { variant: "secondary", wide: true, prefix: jsx(FaToolboxIcon, {}), suffix: jsx(FaAngleRightIcon, { className: "shr-ms-auto" }), onClick: onClick, children: jsx(Translate, { children: children }) }) }));
};
const NavigationAccordion = memo(({ appName, menuClose, className }) => {
    const { navigations } = useContext(NavigationContext);
    const children = jsx(Navigation, { navigations: navigations, onClickNavigation: menuClose });
    return navigations.length > 0 && appName ? (jsx(ActualNavigationAccordion, { appName: appName, className: className, children: children })) : (jsx("div", { className: className, children: children }));
});
const ActualNavigationAccordion = ({ appName, children, className }) => {
    const [isOpen, setIsOpen] = useState(true);
    return (jsx("div", { className: className, children: jsx(MenuAccordion, { isOpen: isOpen, setIsOpen: setIsOpen, title: appName, children: children }) }));
};
const AdditionalContent = ({ title, children, className, }) => {
    const [isOpen, setIsOpen] = useState(true);
    return (jsx("div", { className: className, children: jsx(MenuAccordion, { isOpen: isOpen, setIsOpen: setIsOpen, title: title, children: children }) }));
};
const ReleaseNoteButton = memo(({ children, className }) => {
    const { releaseNote, setIsReleaseNoteSelected } = useContext(ReleaseNoteContext);
    return (releaseNote && (jsx(ActualReleaseNoteButton, { setIsReleaseNoteSelected: setIsReleaseNoteSelected, className: className, children: children })));
});
const ActualReleaseNoteButton = memo(({ setIsReleaseNoteSelected, children, className }) => {
    const onClick = useCallback(() => setIsReleaseNoteSelected(true), [setIsReleaseNoteSelected]);
    return (jsx("div", { className: className, children: jsx(MenuButton, { onClick: onClick, children: children }) }));
});

export { Menu };
//# sourceMappingURL=Menu.js.map
