import { jsxs, jsx } from 'react/jsx-runtime';
import { memo, useCallback, useMemo, useId } from 'react';
import { Button } from '../../../Button/Button.js';
import '../../../Button/AnchorButton.js';
import '../../../Button/UnstyledButton.js';
import { Heading } from '../../../Heading/Heading.js';
import { FaCaretUpIcon, FaCaretDownIcon } from '../../../Icon/Icon.js';
import '../../../Icon/generateIcon.js';
import '../../../Layout/Stack/Stack.js';
import { Cluster } from '../../../Layout/Cluster/Cluster.js';
import '../../../Layout/Reel/Reel.js';
import '../../../Layout/Sidebar/Sidebar.js';
import '../../../Layout/Center/Center.js';
import { Section } from '../../../SectioningContent/SectioningContent.js';
import '../../../SectioningContent/levelContext.js';
import { useTranslate } from '../../hooks/useTranslate.js';
import { Translate } from '../common/Translate.js';

const MenuAccordion = ({ title, children, ...rest }) => title ? (jsx(ActualMenuAccordion, { ...rest, title: title, children: children })) : (children);
const ActualMenuAccordion = ({ isOpen, children, ...rest }) => {
    const id = useId();
    return (jsxs(Section, { children: [jsx(AccordionHeading, { ...rest, isOpen: isOpen, id: id }), jsx("div", { id: id, children: isOpen && jsx("div", { className: "shr-mt-0.5", children: children }) })] }));
};
const AccordionHeading = memo(({ isOpen, setIsOpen, title, id }) => {
    const onClickButton = useCallback(() => setIsOpen((prev) => !prev), [setIsOpen]);
    const translate = useTranslate();
    const translated = useMemo(() => ({
        close: translate('MobileHeader/MenuAccordion/close'),
        open: translate('MobileHeader/MenuAccordion/open'),
    }), [translate]);
    return (jsxs(Cluster, { justify: "space-between", align: "center", children: [jsx(Heading, { type: "subSubBlockTitle", children: jsx(Translate, { children: title }) }), jsx(Button, { size: "s", "aria-expanded": isOpen, "aria-controls": id, className: "[&&]:shr-min-h-0 [&&]:shr-p-0.25", onClick: onClickButton, children: isOpen ? (jsx(FaCaretUpIcon, { alt: translated.close })) : (jsx(FaCaretDownIcon, { alt: translated.open })) })] }));
});

export { MenuAccordion };
//# sourceMappingURL=MenuAccordion.js.map
