import { jsx, jsxs } from 'react/jsx-runtime';
import { useState } from 'react';
import { Header } from '../../../Header/Header.js';
import '../../../Header/LanguageSwitcher/LanguageSwitcher.js';
import '../../../Header/HeaderLink.js';
import '../../../Header/HeaderDropdownMenuButton.js';
import '../../../Header/AppLauncher/AppLauncher.js';
import { useLocale } from '../../hooks/useLocale.js';
import { AppLauncherContext } from './AppLauncherContext.js';
import { Help } from './Help.js';
import { Menu } from './Menu.js';
import { NavigationContext } from './NavigationContext.js';
import { ReleaseNoteContext } from './ReleaseNoteContext.js';
import { TenantSelector } from './TenantSelector.js';
import { UserInfo } from './UserInfo.js';

const MobileHeader = ({ navigations, features, releaseNote, className = '', tenants, children, helpPageUrl, schoolUrl, userInfo, appName, currentTenantId, onTenantSelect, mobileAdditionalContent, ...props }) => {
    const [isAppLauncherSelected, setIsAppLauncherSelected] = useState(false);
    const [isReleaseNoteSelected, setIsReleaseNoteSelected] = useState(false);
    const [selectedNavigationGroup, setSelectedNavigationGroup] = useState(null);
    const { locale } = useLocale();
    // navigations の設定をメニューの解放条件とする
    const isMenuAvailable = navigations && navigations.length > 0;
    return (jsx(AppLauncherContext.Provider, { value: {
            features,
            isAppLauncherSelected,
            setIsAppLauncherSelected,
        }, children: jsx(NavigationContext.Provider, { value: {
                navigations: navigations ?? [],
                selectedNavigationGroup,
                setSelectedNavigationGroup,
            }, children: jsx(ReleaseNoteContext.Provider, { value: {
                    releaseNote,
                    isReleaseNoteSelected,
                    setIsReleaseNoteSelected,
                }, children: jsxs(Header, { ...props, className: `${className} min-[752px]:!shr-hidden`, tenants: isMenuAvailable ? undefined : tenants, children: [children, jsx(Help, { helpPageUrl: helpPageUrl, schoolUrl: schoolUrl }), jsx(UserInfo, { ...userInfo, locale: locale }), isMenuAvailable && (jsx(Menu, { appName: appName, tenantSelector: jsx(TenantSelector, { tenants: tenants, currentTenantId: currentTenantId, onTenantSelect: onTenantSelect }), additionalContent: mobileAdditionalContent }))] }) }) }) }));
};

export { MobileHeader };
//# sourceMappingURL=MobileHeader.js.map
