import { jsx } from 'react/jsx-runtime';
import { memo, useMemo, useCallback, useContext } from 'react';
import { tv as ce } from './../../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { isChildNavigation } from '../../utils.js';
import { commonButtonClassNameGenerator, CommonButton } from '../common/CommonButton.js';
import { Translate } from '../common/Translate.js';
import { MenuButton } from './MenuButton.js';
import { NavigationContext } from './NavigationContext.js';

const classNameGenerator = ce({
    base: ['[&&]:shr-px-0.5'],
});
const NavigationItem = ({ navigation, onClickNavigation }) => {
    const className = classNameGenerator();
    if ('elementAs' in navigation) {
        return (jsx(NavigationCustomTag, { ...navigation, onClickNavigation: onClickNavigation, className: `${className} ${navigation.className}` }));
    }
    if ('href' in navigation) {
        return jsx(NavigationLink, { ...navigation, className: className });
    }
    if ('onClick' in navigation) {
        return (jsx(NavigationButton, { navigation: navigation, onClickNavigation: onClickNavigation, className: className }));
    }
    return jsx(NavigationGroupMenuButton, { navigation: navigation });
};
const NavigationCustomTag = memo(({ children, elementAs: Tag, current, className, onClickNavigation, ...rest }) => {
    const actualClassName = useMemo(() => commonButtonClassNameGenerator({
        current,
        boldWhenCurrent: true,
        className,
    }), [current, className]);
    return (
    // eslint-disable-next-line smarthr/a11y-delegate-element-has-role-presentation
    jsx(Tag, { ...rest, onClick: onClickNavigation, className: actualClassName, children: jsx(Translate, { children: children }) }));
});
const NavigationLink = memo(({ href, current, children, className }) => (jsx(CommonButton, { elementAs: "a", href: href, current: current, boldWhenCurrent: true, className: className, children: jsx(Translate, { children: children }) })));
const NavigationButton = ({ navigation, onClickNavigation, className }) => {
    const onClick = useCallback((e) => {
        navigation.onClick(e);
        onClickNavigation();
    }, [navigation, onClickNavigation]);
    return (jsx(CommonButton, { elementAs: "button", type: "button", onClick: onClick, current: navigation.current, boldWhenCurrent: true, className: className, children: jsx(Translate, { children: navigation.children }) }));
};
const NavigationGroupMenuButton = ({ navigation }) => {
    const { setSelectedNavigationGroup } = useContext(NavigationContext);
    const onClick = useCallback(() => setSelectedNavigationGroup(navigation), [navigation, setSelectedNavigationGroup]);
    // 子要素に current を持っているものがあるかどうか
    const isCurrent = useMemo(() => navigation.current ||
        navigation.childNavigations.some((child) => {
            if (isChildNavigation(child)) {
                return child.current;
            }
            return child.childNavigations.some((c) => c.current);
        }), [navigation]);
    return (jsx(MenuButton, { onClick: onClick, isCurrent: isCurrent, children: navigation.children }));
};

export { NavigationItem };
//# sourceMappingURL=NavigationItem.js.map
