import { useMemo, useSyncExternalStore } from 'react';

const mediaQuery = {
    desktop: '(min-width: 752px)',
};
const NOOP = () => undefined;
const RETURN_FALSE = () => false;
const useMediaQuery = (query) => {
    const mediaQueryList = useMemo(() => (typeof window === 'undefined' ? null : matchMedia(query)), [query]);
    const syncArgs = useMemo(() => ({
        subscribe: (callback) => {
            if (!mediaQueryList) {
                return NOOP;
            }
            mediaQueryList.addEventListener('change', callback);
            return () => {
                mediaQueryList.removeEventListener('change', callback);
            };
        },
        getSnapshot: () => mediaQueryList?.matches ?? false,
    }), [mediaQueryList]);
    return useSyncExternalStore(syncArgs.subscribe, syncArgs.getSnapshot, RETURN_FALSE);
};

export { mediaQuery, useMediaQuery };
//# sourceMappingURL=useMediaQuery.js.map
