import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Text } from '../Text/Text.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-Badge shr-relative shr-inline-flex',
        pill: ['shr-h-[1.75em] shr-min-w-[1.75em] shr-px-[0.5em] shr-tabular-nums'],
        dotElement: ['shr-h-[0.625em] shr-w-[0.625em]'],
    },
    variants: {
        color: {
            grey: {},
            blue: {},
            yellow: {},
            red: {},
        },
        withChildren: {
            true: {},
        },
    },
    compoundSlots: [
        {
            slots: ['pill', 'dotElement'],
            className: [
                'shr-box-border shr-flex shr-items-center shr-justify-center',
                'shr-rounded-full',
            ],
        },
        {
            slots: ['pill', 'dotElement'],
            withChildren: true,
            className: [
                'shr-absolute -shr-translate-y-1/2 shr-translate-x-1/2 [inset-block-start:0] [inset-inline-end:0]',
            ],
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'blue',
            className: 'shr-bg-main',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'yellow',
            className: 'shr-bg-warning-yellow',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'red',
            className: 'shr-bg-danger',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'grey',
            className: 'shr-bg-[theme(colors.grey.65)]',
        },
        {
            slots: ['pill', 'dotElement'],
            color: ['grey', 'blue', 'red'],
            className: 'shr-shadow-[0_0_0_1px_theme(colors.white)]',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'yellow',
            className: 'shr-shadow-[0_0_0_1px_theme(colors.black)]',
        },
        {
            slots: ['pill'],
            color: ['grey', 'blue', 'red'],
            className: 'shr-text-white',
        },
        {
            slots: ['pill'],
            color: ['yellow'],
            className: 'shr-text-black',
        },
    ],
});
const Badge = memo(({ count, showZero, ...rest }) => {
    // ドット表示の場合、数値表示は無いため、早期returnする
    if (rest.dot) {
        return jsx(ActualBadge, { ...rest });
    }
    const actualCount = count && count > 0 ? count : showZero ? 0 : undefined;
    // 0値を表示するでもない場合は何も表示しない
    if (actualCount === undefined && !rest.children) {
        return null;
    }
    return jsx(ActualBadge, { ...rest, count: actualCount });
});
const ActualBadge = ({ count, overflowCount, type, dot, children, className, ...rest }) => {
    // HINT: boolean化することでmemoが有効になる可能性を高くする
    const withChildren = !!children;
    const classNames = useMemo(() => {
        const { wrapper, pill, dotElement } = classNameGenerator({
            color: type || 'blue',
            withChildren,
        });
        return {
            wrapper: wrapper({ className }),
            pill: pill(),
            dot: dotElement(),
        };
    }, [withChildren, type, className]);
    return (jsxs("span", { ...rest, className: classNames.wrapper, children: [children, dot ? (jsx(Dot, { className: classNames.dot })) : (jsx(CountText, { count: count, overflowCount: overflowCount, className: classNames.pill }))] }));
};
const Dot = memo(({ className }) => jsx("span", { className: className }));
const CountText = memo(({ count, overflowCount = 99, className }) => count !== undefined && (jsx(Text, { size: "XS", className: className, children: count > overflowCount ? `${overflowCount}+` : count })));

export { Badge };
//# sourceMappingURL=Badge.js.map
