import { type ComponentProps, type ComponentPropsWithRef, type ComponentType, type FC, type FunctionComponentElement, type MouseEventHandler, type ReactNode } from 'react';
import { type AnchorButton, Button } from '../Button';
import type { ComponentProps as IconProps } from '../Icon';
export type ButtonType = FunctionComponentElement<ComponentProps<typeof Button>> | FunctionComponentElement<ComponentProps<typeof AnchorButton>>;
type ElementProps = Omit<ComponentPropsWithRef<'div'>, keyof Props>;
type Props = {
    /** この領域の説明 */
    description?: ReactNode;
    /** 表示する `Button` または `AnchorButton` （`variant="primary"` である必要がある） */
    primaryButton?: ButtonType;
    /** 表示する `Button` または `AnchorButton` （`variant="secondary"` である必要がある）*/
    secondaryButton?: ButtonType;
    /** 表示する tertialy link のプロパティの配列 */
    tertiaryLinks?: Array<ComponentPropsWithRef<'button'> & {
        text: ReactNode;
        icon?: ComponentType<IconProps>;
        type?: 'button' | 'reset';
        onClick?: MouseEventHandler<HTMLButtonElement>;
    }>;
    /** コンポーネントに適用する z-index 値 */
    zIndex?: number;
};
/**
 * @deprecated BottomFixedArea は非推奨です。FloatArea を使ってください。 https://smarthr.design/products/components/float-area/
 */
export declare const BottomFixedArea: FC<Props & ElementProps>;
export {};
