"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { useMemo, useCallback } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../hooks/useDecorators.js';
import '../../intl/IntlProvider.js';
import { useIntl } from '../../intl/useIntl.js';
import 'react-intl';
import { Text } from '../Text/Text.js';
import { BrowserColumn } from './BrowserColumn.js';
import { ItemNode } from './models/ItemNode.js';
import { RootNode } from './models/RootNode.js';
import { getElementIdFromNode } from './utils.js';

const classNameGenerator = ce({
    base: 'smarthr-ui-Browser shr-flex shr-min-h-[355px] shr-flex-row shr-flex-nowrap',
    variants: {
        columnCount: {
            0: 'shr-items-center shr-justify-center',
            1: '[&>div]:shr-flex-1',
            2: '[&>div:nth-child(1)]:shr-flex-1 [&>div:nth-child(2)]:shr-flex-[2]',
            3: '[&>div]:shr-flex-1',
        },
    },
    defaultVariants: {
        columnCount: 0,
    },
});
const Browser = ({ value, items, decorators, onSelectItem }) => {
    const { localize } = useIntl();
    const rootNode = useMemo(() => RootNode.from({ children: items }), [items]);
    const columns = useMemo(() => rootNode.toViewData(value), [rootNode, value]);
    const className = useMemo(() => classNameGenerator({ columnCount: columns.length }), [columns.length]);
    const decoratorDefaultTexts = useMemo(() => ({
        notFoundTitle: localize({
            id: 'smarthr-ui/Browser/notFoundTitle',
            defaultText: '該当する項目がありません。',
        }),
        notFoundDescription: localize({
            id: 'smarthr-ui/Browser/notFoundDescription',
            defaultText: '別の条件を試してください。',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    const selectedNode = useMemo(() => (value ? rootNode.findByValue(value) : undefined), [value, rootNode]);
    // FIXME: focusメソッドのfocusVisibleが主要ブラウザでサポートされたら使うようにしたい(現状ではマウスクリックでもfocusのoutlineが出てしまう)
    // https://developer.mozilla.org/ja/docs/Web/API/HTMLElement/focus
    const handleKeyDown = useCallback((e) => {
        if (!selectedNode) {
            return;
        }
        let target = undefined;
        switch (e.key) {
            case 'ArrowUp': {
                target = selectedNode.getPrev() ?? selectedNode.parent?.getLastChild();
                break;
            }
            case 'ArrowDown': {
                target = selectedNode.getNext() ?? selectedNode.parent?.getFirstChild();
                break;
            }
            case 'ArrowLeft': {
                const node = selectedNode.parent;
                if (node instanceof ItemNode) {
                    target = node;
                }
                break;
            }
            case 'ArrowRight':
            case 'Enter':
            case ' ': {
                target = selectedNode.getFirstChild();
                break;
            }
        }
        if (target) {
            e.preventDefault();
            onSelectItem?.(target.value);
            document.getElementById(getElementIdFromNode(target.value))?.focus();
        }
    }, [selectedNode, onSelectItem]);
    const onChangeInput = useMemo(() => onSelectItem
        ? (e) => onSelectItem(e.currentTarget.value)
        : undefined, [onSelectItem]);
    return (
    // eslint-disable-next-line smarthr/a11y-delegate-element-has-role-presentation, jsx-a11y/no-noninteractive-element-interactions
    jsx("div", { role: "application", onKeyDown: handleKeyDown, className: className, children: columns.length > 0 ? (columns.map((colItems, index) => (jsx(BrowserColumn, { items: colItems, index: index, value: value, onChangeInput: onChangeInput }, index)))) : (jsxs(Text, { children: [decorated.notFoundTitle, jsx("br", {}), decorated.notFoundDescription] })) }));
};

export { Browser };
//# sourceMappingURL=Browser.js.map
