"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import dayjs from '../../_virtual/dayjs.min.js';
import { forwardRef, useMemo, useState, useId, useEffect, useCallback, memo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { FaCaretDownIcon, FaChevronLeftIcon, FaChevronRightIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { CalendarTable } from './CalendarTable.js';
import { YearPicker } from './YearPicker.js';
import { getFromDate, minDate, getToDate, isBetween, getMonthArray } from './calendarHelper.js';

const classNameGenerator = ce({
    slots: {
        container: 'smarthr-ui-Calendar shr-inline-block shr-overflow-hidden shr-rounded-m shr-bg-white shr-text-black shr-shadow-layer-3 forced-colors:shr-border-shorthand forced-colors:shr-shadow-none',
        header: 'smarthr-ui-Calendar-header shr-border-b-shorthand shr-flex shr-items-center shr-p-1',
        yearMonth: 'smarthr-ui-Calendar-yearMonth shr-me-0.5 shr-text-base shr-font-bold',
        monthButtons: 'smarthr-ui-Calendar-monthButtons shr-ms-auto shr-flex',
        tableLayout: 'shr-relative',
        yearSelectButton: 'smarthr-ui-Calendar-selectingYear [&[aria-expanded="true"]_.smarthr-ui-Icon]:shr-rotate-180',
    },
});
const Calendar = forwardRef(({ from = minDate, to, onSelectDate, value, className, ...props }, ref) => {
    const classNames = useMemo(() => {
        const { container, yearMonth, header, monthButtons, tableLayout, yearSelectButton } = classNameGenerator();
        return {
            container: container({ className }),
            header: header(),
            yearMonth: yearMonth(),
            monthButtons: monthButtons(),
            tableLayout: tableLayout(),
            yearSelectButton: yearSelectButton(),
        };
    }, [className]);
    const formattedFrom = useMemo(() => {
        const date = getFromDate(from);
        const day = dayjs(date);
        return {
            day,
            date,
            year: day.year(),
        };
    }, [from]);
    const formattedTo = useMemo(() => {
        const date = getToDate(to);
        const day = dayjs(date);
        return {
            day,
            date,
            year: day.year(),
        };
    }, [to]);
    const isValidValue = useMemo(() => value && isBetween(value, formattedFrom.date, formattedTo.date), [value, formattedFrom.date, formattedTo.date]);
    const [currentMonth, setCurrentMonth] = useState((() => {
        if (isValidValue) {
            return dayjs(value);
        }
        const today = dayjs();
        return formattedTo.day.isBefore(today)
            ? formattedTo.day
            : formattedFrom.day.isAfter(today)
                ? formattedFrom.day
                : today;
    })());
    const [isSelectingYear, setIsSelectingYear] = useState(false);
    const yearPickerId = useId();
    useEffect(() => {
        if (isValidValue) {
            setCurrentMonth(dayjs(value));
        }
    }, [value, isValidValue]);
    const calculatedCurrentMonth = useMemo(() => ({
        prev: currentMonth.subtract(1, 'month'),
        next: currentMonth.add(1, 'month'),
        day: currentMonth,
        months: getMonthArray(currentMonth.toDate()),
        yearMonthText: `${currentMonth.year()}年${currentMonth.month() + 1}月`,
        selectedText: currentMonth.toString(),
    }), [currentMonth]);
    const onSelectYear = useCallback((e) => {
        setCurrentMonth(currentMonth.year(parseInt(e.currentTarget.value, 10)));
        setIsSelectingYear(false);
    }, [currentMonth]);
    const onClickSelectYear = useCallback((e) => {
        e.stopPropagation();
        setIsSelectingYear((current) => !current);
    }, []);
    return (jsxs("div", { ...props, ref: ref, className: classNames.container, children: [jsxs("header", { className: classNames.header, children: [jsx(YearMonthRender, { className: classNames.yearMonth, children: calculatedCurrentMonth.yearMonthText }), jsx(YearSelectButton, { "aria-expanded": isSelectingYear, "aria-controls": yearPickerId, onClick: onClickSelectYear, className: classNames.yearSelectButton }), jsx(MonthDirectionCluster, { isSelectingYear: isSelectingYear, directionMonth: calculatedCurrentMonth, from: formattedFrom.day, to: formattedTo.day, setCurrentMonth: setCurrentMonth, className: classNames.monthButtons })] }), jsxs("div", { className: classNames.tableLayout, children: [jsx(YearPicker, { fromYear: formattedFrom.year, toYear: formattedTo.year, selectedYear: value?.getFullYear(), onSelectYear: onSelectYear, isDisplayed: isSelectingYear, id: yearPickerId }), jsx(CalendarTable, { current: calculatedCurrentMonth, from: formattedFrom.date, to: formattedTo.date, onSelectDate: onSelectDate, selectedDayText: isValidValue ? calculatedCurrentMonth.selectedText : '' })] })] }));
});
const YearMonthRender = memo(({ children, className }) => jsx("div", { className: className, children: children }));
const YearSelectButton = memo((rest) => (jsx(Button, { ...rest, size: "s", children: jsx(FaCaretDownIcon, { alt: "\u5E74\u3092\u9078\u629E\u3059\u308B" }) })));
const MonthDirectionCluster = memo(({ isSelectingYear, directionMonth: { prev, next }, from, to, setCurrentMonth, className }) => {
    const onClickMonthPrev = useCallback(() => setCurrentMonth(prev), [prev, setCurrentMonth]);
    const onClickMonthNext = useCallback(() => setCurrentMonth(next), [next, setCurrentMonth]);
    return (jsxs(Cluster, { gap: 0.5, className: className, children: [jsx(Button, { disabled: isSelectingYear || prev.isBefore(from, 'month'), onClick: onClickMonthPrev, size: "s", className: "smarthr-ui-Calendar-monthButtonPrev", children: jsx(FaChevronLeftIcon, { alt: "\u524D\u306E\u6708\u3078" }) }), jsx(Button, { disabled: isSelectingYear || next.isAfter(to, 'month'), onClick: onClickMonthNext, size: "s", className: "smarthr-ui-Calendar-monthButtonNext", children: jsx(FaChevronRightIcon, { alt: "\u6B21\u306E\u6708\u3078" }) })] }));
});

export { Calendar };
//# sourceMappingURL=Calendar.js.map
