import { jsx, jsxs } from 'react/jsx-runtime';
import dayjs from '../../_virtual/dayjs.min.js';
import { memo, useMemo, useCallback } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import '../Button/Button.js';
import '../Button/AnchorButton.js';
import { UnstyledButton } from '../Button/UnstyledButton.js';
import { daysInWeek, isBetween } from './calendarHelper.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'shr-px-0.75 shr-pb-1 shr-pt-0.25',
        table: 'smarthr-ui-CalendarTable shr-border-spacing-0 shr-text-base shr-text-black',
        th: 'smarthr-ui-CalendarTable-headCell shr-px-0 shr-py-0.5 shr-text-center shr-align-middle shr-font-normal shr-text-grey',
        td: 'smarthr-ui-CalendarTable-dataCell shr-p-0 shr-align-middle',
        cellButton: 'shr-group shr-flex shr-items-center shr-justify-center shr-px-0.5 shr-py-0.25 disabled:shr-cursor-not-allowed disabled:shr-text-disabled',
        dateCell: [
            'shr-box-border shr-flex shr-h-[1.75rem] shr-w-[1.75rem] shr-items-center shr-justify-center shr-rounded-[50%] shr-leading-[0] group-[:not(:disabled)]:group-hover:shr-bg-base-grey group-[:not(:disabled)]:group-hover:shr-text-black',
            '[[aria-pressed="true"]>&&&]:shr-bg-main [[aria-pressed="true"]>&&&]:shr-text-white',
            '[[data-is-today="true"]>&&&]:shr-border-shorthand [[aria-pressed="true"]>&&&]:contrast-more:shr-border-high-contrast',
        ],
    },
});
const CalendarTable = ({ current, from, to, onSelectDate, selectedDayText, className, ...props }) => {
    const classNames = useMemo(() => {
        const { wrapper, table, th, td, cellButton, dateCell } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            table: table(),
            th: th(),
            td: td(),
            cellButton: cellButton(),
            dateCell: dateCell(),
        };
    }, [className]);
    // HINT: dayjsのisSameは文字列でも比較可能なため、cacheが効きやすいstringにする
    const nowDateText = dayjs().startOf('date').toString();
    return (jsx("div", { className: classNames.wrapper, children: jsxs("table", { ...props, className: classNames.table, children: [jsx(MemoizedThead, { thStyle: classNames.th }), jsx("tbody", { children: current.months.map((week, weekIndex) => (jsx("tr", { children: week.map((date, dateIndex) => date ? (jsx(SelectTdButton, { date: date, currentDay: current.day, selectedDayText: selectedDayText, from: from, to: to, nowDateText: nowDateText, onClick: onSelectDate, classNames: classNames }, dateIndex)) : (jsx(NullTd, { className: classNames.td }, dateIndex))) }, weekIndex))) })] }) }));
};
const MemoizedThead = memo(({ thStyle }) => (jsx("thead", { children: jsx("tr", { children: daysInWeek.map((day) => (jsx("th", { className: thStyle, children: day }, day))) }) })));
const NullTd = memo(({ className }) => jsx("td", { className: className }));
const SelectTdButton = memo(({ date, currentDay, selectedDayText, from, to, nowDateText, onClick, classNames }) => {
    const target = useMemo(() => {
        const day = currentDay.date(date);
        return {
            day,
            date: day.toDate(),
        };
    }, [currentDay, date]);
    const disabled = useMemo(() => !isBetween(target.date, from, to), [target.date, from, to]);
    const ariaPressed = useMemo(() => target.day.isSame(selectedDayText, 'date'), [selectedDayText, target.day]);
    const dataIsToday = useMemo(() => target.day.isSame(nowDateText, 'date'), [nowDateText, target.day]);
    const actualOnClick = useCallback((e) => {
        onClick(e, target.date);
    }, [onClick, target.date]);
    return (jsx("td", { className: classNames.td, children: jsx(UnstyledButton, { type: "button", disabled: disabled, "aria-pressed": ariaPressed, onClick: actualOnClick, className: classNames.cellButton, "data-is-today": dataIsToday, children: jsx(SelectButtonTdDateCell, { className: classNames.dateCell, children: date }) }) }));
});
const SelectButtonTdDateCell = memo(({ children, className }) => jsx("span", { className: className, children: children }));

export { CalendarTable };
//# sourceMappingURL=CalendarTable.js.map
