import dayjs from '../../_virtual/dayjs.min.js';
import dayjsIsBetween from '../../_virtual/isBetween.js';

dayjs.extend(dayjsIsBetween);
const daysInWeek = ['日', '月', '火', '水', '木', '金', '土'];
const minDate = new Date(1900, 0, 1);
const minDatetime = minDate.getTime();
const maxDate = new Date(9999, 11, 31);
const maxDatetime = maxDate.getTime();
function getFromDate(date) {
    const time = date.getTime();
    return isNaN(time) || time < minDatetime ? minDate : date;
}
function getToDate(date) {
    if (!date) {
        return dayjs().add(50, 'year').toDate();
    }
    const time = date.getTime();
    if (isNaN(time)) {
        return dayjs().add(50, 'year').toDate();
    }
    return time > maxDatetime ? maxDate : date;
}
function getMonthArray(date) {
    const day = dayjs(date);
    const startDay = day.date(1).day();
    const lastDate = day.add(1, 'month').date(0).date();
    const numOfWeek = Math.ceil((lastDate + startDay) / 7);
    const result = [];
    for (let weekIndex = 0; weekIndex < numOfWeek; weekIndex++) {
        // 週毎の配列を形成
        const startDateInWeek = weekIndex * 7 - startDay + 1;
        const weekNumbers = [];
        for (let dateIndex = 0; dateIndex < 7; dateIndex++) {
            // 1週の配列を形成
            const dateNum = startDateInWeek + dateIndex;
            weekNumbers[dateIndex] = dateNum > 0 && dateNum <= lastDate ? dateNum : null;
        }
        result[weekIndex] = weekNumbers;
    }
    return result;
}
function isBetween(date, from, to) {
    return dayjs(date).isBetween(from, to, 'day', '[]');
}

export { daysInWeek, getFromDate, getMonthArray, getToDate, isBetween, minDate };
//# sourceMappingURL=calendarHelper.js.map
