import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useRef, useEffect, useCallback, useMemo, useState, useId } from 'react';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../../hooks/useDecorators.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react-intl';
import '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import { UnstyledButton } from '../../Button/UnstyledButton.js';
import { Chip } from '../../Chip/Chip.js';
import '../../Icon/generateIcon.js';
import { FaTimesCircleIcon } from '../../Icon/DeprecatedIcon.js';
import { Tooltip } from '../../Tooltip/Tooltip.js';
import { VisuallyHiddenText } from '../../VisuallyHiddenText/VisuallyHiddenText.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-MultiCombobox-selectedItem shr-flex shr-items-center shr-gap-0.75 shr-leading-normal [&]:shr-rounded-em',
        itemLabel: 'smarthr-ui-MultiCombobox-selectedItemLabel',
        deleteButton: [
            'smarthr-ui-MultiCombobox-deleteButton',
            'shr-group/deleteButton',
            'shr-shrink shr-rounded-full shr-leading-[0] shr-text-black',
            'focus-visible:shr-shadow-[unset]',
        ],
        deleteButtonIcon: 'group-focus-visible/deleteButton:shr-focus-indicator group-focus-visible/deleteButton:shr-rounded-full',
    },
    variants: {
        enableEllipsis: {
            true: {
                itemLabel: 'shr-overflow-hidden shr-overflow-ellipsis shr-whitespace-nowrap',
            },
        },
        disabled: {
            true: {
                deleteButton: 'shr-cursor-not-allowed',
            },
            false: {},
        },
    },
});
function MultiSelectedItem({ item, disabled, onDelete, enableEllipsis, buttonRef, decorators, }) {
    const [needsTooltip, setNeedsTooltip] = useState(false);
    const { deletable = true } = item;
    const idPrefix = useId();
    const labelId = `${idPrefix}-item-label`;
    const destroySuffixTextId = `${idPrefix}-item-destroy-button-suffix`;
    const classNames = useMemo(() => {
        const { wrapper, itemLabel, deleteButton, deleteButtonIcon } = classNameGenerator();
        return {
            wrapper: wrapper(),
            itemLabel: itemLabel({ enableEllipsis }),
            deleteButton: deleteButton({ disabled }),
            deleteButtonIcon: deleteButtonIcon(),
        };
    }, [disabled, enableEllipsis]);
    const body = (jsxs(Chip, { disabled: disabled, className: classNames.wrapper, children: [jsx(ItemLabel, { id: labelId, className: classNames.itemLabel, setNeedsTooltip: setNeedsTooltip, children: item.label }), deletable && (jsx(DestroyButton, { labelId: labelId, suffixTextId: destroySuffixTextId, item: item, onDelete: onDelete, disabled: disabled, buttonRef: buttonRef, decorators: decorators, className: classNames.deleteButton, iconStyle: classNames.deleteButtonIcon }))] }));
    if (needsTooltip) {
        return jsx(Tooltip, { message: item.label, children: body });
    }
    return body;
}
const ItemLabel = memo(({ children, id, enableEllipsis, setNeedsTooltip, className }) => {
    const labelRef = useRef(null);
    useEffect(() => {
        if (enableEllipsis && labelRef.current) {
            const elem = labelRef.current;
            setNeedsTooltip(elem.offsetWidth < elem.scrollWidth);
        }
    }, [enableEllipsis, setNeedsTooltip]);
    return (jsx("span", { ref: labelRef, id: id, className: className, children: children }));
});
const typedMemo = memo;
const EXEC_DESTROY_KEY = /^(Enter|Backspace| )$/;
const BaseDestroyButton = ({ labelId, suffixTextId, item, onDelete, disabled, buttonRef, decorators, className, iconStyle, }) => {
    const { localize } = useIntl();
    const onClick = useCallback(() => {
        onDelete(item);
    }, [item, onDelete]);
    const onKeyDown = useCallback((e) => {
        if (EXEC_DESTROY_KEY.test(e.key)) {
            e.stopPropagation();
            // HINT: イベントの伝播が止まる関係でonClickに設定したonDeleteは実行されない
            // このタイミングで明示的に削除処理を実行する
            onClick();
        }
    }, [onClick]);
    const decoratorDefaultTexts = useMemo(() => ({
        destroyButtonIconAltSuffix: localize({
            id: 'smarthr-ui/MultiCombobox/destroyButtonIconAltSuffix',
            defaultText: 'を削除',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    return (jsxs(UnstyledButton, { ref: buttonRef, disabled: disabled, tabIndex: -1, "aria-labelledby": `${labelId} ${suffixTextId}`, onClick: onClick, onKeyDown: onKeyDown, className: className, children: [jsx(VisuallyHiddenText, { id: suffixTextId, children: decorated.destroyButtonIconAltSuffix }), jsx(FaTimesCircleIcon, { color: disabled ? 'TEXT_DISABLED' : 'inherit', className: iconStyle })] }));
};
const DestroyButton = typedMemo(BaseDestroyButton);

export { MultiSelectedItem };
//# sourceMappingURL=MultiSelectedItem.js.map
