"use client";
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import { useRef, useState, useImperativeHandle, useCallback, useMemo, useEffect } from 'react';
import innerText from '../../../_virtual/index.js';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useClick } from '../../../hooks/useClick.js';
import { useDecorators } from '../../../hooks/useDecorators.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react-intl';
import { genericsForwardRef } from '../../../libs/util.js';
import { textColor } from '../../../themes/tailwind/TailwindConfig.js';
import '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import { UnstyledButton } from '../../Button/UnstyledButton.js';
import { FaCircleXmarkIcon, FaCaretDownIcon } from '../../Icon/Icon.js';
import '../../Icon/generateIcon.js';
import { Input } from '../../Input/Input.js';
import '../../Input/CurrencyInput/CurrencyInput.js';
import '../../Input/SearchInput/SearchInput.js';
import { useListbox } from '../useListbox.js';
import { useSingleOptions } from '../useOptions.js';

const NOOP = () => undefined;
const ESCAPE_KEY_REGEX = /^Esc(ape)?$/;
const ARROW_UP_DOWN_REGEX = /^(Arrow)?(Up|Down)$/;
const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-SingleCombobox shr-inline-block',
        input: 'smarthr-ui-SingleCombobox-input shr-w-full',
        caretDownLayout: [
            'shr-relative -shr-me-0.5 shr-p-0.5',
            'before:shr-border-0',
            'before:shr-absolute before:shr-inset-x-0 before:shr-inset-y-0.25 before:shr-w-0 before:shr-border-l before:shr-border-solid before:shr-border-default before:shr-content-[""]',
        ],
        caretDownIcon: 'shr-block',
        clearButton: [
            'smarthr-ui-SingleCombobox-clearButton',
            'shr-group/clearButton',
            'shr-me-0.5',
            'focus-visible:shr-shadow-none',
        ],
        clearButtonIcon: [
            'shr-block',
            'group-focus-visible/clearButton:shr-focus-indicator group-focus-visible/clearButton:shr-rounded-full',
        ],
    },
    variants: {
        disabled: {
            true: {
                wrapper: 'shr-cursor-not-allowed',
            },
        },
        hidden: {
            true: {
                clearButton: 'shr-hidden',
            },
        },
    },
});
const ActualSingleCombobox = ({ items, selectedItem, defaultItem, name, disabled, readOnly, required, prefix, error, creatable, placeholder, autoComplete, dropdownHelpMessage, isLoading, width, dropdownWidth = 'auto', className, onChange, onChangeInput, onAdd, onSelect, onClear, onClearClick, onChangeSelected, onFocus, onBlur, onKeyPress, decorators, style, ...rest }, ref) => {
    const { localize } = useIntl();
    const outerRef = useRef(null);
    const inputRef = useRef(null);
    const clearButtonRef = useRef(null);
    const [isFocused, setIsFocused] = useState(false);
    const [isExpanded, setIsExpanded] = useState(false);
    const [inputValue, setInputValue] = useState('');
    const [isComposing, setIsComposing] = useState(false);
    const [isEditing, setIsEditing] = useState(false);
    useImperativeHandle(ref, () => inputRef.current);
    const { options } = useSingleOptions({
        items,
        selected: selectedItem,
        creatable,
        inputValue,
        isFilteringDisabled: !isEditing,
    });
    const { renderListBox, activeOption, onKeyDownListBox, listBoxId, listBoxRef } = useListbox({
        options,
        dropdownHelpMessage,
        dropdownWidth,
        onAdd,
        onSelect: useCallback((selected) => {
            onSelect?.(selected);
            onChangeSelected?.(selected);
            // HINT: Dropdown系コンポーネント内でComboboxを使うと、選択肢がportalで表現されている関係上Dropdownが閉じてしまう
            // requestAnimationFrameを追加、処理を遅延させることで正常に閉じる/閉じないの判定を行えるようにする
            requestAnimationFrame(() => {
                setIsExpanded(false);
            });
            setIsEditing(false);
        }, [onChangeSelected, onSelect]),
        isExpanded,
        isLoading,
        triggerRef: outerRef,
        decorators,
    });
    const selectDefaultItem = useMemo(() => (onSelect && defaultItem ? () => onSelect(defaultItem) : NOOP), [onSelect, defaultItem]);
    const focus = useCallback(() => {
        onFocus?.();
        setIsFocused(true);
        if (!isFocused) {
            setIsExpanded(true);
        }
    }, [onFocus, isFocused]);
    const unfocus = useCallback(() => {
        if (!isFocused)
            return;
        onBlur?.();
        setIsFocused(false);
        setIsExpanded(false);
        setIsEditing(false);
        if (!selectedItem && defaultItem) {
            setInputValue(innerText(defaultItem.label));
            selectDefaultItem();
        }
    }, [isFocused, onBlur, selectedItem, defaultItem, selectDefaultItem]);
    const onClickClear = useCallback((e) => {
        e.stopPropagation();
        let isExecutedPreventDefault = false;
        onClearClick?.({
            ...e,
            preventDefault: () => {
                e.preventDefault();
                isExecutedPreventDefault = true;
            },
        });
        if (!isExecutedPreventDefault) {
            onClear?.();
            onChangeSelected?.(null);
            inputRef.current?.focus();
            setIsFocused(true);
            setIsExpanded(true);
        }
    }, [onClearClick, onClear, onChangeSelected]);
    const onClickInput = useCallback((e) => {
        if (disabled || readOnly) {
            e.stopPropagation();
            return;
        }
        inputRef.current?.focus();
        if (!isExpanded) {
            setIsExpanded(true);
        }
    }, [disabled, readOnly, inputRef, isExpanded]);
    const actualOnChangeInput = useCallback((e) => {
        onChange?.(e);
        onChangeInput?.(e);
        if (!isEditing)
            setIsEditing(true);
        const { value } = e.currentTarget;
        setInputValue(value);
        if (value === '') {
            onClear?.();
            onChangeSelected?.(null);
        }
    }, [isEditing, onChange, onChangeInput, onClear, onChangeSelected]);
    const onCompositionStart = useCallback(() => setIsComposing(true), []);
    const onCompositionEnd = useCallback(() => setIsComposing(false), []);
    const onKeyDownInput = useCallback((e) => {
        if (isComposing) {
            return;
        }
        if (ESCAPE_KEY_REGEX.test(e.key)) {
            if (isExpanded) {
                e.stopPropagation();
                setIsExpanded(false);
            }
        }
        else if (e.key === 'Tab') {
            unfocus();
        }
        else {
            if (ARROW_UP_DOWN_REGEX.test(e.key)) {
                e.preventDefault();
            }
            inputRef.current?.focus();
            if (!isExpanded) {
                setIsExpanded(true);
            }
        }
        onKeyDownListBox(e);
    }, [isComposing, isExpanded, unfocus, onKeyDownListBox]);
    // HINT: form内にcomboboxを設置 & 検索inputにfocusした状態で
    // アイテムをキーボードで選択し、Enterを押すとinput上でEnterを押したことになるため、
    // submitイベントが発生し、formが送信される場合がある
    const handleKeyPress = useCallback((e) => {
        if (e.key === 'Enter')
            e.preventDefault();
        onKeyPress?.(e);
    }, [onKeyPress]);
    const caretIconColor = useMemo(() => {
        if (isFocused)
            return textColor.black;
        if (disabled || readOnly)
            return textColor.disabled;
        return textColor.grey;
    }, [disabled, readOnly, isFocused]);
    useClick(useMemo(() => [outerRef, listBoxRef, clearButtonRef], [outerRef, listBoxRef, clearButtonRef]), isFocused || selectedItem ? NOOP : selectDefaultItem, unfocus);
    useEffect(() => {
        setInputValue(selectedItem ? innerText(selectedItem.label) : '');
        if (isFocused && inputRef.current) {
            inputRef.current.focus();
        }
        else if (!selectedItem) {
            selectDefaultItem();
        }
    }, [isFocused, selectedItem, selectDefaultItem]);
    const wrapperStyle = useMemo(() => ({
        ...style,
        width: typeof width === 'number' ? `${width}px` : width,
    }), [style, width]);
    const notSelected = selectedItem === null;
    const classNames = useMemo(() => {
        const { wrapper, input, caretDownLayout, caretDownIcon, clearButton, clearButtonIcon } = classNameGenerator();
        return {
            wrapper: wrapper({ disabled, className }),
            input: input(),
            caretDownLayout: caretDownLayout(),
            caretDownIcon: caretDownIcon(),
            clearButton: clearButton({ hidden: notSelected || disabled || readOnly }),
            clearButtonIcon: clearButtonIcon(),
        };
    }, [notSelected, disabled, readOnly, className]);
    const decoratorDefaultTexts = useMemo(() => ({
        destroyButtonIconAlt: localize({
            id: 'smarthr-ui/SingleCombobox/destroyButtonIconAlt',
            defaultText: '削除',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    return (jsxs("div", { className: classNames.wrapper, style: wrapperStyle, ref: outerRef, children: [jsx(Input, { ...rest, ref: inputRef, type: "text", role: "combobox", name: name, value: inputValue, disabled: disabled, readOnly: readOnly, required: required, autoComplete: autoComplete ?? 'off', "aria-haspopup": "listbox", "aria-controls": listBoxId, "aria-expanded": isFocused, "aria-activedescendant": activeOption?.id, "aria-autocomplete": "list", 
                /* eslint-disable-next-line smarthr/a11y-prohibit-input-placeholder */
                placeholder: placeholder, onClick: onClickInput, onChange: actualOnChangeInput, onFocus: isFocused ? undefined : focus, onCompositionStart: onCompositionStart, onCompositionEnd: onCompositionEnd, onKeyDown: onKeyDownInput, onKeyPress: handleKeyPress, error: error, prefix: prefix, suffix: jsxs(Fragment, { children: [jsx(UnstyledButton, { onClick: onClickClear, ref: clearButtonRef, className: classNames.clearButton, children: jsx(FaCircleXmarkIcon, { color: "TEXT_BLACK", alt: decorated.destroyButtonIconAlt, className: classNames.clearButtonIcon }) }), jsx("span", { onClick: onClickInput, role: "presentation", className: classNames.caretDownLayout, children: jsx(FaCaretDownIcon, { color: caretIconColor, className: classNames.caretDownIcon }) })] }), className: classNames.input, "data-smarthr-ui-input": "true" }), !readOnly && renderListBox()] }));
};
const SingleCombobox = genericsForwardRef(ActualSingleCombobox);

export { SingleCombobox };
//# sourceMappingURL=SingleCombobox.js.map
