import { useCallback, useId, useMemo } from 'react';
import innerText from '../../_virtual/index.js';
import { areItemsEqual, convertMatchableString } from './helper.js';

const defaultIsItemSelected = (targetItem, selectedItems) => selectedItems.some((item) => areItemsEqual(item, targetItem));
const useSingleOptions = ({ selected, ...rest }) => {
    const isSelected = useCallback((item) => selected !== null && areItemsEqual(selected, item), [selected]);
    return useOptions(rest, isSelected);
};
const useMultiOptions = ({ selected, isItemSelected = defaultIsItemSelected, ...rest }) => {
    const isSelected = useCallback((item) => isItemSelected(item, selected), [selected, isItemSelected]);
    return useOptions(rest, isSelected);
};
function useOptions({ items, creatable, inputValue = '', isFilteringDisabled = false }, isSelected) {
    const newItemId = useId();
    const optionIdPrefix = useId();
    const existedOptions = useMemo(() => items.map((item, i) => ({
        id: `${optionIdPrefix}-${i}`,
        selected: isSelected(item),
        isNew: false,
        item,
    })), [isSelected, items, optionIdPrefix]);
    const addingOption = useMemo(() => creatable && inputValue && items.every((item) => item.label !== inputValue)
        ? {
            id: newItemId,
            isNew: true,
            selected: false,
            item: { label: inputValue, value: inputValue },
        }
        : null, [inputValue, items, creatable, newItemId]);
    const allOptions = useMemo(() => (addingOption ? [addingOption, ...existedOptions] : existedOptions), [existedOptions, addingOption]);
    const options = useMemo(() => {
        if (isFilteringDisabled || !inputValue) {
            return allOptions;
        }
        return allOptions.filter(({ item: { label } }) => convertMatchableString(innerText(label)).includes(convertMatchableString(inputValue)));
    }, [allOptions, inputValue, isFilteringDisabled]);
    return {
        options,
    };
}

export { useMultiOptions, useSingleOptions };
//# sourceMappingURL=useOptions.js.map
