import { jsx } from 'react/jsx-runtime';
import { useCallback, useState, useEffect, useMemo, useRef } from 'react';

const OPTION_INCREMENT_AMOUNT = 100;
const RETURN_NULL = () => null;
function usePartialRendering({ items, minLength = 0, }) {
    const limiter = useCallback((length) => Math.max(length, minLength), [minLength]);
    const [currentItemLength, setCurrentItemLength] = useState(limiter(OPTION_INCREMENT_AMOUNT));
    useEffect(() => {
        setCurrentItemLength((current) => limiter(current));
    }, [limiter]);
    // minLength も考慮した実際のアイテム数を算出
    const partialItems = useMemo(() => items.slice(0, currentItemLength), [currentItemLength, items]);
    const renderIntersection = useCallback(() => (jsx(Intersection, { onIntersect: () => {
            setCurrentItemLength((current) => limiter(current + OPTION_INCREMENT_AMOUNT));
        } })), [limiter]);
    return {
        items: partialItems,
        renderIntersection: currentItemLength >= items.length ? RETURN_NULL : renderIntersection,
    };
}
const Intersection = ({ onIntersect }) => {
    const ref = useRef(null);
    useEffect(() => {
        const target = ref.current;
        if (target === null) {
            return;
        }
        // スクロール最下部に到達する度に表示するアイテム数を増加させるための IntersectionObserver
        const observer = new IntersectionObserver(([entry]) => {
            if (entry.isIntersecting) {
                onIntersect();
            }
        });
        observer.observe(target);
        return () => observer.disconnect();
    }, [onIntersect]);
    return jsx("div", { ref: ref });
};

export { usePartialRendering };
//# sourceMappingURL=usePartialRendering.js.map
