"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import dayjs from '../../_virtual/dayjs.min.js';
import { forwardRef, useMemo, useState, useRef, useId, useImperativeHandle, useCallback, useEffect, memo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useOuterClick } from '../../hooks/useOuterClick.js';
import { textColor } from '../../themes/tailwind/TailwindConfig.js';
import { Calendar } from '../Calendar/Calendar.js';
import '../Icon/generateIcon.js';
import { FaCalendarAltIcon } from '../Icon/DeprecatedIcon.js';
import { Input } from '../Input/Input.js';
import '../Input/CurrencyInput/CurrencyInput.js';
import '../Input/SearchInput/SearchInput.js';
import { Portal } from './Portal.js';
import { parseJpnDateString } from './datePickerHelper.js';
import { useGlobalKeyDown } from './useGlobalKeyDown.js';

const DEFAULT_FROM = new Date(1900, 0, 1);
const classNameGenerator = ce({
    slots: {
        container: 'smarthr-ui-DatePicker shr-inline-block',
        inputSuffixLayout: 'shr-box-border shr-h-full shr-py-0.5',
        inputSuffixWrapper: 'shr-border-l-shorthand shr-box-border shr-flex shr-h-full shr-items-center shr-justify-center shr-ps-0.5 shr-text-base',
        inputSuffixText: 'shr-text-gray shr-me-0.5 shr-text-sm',
    },
});
const DEFAULT_DATE_TO_STRING_FORMAT = 'YYYY/MM/DD';
const DEFAULT_DATE_TO_STRING = (d) => d ? dayjs(d).format(DEFAULT_DATE_TO_STRING_FORMAT) : '';
const RETURN_NULL = () => null;
const ESCAPE_KEY_REGEX = /^Esc(ape)?$/;
/** @deprecated DatePicker は非推奨です。Input[type=date] を使ってください。 */
const DatePicker = forwardRef(({ value, name, from = DEFAULT_FROM, to, disabled, width, error, className, parseInput, formatDate, showAlternative, onChangeDate, onBlur, ...inputAttrs }, ref) => {
    const containerStyle = useMemo(() => ({
        width: typeof width === 'number' ? `${width}px` : width,
    }), [width]);
    const classNames = useMemo(() => {
        const { container, inputSuffixLayout, inputSuffixWrapper, inputSuffixText } = classNameGenerator();
        return {
            container: container({ className }),
            inputSuffixLayout: inputSuffixLayout(),
            inputSuffixWrapper: inputSuffixWrapper(),
            inputSuffixText: inputSuffixText(),
        };
    }, [className]);
    const stringToDate = useMemo(() => parseInput
        ? (str) => (str ? parseInput(str) : null)
        : (str) => (str ? parseJpnDateString(str) : null), [parseInput]);
    const dateToString = useMemo(() => formatDate || DEFAULT_DATE_TO_STRING, [formatDate]);
    const dateToAlternativeFormat = useMemo(() => (showAlternative ? (d) => (d ? showAlternative(d) : null) : RETURN_NULL), [showAlternative]);
    const [selectedDate, setSelectedDate] = useState(stringToDate(value));
    const inputRef = useRef(null);
    const inputWrapperRef = useRef(null);
    const calendarPortalRef = useRef(null);
    const [inputRect, setInputRect] = useState(null);
    const [isInputFocused, setIsInputFocused] = useState(false);
    const [isCalendarShown, setIsCalendarShown] = useState(false);
    const [alternativeFormat, setAlternativeFormat] = useState(null);
    const calenderId = useId();
    useImperativeHandle(ref, () => inputRef.current);
    const baseUpdateDate = useCallback((newDate) => {
        if (!inputRef.current ||
            newDate === selectedDate ||
            (newDate && selectedDate && newDate.getTime() === selectedDate.getTime())) {
            // Do not update date if the new date is same with the old one.
            return;
        }
        const isValid = !newDate || dayjs(newDate).isValid();
        const errors = [];
        if (!isValid) {
            errors.push('INVALID_DATE');
        }
        const nextDate = isValid ? newDate : null;
        const currentValue = dateToString(nextDate);
        inputRef.current.value = currentValue;
        setAlternativeFormat(dateToAlternativeFormat(nextDate));
        setSelectedDate(nextDate);
        return [nextDate, currentValue, errors];
    }, [selectedDate, dateToString, dateToAlternativeFormat]);
    const updateDate = useMemo(() => onChangeDate
        ? (newDate) => {
            const result = baseUpdateDate(newDate);
            if (result) {
                const [nextDate, currentValue, errors] = result;
                onChangeDate(nextDate, currentValue, { errors });
            }
        }
        : baseUpdateDate, [onChangeDate, baseUpdateDate]);
    const closeCalendar = useCallback(() => setIsCalendarShown(false), []);
    const openCalendar = useCallback(() => {
        if (inputWrapperRef.current) {
            setIsCalendarShown(true);
            setInputRect(inputWrapperRef.current.getBoundingClientRect());
        }
    }, []);
    useEffect(() => {
        if (value === undefined || !inputRef.current) {
            return;
        }
        /**
         * Do not format the given value in the following cases
         * - while input element is focused.
         * - if the given value is not date formattable.
         */
        if (!isInputFocused) {
            const newDate = stringToDate(value);
            if (newDate && dayjs(newDate).isValid()) {
                inputRef.current.value = dateToString(newDate);
                setAlternativeFormat(dateToAlternativeFormat(newDate));
                setSelectedDate(newDate);
                return;
            }
            setSelectedDate(null);
        }
        inputRef.current.value = value || '';
    }, [value, isInputFocused, dateToString, dateToAlternativeFormat, stringToDate]);
    useOuterClick(useMemo(() => [inputWrapperRef, calendarPortalRef], [inputWrapperRef, calendarPortalRef]), closeCalendar);
    const handleKeyDown = useCallback((e) => {
        if (!inputRef.current || !calendarPortalRef.current || e.key !== 'Tab') {
            return;
        }
        const calendarButtons = calendarPortalRef.current.querySelectorAll('button');
        if (calendarButtons.length === 0) {
            return;
        }
        const firstCalendarButton = calendarButtons[0];
        if (isInputFocused) {
            if (e.shiftKey) {
                // move focus from Input to previous elements of DatePicker
                closeCalendar();
                return;
            }
            // move focus from Input to Calendar
            e.preventDefault();
            firstCalendarButton.focus();
            return;
        }
        const calendarButtonAry = Array.from(calendarButtons);
        const currentFocused = calendarButtonAry.find((button) => button === e.target);
        if (e.shiftKey) {
            if (currentFocused === firstCalendarButton) {
                // move focus from Calendar to Input
                inputRef.current.focus();
                e.preventDefault();
            }
        }
        else if (currentFocused === calendarButtonAry.at(-1)) {
            // move focus from Calendar to next elements of DatePicker
            inputRef.current.focus();
            closeCalendar();
        }
    }, [isInputFocused, closeCalendar]);
    const baseHandleBlur = useCallback((e) => {
        setIsInputFocused(false);
        updateDate(e.target.value ? stringToDate(e.target.value) : null);
    }, [stringToDate, updateDate]);
    const handleBlur = useMemo(() => onBlur
        ? (e) => {
            baseHandleBlur(e);
            onBlur(e);
        }
        : baseHandleBlur, [onBlur, baseHandleBlur]);
    useGlobalKeyDown(handleKeyDown);
    const caretIconColor = useMemo(() => {
        if (isInputFocused || isCalendarShown)
            return textColor.black;
        if (disabled)
            return textColor.disabled;
        return textColor.grey;
    }, [isInputFocused, isCalendarShown, disabled]);
    const onDelegateKeyDown = useCallback((e) => {
        if (ESCAPE_KEY_REGEX.test(e.key)) {
            e.stopPropagation();
            // delay hiding calendar because calendar will be displayed when input is focused
            requestAnimationFrame(closeCalendar);
            if (inputRef.current)
                inputRef.current.focus();
        }
    }, [closeCalendar]);
    const onKeyPressInput = useCallback((e) => {
        if (e.key === 'Enter') {
            (isCalendarShown ? openCalendar : closeCalendar)();
            updateDate(stringToDate(e.currentTarget.value));
        }
    }, [isCalendarShown, updateDate, closeCalendar, openCalendar, stringToDate]);
    const onFocusInput = useCallback(() => {
        setIsInputFocused(true);
        openCalendar();
    }, [openCalendar]);
    const onSelectDateCalendar = useCallback((_, selected) => {
        updateDate(selected);
        // delay hiding calendar because calendar will be displayed when input is focused
        requestAnimationFrame(closeCalendar);
        if (inputRef.current)
            inputRef.current.focus();
    }, [updateDate, closeCalendar]);
    return (jsxs("div", { onClick: !isCalendarShown && !disabled ? openCalendar : undefined, onKeyDown: isCalendarShown ? onDelegateKeyDown : undefined, role: "presentation", className: classNames.container, style: containerStyle, children: [jsx("div", { ref: inputWrapperRef, children: jsx(Input, { ...inputAttrs, "data-smarthr-ui-input": "true", width: "100%", name: name, onChange: isCalendarShown ? closeCalendar : undefined, onKeyPress: onKeyPressInput, onFocus: onFocusInput, onBlur: handleBlur, suffix: jsx(InputSuffixIcon, { alternativeFormat: showAlternative ? alternativeFormat : null, caretIconColor: caretIconColor, classNames: classNames }), disabled: disabled, error: error, ref: inputRef, className: "smarthr-ui-DatePicker-inputContainer", "aria-expanded": isCalendarShown, "aria-controls": calenderId, "aria-haspopup": true }) }), isCalendarShown && inputRect && (jsx(Portal, { inputRect: inputRect, ref: calendarPortalRef, children: jsx(Calendar, { id: calenderId, value: selectedDate || undefined, from: from, to: to, onSelectDate: onSelectDateCalendar }) }))] }));
});
const InputSuffixIcon = memo(({ classNames, alternativeFormat, caretIconColor }) => (jsx("span", { className: classNames.inputSuffixLayout, children: jsxs("span", { className: classNames.inputSuffixWrapper, children: [alternativeFormat && jsx("span", { className: classNames.inputSuffixText, children: alternativeFormat }), jsx(FaCalendarAltIcon, { color: caretIconColor })] }) })));

export { DEFAULT_FROM, DatePicker };
//# sourceMappingURL=DatePicker.js.map
