"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { memo, useCallback, useMemo } from 'react';
import { useDecorators } from '../../../hooks/useDecorators.js';
import { useResponseStatus } from '../../../hooks/useResponseStatus.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react-intl';
import { Button } from '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import '../../Button/UnstyledButton.js';
import { Stack } from '../../Layout/Stack/Stack.js';
import { Cluster } from '../../Layout/Cluster/Cluster.js';
import '../../Layout/Reel/Reel.js';
import '../../Layout/Sidebar/Sidebar.js';
import '../../Layout/Center/Center.js';
import { Section } from '../../SectioningContent/SectioningContent.js';
import '../../SectioningContent/levelContext.js';
import { DialogBody } from '../DialogBody.js';
import { DialogContentResponseStatusMessage } from '../DialogContentResponseStatusMessage.js';
import { DialogHeader } from '../DialogHeader.js';
import { dialogContentInner } from '../dialogInnerStyle.js';

const ACTION_AREA_CLUSTER_GAP = { row: 0.5, column: 1 };
const ActionDialogContentInner = ({ children, title, titleId, subtitle, titleTag, contentBgColor, contentPadding, actionText, actionTheme, onClickAction, onClickClose, responseStatus, actionDisabled, closeDisabled, subActionArea, decorators, }) => {
    const calcedResponseStatus = useResponseStatus(responseStatus);
    const styles = useMemo(() => {
        const { wrapper, actionArea, buttonArea, message } = dialogContentInner();
        return {
            wrapper: wrapper(),
            actionArea: actionArea(),
            buttonArea: buttonArea(),
            message: message(),
        };
    }, []);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    jsxs(Section, { className: styles.wrapper, children: [jsx(DialogHeader, { title: title, subtitle: subtitle, titleTag: titleTag, titleId: titleId }), jsx(DialogBody, { contentPadding: contentPadding, contentBgColor: contentBgColor, children: children }), jsxs(Stack, { gap: 0.5, className: styles.actionArea, children: [jsxs(Cluster, { justify: "space-between", children: [subActionArea, jsx(ActionAreaCluster, { onClickClose: onClickClose, onClickAction: onClickAction, closeDisabled: closeDisabled, actionDisabled: actionDisabled, loading: calcedResponseStatus.isProcessing, actionTheme: actionTheme, decorators: decorators, actionText: actionText, className: styles.buttonArea })] }), jsx(DialogContentResponseStatusMessage, { responseStatus: calcedResponseStatus, className: styles.message })] })] }));
};
const ActionAreaCluster = memo(({ onClickClose, onClickAction, closeDisabled, actionDisabled, loading, actionTheme, decorators, actionText, className, }) => {
    const handleClickAction = useCallback(() => {
        onClickAction(onClickClose);
    }, [onClickAction, onClickClose]);
    return (jsxs(Cluster, { gap: ACTION_AREA_CLUSTER_GAP, className: className, children: [jsx(CloseButton, { onClick: onClickClose, disabled: closeDisabled || loading, decorators: decorators }), jsx(ActionButton, { variant: actionTheme, disabled: actionDisabled, loading: loading, onClick: handleClickAction, children: actionText })] }));
});
const ActionButton = memo(({ variant = 'primary', disabled, loading, onClick, children }) => (jsx(Button, { type: "submit", variant: variant, disabled: disabled, loading: loading, onClick: onClick, className: "smarthr-ui-Dialog-actionButton", children: children })));
const CloseButton = memo(({ onClick, disabled, decorators }) => {
    const { localize } = useIntl();
    const decoratorDefaultTexts = useMemo(() => ({
        closeButtonLabel: localize({
            id: 'smarthr-ui/ActionDialog/closeButtonLabel',
            defaultText: 'キャンセル',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    return (jsx(Button, { onClick: onClick, disabled: disabled, className: "smarthr-ui-Dialog-closeButton", children: decorated.closeButtonLabel }));
});

export { ActionDialogContentInner };
//# sourceMappingURL=ActionDialogContentInner.js.map
