import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import { tabbable } from '../../libs/tabbable.js';

const FocusTrap = forwardRef(({ firstFocusTarget, children }, ref) => {
    const innerRef = useRef(null);
    const dummyFocusRef = useRef(null);
    useImperativeHandle(ref, () => ({
        focus: () => {
            if (firstFocusTarget?.current) {
                firstFocusTarget.current.focus();
            }
            else {
                dummyFocusRef.current?.focus();
            }
        },
    }));
    useEffect(() => {
        const handleKeyDown = (e) => {
            if (e.key !== 'Tab' || innerRef.current === null) {
                return;
            }
            const tabbables = tabbable(innerRef.current).filter((elm) => elm.tabIndex >= 0);
            if (tabbables.length === 0) {
                return;
            }
            const firstTabbable = tabbables[0];
            const lastTabbable = tabbables[tabbables.length - 1];
            const currentFocused = tabbables.find((elm) => elm === e.target);
            if (e.shiftKey) {
                if (currentFocused === firstTabbable || document.activeElement === dummyFocusRef.current) {
                    e.preventDefault();
                    lastTabbable.focus();
                }
            }
            else if (currentFocused === lastTabbable) {
                e.preventDefault();
                firstTabbable.focus();
            }
        };
        window.addEventListener('keydown', handleKeyDown);
        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, []);
    useEffect(() => {
        const triggerElement = document.activeElement;
        if (firstFocusTarget?.current) {
            firstFocusTarget.current.focus();
        }
        else {
            dummyFocusRef.current?.focus();
        }
        return () => {
            // フォーカストラップ終了時にトリガにフォーカスを戻す
            if (triggerElement instanceof HTMLElement) {
                triggerElement.focus();
            }
        };
    }, [firstFocusTarget]);
    return (jsxs("div", { ref: innerRef, children: [jsx("div", { ref: dummyFocusRef, tabIndex: -1 }), children] }));
});

export { FocusTrap };
//# sourceMappingURL=FocusTrap.js.map
