import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { useDecorators } from '../../../hooks/useDecorators.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react-intl';
import { Button } from '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import '../../Button/UnstyledButton.js';
import '../../Layout/Stack/Stack.js';
import { Cluster } from '../../Layout/Cluster/Cluster.js';
import '../../Layout/Reel/Reel.js';
import '../../Layout/Sidebar/Sidebar.js';
import '../../Layout/Center/Center.js';
import { Section } from '../../SectioningContent/SectioningContent.js';
import '../../SectioningContent/levelContext.js';
import { DialogBody } from '../DialogBody.js';
import { DialogHeader } from '../DialogHeader.js';
import { dialogContentInner } from '../dialogInnerStyle.js';

const MessageDialogContentInner = ({ title, subtitle, titleTag, titleId, contentBgColor, contentPadding, description, onClickClose, decorators, }) => {
    const styles = useMemo(() => {
        const { wrapper, actionArea } = dialogContentInner();
        return {
            wrapper: wrapper(),
            actionArea: actionArea(),
        };
    }, []);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    jsxs(Section, { className: styles.wrapper, children: [jsx(DialogHeader, { title: title, subtitle: subtitle, titleTag: titleTag, titleId: titleId }), jsx(DialogBody, { contentPadding: contentPadding, contentBgColor: contentBgColor, children: description }), jsx(FooterCluster, { onClickClose: onClickClose, decorators: decorators, className: styles.actionArea })] }));
};
const FooterCluster = memo(({ onClickClose, decorators, className }) => {
    const { localize } = useIntl();
    const decoratorDefaultTexts = useMemo(() => ({
        closeButtonLabel: localize({
            id: 'smarthr-ui/MessageDialog/closeButtonLabel',
            defaultText: '閉じる',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    return (jsx(Cluster, { as: "footer", justify: "flex-end", className: className, children: jsx(Button, { onClick: onClickClose, className: "smarthr-ui-Dialog-closeButton", children: decorated.closeButtonLabel }) }));
});

export { MessageDialogContentInner };
//# sourceMappingURL=MessageDialogContentInner.js.map
