import { type FC, type MouseEvent, type PropsWithChildren, type ReactNode, type RefObject } from 'react';
import { type VariantProps } from 'tailwind-variants';
import { type BaseElementProps } from '../../Base';
import { type Props as DialogBodyProps } from '../DialogBody';
import type { DecoratorsType } from '../../../hooks/useDecorators';
type Props = PropsWithChildren<{
    /**
     * ダイアログのタイトルの内容
     */
    title: ReactNode;
    /**
     * ダイアログのフッタ部分の内容
     */
    footer?: ReactNode;
    /**
     * ダイアログが開かれているかどうかの真偽値
     */
    isOpen: boolean;
    /**
     * 閉じるボタンを押下したときのハンドラ
     */
    onClickClose?: (e: MouseEvent<HTMLButtonElement>) => void;
    /**
     * ダイアログが開いている状態で Escape キーを押下したときのハンドラ
     */
    onPressEscape?: () => void;
    /**
     * ダイアログの幅
     */
    width?: string | number;
    /**
     * ダイアログの高さ
     */
    height?: string | number;
    /**
     * ダイアログを開いたときの初期 top 位置
     */
    top?: string | number;
    /**
     * ダイアログを開いたときの初期 left 位置
     */
    left?: string | number;
    /**
     * ダイアログを開いたときの初期 right 位置
     */
    right?: string | number;
    /**
     * ダイアログを開いたときの初期 bottom 位置
     */
    bottom?: string | number;
    /**
     * ポータルの container となる DOM 要素を追加する親要素
     */
    portalParent?: HTMLElement | RefObject<HTMLElement>;
    /** コンポーネント内の文言を変更するための関数を設定 */
    decorators?: DecoratorsType<'closeButtonIconAlt'> & {
        dialogHandlerAriaLabel?: (txt: string) => string;
        dialogHandlerAriaValuetext?: (txt: string, data: DOMRect | undefined) => string;
    };
}> & DialogBodyProps;
declare const classNameGenerator: import("tailwind-variants").TVReturnType<{
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}, {
    overlap: string;
    wrapper: string;
    headerEl: string;
    dialogHandler: string[];
    titleEl: string[];
    closeButtonLayout: string[];
    footerEl: string;
}, undefined, import("tailwind-variants/dist/config.js").TVConfig<{
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}, {
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}>, {
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}, {
    overlap: string;
    wrapper: string;
    headerEl: string;
    dialogHandler: string[];
    titleEl: string[];
    closeButtonLayout: string[];
    footerEl: string;
}, import("tailwind-variants").TVReturnType<{
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}, {
    overlap: string;
    wrapper: string;
    headerEl: string;
    dialogHandler: string[];
    titleEl: string[];
    closeButtonLayout: string[];
    footerEl: string;
}, undefined, import("tailwind-variants/dist/config.js").TVConfig<{
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}, {
    resizable: {
        true: {
            wrapper: string;
        };
        false: {};
    };
}>, unknown, unknown, undefined>>;
export declare const ModelessDialog: FC<Props & BaseElementProps & VariantProps<typeof classNameGenerator>>;
export {};
