"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useId, useRef, useMemo, useState, useCallback, useEffect } from 'react';
import Draggable from '../../../_virtual/cjs.js';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useHandleEscape } from '../../../hooks/useHandleEscape.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react-intl';
import { Base } from '../../Base/Base.js';
import '../../Base/BaseColumn/BaseColumn.js';
import { Button } from '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import '../../Button/UnstyledButton.js';
import { Heading } from '../../Heading/Heading.js';
import { FaGripIcon, FaXmarkIcon } from '../../Icon/Icon.js';
import '../../Icon/generateIcon.js';
import { DialogBody } from '../DialogBody.js';
import { DialogOverlap } from '../DialogOverlap.js';
import { useDialogPortal } from '../useDialogPortal.js';

const classNameGenerator = ce({
    slots: {
        overlap: 'shr-inset-[unset]',
        wrapper: 'smarthr-ui-ModelessDialog shr-fixed shr-flex shr-flex-col',
        headerEl: 'smarthr-ui-ModelessDialog-header shr-border-b-shorthand shr-relative shr-flex shr-cursor-move shr-items-center shr-rounded-tl-l shr-rounded-tr-l shr-pe-1 shr-ps-1.5 hover:shr-bg-white-darken',
        dialogHandler: [
            'smarthr-ui-ModelessDialog-handle shr-absolute shr-inset-x-0 shr-bottom-0 shr-top-[2px] shr-m-auto shr-flex shr-justify-center shr-rounded-tl-s shr-rounded-tr-s shr-text-grey shr-transition-colors shr-duration-100 shr-ease-in-out',
            'focus-visible:shr-bg-white-darken focus-visible:shr-shadow-outline focus-visible:shr-outline-none',
        ],
        titleEl: [
            'shr-my-1 shr-me-1',
            /* DialogHandlerの上に出すためにスタッキングコンテキストを生成 */
            '[.smarthr-ui-ModelessDialog-handle:focus-visible_+_&]:shr-relative',
        ],
        closeButtonLayout: [
            'shr-relative' /* DialogHandlerの上に出すためにスタッキングコンテキストを生成 */,
            'shr-ml-auto shr-shrink-0',
        ],
        footerEl: 'smarthr-ui-ModelessDialog-footer shr-border-t-shorthand',
    },
    variants: {
        resizable: {
            true: {
                wrapper: 'shr-resize shr-overflow-auto',
            },
            false: {},
        },
    },
});
const ModelessDialog = ({ title, children, contentBgColor, contentPadding, footer, isOpen, onPressEscape, resizable = false, width, height, top, left, right, bottom, portalParent, className, decorators, id, onClickClose, ...props }) => {
    const labelId = useId();
    const lastFocusElementRef = useRef(null);
    const { createPortal } = useDialogPortal(portalParent, id);
    const { localize } = useIntl();
    const classNames = useMemo(() => {
        const { overlap, wrapper, headerEl, titleEl, dialogHandler, closeButtonLayout, footerEl } = classNameGenerator();
        return {
            overlap: overlap({ className }),
            wrapper: wrapper({ resizable }),
            header: headerEl(),
            title: titleEl(),
            dialogHandler: dialogHandler(),
            closeButtonLayout: closeButtonLayout(),
            footer: footerEl(),
        };
    }, [className, resizable]);
    const wrapperRef = useRef(null);
    const focusTargetRef = useRef(null);
    const [wrapperPosition, setWrapperPosition] = useState(undefined);
    const [centering, setCentering] = useState({});
    const [position, setPosition] = useState({
        x: 0,
        y: 0,
    });
    const [draggableBounds, setDraggableBounds] = useState();
    const decoratorDefaultTexts = useMemo(() => ({
        closeButtonIconAlt: localize({
            id: 'smarthr-ui/ModelessDialog/closeButtonIconAlt',
            defaultText: '閉じる',
        }),
        dialogHandlerAriaLabel: localize({
            id: 'smarthr-ui/ModelessDialog/dialogHandlerAriaLabel',
            defaultText: 'ダイアログの位置',
        }),
        dialogHandlerAriaValuetext: wrapperPosition
            ? localize({
                id: 'smarthr-ui/ModelessDialog/dialogHandlerAriaValuetext',
                defaultText: '上から{top}px、左から{left}px',
            }, {
                top: Math.trunc(wrapperPosition.top).toString(),
                left: Math.trunc(wrapperPosition.left).toString(),
            })
            : '',
    }), [localize, wrapperPosition]);
    const decorated = useMemo(() => {
        if (!decorators) {
            return {
                dialogHandlerAriaLabel: decoratorDefaultTexts.dialogHandlerAriaLabel,
                closeButtonIconAlt: decoratorDefaultTexts.closeButtonIconAlt,
                dialogHandlerAriaValuetext: decoratorDefaultTexts.dialogHandlerAriaValuetext,
            };
        }
        return {
            dialogHandlerAriaLabel: decorators.dialogHandlerAriaLabel?.(decoratorDefaultTexts.dialogHandlerAriaLabel) ||
                decoratorDefaultTexts.dialogHandlerAriaLabel,
            closeButtonIconAlt: decorators.closeButtonIconAlt?.(decoratorDefaultTexts.closeButtonIconAlt) ||
                decoratorDefaultTexts.closeButtonIconAlt,
            dialogHandlerAriaValuetext: decorators.dialogHandlerAriaValuetext?.(decoratorDefaultTexts.dialogHandlerAriaValuetext, wrapperPosition),
        };
    }, [decorators, decoratorDefaultTexts, wrapperPosition]);
    const positionStyle = useMemo(() => ({
        top: centering.top ?? top,
        left: centering.left ?? left,
        right,
        bottom,
        width,
        height,
    }), [centering, top, left, right, bottom, width, height]);
    const handleArrowKey = useCallback((e) => {
        if (!isOpen || document.activeElement !== e.currentTarget) {
            return;
        }
        const movingDistance = 20;
        switch (e.key) {
            case 'ArrowUp':
                setPosition((prev) => ({
                    x: prev.x,
                    y: prev.y - movingDistance,
                }));
                e.preventDefault();
                break;
            case 'ArrowDown':
                setPosition((prev) => ({
                    x: prev.x,
                    y: prev.y + movingDistance,
                }));
                e.preventDefault();
                break;
            case 'ArrowLeft':
                setPosition((prev) => ({
                    x: prev.x - movingDistance,
                    y: prev.y,
                }));
                e.preventDefault();
                break;
            case 'ArrowRight':
                setPosition((prev) => ({
                    x: prev.x + movingDistance,
                    y: prev.y,
                }));
                e.preventDefault();
                break;
        }
    }, [isOpen]);
    useEffect(() => {
        if (wrapperRef.current instanceof Element) {
            setWrapperPosition(wrapperRef.current.getBoundingClientRect());
        }
    }, [position]);
    useEffect(() => {
        // 中央寄せの座標計算を行う
        if (!wrapperRef.current || !isOpen) {
            return;
        }
        const isXCenter = left === undefined && right === undefined;
        const isYCenter = top === undefined && bottom === undefined;
        if (isXCenter || isYCenter) {
            const rect = wrapperRef.current.getBoundingClientRect();
            setCentering({
                top: isYCenter ? window.innerHeight / 2 - rect.height / 2 : undefined,
                left: isXCenter ? window.innerWidth / 2 - rect.width / 2 : undefined,
            });
        }
    }, [bottom, isOpen, left, right, top]);
    useEffect(() => {
        if (!isOpen)
            return;
        if (centering.top) {
            setDraggableBounds({ top: centering.top * -1 });
            return;
        }
        if (wrapperRef.current) {
            const rect = wrapperRef.current.getBoundingClientRect();
            setDraggableBounds({ top: rect.top * -1 });
        }
    }, [isOpen, centering.top]);
    useEffect(() => {
        if (isOpen) {
            setPosition({ x: 0, y: 0 });
            focusTargetRef.current?.focus();
        }
    }, [isOpen]);
    const actualOnClickClose = useCallback((e) => {
        lastFocusElementRef.current?.focus();
        onClickClose?.(e);
    }, [onClickClose]);
    const actualOnPressEscape = useMemo(() => onPressEscape
        ? () => {
            lastFocusElementRef.current?.focus();
            onPressEscape();
        }
        : undefined, [onPressEscape]);
    useHandleEscape(useMemo(() => (actualOnPressEscape && isOpen ? actualOnPressEscape : undefined), [isOpen, actualOnPressEscape]));
    useEffect(() => {
        const focusHandler = (e) => {
            // e.target(現在フォーカスがあたっている要素)がModeless dialog外の要素であれば、lastFocusElementRefに代入する
            if (e.target instanceof HTMLElement && !wrapperRef?.current?.contains(e.target)) {
                lastFocusElementRef.current = e.target;
            }
        };
        document.addEventListener('focus', focusHandler, true);
        return () => document.removeEventListener('focus', focusHandler, true);
    }, []);
    const onDragStart = useCallback((_, data) => setPosition(data), []);
    const onDrag = useCallback((_, data) => {
        setPosition((prev) => ({
            x: prev.x + data.deltaX,
            y: prev.y + data.deltaY,
        }));
    }, []);
    return createPortal(jsx(DialogOverlap, { isOpen: isOpen, className: classNames.overlap, as: "section", children: jsx(Draggable, { handle: ".smarthr-ui-ModelessDialog-handle", onStart: onDragStart, onDrag: onDrag, position: position, bounds: draggableBounds, nodeRef: wrapperRef, children: jsxs(Base, { ...props, ref: wrapperRef, role: "dialog", "aria-labelledby": labelId, radius: "m", layer: 3, overflow: "auto", className: classNames.wrapper, style: positionStyle, children: [jsx("div", { tabIndex: -1, ref: focusTargetRef }), jsxs("div", { className: classNames.header, children: [jsx(Handler, { "aria-label": decorated.dialogHandlerAriaLabel, "aria-valuetext": decorated.dialogHandlerAriaValuetext, onArrowKeyDown: handleArrowKey, className: classNames.dialogHandler }), jsx("div", { id: labelId, className: classNames.title, children: jsx(Heading, { children: title }) }), jsx(CloseButton, { onClick: actualOnClickClose, className: classNames.closeButtonLayout, iconAlt: decorated.closeButtonIconAlt })] }), jsx(DialogBody, { contentBgColor: contentBgColor, contentPadding: contentPadding, className: "smarthr-ui-ModelessDialog-content shr-overscroll-contain", children: children }), footer && jsx("div", { className: classNames.footer, children: footer })] }) }) }));
};
const Handler = memo(({ onArrowKeyDown, ...rest }) => (
// eslint-disable-next-line jsx-a11y/role-has-required-aria-props
jsx("div", { ...rest, tabIndex: 0, role: "slider", onKeyDown: onArrowKeyDown, children: jsx(FaGripIcon, {}) })));
const CloseButton = memo(({ onClick, iconAlt, className }) => (jsx("div", { className: className, children: jsx(Button, { type: "button", size: "s", onClick: onClick, className: "smarthr-ui-ModelessDialog-closeButton", children: jsx(FaXmarkIcon, { alt: iconAlt }) }) })));

export { ModelessDialog };
//# sourceMappingURL=ModelessDialog.js.map
