"use client";
import { useCallback, useMemo, cloneElement } from 'react';
import { TRIGGER_EVENT } from '../useRemoteTrigger.js';

const onClickRemoteDialogTrigger = (ariaControls) => {
    document.dispatchEvent(new CustomEvent(TRIGGER_EVENT, {
        detail: { id: ariaControls },
    }));
};
const RemoteDialogTrigger = ({ targetId, children, onClick, ...rest }) => {
    const actualOnClick = useCallback((e) => {
        // HINT: onClick内で非同期処理される場合、e.currentTargetがnullになってしまう可能性があるため
        // 先にariaControlsを取得しておく
        const ariaControls = e.currentTarget.getAttribute('aria-controls');
        if (onClick) {
            return onClick(() => {
                onClickRemoteDialogTrigger(ariaControls);
            });
        }
        onClickRemoteDialogTrigger(ariaControls);
    }, [onClick]);
    const actualTrigger = useMemo(() => cloneElement(children, {
        onClick: actualOnClick,
        'aria-haspopup': 'dialog',
        'aria-controls': targetId,
        ...rest,
    }), [children, actualOnClick, targetId, rest]);
    return actualTrigger;
};

export { RemoteDialogTrigger };
//# sourceMappingURL=RemoteDialogTrigger.js.map
