"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { useContext, useMemo, useCallback } from 'react';
import { useDecorators } from '../../../hooks/useDecorators.js';
import { useResponseStatus } from '../../../hooks/useResponseStatus.js';
import { Button } from '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import '../../Button/UnstyledButton.js';
import { Stack } from '../../Layout/Stack/Stack.js';
import { Cluster } from '../../Layout/Cluster/Cluster.js';
import '../../Layout/Reel/Reel.js';
import '../../Layout/Sidebar/Sidebar.js';
import '../../Layout/Center/Center.js';
import { Section } from '../../SectioningContent/SectioningContent.js';
import '../../SectioningContent/levelContext.js';
import { DialogBody } from '../DialogBody.js';
import { DialogContentResponseStatusMessage } from '../DialogContentResponseStatusMessage.js';
import { DialogHeader } from '../DialogHeader.js';
import { dialogContentInner } from '../dialogInnerStyle.js';
import { StepFormDialogContext } from './StepFormDialogProvider.js';

const DECORATOR_DEFAULT_TEXTS = {
    closeButtonLabel: 'キャンセル',
    nextButtonLabel: '次へ',
    backButtonLabel: '戻る',
};
const BUTTON_COLUMN_GAP = {
    row: 0.5,
    column: 1,
};
const StepFormDialogContentInner = ({ children, title, titleId, subtitle, titleTag, contentBgColor, contentPadding, submitLabel, actionTheme = 'primary', stepLength, firstStep, onSubmit, onClickClose, responseStatus, actionDisabled, closeDisabled, decorators, onClickBack, }) => {
    const { currentStep, stepQueue, setCurrentStep, scrollerRef } = useContext(StepFormDialogContext);
    const activeStep = useMemo(() => currentStep?.stepNumber ?? 1, [currentStep]);
    const handleCloseAction = useCallback(() => {
        onClickClose();
        setTimeout(() => {
            // HINT: ダイアログが閉じるtransitionが完了してから初期化をしている
            stepQueue.current = [];
            setCurrentStep(firstStep);
        }, 300);
    }, [firstStep, stepQueue, setCurrentStep, onClickClose]);
    const changeCurrentStep = useCallback((step) => {
        setCurrentStep(step);
        // HINT: stepが切り替わるごとにbodyのscroll位置を先頭に戻す処理
        if (scrollerRef.current) {
            scrollerRef.current.scroll(0, 0);
        }
    }, [setCurrentStep, scrollerRef]);
    const handleSubmitAction = useCallback((e) => {
        e.preventDefault();
        // HINT: React Potals などで擬似的にformがネストしている場合など、stopPropagationを実行しないと
        // 親formが意図せずsubmitされてしまう場合がある
        e.stopPropagation();
        const next = onSubmit(handleCloseAction, e, currentStep);
        if (next) {
            stepQueue.current.push(currentStep);
            changeCurrentStep(next);
        }
    }, [currentStep, stepQueue, onSubmit, handleCloseAction, changeCurrentStep]);
    const handleBackAction = useCallback(() => {
        onClickBack?.();
        changeCurrentStep(stepQueue.current.pop() ?? firstStep);
    }, [firstStep, stepQueue, onClickBack, changeCurrentStep]);
    const classNames = useMemo(() => {
        const { wrapper, actionArea, buttonArea, message } = dialogContentInner();
        return {
            wrapper: wrapper(),
            actionArea: actionArea(),
            buttonArea: buttonArea(),
            message: message(),
        };
    }, []);
    const decorated = useDecorators(DECORATOR_DEFAULT_TEXTS, decorators);
    const actionText = activeStep === stepLength ? submitLabel : decorated.nextButtonLabel;
    const stepText = `（${activeStep}/${stepLength}）`;
    const calcedResponseStatus = useResponseStatus(responseStatus);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content, smarthr/a11y-prohibit-sectioning-content-in-form
    jsx(Section, { children: jsx("form", { onSubmit: handleSubmitAction, children: jsxs("div", { className: classNames.wrapper, children: [jsx(DialogHeader, { title: subtitle ? title : `${title}${stepText}`, subtitle: subtitle ? `${subtitle}${stepText}` : undefined, titleTag: titleTag, titleId: titleId }), jsx(DialogBody, { contentPadding: contentPadding, contentBgColor: contentBgColor, ref: scrollerRef, children: children }), jsxs(Stack, { gap: 0.5, className: classNames.actionArea, children: [jsxs(Cluster, { justify: "space-between", gap: { row: 0.5, column: 2 }, children: [activeStep > 1 && (jsx(Button, { onClick: handleBackAction, disabled: calcedResponseStatus.isProcessing, className: "smarthr-ui-Dialog-backButton", children: decorated.backButtonLabel })), jsxs(Cluster, { gap: BUTTON_COLUMN_GAP, className: classNames.buttonArea, children: [jsx(Button, { onClick: handleCloseAction, disabled: closeDisabled || calcedResponseStatus.isProcessing, className: "smarthr-ui-Dialog-closeButton", children: decorated.closeButtonLabel }), jsx(Button, { type: "submit", variant: actionTheme, disabled: actionDisabled, loading: calcedResponseStatus.isProcessing, className: "smarthr-ui-Dialog-actionButton", children: actionText })] })] }), jsx(DialogContentResponseStatusMessage, { responseStatus: calcedResponseStatus, className: classNames.message })] })] }) }) }));
};

export { StepFormDialogContentInner };
//# sourceMappingURL=StepFormDialogContentInner.js.map
