import { useRef, useEffect } from 'react';

const useBodyScrollLock = (isOpen) => {
    const paddingRightRef = useRef(null);
    useEffect(() => {
        if (!isOpen)
            return;
        if (paddingRightRef.current === null) {
            const scrollBarWidth = window.innerWidth - document.body.clientWidth;
            const originalPaddingRight = getComputedStyle(document.body).getPropertyValue('padding-right');
            paddingRightRef.current = `${scrollBarWidth + parseInt(originalPaddingRight, 10)}px`;
        }
        document.body.style.paddingInlineEnd = paddingRightRef.current;
        document.body.style.overflow = 'hidden';
        return () => {
            document.body.style.paddingInlineEnd = '';
            document.body.style.overflow = '';
        };
    }, [isOpen]);
};

export { useBodyScrollLock };
//# sourceMappingURL=useBodyScrollLock.js.map
