import { useState, useRef, useCallback, useEffect } from 'react';

const TRIGGER_EVENT = 'smarthr-ui:remote-dialog-trigger-dispatch';
function useRemoteTrigger({ onClickClose: orgOnClickClose, onPressEscape: orgOnPressEscape, onToggle, onOpen, onClose, id, }) {
    const [isOpen, setIsOpen] = useState(false);
    const togglerRef = useRef({
        onToggle,
        onOpen,
        onClose,
    });
    const onClickClose = useCallback(() => {
        if (orgOnClickClose) {
            return orgOnClickClose(() => {
                setIsOpen(false);
            });
        }
        setIsOpen(false);
    }, [orgOnClickClose]);
    const onPressEscape = useCallback(() => {
        if (orgOnPressEscape) {
            return orgOnPressEscape(() => {
                setIsOpen(false);
            });
        }
        setIsOpen(false);
    }, [orgOnPressEscape]);
    useEffect(() => {
        const handler = ((e) => {
            if (id === e.detail.id) {
                setIsOpen(true);
            }
        });
        document.addEventListener(TRIGGER_EVENT, handler);
        return () => {
            document.removeEventListener(TRIGGER_EVENT, handler);
        };
    }, [id]);
    useEffect(() => {
        togglerRef.current.onToggle = onToggle;
        togglerRef.current.onOpen = onOpen;
        togglerRef.current.onClose = onClose;
    }, [onToggle, onOpen, onClose]);
    useEffect(() => {
        togglerRef.current.onToggle?.(isOpen);
        if (isOpen) {
            togglerRef.current.onOpen?.();
        }
        else {
            togglerRef.current.onClose?.();
        }
    }, [isOpen]);
    return {
        isOpen,
        onClickClose,
        onPressEscape,
    };
}

export { TRIGGER_EVENT, useRemoteTrigger };
//# sourceMappingURL=useRemoteTrigger.js.map
