"use client";
import { jsx } from 'react/jsx-runtime';
import { useState, useCallback, useMemo, cloneElement, useEffect } from 'react';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';

const TRIGGER_EVENT = 'smarthr-ui:disclosure-trigger-dispatch';
const CONTENT_TOGGLE_EVENT = 'smarthr-ui:disclosure-content-toggle-dispatch';
const toggleEffectListener = (event_key, callback) => {
    document.addEventListener(event_key, callback);
    return () => {
        document.removeEventListener(event_key, callback);
    };
};
const DisclosureTrigger = ({ targetId, children, onClick, ...rest }) => {
    const [expanded, setExpanded] = useState(false);
    const actualOnClick = useCallback((e) => {
        const toggleExpanded = () => {
            setExpanded((current) => !current);
        };
        if (onClick) {
            return onClick(toggleExpanded, e);
        }
        toggleExpanded();
    }, [onClick]);
    const actualTrigger = useMemo(() => {
        const actualChildren = children instanceof Function ? children({ expanded }) : children;
        return cloneElement(actualChildren, {
            onClick: actualOnClick,
            'aria-expanded': expanded.toString(),
            'aria-controls': targetId,
            ...rest,
        });
    }, [expanded, children, actualOnClick, targetId, rest]);
    useEffect(() => toggleEffectListener(CONTENT_TOGGLE_EVENT, (e) => {
        if (targetId === e.detail.id) {
            setExpanded(e.detail.expanded);
        }
    }), [targetId]);
    useEffect(() => {
        // HINT: 基本的にtriggerはcontentより先にレンダリングされる
        // そのため、contentがレンダリングされたあとになることを期待して
        // requestAnimationFrameでイベント発火を遅延させる
        requestAnimationFrame(() => {
            document.dispatchEvent(new CustomEvent(TRIGGER_EVENT, {
                detail: { id: targetId, expanded },
            }));
        });
    }, [expanded, targetId]);
    return actualTrigger;
};
const DisclosureContent = ({ id, isOpen, visuallyHidden, children, ...rest }) => {
    const [expanded, setExpanded] = useState(isOpen || false);
    useEffect(() => {
        document.dispatchEvent(new CustomEvent(CONTENT_TOGGLE_EVENT, {
            detail: { id, expanded: isOpen || false },
        }));
    }, [isOpen, id]);
    useEffect(() => toggleEffectListener(TRIGGER_EVENT, (e) => {
        if (id === e.detail.id) {
            setExpanded(e.detail.expanded);
        }
    }), [id]);
    if (expanded) {
        return (jsx("div", { ...rest, id: id, children: children }));
    }
    if (visuallyHidden) {
        return (jsx(VisuallyHiddenText, { ...rest, id: id, as: "div", children: children }));
    }
    return null;
};

export { DisclosureContent, DisclosureTrigger };
//# sourceMappingURL=Disclosure.js.map
