"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useState, useMemo, useImperativeHandle, useCallback, memo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../hooks/useDecorators.js';
import '../../intl/IntlProvider.js';
import { useIntl } from '../../intl/useIntl.js';
import 'react-intl';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { FaFolderOpenIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';

const dropZone = ce({
    slots: {
        wrapper: [
            'smarthr-ui-DropZone',
            'shr-border-shorthand shr-flex shr-flex-col shr-items-center shr-justify-center shr-bg-column shr-p-2.5',
        ],
        input: 'shr-hidden',
    },
    variants: {
        filesDraggedOver: {
            true: {
                wrapper: 'shr-border-main',
            },
            false: {
                wrapper: 'shr-border-dashed',
            },
        },
    },
});
const overrideEventDefault = (e) => {
    e.preventDefault();
    e.stopPropagation();
};
const DropZone = forwardRef(({ children, onSelectFiles, multiple = true, decorators, ...props }, ref) => {
    const fileRef = useRef(null);
    const [filesDraggedOver, setFilesDraggedOver] = useState(false);
    const { wrapper, input } = useMemo(() => dropZone({ filesDraggedOver }), [filesDraggedOver]);
    useImperativeHandle(ref, () => fileRef.current);
    const onDrop = useCallback((e) => {
        overrideEventDefault(e);
        setFilesDraggedOver(false);
        onSelectFiles(e, e.dataTransfer.files);
        if (fileRef.current) {
            fileRef.current.files = e.dataTransfer.files;
        }
    }, [setFilesDraggedOver, onSelectFiles]);
    const onDragOver = useCallback((e) => {
        overrideEventDefault(e);
        setFilesDraggedOver(true);
    }, [setFilesDraggedOver]);
    const onDragLeave = useCallback(() => {
        setFilesDraggedOver(false);
    }, [setFilesDraggedOver]);
    const onChange = useCallback((e) => {
        onSelectFiles(e, e.target.files);
    }, [onSelectFiles]);
    const onClickButton = useCallback(() => {
        fileRef.current.click();
    }, []);
    return (
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions
    jsxs("div", { onDrop: onDrop, onDragOver: onDragOver, onDragLeave: onDragLeave, className: wrapper(), children: [children, jsx(SelectButton, { decorators: decorators, onClick: onClickButton }), jsx("input", { ...props, "data-smarthr-ui-input": "true", ref: fileRef, type: "file", multiple: multiple, onChange: onChange, className: input() })] }));
});
const SelectButton = memo(({ onClick, decorators }) => {
    const { localize } = useIntl();
    const decoratorDefaultTexts = useMemo(() => ({
        selectButtonLabel: localize({
            id: 'smarthr-ui/DropZone/selectButtonLabel',
            defaultText: 'ファイルを選択',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    return (jsx(Button, { prefix: jsx(FaFolderOpenIcon, {}), onClick: onClick, children: decorated.selectButtonLabel }));
});

export { DropZone };
//# sourceMappingURL=DropZone.js.map
