"use client";
import { jsx } from 'react/jsx-runtime';
import { createContext, createRef, useState, useContext, useRef, useId, useEffect, useMemo, useCallback } from 'react';
import { usePortal } from '../../hooks/usePortal.js';
import { getFirstTabbable, isEventFromChild } from './dropdownHelper.js';

const initialRect = { top: 0, right: 0, bottom: 0, left: 0 };
const DropdownContext = createContext({
    active: false,
    triggerRect: initialRect,
    triggerElementRef: createRef(),
    rootTriggerRef: null,
    onClickTrigger: () => {
        /* noop */
    },
    onClickCloser: () => {
        /* noop */
    },
    DropdownContentRoot: () => null,
    contentId: '',
});
const Dropdown = ({ onOpen, onClose, children }) => {
    const [active, setActive] = useState(false);
    const [triggerRect, setTriggerRect] = useState(initialRect);
    const { rootTriggerRef } = useContext(DropdownContext);
    const { createPortal, portalRoot, isPortalRootMounted, isChildPortal, PortalParentProvider } = usePortal();
    const triggerElementRef = useRef(null);
    const contentId = useId();
    if (portalRoot) {
        portalRoot.setAttribute('id', contentId);
    }
    useEffect(() => {
        const onClickBody = (e) => {
            // ignore events from events within DropdownTrigger and DropdownContent
            if (!isEventFromChild(e, triggerElementRef.current) && !isChildPortal(e.target)) {
                setActive(false);
            }
        };
        document.body.addEventListener('click', onClickBody, false);
        return () => {
            document.body.removeEventListener('click', onClickBody, false);
        };
    }, [isChildPortal, portalRoot]);
    // This is the root container of a dropdown content located in outside the DOM tree
    const DropdownContentRoot = useMemo(() => {
        const result = (props) => active ? createPortal(props.children) : null;
        // set the displayName explicit for DevTools
        result.displayName = 'DropdownContentRoot';
        return result;
    }, [active, createPortal]);
    const togglerRef = useRef({
        isPortalRootMounted,
        onOpen,
        onClose,
    });
    useEffect(() => {
        togglerRef.current = {
            isPortalRootMounted,
            onOpen,
            onClose,
        };
    }, [isPortalRootMounted, onOpen, onClose]);
    useEffect(() => {
        if (togglerRef.current.isPortalRootMounted()) {
            togglerRef.current[active ? 'onOpen' : 'onClose']?.();
        }
    }, [active]);
    const onClickTrigger = useCallback((rect) => {
        setActive((current) => {
            const newActive = !current;
            if (newActive) {
                setTriggerRect(rect);
            }
            return newActive;
        });
    }, []);
    const onClickCloser = useCallback(() => {
        setActive(false);
        // return focus to the Trigger
        getFirstTabbable(triggerElementRef)?.focus();
    }, []);
    return (jsx(PortalParentProvider, { children: jsx(DropdownContext.Provider, { value: {
                active,
                triggerRect,
                triggerElementRef,
                rootTriggerRef: rootTriggerRef || triggerElementRef || null,
                onClickTrigger,
                onClickCloser,
                DropdownContentRoot,
                contentId,
            }, children: children }) }));
};

export { Dropdown, DropdownContext };
//# sourceMappingURL=Dropdown.js.map
