"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useContext, useMemo, useRef, Children, isValidElement, Fragment, cloneElement } from 'react';
import innerText from '../../../_virtual/index.js';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { DropdownContext, Dropdown } from '../Dropdown.js';
import { DropdownTrigger } from '../DropdownTrigger.js';
import { DropdownContent } from '../DropdownContent.js';
import { DropdownCloser } from '../DropdownCloser.js';
import '../FilterDropdown/FilterDropdown.js';
import { DropdownMenuGroup } from './DropdownMenuGroup.js';
import '../SortDropdown/SortDropdown.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react-intl';
import { Button } from '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import '../../Button/UnstyledButton.js';
import { FaCaretDownIcon, FaEllipsisIcon } from '../../Icon/Icon.js';
import '../../Icon/generateIcon.js';
import useKeyboardNavigation from './useKeyboardNavigation.js';

const classNameGenerator = ce({
    slots: {
        triggerWrapper: 'smarthr-ui-DropdownMenuButton',
        triggerButton: 'smarthr-ui-DropdownMenuButton-trigger [&[aria-expanded="true"]_.smarthr-ui-Icon:last-child]:shr-rotate-180',
        actionList: [
            'smarthr-ui-DropdownMenuButton-panel',
            'shr-list-none shr-py-0.5',
            [
                /* unset した Button の右 padding 分 */
                '[&_.smarthr-ui-Button-disabledWrapper]:shr-pe-1',
                '[&_.smarthr-ui-Button-disabledWrapper]:shr-gap-x-0.5',
                '[&_.smarthr-ui-Button-disabledWrapper_>_.smarthr-ui-Button]:shr-w-[unset] [&_.smarthr-ui-Button-disabledWrapper_>_.smarthr-ui-Button]:shr-bg-transparent [&_.smarthr-ui-Button-disabledWrapper_>_.smarthr-ui-Button]:shr-pe-[unset]',
            ],
        ],
        actionListItemButton: [
            'shr-justify-start shr-rounded-none shr-border-none shr-py-0.5 shr-font-normal',
            'focus-visible:shr-focus-indicator--inner',
        ],
    },
});
const { triggerWrapper, triggerButton, actionList, actionListItemButton } = classNameGenerator();
const DropdownMenuButton = ({ label, children, triggerSize, onlyIconTrigger, triggerIcon, onOpen, onClose, className, ...rest }) => {
    const containerRef = useRef(null);
    useKeyboardNavigation(containerRef);
    const classNames = useMemo(() => ({
        triggerWrapper: triggerWrapper({ className }),
        triggerButton: triggerButton(),
        actionList: actionList(),
    }), [className]);
    return (jsxs(Dropdown, { onOpen: onOpen, onClose: onClose, children: [jsx(MemoizedTriggerButton, { ...rest, label: label, onlyIconTrigger: onlyIconTrigger, triggerIcon: triggerIcon, triggerSize: triggerSize, classNames: classNames }), jsx(DropdownContent, { controllable: true, children: jsx("menu", { ref: containerRef, role: "menu", className: classNames.actionList, children: renderButtonList(children) }) })] }));
};
const MemoizedTriggerButton = memo(({ onlyIconTrigger, triggerSize, label, triggerIcon, classNames, ...rest }) => {
    const { localize } = useIntl();
    const { active } = useContext(DropdownContext);
    const tooltip = useMemo(() => ({ show: onlyIconTrigger, message: label }), [label, onlyIconTrigger]);
    return (jsx(DropdownTrigger, { className: classNames.triggerWrapper, tooltip: tooltip, children: jsx(Button, { ...rest, suffix: !onlyIconTrigger && (jsx(FaCaretDownIcon, { alt: active
                    ? localize({
                        id: 'smarthr-ui/DropdownMenuButton/triggerActive',
                        defaultText: '候補を閉じる',
                    })
                    : localize({
                        id: 'smarthr-ui/DropdownMenuButton/triggerInactive',
                        defaultText: '候補を開く',
                    }) })), size: triggerSize, className: classNames.triggerButton, children: jsx(TriggerLabelText, { label: label, onlyIconTrigger: onlyIconTrigger, triggerIcon: triggerIcon }) }) }));
});
const TriggerLabelText = memo(({ label, onlyIconTrigger, triggerIcon }) => {
    if (!onlyIconTrigger) {
        return label;
    }
    const Icon = triggerIcon || FaEllipsisIcon;
    return jsx(Icon, { alt: typeof label === 'string' ? label : innerText(label) });
});
const renderButtonList = (children) => Children.map(children, (item) => {
    if (!item || !isValidElement(item)) {
        return null;
    }
    switch (item.type) {
        case Fragment:
            return renderButtonList(item.props.children);
        case DropdownMenuGroup:
            return item;
    }
    return (jsx("li", { role: "presentation", children: jsx(DropdownCloser, { children: cloneElement(item, {
                wide: true,
                role: 'menuitem',
                className: actionListItemButton({ className: item.props.className }),
            }) }) }));
});

export { DropdownMenuButton, renderButtonList };
//# sourceMappingURL=DropdownMenuButton.js.map
