import { useMemo, useState, useEffect, useCallback } from 'react';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../../hooks/useDecorators.js';
import '../../../intl/IntlProvider.js';
import { useIntl } from '../../../intl/useIntl.js';
import 'react/jsx-runtime';
import 'react-intl';
import { FaArrowUpWideShortIcon, FaArrowDownWideShortIcon } from '../../Icon/Icon.js';
import '../../Icon/generateIcon.js';

const classNameGenerator = ce({
    slots: {
        body: 'shr-p-1.5',
        select: 'shr-min-w-[16em]',
        footer: 'shr-border-t-shorthand shr-px-1.5 shr-py-1',
    },
});
const useSortDropdown = ({ sortFields, defaultOrder, onApply, decorators }) => {
    const { localize } = useIntl();
    const decoratorDefaultTexts = useMemo(() => ({
        sortFieldLabel: localize({
            id: 'smarthr-ui/SortDropdown/sortFieldLabel',
            defaultText: '並べ替え項目',
        }),
        sortOrderLabel: localize({
            id: 'smarthr-ui/SortDropdown/sortOrderLabel',
            defaultText: '並び順',
        }),
        ascLabel: localize({
            id: 'smarthr-ui/SortDropdown/ascLabel',
            defaultText: '昇順',
        }),
        descLabel: localize({
            id: 'smarthr-ui/SortDropdown/descLabel',
            defaultText: '降順',
        }),
        applyButtonLabel: localize({
            id: 'smarthr-ui/SortDropdown/applyButtonLabel',
            defaultText: '適用',
        }),
        cancelButtonLabel: localize({
            id: 'smarthr-ui/SortDropdown/cancelButtonLabel',
            defaultText: 'キャンセル',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    // 外向きの値
    const [selectedLabel, setSelectedLabel] = useState();
    const [checkedOrder, setCheckedOrder] = useState(defaultOrder);
    // 内部的な値
    const [innerFields, setInnerFields] = useState(sortFields);
    const [innerSelectedField, setInnerSelectedField] = useState();
    const [innerCheckedOrder, setCheckedInnerOrder] = useState(defaultOrder);
    useEffect(() => {
        if (selectedLabel)
            return;
        // 初期値は option に紛れているので、選択されている項目を取得
        const defaultField = sortFields.find((field) => 'selected' in field && field.selected) || sortFields[0];
        setSelectedLabel(defaultField.label);
        setInnerSelectedField(defaultField.label);
    }, [selectedLabel, sortFields]);
    // 外向きな値で構成
    const triggerLabel = useMemo(() => {
        const sortLabel = checkedOrder === 'asc' ? decorated.ascLabel : decorated.descLabel;
        return `${selectedLabel}（${sortLabel}）`;
    }, [decorated.ascLabel, decorated.descLabel, selectedLabel, checkedOrder]);
    const SortIcon = useMemo(() => (checkedOrder === 'asc' ? FaArrowUpWideShortIcon : FaArrowDownWideShortIcon), [checkedOrder]);
    const handleChange = useCallback((e) => {
        const select = e.currentTarget;
        const newLabel = select.options[select.selectedIndex].label;
        const newFields = innerFields.map((field) => {
            if (field.label !== newLabel && field.selected) {
                return {
                    ...field,
                    selected: false,
                };
            }
            if (field.label === newLabel && !field.selected) {
                return {
                    ...field,
                    selected: true,
                };
            }
            return field;
        });
        setInnerFields(newFields);
        setInnerSelectedField(newLabel);
    }, [innerFields]);
    const handleApply = useCallback(() => {
        setSelectedLabel(innerSelectedField);
        setCheckedOrder(innerCheckedOrder);
        onApply({ field: innerSelectedField || '', order: innerCheckedOrder, newfields: innerFields });
    }, [innerCheckedOrder, innerFields, innerSelectedField, onApply]);
    const onChangeSortOrderRadio = useCallback((e) => {
        setCheckedInnerOrder(e.currentTarget.value);
    }, []);
    const classNames = useMemo(() => {
        const { body, select, footer } = classNameGenerator();
        return {
            body: body(),
            select: select(),
            footer: footer(),
        };
    }, []);
    return {
        onChangeSortOrderRadio,
        labels: {
            triggerLabel,
            ...decorated,
        },
        handler: { handleApply, handleChange },
        innerValues: { innerFields, innerSelectedField, innerCheckedOrder },
        SortIcon,
        classNames,
    };
};

export { useSortDropdown };
//# sourceMappingURL=useSortDropdown.js.map
