"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { Decimal } from './../../vendor/.pnpm/decimal.js@10.5.0/vendor/decimal.js/decimal.js';
import { memo, useRef, useState, useMemo, useCallback, useEffect } from 'react';
import { ImageViewer } from './ImageViewer.js';
import { PDFViewer } from './PDFViewer.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Stack/Stack.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { FaMagnifyingGlassMinusIcon, FaMagnifyingGlassPlusIcon, FaArrowRotateLeftIcon } from '../Icon/Icon.js';
import { DropdownMenuButton } from '../Dropdown/DropdownMenuButton/DropdownMenuButton.js';
import '../Dropdown/DropdownMenuButton/DropdownMenuGroup.js';
import '../Dropdown/Dropdown.js';
import '../Dropdown/DropdownTrigger.js';
import '../Dropdown/DropdownContent.js';
import '../Dropdown/DropdownCloser.js';
import '../Dropdown/FilterDropdown/FilterDropdown.js';
import '../Dropdown/SortDropdown/SortDropdown.js';
import { Text } from '../Text/Text.js';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';
import { Loader } from '../Loader/Loader.js';

const defaultScaleStep = new Decimal(0.2);
const defaultScaleSteps = [0.2, 0.6, 1, 1.6, 2, 3];
const FileViewer = ({ file, scaleStep, scaleSteps, width: fixedWidth }) => {
    const ref = useRef(null);
    const [scale, setScale] = useState(1);
    const [loaded, setLoaded] = useState(false);
    const [rotation, setRotation] = useState(0);
    const [width, setWidth] = useState(fixedWidth ?? 0);
    const internalScaleStep = useMemo(() => (scaleStep ? new Decimal(scaleStep) : defaultScaleStep), [scaleStep]);
    const scaleUp = useCallback(() => {
        setScale((currentScale) => new Decimal(currentScale).add(internalScaleStep).toNumber());
    }, [internalScaleStep]);
    const scaleDown = useCallback(() => {
        setScale((currentScale) => new Decimal(currentScale).sub(internalScaleStep).toNumber());
    }, [internalScaleStep]);
    const rotate = useCallback(() => {
        setRotation((currentRotation) => currentRotation - 90);
    }, []);
    const handleLoaded = useCallback(() => {
        setLoaded(true);
    }, []);
    useEffect(() => {
        if (!ref.current || fixedWidth !== undefined) {
            return;
        }
        const resizeObserver = new ResizeObserver(() => {
            setWidth((ref.current?.clientWidth ?? 0) - 64);
        });
        resizeObserver.observe(ref.current);
        return () => {
            resizeObserver.disconnect();
        };
    }, [fixedWidth]);
    return (jsxs("div", { className: "shr-flex shr-h-full shr-w-full shr-flex-col shr-gap-2 shr-overflow-auto shr-bg-scrim shr-bg-[radial-gradient(theme(textColor.black)_1px,_transparent_0)] shr-bg-[length:16px_16px]", ref: ref, children: [jsx("div", { className: "shr-sticky shr-start-0 shr-top-0 shr-z-[1] shr-flex shr-w-full shr-flex-shrink-0 shr-gap-0.5", children: jsx(Controller, { scale: scale, setScale: setScale, scaleSteps: scaleSteps || defaultScaleSteps, onClickScaleUpButton: scaleUp, onClickScaleDownButton: scaleDown, onClickRotateButton: rotate }) }), jsxs("div", { className: "shr-z-[0] shr-mx-auto shr-my-0 shr-box-border shr-flex shr-w-fit shr-flex-shrink-0 shr-grow shr-items-center shr-justify-center shr-px-2 shr-pb-2", children: [!loaded && (jsx("div", { className: "shr-pointer-events-none shr-fixed shr-inset-0 shr-flex shr-h-full shr-w-full shr-items-center shr-justify-center", children: jsx(Loader, { type: "light", size: "m" }) })), jsx("div", { className: !loaded ? 'shr-invisible' : '', children: file.contentType === 'application/pdf' ? (jsx(PDFViewer, { scale: scale, rotation: rotation, file: file, width: width, onLoad: handleLoaded })) : file.contentType.startsWith('image/') ? (jsx(ImageViewer, { scale: scale, rotation: rotation, file: file, width: width, onLoad: handleLoaded })) : (jsx(Text, { children: "\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u306A\u3044\u5F62\u5F0F\u306E\u30D5\u30A1\u30A4\u30EB\u3067\u3059\u3002" })) })] })] }));
};
const Controller = memo(({ scale, setScale, scaleSteps, onClickScaleUpButton, onClickScaleDownButton, onClickRotateButton, }) => (jsx("div", { className: "shr-sticky shr-flex shr-w-full shr-items-center shr-justify-center shr-justify-items-center shr-gap-0.5 shr-bg-scrim shr-p-0.5 shr-shadow-layer-1", children: jsxs(Cluster, { gap: 0.5, children: [jsxs("div", { className: "shr-border-shorthand shr-flex shr-divide-x shr-divide-solid shr-overflow-hidden shr-rounded-m", children: [jsx(Button, { onClick: onClickScaleDownButton, disabled: scale <= scaleSteps[0], className: "shr-rounded-none shr-border-none", children: jsx(FaMagnifyingGlassMinusIcon, { alt: "\u7E2E\u5C0F" }) }), jsx(DropdownMenuButton, { label: jsxs(Text, { children: [jsx(VisuallyHiddenText, { children: "\u62E1\u5927\u7387" }), `${(scale * 100).toFixed(0)}%`] }), className: "shr-border-y-0 shr-border-[theme(borderColor.default)] [&_.smarthr-ui-Button]:shr-rounded-none [&_.smarthr-ui-Button]:shr-border-[transparent]", children: scaleSteps.map((step) => (jsx(Button, { onClick: () => setScale(step), className: "shr-rounded-none shr-border-0", children: `${(step * 100).toFixed(0)}%` }, step.toString()))) }), jsx(Button, { onClick: onClickScaleUpButton, className: "shr-rounded-none shr-border-0", children: jsx(FaMagnifyingGlassPlusIcon, { alt: "\u62E1\u5927" }) })] }), jsx(Button, { onClick: onClickRotateButton, className: "shr-p-0.75", children: jsx(FaArrowRotateLeftIcon, { alt: "\u5DE6\u56DE\u8EE2" }) })] }) })));

export { FileViewer };
//# sourceMappingURL=FileViewer.js.map
