import { type ComponentProps, type ComponentPropsWithoutRef, type ComponentType, type FC, type FunctionComponentElement, type PropsWithChildren, type ReactNode } from 'react';
import { StatusLabel } from '../StatusLabel';
import { type TextProps } from '../Text';
import type { Gap } from '../../types';
type StatusLabelProps = ComponentProps<typeof StatusLabel>;
type StatusLabelType = FunctionComponentElement<StatusLabelProps>;
type Props = PropsWithChildren<{
    /** グループのタイトル名 */
    title: ReactNode;
    /** タイトルの見出しのタイプ */
    titleType?: TextProps['styleType'];
    /** タイトル右の領域 */
    subActionArea?: ReactNode;
    /** タイトルの見出しを視覚的に隠すかどうか */
    dangerouslyTitleHidden?: boolean;
    /** label 要素に適用する `htmlFor` 値 */
    htmlFor?: string;
    /** label 要素に適用する `id` 値 */
    labelId?: string;
    /** タイトル群と子要素の間の間隔調整用（基本的には不要） */
    innerMargin?: Gap;
    /** タイトルの隣に表示する `StatusLabel` の Props の配列 */
    /**
     * @deprecated statusLabelProps属性は非推奨です。statusLabelsを使ってください。
     */
    statusLabelProps?: StatusLabelProps | StatusLabelProps[];
    /** タイトルの隣に表示する `StatusLabel` の配列 */
    statusLabels?: StatusLabelType | StatusLabelType[];
    /** タイトルの下に表示するヘルプメッセージ */
    helpMessage?: ReactNode;
    /** タイトルの下に表示する入力例 */
    exampleMessage?: ReactNode;
    /** タイトルの下に表示するエラーメッセージ */
    errorMessages?: ReactNode | ReactNode[];
    /** エラーがある場合に自動的に入力要素を error にするかどうか */
    autoBindErrorInput?: boolean;
    /** フォームコントロールの下に表示する補足メッセージ */
    supplementaryMessage?: ReactNode;
    /** `true` のとき、文字色を `TEXT_DISABLED` にする */
    disabled?: boolean;
    as?: string | ComponentType<any>;
}>;
type ElementProps = Omit<ComponentPropsWithoutRef<'div'>, keyof Props | 'aria-labelledby'>;
export declare const ActualFormControl: FC<Props & ElementProps>;
export declare const FormControl: FC<Omit<Props & ElementProps, 'as' | 'disabled'>>;
export {};
