"use client";
import { memo, useMemo, useId, useRef, Fragment as Fragment$1, createElement, useEffect } from 'react';
import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import innerText from '../../_virtual/index.js';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { FaCircleExclamationIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import { Stack } from '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { StatusLabel } from '../StatusLabel/StatusLabel.js';
import '../StatusLabel/RequiredLabel/RequiredLabel.js';
import { Text } from '../Text/Text.js';
import { VisuallyHiddenText, visuallyHiddenTextClassNameGenerator } from '../VisuallyHiddenText/VisuallyHiddenText.js';

const classNameGenerator = ce({
    slots: {
        wrapper: [
            'smarthr-ui-FormControl',
            'shr-mx-[unset] shr-border-none shr-p-[unset]',
            'disabled:shr-text-disabled',
            '[&:disabled_.smarthr-ui-FormControl-label_>_span]:shr-text-disabled',
            '[&:disabled_.smarthr-ui-FormControl-exampleMessage]:shr-text-color-inherit',
            '[&:disabled_.smarthr-ui-FormControl-errorMessage]:shr-text-color-inherit',
            '[&:disabled_.smarthr-ui-FormControl-supplementaryMessage]:shr-text-color-inherit',
            '[&:disabled_.smarthr-ui-Input]:shr-border-default/50 [&:disabled_.smarthr-ui-Input]:shr-bg-white-darken',
        ],
        label: ['smarthr-ui-FormControl-label'],
        errorList: ['shr-list-none'],
        errorIcon: ['smarthr-ui-FormControl-errorMessage', 'shr-text-danger'],
        underTitleStack: ['[&&&]:shr-mt-0'],
        childrenWrapper: [],
    },
    variants: {
        innerMargin: {
            0: {},
            0.25: {},
            0.5: {},
            0.75: {},
            1: {},
            1.25: {},
            1.5: {},
            2: {},
            2.5: {},
            3: {},
            3.5: {},
            4: {},
            8: {},
            X3S: {},
            XXS: {},
            XS: {},
            S: {},
            M: {},
            L: {},
            XL: {},
            XXL: {},
            X3L: {},
        },
        isFieldset: {
            true: {},
            false: {},
        },
    },
    compoundVariants: [
        // TODO: innerMarginが未指定、初期値の場合、かつFieldsetの場合、childrenの上部の余白を広げることで
        // FormControltとの差をわかりやすくしている
        // 微妙な方法ではあるので、必要に応じてinnerMarginではない属性を用意する
        // https://kufuinc.slack.com/archives/CGC58MW01/p1737944965871159?thread_ts=1737541173.404369&cid=CGC58MW01
        {
            innerMargin: undefined,
            isFieldset: true,
            class: {
                childrenWrapper: '[:not([hidden])_~_&&&]:shr-mt-1',
            },
        },
        {
            innerMargin: undefined,
            isFieldset: false,
            class: {
                childrenWrapper: '[:not([hidden])_~_&&&]:shr-mt-0.5',
            },
        },
    ],
});
const SMARTHR_UI_INPUT_SELECTOR = '[data-smarthr-ui-input="true"]';
const ActualFormControl = ({ title, titleType = 'blockTitle', subActionArea, dangerouslyTitleHidden = false, htmlFor, labelId, innerMargin, statusLabels, statusLabelProps, helpMessage, exampleMessage, errorMessages, autoBindErrorInput = true, supplementaryMessage, as = 'div', className, children, ...props }) => {
    const defaultHtmlFor = useId();
    const defaultLabelId = useId();
    const managedHtmlFor = htmlFor || defaultHtmlFor;
    const managedLabelId = labelId || defaultLabelId;
    const inputWrapperRef = useRef(null);
    const isFieldset = as === 'fieldset';
    const describedbyIds = useMemo(() => {
        const temp = [];
        if (helpMessage) {
            temp.push(`${managedHtmlFor}_helpMessage`);
        }
        if (exampleMessage) {
            temp.push(`${managedHtmlFor}_exampleMessage`);
        }
        if (supplementaryMessage) {
            temp.push(`${managedHtmlFor}_supplementaryMessage`);
        }
        if (errorMessages) {
            temp.push(`${managedHtmlFor}_errorMessages`);
        }
        return temp.join(' ');
    }, [helpMessage, exampleMessage, supplementaryMessage, errorMessages, managedHtmlFor]);
    const actualStatusLabels = useMemo(() => {
        if (statusLabels) {
            return (Array.isArray(statusLabels) ? statusLabels : [statusLabels]).map((statusLabel, index) => jsx(Fragment$1, { children: statusLabel }, index));
        }
        if (!statusLabelProps) {
            return [];
        }
        const labelProps = Array.isArray(statusLabelProps) ? statusLabelProps : [statusLabelProps];
        return labelProps.map((prop, index) => createElement(StatusLabel, { ...prop, key: index }));
    }, [statusLabels, statusLabelProps]);
    const actualErrorMessages = useMemo(() => {
        if (!errorMessages) {
            return [];
        }
        return Array.isArray(errorMessages) ? errorMessages : [errorMessages];
    }, [errorMessages]);
    const actualInnerMargin = useMemo(() => innerMargin ?? 0.5, [innerMargin]);
    const classNames = useMemo(() => {
        const { wrapper, label, errorList, errorIcon, underTitleStack, childrenWrapper } = classNameGenerator({ innerMargin, isFieldset });
        return {
            wrapper: wrapper({ className }),
            label: label({
                className: dangerouslyTitleHidden ? visuallyHiddenTextClassNameGenerator() : '',
            }),
            errorList: errorList(),
            errorIcon: errorIcon(),
            underTitleStack: underTitleStack(),
            childrenWrapper: childrenWrapper(),
        };
    }, [innerMargin, isFieldset, dangerouslyTitleHidden, className]);
    useEffect(() => {
        if (isFieldset ||
            !inputWrapperRef?.current ||
            // HINT: 対象idを持つ要素が既に存在する場合、何もしない
            document.getElementById(managedHtmlFor)) {
            return;
        }
        const input = inputWrapperRef.current.querySelector(SMARTHR_UI_INPUT_SELECTOR);
        if (!input) {
            return;
        }
        if (!input.getAttribute('id')) {
            input.setAttribute('id', managedHtmlFor);
        }
        if (input instanceof HTMLInputElement && input.type === 'file') {
            const attrName = 'aria-labelledby';
            const inputLabelledByIds = input.getAttribute(attrName);
            if (inputLabelledByIds) {
                // InputFileの場合はlabel要素の可視ラベルをアクセシブルネームに含める
                input.setAttribute(attrName, `${inputLabelledByIds} ${managedLabelId}`);
            }
        }
    }, [managedHtmlFor, isFieldset, managedLabelId]);
    useEffect(() => {
        if (!describedbyIds || !inputWrapperRef?.current) {
            return;
        }
        const inputWrapper = inputWrapperRef.current;
        const attrName = 'aria-describedby';
        if (inputWrapper.querySelector(`[${attrName}="${describedbyIds}"]`)) {
            return;
        }
        const input = inputWrapper.querySelector(SMARTHR_UI_INPUT_SELECTOR);
        if (input) {
            const attribute = input.getAttribute(attrName);
            input.setAttribute(attrName, attribute ? `${attribute} ${describedbyIds}` : describedbyIds);
        }
    }, [describedbyIds]);
    useEffect(() => {
        if (!autoBindErrorInput || !inputWrapperRef?.current) {
            return;
        }
        const input = inputWrapperRef.current.querySelector(SMARTHR_UI_INPUT_SELECTOR);
        if (input) {
            const attrName = 'aria-invalid';
            if (actualErrorMessages.length > 0) {
                input.setAttribute(attrName, 'true');
            }
            else {
                input.removeAttribute(attrName);
            }
        }
    }, [actualErrorMessages.length, autoBindErrorInput]);
    let body = (jsxs(Fragment, { children: [jsx(HelpMessageParagraph, { helpMessage: helpMessage, managedHtmlFor: managedHtmlFor }), jsx(ExampleMessageText, { exampleMessage: exampleMessage, managedHtmlFor: managedHtmlFor }), jsx(ErrorMessageList, { errorMessages: actualErrorMessages, managedHtmlFor: managedHtmlFor, classNames: classNames }), jsx("div", { className: classNames.childrenWrapper, ref: inputWrapperRef, children: children }), jsx(SupplementaryMessageText, { supplementaryMessage: supplementaryMessage, managedHtmlFor: managedHtmlFor })] }));
    // HINT: dangerouslyTitleHiddenの場合、body以下の余白の計算を簡略化するため
    // Stackをネストし、そのStackに対してmargin-top: 0を指定する
    // こうすることでinner Stack以下の要素は擬似的にStackの最初の要素になる
    if (dangerouslyTitleHidden) {
        body = (jsx(Stack, { gap: actualInnerMargin, className: classNames.underTitleStack, children: body }));
    }
    return (jsxs(Stack, { ...props, as: as, gap: actualInnerMargin, "aria-describedby": isFieldset && describedbyIds ? describedbyIds : undefined, className: classNames.wrapper, children: [jsx(TitleCluster, { isFieldset: isFieldset, managedHtmlFor: managedHtmlFor, managedLabelId: managedLabelId, dangerouslyTitleHidden: dangerouslyTitleHidden, titleType: titleType, title: title, statusLabels: actualStatusLabels, subActionArea: subActionArea, labelClassName: classNames.label }), body] }));
};
const TitleCluster = memo(({ isFieldset, managedHtmlFor, managedLabelId, dangerouslyTitleHidden, titleType, title, subActionArea, labelClassName, statusLabels, }) => {
    const body = (jsxs(Fragment, { children: [jsx(Text, { styleType: titleType, children: title }), jsx(StatusLabelCluster, { statusLabels: statusLabels })] }));
    const attrs = useMemo(() => {
        if (dangerouslyTitleHidden) {
            return {
                label: null,
                visuallyHidden: isFieldset
                    ? {
                        as: 'legend',
                    }
                    : {
                        as: 'label',
                        htmlFor: managedHtmlFor,
                        id: managedLabelId,
                    },
            };
        }
        if (isFieldset) {
            return {
                label: { 'aria-hidden': 'true' },
                visuallyHidden: { as: 'legend' },
            };
        }
        return {
            label: {
                as: 'label',
                htmlFor: managedHtmlFor,
                id: managedLabelId,
            },
            visuallyHidden: null,
        };
    }, [managedLabelId, managedHtmlFor, dangerouslyTitleHidden, isFieldset]);
    return (jsxs(Fragment, { children: [attrs.visuallyHidden && (jsx(VisuallyHiddenText, { ...attrs.visuallyHidden, children: 
                // HINT: innerTextでは正しく文字が取得できない場合がある
                // 安全策としてinnerTextが空を取得してきたらbody自体を埋めこみます
                innerText(body) || body })), attrs.label && (jsxs(Cluster, { justify: "space-between", 
                // HINT: UI上、常にトップの要素になるため、Stackの計算が狂わないよう、
                // 常にmargin-topを0にする
                className: "[&&&]:shr--mt-0", children: [jsx(Cluster, { ...attrs.label, align: "center", className: labelClassName, children: body }), subActionArea && jsx("div", { className: "shr-grow", children: subActionArea })] }))] }));
});
const StatusLabelCluster = memo(({ statusLabels }) => statusLabels.length === 0 ? null : (jsx(Cluster, { gap: 0.25, as: "span", children: statusLabels })));
const HelpMessageParagraph = memo(({ helpMessage, managedHtmlFor }) => helpMessage ? (jsx("p", { className: "smarthr-ui-FormControl-helpMessage", id: `${managedHtmlFor}_helpMessage`, children: helpMessage })) : null);
const ExampleMessageText = memo(({ exampleMessage, managedHtmlFor }) => exampleMessage ? (jsx(Text, { as: "p", color: "TEXT_GREY", italic: true, id: `${managedHtmlFor}_exampleMessage`, className: "smarthr-ui-FormControl-exampleMessage", children: exampleMessage })) : null);
const ErrorMessageList = memo(({ errorMessages, managedHtmlFor, classNames }) => errorMessages.length > 0 ? (jsx("div", { id: `${managedHtmlFor}_errorMessages`, className: classNames.errorList, role: "alert", children: errorMessages.map((message, index) => (jsx("p", { children: jsx(FaCircleExclamationIcon, { text: message, className: classNames.errorIcon }) }, index))) })) : null);
const SupplementaryMessageText = memo(({ supplementaryMessage, managedHtmlFor }) => supplementaryMessage ? (jsx(Text, { as: "p", size: "S", color: "TEXT_GREY", id: `${managedHtmlFor}_supplementaryMessage`, className: "smarthr-ui-FormControl-supplementaryMessage", children: supplementaryMessage })) : null);
const FormControl = ActualFormControl;

export { ActualFormControl, FormControl };
//# sourceMappingURL=FormControl.js.map
