import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { SmartHRLogo } from '../SmartHRLogo/SmartHRLogo.js';
import { Text } from '../Text/Text.js';
import './LanguageSwitcher/LanguageSwitcher.js';
import './HeaderLink.js';
import { HeaderDropdownMenuButton } from './HeaderDropdownMenuButton.js';
import { AppLauncher } from './AppLauncher/AppLauncher.js';

const classNameGenerator = ce({
    slots: {
        wrapper: ['smarthr-ui-Header', 'shr-bg-brand shr-px-1.25', 'max-md:shr-px-0.75'],
        logoLink: [
            'smarthr-ui-Header-logoLink',
            /* ロゴが持つ padding 分だけ調整 */
            '-shr-ms-0.75',
            'focus-visible:shr-focus-indicator',
        ],
        tenantInfo: ['smarthr-ui-Header-tenantInfo', 'shr-ms-auto'],
        tenantNameText: 'shr-px-0.25',
        actions: ['smarthr-ui-Header-actions', 'shr-ms-auto'],
    },
    variants: {
        enableNew: {
            true: {
                wrapper: [
                    'shr-border-0 shr-border-b shr-border-t-6 shr-border-solid shr-border-b-default shr-border-t-brand shr-bg-white shr-px-1.5',
                ],
                logoLink: '',
                tenantInfo: '',
                tenantNameText: '',
                actions: 'shr-py-0.5',
            },
        },
    },
});
const COMMON_GAP = { column: 0.25, row: 0 };
const CHILDREN_GAP = { column: 0.5, row: 0.25 };
const Header = ({ enableNew, logo, logoHref, featureName, apps, tenants, currentTenantId, onTenantSelect, children, className, }) => {
    const classNames = useMemo(() => {
        const { wrapper, logoLink, tenantInfo: tenantInfoStyle, tenantNameText, actions, } = classNameGenerator({ enableNew });
        return {
            wrapper: wrapper({ className }),
            logoLink: logoLink(),
            tenantInfo: tenantInfoStyle(),
            tenantNameText: tenantNameText(),
            actions: actions(),
        };
    }, [enableNew, className]);
    return (jsxs(Cluster, { as: "header", justify: "space-between", gap: COMMON_GAP, className: classNames.wrapper, children: [jsxs(Cluster, { align: "center", gap: COMMON_GAP, children: [jsx(Logo, { href: logoHref, enableNew: enableNew, className: classNames.logoLink, children: logo }), enableNew ? (jsx(MemoizedAppLauncher, { featureName: featureName, apps: apps, enableNew: enableNew })) : (jsx(TenantSwitcher, { currentTenantId: currentTenantId, tenants: tenants, classNames: classNames, onTenantSelect: onTenantSelect }))] }), jsx(Cluster, { align: "center", justify: "flex-end", gap: CHILDREN_GAP, className: classNames.actions, children: children })] }));
};
const Logo = memo(({ children, href, enableNew, className }) => (jsx("a", { href: href || '/', className: className, children: children || jsx(SmartHRLogo, { fill: enableNew ? 'brand' : undefined, className: "shr-p-0.75" }) })));
const MemoizedAppLauncher = memo(({ featureName, apps = [], enableNew }) => {
    const decorators = useMemo(() => {
        if (!featureName) {
            return undefined;
        }
        return { triggerLabel: () => featureName };
    }, [featureName]);
    return featureName && jsx(AppLauncher, { apps: apps, enableNew: enableNew, decorators: decorators });
});
const TenantSwitcher = memo(({ currentTenantId, tenants, classNames, onTenantSelect }) => {
    const currentTenantName = useMemo(() => {
        if (tenants && tenants.length >= 1) {
            const current = tenants.find(({ id }) => id === currentTenantId);
            return current ? current.name : tenants[0].name;
        }
        return undefined;
    }, [currentTenantId, tenants]);
    return (currentTenantName && (jsx("div", { className: classNames.tenantInfo, children: tenants && tenants.length > 1 ? (jsx(MultiTenantDropdownMenuButton, { label: currentTenantName, tenants: tenants, onTenantSelect: onTenantSelect })) : (jsx(Text, { color: "TEXT_WHITE", className: classNames.tenantNameText, children: currentTenantName })) })));
});
const MultiTenantDropdownMenuButton = memo(({ label, tenants, onTenantSelect }) => {
    const onClick = useMemo(() => onTenantSelect
        ? (e) => {
            onTenantSelect(e.currentTarget.value);
        }
        : undefined, [onTenantSelect]);
    return (jsx(HeaderDropdownMenuButton, { label: label, children: tenants.map(({ id, name }) => (jsx(Button, { value: id, onClick: onClick, children: name }, id))) }));
});

export { Header };
//# sourceMappingURL=Header.js.map
