"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../../hooks/useDecorators.js';
import { tabbable } from '../../../libs/tabbable.js';
import { Button } from '../../Button/Button.js';
import '../../Button/AnchorButton.js';
import '../../Button/UnstyledButton.js';
import { Dropdown } from '../../Dropdown/Dropdown.js';
import { DropdownTrigger } from '../../Dropdown/DropdownTrigger.js';
import { DropdownContent } from '../../Dropdown/DropdownContent.js';
import '../../Dropdown/DropdownCloser.js';
import '../../Dropdown/FilterDropdown/FilterDropdown.js';
import '../../Dropdown/DropdownMenuButton/DropdownMenuButton.js';
import '../../Dropdown/DropdownMenuButton/DropdownMenuGroup.js';
import '../../Dropdown/SortDropdown/SortDropdown.js';
import { FaCheckIcon, FaGlobeIcon, FaCaretDownIcon } from '../../Icon/Icon.js';
import '../../Icon/generateIcon.js';
import { LanguageIcon } from '../../Icon/LanguageIcon.js';

const DECORATOR_DEFAULT_TEXTS = {
    triggerLabel: 'Language',
    checkIconAlt: '選択中',
};
const ARROW_KEY_REGEX = /^Arrow(Up|Down|Left|Right)$/;
const ARROW_UPS_REGEX = /^Arrow(Up|Left)$/;
const onKeyDownContent = (e) => {
    if (!ARROW_KEY_REGEX.test(e.key)) {
        return;
    }
    e.preventDefault();
    const buttons = tabbable(e.currentTarget);
    const i = buttons.indexOf(e.target);
    let buttonAt = 0;
    if (ARROW_UPS_REGEX.test(e.key)) {
        buttonAt = i - 1;
    }
    else if (i + 1 === buttons.length) {
        buttonAt = i + 1;
    }
    buttons.at(buttonAt)?.focus();
};
const classNameGenerator = ce({
    slots: {
        switchButton: [
            'shr-border-none shr-bg-transparent shr-px-0.25 shr-font-normal shr-text-white shr-transition-transform shr-duration-100',
            'hover:shr-border-transparent hover:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:shr-bg-transparent',
            'forced-colors:shr-border-shorthand',
            '[&_.smarthr-ui-Icon]:aria-expanded:shr-rotate-180',
        ],
        languageItemsList: ['shr-p-0.5'],
        languageItem: ['shr-flex shr-items-center'],
        languageButton: [
            'shr-justify-start shr-border-transparent shr-px-0.5 shr-font-normal',
            '[&:not(:has(svg))]:shr-ps-2',
            'hover:shr-border-transparent',
        ],
    },
    variants: {
        invert: {
            true: {
                switchButton: [
                    'shr-text-black',
                    'hover:shr-bg-white-darken',
                    'focus-visible:shr-bg-white-darken',
                ],
            },
        },
        enableNew: {
            true: {
                switchButton: 'shr-px-0.5',
            },
        },
    },
});
const LanguageSwitcher = ({ narrow, enableNew, invert = enableNew, decorators, localeMap, locale, defaultLocale, onLanguageSelect, ...rest }) => {
    const { locales, defaultCurrentLang } = useMemo(() => ({
        locales: Object.entries(localeMap),
        defaultCurrentLang: Object.keys(localeMap)[0],
    }), [localeMap]);
    const decorated = useDecorators(DECORATOR_DEFAULT_TEXTS, decorators);
    const currentLang = locale || defaultLocale || defaultCurrentLang;
    const classNames = useMemo(() => {
        const { languageButton, languageItemsList, languageItem, switchButton } = classNameGenerator();
        return {
            languageButton: languageButton(),
            languageItemsList: languageItemsList(),
            languageItem: languageItem(),
            switchButton: switchButton({ invert, enableNew }),
        };
    }, [enableNew, invert]);
    const onClickLanguageSelect = useMemo(() => onLanguageSelect
        ? (e) => {
            onLanguageSelect(e.currentTarget.value);
        }
        : undefined, [onLanguageSelect]);
    return (jsxs(Dropdown, { ...rest, children: [jsx(MemoizedDropdownTrigger, { narrow: narrow, invert: invert, className: classNames.switchButton, label: decorated.triggerLabel }), jsx(DropdownContent, { role: "presentation", onKeyDown: onKeyDownContent, children: jsx("ul", { className: classNames.languageItemsList, children: locales.map(([code, label]) => (jsx(LanguageListItemButton, { code: code, className: classNames.languageItem, buttonStyle: classNames.languageButton, current: currentLang === code, onClick: onClickLanguageSelect, iconAlt: decorated.checkIconAlt, children: label }, code))) }) })] }));
};
const LanguageListItemButton = memo(({ code, children, buttonStyle, className, current, iconAlt, onClick }) => (jsx("li", { className: className, "aria-current": current, lang: code, children: jsx(Button, { value: code, onClick: onClick, wide: true, prefix: current ? jsx(FaCheckIcon, { color: "MAIN", alt: iconAlt }) : null, className: buttonStyle, children: children }) }, code)));
const MemoizedDropdownTrigger = memo(({ narrow, invert, className, label }) => (jsx(DropdownTrigger, { children: narrow ? (jsx(Button, { suffix: jsx(FaCaretDownIcon, {}), className: className, children: invert ? jsx(LanguageIcon, { alt: label }) : jsx(FaGlobeIcon, { alt: label }) })) : (jsx(Button, { prefix: invert ? jsx(LanguageIcon, {}) : jsx(FaGlobeIcon, {}), suffix: jsx(FaCaretDownIcon, {}), className: className, children: label })) })));

export { LanguageSwitcher };
//# sourceMappingURL=LanguageSwitcher.js.map
