import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { textColor, colors, fontSize } from '../../themes/tailwind/TailwindConfig.js';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';

const colorSet = {
    TEXT_BLACK: 'black',
    TEXT_WHITE: 'white',
    TEXT_GREY: 'grey',
    TEXT_DISABLED: 'disabled',
    TEXT_LINK: 'link',
    MAIN: 'main',
    DANGER: 'danger',
    WARNING: 'warning-yellow',
    BRAND: 'brand',
};
const existsColor = (color) => color in colorSet;
const fontSizeMap = {
    XXS: '2xs',
    XS: 'xs',
    S: 'sm',
    M: 'base',
    L: 'lg',
    XL: 'xl',
    XXL: '2xl',
};
// HINT: smarthr-ui-Icon-extendedはアイコン+α(例えば複数のアイコンをまとめて一つにしているなど)を表すclass
// altなどもVisuallyHiddenTextで表現している関係上、squareの計算などの際に複数要素として判断されると認知と違う結果になるため使用しています
const classNameGenerator = ce({
    slots: {
        icon: 'smarthr-ui-Icon group-[]/iconWrapper:shr-shrink-0 group-[]/iconWrapper:shr-translate-y-[0.125em] forced-colors:shr-fill-[CanvasText]',
        wrapperWithAlt: 'smarthr-ui-Icon-extended smarthr-ui-Icon-withAlt shr-leading-[0]',
    },
});
const wrapperClassNameGenerator = ce({
    base: [
        'smarthr-ui-Icon-extended smarthr-ui-Icon-withText shr-group/iconWrapper shr-inline-flex shr-items-baseline',
    ],
    variants: {
        gap: {
            0: 'shr-gap-x-0',
            0.25: 'shr-gap-x-0.25',
            0.5: 'shr-gap-x-0.5',
            0.75: 'shr-gap-x-0.75',
            1: 'shr-gap-x-1',
            1.25: 'shr-gap-x-1.25',
            1.5: 'shr-gap-x-1.5',
            2: 'shr-gap-x-2',
            2.5: 'shr-gap-x-2.5',
            3: 'shr-gap-x-3',
            3.5: 'shr-gap-x-3.5',
            4: 'shr-gap-x-4',
            8: 'shr-gap-x-8',
            '-0.25': '-shr-gap-x-0.25',
            '-0.5': '-shr-gap-x-0.5',
            '-0.75': '-shr-gap-x-0.75',
            '-1': '-shr-gap-x-1',
            '-1.25': '-shr-gap-x-1.25',
            '-1.5': '-shr-gap-x-1.5',
            '-2': '-shr-gap-x-2',
            '-2.5': '-shr-gap-x-2.5',
            '-3': '-shr-gap-x-3',
            '-3.5': '-shr-gap-x-3.5',
            '-4': '-shr-gap-x-4',
            '-8': '-shr-gap-x-8',
            X3S: 'shr-gap-x-0.25',
            XXS: 'shr-gap-x-0.5',
            XS: 'shr-gap-x-1',
            S: 'shr-gap-x-1.5',
            M: 'shr-gap-x-2',
            L: 'shr-gap-x-2.5',
            XL: 'shr-gap-x-3',
            XXL: 'shr-gap-x-3.5',
            X3L: 'shr-gap-x-4',
        },
    },
});
const generateIcon = (SvgIcon) => {
    const Icon = memo(({ color, className, role = 'img', alt, 'aria-hidden': ariaHidden, 'aria-label': ariaLabel, 'aria-labelledby': ariaLabelledby, focusable = false, text, iconGap = 0.25, right, size, ...props }) => {
        const actualAriaHidden = useMemo(() => {
            if (ariaHidden !== undefined) {
                return ariaHidden;
            }
            if (alt !== undefined || (ariaLabel === undefined && ariaLabelledby === undefined)) {
                return true;
            }
            return undefined;
        }, [ariaHidden, alt, ariaLabel, ariaLabelledby]);
        const classNames = useMemo(() => {
            const { icon, wrapperWithAlt } = classNameGenerator();
            return {
                icon: icon({ className }),
                wrapperWithAlt: wrapperWithAlt(),
            };
        }, [className]);
        const wrapperClassName = useMemo(() => wrapperClassNameGenerator({ gap: iconGap }), [iconGap]);
        const replacedColor = useMemo(() => {
            if (color && existsColor(color)) {
                const colorName = colorSet[color];
                if (colorName in textColor) {
                    return textColor[colorName];
                }
                return colors[colorName];
            }
            return color;
        }, [color]);
        const iconSize = size ? fontSize[fontSizeMap[size]] : '1em'; // 指定がない場合は親要素のフォントサイズを継承する
        const svgIcon = (jsx(SvgIcon, { ...props, stroke: "currentColor", fill: "currentColor", strokeWidth: "0", 
            // size は react-icons のアイコンの大きさ、width / height は自前で SVG からアイコンを作る場合の大きさ指定
            size: iconSize, width: iconSize, height: iconSize, color: replacedColor, className: classNames.icon, role: role, "aria-hidden": actualAriaHidden, "aria-label": ariaLabel, "aria-labelledby": ariaLabelledby, focusable: focusable }));
        const visuallyHiddenAlt = alt && jsx(VisuallyHiddenText, { children: alt });
        if (text) {
            return (jsxs("span", { className: wrapperClassName, children: [right && text, visuallyHiddenAlt, svgIcon, !right && text] }));
        }
        if (visuallyHiddenAlt) {
            return (
            // HINT: visuallyが存在すると、アイコンなのに2つの要素がある状態になってしまい
            // styleなどを記述する際、意図しない状態になる場合がある
            // 回避するため、spanでラップし、開発者のメンタルモデルに合わせる
            jsxs("span", { className: classNames.wrapperWithAlt, children: [visuallyHiddenAlt, svgIcon] }));
        }
        return svgIcon;
    });
    Icon.displayName = SvgIcon.name;
    return Icon;
};

export { colorSet, generateIcon };
//# sourceMappingURL=generateIcon.js.map
