"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useState, useId, useEffect, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../hooks/useDecorators.js';
import '../../intl/IntlProvider.js';
import { useIntl } from '../../intl/useIntl.js';
import 'react-intl';
import { Base } from '../Base/Base.js';
import '../Base/BaseColumn/BaseColumn.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { Heading } from '../Heading/Heading.js';
import { FaCaretUpIcon, FaCaretDownIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import '../Layout/Stack/Stack.js';
import '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import { Sidebar } from '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { ResponseMessage } from '../ResponseMessage/ResponseMessage.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-InformationPanel shr-shadow-layer-3',
        header: 'shr-p-1.5',
        heading: 'smarthr-ui-InformationPanel-title',
        togglableButton: 'smarthr-ui-InformationPanel-closeButton -shr-my-0.5 shr-ms-auto',
        content: [
            'smarthr-ui-InformationPanel-content',
            'shr-p-1.5 shr-pt-0 shr-text-base aria-hidden:shr-hidden',
        ],
    },
    variants: {
        type: {
            success: {},
            info: {},
            warning: {},
            error: {},
            sync: {},
        },
        active: {
            true: {},
            false: {
                header: 'shr-py-1',
            },
        },
        bold: {
            true: {
                header: 'shr-py-1',
                content: 'shr-pt-1',
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            type: ['success', 'warning', 'error'],
            bold: true,
            className: {
                header: 'shr-text-white',
                heading: '[&_.smarthr-ui-Icon]:shr-fill-white',
            },
        },
        {
            type: 'success',
            bold: true,
            className: {
                header: 'shr-bg-main',
            },
        },
        {
            type: 'warning',
            bold: true,
            className: {
                header: 'shr-bg-warning-yellow shr-text-black',
                heading: [
                    '[&_.smarthr-ui-WarningIcon-wrapper]:shr-fill-black',
                    '[&_.smarthr-ui-WarningIcon-mark]:shr-fill-warning-yellow',
                ],
            },
        },
        {
            type: 'error',
            bold: true,
            className: {
                header: 'shr-bg-danger',
            },
        },
    ],
});
const InformationPanel = ({ title, titleTag, type = 'info', togglable, active: activeProps = true, bold, className, children, onClickTrigger, decorators, ...props }) => {
    const [active, setActive] = useState(activeProps);
    const id = useId();
    const titleId = `${id}-title`;
    const contentId = `${id}-content`;
    useEffect(() => {
        setActive(activeProps);
    }, [activeProps]);
    const classNamesMapper = useMemo(() => {
        const withActive = classNameGenerator({
            type,
            active: true,
            bold,
        });
        const withInactive = classNameGenerator({
            type,
            active: false,
            bold,
        });
        const wrapperProps = { className };
        return {
            active: {
                wrapper: withActive.wrapper(wrapperProps),
                header: withActive.header(),
                heading: withActive.heading(),
                togglableButton: withActive.togglableButton(),
                content: withActive.content(),
            },
            inactive: {
                wrapper: withInactive.wrapper(wrapperProps),
                header: withInactive.header(),
                heading: withInactive.heading(),
                togglableButton: withInactive.togglableButton(),
                content: withInactive.content(),
            },
        };
    }, [bold, type, className]);
    const classNames = classNamesMapper[active ? 'active' : 'inactive'];
    return (jsxs(Base, { ...props, overflow: "hidden", as: "section", className: classNames.wrapper, children: [jsxs(Sidebar, { align: "baseline", right: true, className: classNames.header, children: [jsx(MemoizedHeading, { tag: titleTag, id: titleId, className: classNames.heading, type: type, children: title }), togglable && (jsx(TogglableButton, { active: active, onClickTrigger: onClickTrigger, setActive: setActive, contentId: contentId, className: classNames.togglableButton, decorators: decorators }))] }), jsx("div", { id: contentId, "aria-hidden": !active, className: classNames.content, children: children })] }));
};
const MemoizedHeading = memo(({ type, children, ...rest }) => (jsx(Heading, { ...rest, type: "blockTitle", children: jsx(ResponseMessage, { type: type, iconGap: 0.5, children: children }) })));
const TogglableButton = ({ active, onClickTrigger, setActive, contentId, className, decorators }) => {
    const { localize } = useIntl();
    const decoratorDefaultTexts = useMemo(() => ({
        openButtonLabel: localize({
            id: 'smarthr-ui/InformationPanel/openButtonLabel',
            defaultText: '開く',
        }),
        closeButtonLabel: localize({
            id: 'smarthr-ui/InformationPanel/closeButtonLabel',
            defaultText: '閉じる',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    const onClick = useMemo(() => (onClickTrigger ? () => onClickTrigger(active) : () => setActive(!active)), [active, onClickTrigger, setActive]);
    return (jsx(Button, { "aria-expanded": active, "aria-controls": contentId, onClick: onClick, suffix: active ? jsx(FaCaretUpIcon, {}) : jsx(FaCaretDownIcon, {}), size: "s", className: className, children: decorated[active ? 'closeButtonLabel' : 'openButtonLabel'] }));
};

export { InformationPanel, classNameGenerator };
//# sourceMappingURL=InformationPanel.js.map
