"use client";
import { jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useState, useImperativeHandle, useCallback, useEffect } from 'react';
import { Input } from '../Input.js';
import { formatCurrency } from './currencyInputHelper.js';

const CurrencyInput = forwardRef(({ onFormatValue, onFocus, onBlur, className = '', ...props }, ref) => {
    const innerRef = useRef(null);
    const [isFocused, setIsFocused] = useState(false);
    useImperativeHandle(ref, () => innerRef.current);
    const formatValue = useCallback((formatted = '') => {
        if (!innerRef.current || formatted === innerRef.current.value) {
            return;
        }
        innerRef.current.value = formatted;
        if (onFormatValue) {
            onFormatValue(formatted);
        }
    }, [onFormatValue]);
    useEffect(() => {
        if (props.value === undefined && props.defaultValue !== undefined) {
            formatValue(formatCurrency(props.defaultValue));
        }
        // when component did mount
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    useEffect(() => {
        if (!isFocused) {
            if (props.value !== undefined) {
                // for controlled component
                formatValue(formatCurrency(props.value));
            }
            else if (innerRef.current) {
                // for uncontrolled component
                formatValue(formatCurrency(innerRef.current.value));
            }
        }
    }, [isFocused, props.value, formatValue]);
    const handleFocus = useCallback((e) => {
        setIsFocused(true);
        if (innerRef.current) {
            const commaExcluded = innerRef.current.value.replace(/,/g, '');
            formatValue(commaExcluded);
        }
        if (onFocus) {
            onFocus(e);
        }
    }, [formatValue, onFocus]);
    const handleBlur = useCallback((e) => {
        setIsFocused(false);
        if (onBlur) {
            onBlur(e);
        }
    }, [onBlur]);
    return (jsx(Input, { ...props, type: "text", onFocus: handleFocus, onBlur: handleBlur, ref: innerRef, className: `smarthr-ui-CurrencyInput${className ? ` ${className}` : ''}` }));
});

export { CurrencyInput };
//# sourceMappingURL=CurrencyInput.js.map
