"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useImperativeHandle, useMemo, useCallback, useEffect } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { backgroundColor } from '../../themes/tailwind/TailwindConfig.js';

const bgColors = {
    BACKGROUND: 'background',
    COLUMN: 'column',
    BASE_GREY: 'base-grey',
    OVER_BACKGROUND: 'over-background',
    HEAD: 'head',
    BORDER: 'border',
    ACTION_BACKGROUND: 'action-background',
};
const wrapperClassNameGenerator = ce({
    base: [
        'smarthr-ui-Input',
        'shr-border-shorthand shr-box-border shr-inline-flex shr-cursor-text shr-items-center shr-gap-0.5 shr-rounded-m shr-bg-white shr-px-0.5',
        'contrast-more:shr-border-high-contrast',
        'focus-within:shr-focus-indicator',
        'has-[[aria-invalid]]:shr-border-danger',
    ],
    variants: {
        disabled: {
            true: 'shr-pointer-events-none shr-bg-white-darken [&&&]:shr-border-default/50',
        },
        readOnly: {
            true: '[&&&]:shr-border-[theme(backgroundColor.background)] [&&&]:shr-bg-background',
        },
    },
});
const innerClassNameGenerator = ce({
    slots: {
        input: [
            'smarthr-ui-Input-input',
            'shr-inline-block shr-w-full shr-grow shr-border-none shr-bg-transparent shr-py-0.75 shr-text-base shr-leading-none shr-text-black shr-outline-none shr-outline-0',
            'placeholder:shr-text-grey',
            'disabled:shr-text-disabled disabled:shr-opacity-100',
            'shr-h-[theme(fontSize.base)]',
            // HINT: 日付系inputがsafariなどで対応されていないため、input要素内が空白になりフォームが潰れる場合がある
            // マジックナンバーになるが、ほかに適切なプロパティがないため、min-widthで最低幅を指定することで防ぐ
            '[&[type="datetime-local"]]:shr-min-w-[11em] [&[type="month"]]:shr-min-w-[8em] [&[type="time"]]:shr-min-w-[5em]',
        ],
        affix: 'shr-flex shr-shrink-0 shr-items-center shr-text-grey',
    },
    variants: {
        disabled: {
            true: {
                affix: 'shr-text-disabled shr-opacity-100',
            },
        },
    },
});
const Input = forwardRef(({ onFocus, onBlur, autoFocus, prefix, suffix, className, width, disabled, error, readOnly, bgColor, ...props }, ref) => {
    const innerRef = useRef(null);
    useImperativeHandle(ref, () => innerRef.current);
    const handleWheel = useMemo(() => (props.type === 'number' ? disableWheel : undefined), [props.type]);
    const onClickFocus = useCallback(() => innerRef.current?.focus(), []);
    useEffect(() => {
        if (autoFocus && innerRef.current) {
            innerRef.current.focus();
        }
    }, [autoFocus]);
    const wrapperClassName = useMemo(() => wrapperClassNameGenerator({ disabled, readOnly, className }), [disabled, readOnly, className]);
    const wrapperStyle = useMemo(() => {
        const color = bgColor
            ? backgroundColor[bgColors[bgColor]]
            : undefined;
        const maxWidth = typeof width === 'number' ? `${width}px` : width;
        return {
            borderColor: color,
            backgroundColor: color,
            maxWidth,
            width: maxWidth ? '100%' : undefined,
        };
    }, [width, bgColor]);
    const innerClassNames = useMemo(() => {
        const { input, affix } = innerClassNameGenerator({ disabled });
        return {
            input: input(),
            prefix: affix({ className: 'smarthr-ui-Input-prefix' }),
            suffix: affix({ className: 'smarthr-ui-Input-suffix' }),
        };
    }, [disabled]);
    return (jsxs("span", { role: "presentation", onClick: onClickFocus, className: wrapperClassName, style: wrapperStyle, children: [prefix && jsx("span", { className: innerClassNames.prefix, children: prefix }), jsx("input", { ...props, "data-smarthr-ui-input": "true", onFocus: onFocus, onBlur: onBlur, onWheel: handleWheel, disabled: disabled, readOnly: readOnly, ref: innerRef, "aria-invalid": error || undefined, className: innerClassNames.input }), suffix && jsx("span", { className: innerClassNames.suffix, children: suffix })] }));
});
const disableWheel = (e) => {
    // wheel イベントに preventDefault はないため
    if (e.target) {
        e.target.blur();
    }
};

export { Input, bgColors };
//# sourceMappingURL=Input.js.map
