"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useState, useId, useMemo, useRef, useImperativeHandle, useCallback, memo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../hooks/useDecorators.js';
import '../../intl/IntlProvider.js';
import { useIntl } from '../../intl/useIntl.js';
import 'react-intl';
import '../Base/Base.js';
import { BaseColumn } from '../Base/BaseColumn/BaseColumn.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { FaTrashCanIcon, FaFolderOpenIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import { Stack } from '../Layout/Stack/Stack.js';
import '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-InputFile shr-block',
        fileList: ['smarthr-ui-InputFile-fileList', 'shr-list-none shr-self-stretch shr-text-base'],
        fileItem: 'shr-flex shr-items-center',
        inputWrapper: [
            'shr-border-shorthand shr-relative shr-inline-flex shr-rounded-m shr-bg-white shr-font-bold shr-leading-none',
            'contrast-more:shr-border-high-contrast',
            'focus-within:shr-focus-indicator',
            'has-[[aria-invalid]]:shr-border-danger',
        ],
        input: [
            'smarthr-ui-InputFile-input',
            'shr-absolute shr-left-0 shr-top-0 shr-h-full shr-w-full shr-opacity-0',
            'file:shr-h-full file:shr-w-full file:shr-cursor-pointer',
            'file:disabled:shr-cursor-not-allowed',
        ],
        prefix: 'shr-me-0.5 shr-inline-flex',
    },
    variants: {
        size: {
            default: {
                inputWrapper: 'shr-px-1 shr-py-0.75 shr-text-base',
            },
            s: {
                inputWrapper: 'shr-p-0.5 shr-text-sm',
            },
        },
        disabled: {
            true: {
                inputWrapper: 'shr-border-disabled shr-bg-white-darken shr-text-disabled',
            },
            false: {
                inputWrapper: 'hover:shr-border-darken hover:shr-bg-white-darken hover:shr-text-black',
            },
        },
    },
    defaultVariants: {
        size: 'default',
    },
});
const BASE_COLUMN_PADDING = { block: 0.5, inline: 1 };
const InputFile = forwardRef(({ className, size, label, hasFileList = true, onChange, disabled = false, multiple, multiplyAppendable = false, error, decorators, ...props }, ref) => {
    const [files, setFiles] = useState([]);
    const labelId = useId();
    const { localize } = useIntl();
    const decoratorDefaultTexts = useMemo(() => ({
        destroy: localize({
            id: 'smarthr-ui/InputFile/destroy',
            defaultText: '削除',
        }),
    }), [localize]);
    const decorated = useDecorators(decoratorDefaultTexts, decorators);
    const classNames = useMemo(() => {
        const { wrapper, fileList, fileItem, inputWrapper, input, prefix } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            inputWrapper: inputWrapper({ size, disabled }),
            fileList: fileList(),
            fileItem: fileItem(),
            input: input(),
            prefix: prefix(),
        };
    }, [disabled, size, className]);
    // Safari において、input.files への直接代入時に onChange が発火することを防ぐためのフラグ
    const isUpdatingFilesDirectly = useRef(false);
    const inputRef = useRef(null);
    useImperativeHandle(ref, () => inputRef.current);
    const updateInputValue = useCallback((newFiles) => {
        if (!inputRef.current) {
            return;
        }
        const buff = new DataTransfer();
        newFiles.forEach((file) => {
            buff.items.add(file);
        });
        isUpdatingFilesDirectly.current = true;
        inputRef.current.files = buff.files;
        isUpdatingFilesDirectly.current = false;
    }, [inputRef]);
    const updateFiles = useMemo(() => onChange
        ? (newFiles) => {
            onChange(newFiles);
            updateInputValue(newFiles);
            setFiles(newFiles);
        }
        : setFiles, [onChange, updateInputValue]);
    const handleChange = useCallback((e) => {
        // Safari において、input.files への直接代入時はonChangeを発火させない
        if (isUpdatingFilesDirectly.current) {
            return;
        }
        const newFiles = Array.from(e.target.files ?? []);
        if (multiplyAppendable) {
            // multiplyAppendableの場合、すでに選択済みのファイルと結合する
            updateFiles([...files, ...newFiles]);
        }
        else {
            updateFiles(newFiles);
        }
    }, [files, isUpdatingFilesDirectly, updateFiles, multiplyAppendable]);
    const handleDelete = useCallback((e) => {
        if (!inputRef.current) {
            return;
        }
        const index = parseInt(e.currentTarget.value, 10);
        const newFiles = files.filter((_, i) => index !== i);
        updateFiles(newFiles);
    }, [files, inputRef, updateFiles]);
    return (jsxs(Stack, { align: "flex-start", className: classNames.wrapper, children: [!disabled && hasFileList && files.length > 0 && (jsx(BaseColumn, { as: "ul", padding: BASE_COLUMN_PADDING, className: classNames.fileList, children: files.map((file, index) => (jsxs("li", { className: classNames.fileItem, children: [jsx("span", { className: "smarthr-ui-InputFile-fileName", children: file.name }), jsx(Button, { variant: "text", prefix: jsx(FaTrashCanIcon, {}), value: index, onClick: handleDelete, className: "smarthr-ui-InputFile-deleteButton", children: decorated.destroy })] }, index))) })), jsxs("span", { className: classNames.inputWrapper, children: [jsx("input", { ...props, multiple: multiple || multiplyAppendable, "data-smarthr-ui-input": "true", type: "file", onChange: handleChange, disabled: disabled, ref: inputRef, "aria-invalid": error || undefined, "aria-labelledby": labelId, className: classNames.input }), jsx(StyledFaFolderOpenIcon, { className: classNames.prefix }), jsx(LabelRender, { id: labelId, label: label })] })] }));
});
const StyledFaFolderOpenIcon = memo(({ className }) => (jsx("span", { className: className, children: jsx(FaFolderOpenIcon, {}) })));
const LabelRender = memo(({ id, label }) => (jsx("span", { id: id, "aria-hidden": "true", children: label })));

export { InputFile };
//# sourceMappingURL=InputFile.js.map
