"use client";
import { jsx } from 'react/jsx-runtime';
import { forwardRef, useMemo, Children, isValidElement, cloneElement } from 'react';
import { tv as ce } from './../../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useSectionWrapper } from '../../SectioningContent/useSectioningWrapper.js';

const classNameGenerator = ce({
    base: ['shr-flex shr-flex-wrap', 'empty:shr-gap-0'],
    variants: {
        align: {
            start: 'shr-items-start',
            'flex-start': 'shr-items-start',
            end: 'shr-items-end',
            'flex-end': 'shr-items-end',
            center: 'shr-items-center',
            baseline: 'shr-items-baseline',
            stretch: 'shr-items-stretch',
        },
        rowGap: {
            0: 'shr-gap-y-0',
            0.25: 'shr-gap-y-0.25',
            0.5: 'shr-gap-y-0.5',
            0.75: 'shr-gap-y-0.75',
            1: 'shr-gap-y-1',
            1.25: 'shr-gap-y-1.25',
            1.5: 'shr-gap-y-1.5',
            2: 'shr-gap-y-2',
            2.5: 'shr-gap-y-2.5',
            3: 'shr-gap-y-3',
            3.5: 'shr-gap-y-3.5',
            4: 'shr-gap-y-4',
            8: 'shr-gap-y-8',
            X3S: 'shr-gap-y-0.25',
            XXS: 'shr-gap-y-0.5',
            XS: 'shr-gap-y-1',
            S: 'shr-gap-y-1.5',
            M: 'shr-gap-y-2',
            L: 'shr-gap-y-2.5',
            XL: 'shr-gap-y-3',
            XXL: 'shr-gap-y-3.5',
            X3L: 'shr-gap-y-4',
        },
        columnGap: {
            0: 'shr-gap-x-0',
            0.25: 'shr-gap-x-0.25',
            0.5: 'shr-gap-x-0.5',
            0.75: 'shr-gap-x-0.75',
            1: 'shr-gap-x-1',
            1.25: 'shr-gap-x-1.25',
            1.5: 'shr-gap-x-1.5',
            2: 'shr-gap-x-2',
            2.5: 'shr-gap-x-2.5',
            3: 'shr-gap-x-3',
            3.5: 'shr-gap-x-3.5',
            4: 'shr-gap-x-4',
            8: 'shr-gap-x-8',
            X3S: 'shr-gap-x-0.25',
            XXS: 'shr-gap-x-0.5',
            XS: 'shr-gap-x-1',
            S: 'shr-gap-x-1.5',
            M: 'shr-gap-x-2',
            L: 'shr-gap-x-2.5',
            XL: 'shr-gap-x-3',
            XXL: 'shr-gap-x-3.5',
            X3L: 'shr-gap-x-4',
        },
    },
});
const itemClassNameGenerator = ce({
    slots: {
        firstItem: '',
        lastItem: '',
    },
    variants: {
        right: {
            true: {
                firstItem: 'shr-grow-[999] shr-basis-0',
                lastItem: 'shr-grow',
            },
            false: {
                firstItem: 'shr-grow',
                lastItem: 'shr-grow-[999] shr-basis-0',
            },
        },
    },
});
const Sidebar = forwardRef(({ as: Component = 'div', align = 'stretch', contentsMinWidth = '50%', gap = 1, right = false, className, children, ...rest }, ref) => {
    const gaps = useMemo(() => {
        if (gap instanceof Object) {
            return gap;
        }
        return {
            row: gap,
            column: gap,
        };
    }, [gap]);
    const actualClassName = useMemo(() => classNameGenerator({ align, rowGap: gaps.row, columnGap: gaps.column, className }), [align, gaps.row, gaps.column, className]);
    const classNames = useMemo(() => {
        const { firstItem, lastItem } = itemClassNameGenerator({ right });
        return {
            firstItem: firstItem(),
            lastItem: lastItem(),
        };
    }, [right]);
    const styles = useMemo(() => {
        const styleProps = {
            minWidth: contentsMinWidth,
        };
        if (right) {
            return {
                firstItem: styleProps,
                lastItem: undefined,
            };
        }
        return {
            firstItem: undefined,
            lastItem: styleProps,
        };
    }, [contentsMinWidth, right]);
    // tailwindcss で :first-child / :last-child に対して動的な min-height を当てられないため、React で疑似的に処理している
    const maxChildrenIndex = Children.count(children) - 1;
    const styledChildren = Children.map(children, (child, i) => {
        if (isValidElement(child)) {
            const childClassName = child.props.className ?? '';
            if (i === 0) {
                return cloneElement(child, {
                    className: `${classNames.firstItem} ${childClassName}`,
                    style: { ...styles.firstItem, ...child.props.style },
                });
            }
            else if (i === maxChildrenIndex) {
                return cloneElement(child, {
                    className: `${classNames.lastItem} ${childClassName}`,
                    style: { ...styles.lastItem, ...child.props.style },
                });
            }
        }
        return child;
    });
    const Wrapper = useSectionWrapper(Component);
    const body = (jsx(Component, { ...rest, ref: ref, className: actualClassName, children: styledChildren }));
    if (Wrapper) {
        return jsx(Wrapper, { children: body });
    }
    return body;
});

export { Sidebar };
//# sourceMappingURL=Sidebar.js.map
