"use client";
import { jsxs, jsx } from 'react/jsx-runtime';
import { useState, useRef, useEffect, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Tooltip } from '../Tooltip/Tooltip.js';

const classNameGenerator = ce({
    slots: {
        base: 'smarthr-ui-LineClamp shr-relative',
        clampedLine: 'shr-w-full',
        shadowElementWrapper: 'shr-invisible shr-absolute shr-left-0 shr-top-0 shr-h-full shr-w-full shr-overflow-hidden shr-whitespace-normal shr-opacity-0',
        shadowElement: 'shr-absolute shr-left-0 shr-top-0 shr-w-full',
    },
    variants: {
        maxLines: {
            1: {
                clampedLine: 'shr-inline-block shr-w-full shr-overflow-x-clip shr-overflow-ellipsis shr-whitespace-nowrap shr-align-middle',
            },
            2: {
                clampedLine: 'shr-line-clamp-[2]',
            },
            3: {
                clampedLine: 'shr-line-clamp-[3]',
            },
            4: {
                clampedLine: 'shr-line-clamp-[4]',
            },
            5: {
                clampedLine: 'shr-line-clamp-[5]',
            },
            6: {
                clampedLine: 'shr-line-clamp-[6]',
            },
        },
    },
    compoundVariants: [
        {
            maxLines: [2, 3, 4, 5, 6],
            className: {
                // baseがdisplay:-webkit-boxでないと高さ取得用の要素が表示部分と同じ大きさで表示されないバグを回避するため
                base: '[display:-webkit-box]',
            },
        },
    ],
});
const LineClamp = ({ maxLines = 3, children, className, ...rest }) => {
    if (maxLines < 1 || maxLines > 6) {
        throw new Error('"maxLines" は 1 ~ 6 の範囲で指定してください');
    }
    const [isTooltipVisible, setTooltipVisible] = useState(false);
    const ref = useRef(null);
    const shadowRef = useRef(null);
    useEffect(() => {
        const el = ref.current;
        const shadowEl = shadowRef.current;
        // -webkit-line-clamp を使った要素ではel.scrollHeightとel.clientHeightの比較だと
        // フォントの高さの計算が期待と異なり適切な高さが取得できないためshadowElと比較している
        // 参考: https://github.com/kufu/smarthr-ui/pull/4710
        const isMultiLineOverflow = el && shadowEl
            ? shadowEl.clientWidth > el.clientWidth || shadowEl.clientHeight > el.clientHeight
            : false;
        setTooltipVisible(isMultiLineOverflow);
    }, [maxLines, children]);
    const classNames = useMemo(() => {
        const { base, clampedLine, shadowElementWrapper, shadowElement } = classNameGenerator({
            maxLines,
        });
        return {
            base: base({ className }),
            clampedLine: clampedLine(),
            shadowElementWrapper: shadowElementWrapper(),
            shadowElement: shadowElement(),
        };
    }, [maxLines, className]);
    const actualLineClamp = (jsxs("span", { ...rest, className: classNames.base, children: [jsx("span", { ref: ref, className: classNames.clampedLine, children: children }), jsx("span", { "aria-hidden": true, className: classNames.shadowElementWrapper, children: jsx("span", { className: classNames.shadowElement, ref: shadowRef, children: children }) })] }));
    return isTooltipVisible ? (jsx(Tooltip, { message: children, children: actualLineClamp })) : (actualLineClamp);
};

export { LineClamp };
//# sourceMappingURL=LineClamp.js.map
