import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo, Fragment } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import '../../intl/IntlProvider.js';
import 'react-intl';
import { Localizer } from '../../intl/Localizer.js';
import { Base } from '../Base/Base.js';
import '../Base/BaseColumn/BaseColumn.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { FaTriangleExclamationIcon, FaRotateIcon, FaCircleExclamationIcon, FaCircleCheckIcon, FaCircleInfoIcon, FaXmarkIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { WarningIcon } from '../Icon/WarningIcon.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-NotificationBar shr-flex shr-items-baseline shr-justify-between shr-gap-0.5 shr-p-0.75',
        inner: 'shr-flex-grow',
        messageArea: [
            'smarthr-ui-NotificationBar-messageArea',
            'shr-flex shr-grow',
            '[&_.smarthr-ui-Icon-withText]:shr-leading-tight',
        ],
        icon: '',
        actionArea: 'smarthr-ui-NotificationBar-actionArea -shr-my-0.5 shr-shrink-0',
        closeButton: 'smarthr-ui-NotificationBar-closeButton -shr-mb-0.5 -shr-mr-0.5 -shr-mt-0.5 shr-flex-shrink-0 shr-text-black',
    },
    variants: {
        /** 下地 */
        base: {
            none: {},
            base: {
                wrapper: 'shr-py-1 shr-pe-1 shr-ps-1.5',
            },
        },
        /** メッセージの種類 */
        type: {
            info: {
                icon: 'shr-text-grey',
            },
            success: {},
            warning: {
                icon: 'shr-text-black',
            },
            error: {},
            sync: {
                icon: 'shr-text-main',
            },
        },
        /** 強調するかどうか */
        bold: {
            true: '',
            false: '',
        },
        /** スライドインするかどうか */
        animate: {
            true: {
                wrapper: 'shr-animate-[notification-bar-slide-in_0.2s_ease-out]',
            },
        },
    },
    compoundVariants: [
        {
            type: ['info', 'success', 'warning', 'error', 'sync'],
            bold: false,
            className: {
                wrapper: 'shr-bg-white shr-text-black',
            },
        },
        {
            type: 'success',
            bold: false,
            className: {
                icon: 'shr-text-main',
            },
        },
        {
            type: 'error',
            bold: false,
            className: {
                icon: 'shr-text-danger',
            },
        },
        {
            type: ['info', 'sync'],
            bold: true,
            className: {
                wrapper: 'shr-bg-white',
            },
        },
        {
            type: 'success',
            bold: true,
            className: {
                wrapper: 'shr-bg-main shr-text-white',
                icon: 'shr-text-white',
                closeButton: 'shr-text-white hover:[&]:shr-bg-main-darken focus-visible:[&]:shr-bg-main-darken',
            },
        },
        {
            type: 'warning',
            bold: true,
            className: {
                wrapper: 'shr-bg-warning-yellow shr-text-black',
                closeButton: 'shr-text-black hover:[&]:shr-bg-warning-yellow-darken focus-visible:[&]:shr-bg-warning-yellow-darken',
            },
        },
        {
            type: 'error',
            bold: true,
            className: {
                wrapper: 'shr-bg-danger shr-text-white',
                icon: 'shr-text-white',
                closeButton: 'shr-text-white hover:[&]:shr-bg-danger-darken focus-visible:[&]:shr-bg-danger-darken',
            },
        },
    ],
});
const ABSTRACT_ICON_MAPPER = {
    info: FaCircleInfoIcon,
    success: FaCircleCheckIcon,
    error: FaCircleExclamationIcon,
    sync: FaRotateIcon,
};
const ICON_MAPPER = {
    normal: {
        ...ABSTRACT_ICON_MAPPER,
        warning: WarningIcon,
    },
    bold: {
        ...ABSTRACT_ICON_MAPPER,
        warning: FaTriangleExclamationIcon,
    },
};
const ROLE_STATUS_TYPE_REGEX = /^(info|sync)$/;
const NotificationBar = ({ type, bold, animate, message, onClose, children, role, base, layer, className, ...props }) => {
    const actualRole = useMemo(() => {
        if (role) {
            return role;
        }
        return ROLE_STATUS_TYPE_REGEX.test(type) ? 'status' : 'alert';
    }, [role, type]);
    const { WrapBase, baseProps } = useMemo(() => base === 'base'
        ? {
            WrapBase: Base,
            baseProps: {
                layer,
                overflow: 'hidden',
            },
        }
        : {
            WrapBase: Fragment,
            baseProps: {},
        }, [base, layer]);
    const classNames = useMemo(() => {
        const { wrapper, inner, messageArea, icon, actionArea, closeButton } = classNameGenerator({
            type,
            bold: !!bold,
            base: base || 'none',
        });
        return {
            wrapper: wrapper({ animate, className }),
            inner: inner(),
            messageArea: messageArea(),
            icon: icon(),
            actionArea: actionArea(),
            closeButton: closeButton(),
        };
    }, [animate, base, bold, type, className]);
    return (jsx(WrapBase, { ...baseProps, children: jsxs("div", { ...props, className: classNames.wrapper, role: actualRole, children: [jsxs(Cluster, { gap: 1, align: "center", justify: "flex-end", className: classNames.inner, children: [jsx(MessageArea, { message: message, bold: bold, type: type, classNames: classNames }), children && (jsx(Cluster, { align: "center", justify: "flex-end", className: classNames.actionArea, children: children }))] }), jsx(CloseButton, { onClose: onClose, className: classNames.closeButton })] }) }));
};
const MessageArea = memo(({ message, bold, type, classNames }) => {
    const Icon = ICON_MAPPER[bold ? 'bold' : 'normal'][type];
    return (jsx("div", { className: classNames.messageArea, children: jsx(Icon, { text: message, iconGap: 0.5, className: classNames.icon }) }));
});
const CloseButton = memo(({ onClose, className }) => onClose && (jsx(Button, { variant: "text", size: "s", onClick: onClose, className: className, children: jsx(FaXmarkIcon, { alt: jsx(Localizer, { id: "smarthr-ui/NotificationBar/closeButtonIconAlt", defaultText: "\u9589\u3058\u308B" }) }) })));

export { NotificationBar };
//# sourceMappingURL=NotificationBar.js.map
