import { jsxs, jsx } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { range } from '../../libs/lodash.js';
import '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import { Reel } from '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { Nav } from '../SectioningContent/SectioningContent.js';
import '../SectioningContent/levelContext.js';
import { PaginationControllerItemButton } from './PaginationControllerItemButton.js';
import { PaginationItemButton } from './PaginationItemButton.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-Pagination shr-inline-block shr-max-w-full',
        list: 'shr-m-0.25 shr-list-none shr-ps-[unset]',
        firstListItem: 'smarthr-ui-Pagination-first',
        prevListItem: 'smarthr-ui-Pagination-prev',
        nextListItem: 'smarthr-ui-Pagination-next',
        lastListItem: 'smarthr-ui-Pagination-last',
    },
    variants: {
        withoutNumbers: {
            true: {
                firstListItem: 'shr-mr-0.5',
                prevListItem: 'shr-mr-0',
                nextListItem: 'shr-ml-0',
                lastListItem: 'shr-ml-0.5',
            },
            false: {
                prevListItem: 'shr-mr-0.5',
                nextListItem: 'shr-ml-0.5',
            },
        },
    },
});
const BUTTON_REGEX = /^button$/i;
const ANCHOR_REGEX = /^a/i;
const getTargetDelegateElement = (e, regex) => e.nativeEvent.composedPath().find((elm) => regex.test(elm.tagName));
const Pagination = (props) => props.total > 1 ? jsx(ActualPagination, { ...props }) : null;
const ActualPagination = ({ total, current, onClick, padding, className, withoutNumbers, hrefTemplate, linkAs, ...props }) => {
    const classNames = useMemo(() => {
        const { wrapper, list, firstListItem, prevListItem, nextListItem, lastListItem } = classNameGenerator();
        const itemArg = { withoutNumbers: withoutNumbers || false };
        return {
            wrapper: wrapper({ className }),
            list: list(),
            firstListItem: firstListItem(itemArg),
            prevListItem: prevListItem(itemArg),
            nextListItem: nextListItem(itemArg),
            lastListItem: lastListItem(itemArg),
        };
    }, [className, withoutNumbers]);
    const actualOnClick = useMemo(() => {
        if (!onClick) {
            return undefined;
        }
        if (hrefTemplate) {
            return (e) => {
                const anchor = getTargetDelegateElement(e, ANCHOR_REGEX);
                if (!anchor) {
                    return;
                }
                const href = anchor.href;
                if (href) {
                    onClick(href, e);
                }
            };
        }
        return (e) => {
            const button = getTargetDelegateElement(e, BUTTON_REGEX);
            if (button) {
                onClick(parseInt(button.value, 10), e);
            }
        };
    }, [onClick, hrefTemplate]);
    return (jsx(Nav, { ...props, className: classNames.wrapper, "aria-label": "\u30DA\u30FC\u30B8\u30CD\u30FC\u30B7\u30E7\u30F3", children: jsx(Reel, { onClick: actualOnClick, role: "presentation", children: jsx(ItemButtons, { total: total, current: current, padding: padding, withoutNumbers: withoutNumbers, hrefTemplate: hrefTemplate, classNames: classNames, linkAs: linkAs }) }) }));
};
const ItemButtons = memo(({ total, current, padding, withoutNumbers, hrefTemplate, classNames, linkAs }) => {
    const pageNumbers = useMemo(() => {
        if (withoutNumbers) {
            return [];
        }
        const actualPadding = padding ?? 4;
        return range(Math.max(current - actualPadding, 1), Math.min(current + actualPadding, total) + 1);
    }, [current, total, padding, withoutNumbers]);
    const controllerAttrs = useMemo(() => ({
        prev: {
            disabled: current === 1,
            direction: 'prev',
            hrefTemplate,
            linkAs,
        },
        next: {
            disabled: current === total,
            direction: 'next',
            hrefTemplate,
            linkAs,
        },
    }), [current, total, hrefTemplate, linkAs]);
    return (jsxs(Cluster, { as: "ul", className: classNames.list, children: [jsx(DoubleIconItemButton, { ...controllerAttrs.prev, targetPage: 1, className: classNames.firstListItem }), jsx("li", { className: classNames.prevListItem, children: jsx(PaginationControllerItemButton, { ...controllerAttrs.prev, targetPage: current - 1 }) }), pageNumbers.map((page) => (jsx(NumberItemButton, { page: page, disabled: page === current, hrefTemplate: hrefTemplate, linkAs: linkAs }, page))), jsx("li", { className: classNames.nextListItem, children: jsx(PaginationControllerItemButton, { ...controllerAttrs.next, targetPage: current + 1 }) }), jsx(DoubleIconItemButton, { ...controllerAttrs.next, targetPage: total, className: classNames.lastListItem })] }));
});
const NumberItemButton = memo(({ disabled, ...rest }) => (jsx("li", { className: `smarthr-ui-Pagination-${disabled ? 'current' : 'page'}`, children: jsx(PaginationItemButton, { ...rest, disabled: disabled }) })));
const DoubleIconItemButton = memo(({ className, ...rest }) => (jsx("li", { className: className, children: jsx(PaginationControllerItemButton, { ...rest, double: true }) })));

export { Pagination };
//# sourceMappingURL=Pagination.js.map
