import { jsx } from 'react/jsx-runtime';
import { useMemo } from 'react';
import { Button } from '../Button/Button.js';
import { AnchorButton as ForwardedAnchorButton } from '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';
import { FaChevronRightIcon, FaChevronLeftIcon } from '../Icon/Icon.js';
import { FaAngleDoubleRightIcon, FaAngleDoubleLeftIcon } from '../Icon/DeprecatedIcon.js';
import '../Icon/generateIcon.js';

const ICON_MAPPER = {
    prev: {
        single: { Icon: FaChevronLeftIcon, alt: '前へ' },
        double: { Icon: FaAngleDoubleLeftIcon, alt: '最初へ' },
    },
    next: {
        single: { Icon: FaChevronRightIcon, alt: '次へ' },
        double: { Icon: FaAngleDoubleRightIcon, alt: '最後へ' },
    },
};
const PaginationControllerItemButton = ({ direction, disabled, double, targetPage, hrefTemplate, linkAs, }) => {
    const { Icon, alt } = ICON_MAPPER[direction][double ? 'double' : 'single'];
    const { Component, attrs } = useMemo(() => {
        if (hrefTemplate) {
            return {
                Component: ForwardedAnchorButton,
                // HINT: elementAsにnext/linkを設定した場合、hrefがundefinedでは
                // エラーになってしまうため、undefinedで指定されていない状態にする
                attrs: (disabled
                    ? {
                        href: undefined,
                        elementAs: undefined,
                    }
                    : {
                        href: hrefTemplate(targetPage),
                        elementAs: linkAs,
                    }),
            };
        }
        return {
            Component: Button,
            attrs: {
                disabled,
                value: targetPage,
            },
        };
    }, [targetPage, disabled, hrefTemplate, linkAs]);
    return (jsx(Component, { ...attrs, size: "s", className: "shr-rounded-s", children: jsx(Icon, { color: disabled ? 'TEXT_DISABLED' : 'TEXT_BLACK', alt: alt }) }));
};

export { PaginationControllerItemButton };
//# sourceMappingURL=PaginationControllerItemButton.js.map
