"use client";
import { jsx } from 'react/jsx-runtime';
import { useState, useRef, useMemo, useCallback, useEffect } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Button } from '../Button/Button.js';
import '../Button/AnchorButton.js';
import '../Button/UnstyledButton.js';

const classNameGenerator = ce({
    slots: {
        container: 'smarthr-ui-SegmentedControl shr-inline-flex',
        buttonGroup: '-shr-space-x-px',
        button: [
            'smarthr-ui-SegmentedControl-button',
            'shr-m-0 shr-rounded-none',
            'focus-visible:shr-focus-indicator',
            'first:shr-rounded-bl-m first:shr-rounded-tl-m',
            'last:shr-rounded-br-m last:shr-rounded-tr-m',
        ],
    },
    variants: {
        size: {
            default: {
                button: '[&:has(>_span_>_.smarthr-ui-Icon:only-child)]:shr-p-0.75',
            },
            s: {
                button: 'shr-p-0.5',
            },
        },
    },
});
const SegmentedControl = ({ options, value, onClickOption, size = 'default', className, ...props }) => {
    const [isFocused, setIsFocused] = useState(false);
    const containerRef = useRef(null);
    const classNames = useMemo(() => {
        const { container, buttonGroup, button } = classNameGenerator();
        return {
            container: container({ className }),
            buttonGroup: buttonGroup(),
            button: button({ size }),
        };
    }, [className, size]);
    const onFocus = useCallback(() => setIsFocused(true), []);
    const onBlur = useCallback(() => setIsFocused(false), []);
    useEffect(() => {
        const handleKeyDown = (e) => {
            if (!isFocused || !containerRef.current || !document.activeElement) {
                return;
            }
            const radios = Array.from(containerRef.current.querySelectorAll('[role="radio"]:not(:disabled)'));
            if (radios.length < 2) {
                return;
            }
            const focusedIndex = radios.indexOf(document.activeElement);
            if (focusedIndex === -1) {
                return;
            }
            switch (e.key) {
                case 'Down':
                case 'ArrowDown':
                case 'Right':
                case 'ArrowRight': {
                    const nextIndex = focusedIndex + 1;
                    const nextRadio = radios[nextIndex % radios.length];
                    if (nextRadio instanceof HTMLButtonElement) {
                        nextRadio.focus();
                    }
                    break;
                }
                case 'Up':
                case 'ArrowUp':
                case 'Left':
                case 'ArrowLeft': {
                    const nextIndex = focusedIndex - 1;
                    const nextRadio = radios[(nextIndex + radios.length) % radios.length];
                    if (nextRadio instanceof HTMLButtonElement) {
                        nextRadio.focus();
                    }
                    break;
                }
            }
        };
        document.addEventListener('keydown', handleKeyDown);
        return () => {
            document.removeEventListener('keydown', handleKeyDown);
        };
    }, [isFocused]);
    const excludesSelected = useMemo(() => !value || options.every((option) => option.value !== value), [value, options]);
    const actualOnClickOption = useMemo(() => onClickOption
        ? (e) => onClickOption(e.currentTarget.value)
        : undefined, [onClickOption]);
    return (jsx("div", { ...props, className: classNames.container, onFocus: onFocus, onBlur: onBlur, ref: containerRef, role: "toolbar", children: jsx("div", { role: "radiogroup", className: classNames.buttonGroup, children: options.map((option, index) => (jsx(SegmentedControlButton, { option: option, index: index, onClick: actualOnClickOption, size: size, value: value, isFocused: isFocused, excludesSelected: excludesSelected, className: classNames.button }, option.value))) }) }));
};
const SegmentedControlButton = ({ onClick, size, value, option, index, isFocused, excludesSelected, className }) => {
    const attrs = useMemo(() => {
        const checked = value === option.value;
        return {
            checked,
            ariaChecked: checked && !!value,
            variant: checked ? 'primary' : 'secondary',
        };
    }, [value, option.value]);
    const tabIndex = useMemo(() => {
        if (isFocused) {
            return -1;
        }
        if (excludesSelected) {
            return index === 0 ? 0 : -1;
        }
        return attrs.checked ? 0 : -1;
    }, [excludesSelected, isFocused, attrs.checked, index]);
    return (jsx(Button, { value: option.value, disabled: option.disabled, tabIndex: tabIndex, role: "radio", "aria-label": option.ariaLabel, "aria-checked": attrs.ariaChecked, onClick: onClick, variant: attrs.variant, size: size, className: className, children: option.content }));
};

export { SegmentedControl };
//# sourceMappingURL=SegmentedControl.js.map
