import { jsxs, jsx } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { FaCircleExclamationIcon, FaTriangleExclamationIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';

const classNameGenerator = ce({
    base: [
        'smarthr-ui-StatusLabel',
        'shr-border-shorthand shr-box-content shr-inline-flex shr-min-h-em shr-min-w-[3.5em] shr-items-center shr-justify-center shr-gap-0.25 shr-whitespace-nowrap shr-border-current shr-bg-white shr-px-0.5 shr-py-0.25 shr-text-sm shr-font-bold',
        // ラベルが天地中央に揃わないため暫定対応
        'shr-leading-[0]',
    ],
    variants: {
        type: {
            grey: ['shr-border-grey-20 shr-text-grey', 'contrast-more:shr-border-high-contrast'],
            blue: 'shr-text-main',
            /* SmartHR 基本色の Aqua04。StatusLabel 以外では使いません。
             * https://smarthr.design/basics/colors/#h4-1 */
            green: 'shr-text-green',
            red: 'shr-text-danger',
            warning: 'shr-border-warning-yellow shr-bg-warning-yellow shr-text-black',
            error: 'shr-border-danger shr-bg-danger shr-text-white',
        },
        bold: {
            true: 'shr-text-white',
        },
    },
    compoundVariants: [
        {
            type: 'grey',
            bold: true,
            class: 'shr-border-grey-65 shr-bg-[theme(colors.grey.65)]',
        },
        {
            type: 'blue',
            bold: true,
            class: 'shr-border-main shr-bg-main',
        },
        {
            type: 'green',
            bold: true,
            /* SmartHR 基本色の Aqua04。StatusLabel 以外では使いません。
             * https://smarthr.design/basics/colors/#h4-1 */
            class: 'shr-border-green shr-bg-green',
        },
        {
            type: 'red',
            bold: true,
            class: 'shr-border-danger shr-bg-danger',
        },
        {
            type: 'warning',
            bold: true,
            class: 'shr-border-current shr-text-black',
        },
    ],
});
const StatusLabel = memo(({ type = 'grey', bold = false, className, children, ...props }) => {
    const actualClassName = useMemo(() => classNameGenerator({
        className,
        type,
        bold,
    }), [type, bold, className]);
    return (jsxs("span", { ...props, className: actualClassName, children: [jsx(Icon, { type: type, bold: bold }), children] }));
});
const Icon = ({ type, bold }) => {
    if (bold) {
        switch (type) {
            case 'warning':
                return jsx(FaTriangleExclamationIcon, {});
            case 'error':
                return jsx(FaCircleExclamationIcon, {});
        }
    }
    return null;
};

export { StatusLabel, classNameGenerator };
//# sourceMappingURL=StatusLabel.js.map
