import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Text } from '../Text/Text.js';
import { StepCounter } from './StepCounter.js';

const classNameGenerator = ce({
    slots: {
        wrapper: [
            'shr-group/stepItem',
            // 長いステップ名が来ても等幅にする
            'shr-flex-1',
        ],
        labelWrapper: 'shr-flex shr-flex-col shr-items-center shr-gap-0.5',
        stepCounterWrapper: 'shr-flex shr-items-center shr-self-stretch',
        beforeLine: [
            'group-first/stepItem:shr-bg-transparent',
            'shr-h-[theme(borderWidth.2)] shr-grow shr-bg-border',
            'forced-colors:shr-bg-[ButtonBorder]',
        ],
        afterLine: [
            'group-last/stepItem:shr-bg-transparent',
            // compoundSlots で書けるが、variants の上書きが複雑になるため切り出していない
            'shr-h-[theme(borderWidth.2)] shr-grow shr-bg-border',
            'forced-colors:shr-bg-[ButtonBorder]',
        ],
        label: 'shr-px-0.25 shr-text-center shr-text-sm',
    },
    variants: {
        status: {
            completed: {
                afterLine: ['shr-bg-main', 'forced-colors:shr-bg-[Highlight]'],
            },
            closed: {},
        },
        current: {
            true: {
                label: 'shr-font-bold',
            },
            false: {},
        },
        isPrevStepCompleted: {
            true: {
                beforeLine: ['shr-bg-main', 'forced-colors:shr-bg-[Highlight]'],
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            status: ['completed', 'closed'],
            current: false,
            className: {
                label: 'shr-text-grey',
            },
        },
    ],
});
const HorizontalStepItem = memo(({ stepNumber, label, status, current, isPrevStepCompleted }) => {
    const classNames = useMemo(() => {
        const { wrapper, labelWrapper, stepCounterWrapper, beforeLine, afterLine, label: labelText, } = classNameGenerator({
            status: typeof status === 'object' ? status.type : status,
            current,
            isPrevStepCompleted,
        });
        return {
            wrapper: wrapper(),
            labelWrapper: labelWrapper(),
            stepCounterWrapper: stepCounterWrapper(),
            beforeLine: beforeLine(),
            afterLine: afterLine(),
            label: labelText(),
        };
    }, [current, isPrevStepCompleted, status]);
    return (jsx("li", { "aria-current": current ? 'step' : undefined, className: classNames.wrapper, children: jsxs("div", { className: classNames.labelWrapper, children: [jsxs("div", { className: classNames.stepCounterWrapper, children: [jsx("span", { className: classNames.beforeLine }), jsx(StepCounter, { status: status, current: current, stepNumber: stepNumber }), jsx("span", { className: classNames.afterLine })] }), jsx(Text, { styleType: "sectionTitle", className: classNames.label, children: label })] }) }));
});

export { HorizontalStepItem };
//# sourceMappingURL=HorizontalStepItem.js.map
