import { jsx, jsxs } from 'react/jsx-runtime';
import { useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Heading } from '../Heading/Heading.js';
import { Section } from '../SectioningContent/SectioningContent.js';
import { StepCounter } from './StepCounter.js';

const classNameGenerator = ce({
    slots: {
        wrapper: 'shr-group/stepItem',
        section: 'shr-flex shr-gap-1',
        // StepCounterの中心に揃えるため、0.25remとborder分の1px paddingを追加している
        headingWrapper: 'shr-flex shr-items-center shr-gap-1 shr-py-[calc(0.25rem_+_1px)]',
        heading: 'shr-inline-block',
        body: [
            // (stepCounter + :after) + (body > inner) という構造
            'shr-flex shr-grow shr-flex-col',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
        inner: 'shr-grow shr-pb-1.5 shr-pt-0.5',
        stepCounter: [
            // stepCounter の after 疑似要素がステップを繋ぐ線
            'after:shr-relative after:shr-mx-1 after:shr-block after:shr-h-full after:shr-w-[theme(borderWidth.2)] after:shr-bg-border after:shr-content-[""]',
            // 最後のステップの線を消す
            'group-last/stepItem:after:shr-bg-transparent',
        ],
    },
    variants: {
        status: {
            completed: {
                stepCounter: ['after:shr-bg-main', 'forced-colors:after:shr-bg-[Highlight]'],
            },
            closed: {},
        },
        current: {
            true: {
                heading: 'shr-font-bold',
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            status: ['completed', 'closed'],
            current: false,
            className: {
                heading: 'shr-text-grey',
            },
        },
    ],
});
const VerticalStepItem = ({ stepNumber, label, status, children, current }) => {
    const classNames = useMemo(() => {
        const { wrapper, section, headingWrapper, heading, body, inner, stepCounter } = classNameGenerator({
            status: typeof status === 'object' ? status.type : status,
            current,
        });
        return {
            wrapper: wrapper(),
            section: section(),
            headingWrapper: headingWrapper(),
            heading: heading(),
            body: body(),
            inner: inner(),
            stepCounter: stepCounter(),
        };
    }, [current, status]);
    return (jsx("li", { "aria-current": current ? 'step' : undefined, className: classNames.wrapper, children: jsxs(Section, { className: classNames.section, children: [jsx("div", { className: classNames.stepCounter, children: jsx(StepCounter, { status: status, current: current, stepNumber: stepNumber }) }), jsxs("div", { className: classNames.body, children: [jsx("div", { className: classNames.headingWrapper, children: jsx(Heading, { type: "sectionTitle", className: classNames.heading, children: label }) }), jsx("div", { className: classNames.inner, children: children })] })] }) }));
};

export { VerticalStepItem };
//# sourceMappingURL=VerticalStepItem.js.map
