import { jsxs, jsx } from 'react/jsx-runtime';
import { forwardRef, useId, useMemo, memo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { FaCheckIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { Text } from '../Text/Text.js';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';

const classNameGenerator = ce({
    slots: {
        wrapper: [
            // Switch 本体
            'shr-border-shorthand shr-relative shr-inline-flex shr-h-fit shr-w-[calc(theme(fontSize.base)*2)] shr-items-center shr-rounded-full shr-bg-white',
            // 理想的には padding: 2px; だが、box-shadow を outline で使用しているため、border と padding で2pxの疑似余白を作っている。
            'shr-p-px',
            // :focus-visible-within の代替, なぜかhasが機能しないので以下の書き方で代用している
            'has-[:focus-visible]:shr-focus-indicator [&:has(:focus-visible)]:shr-focus-indicator',
            'has-[:checked]:shr-border-[theme(colors.main)] has-[:checked]:shr-bg-main',
            'has-[:disabled]:shr-border-[theme(borderColor.default)] has-[:disabled]:shr-bg-border',
            'forced-colors:has-[:disabled]:shr-border-[GrayText]',
            'supports-[not_selector(:has(+_*))]:shr-border-[revert] supports-[not_selector(:has(+_*))]:shr-bg-[revert]',
            // Switch ツマミ
            'before:shr-box-border before:shr-inline-block before:shr-size-[theme(fontSize.base)] before:shr-scale-[calc(2/3)] before:shr-rounded-full before:shr-border before:shr-border-solid before:shr-border-[theme(textColor.grey)] before:shr-bg-[theme(textColor.grey)] before:shr-transition-[transform,margin] before:shr-duration-150 before:shr-ease-out before:shr-content-[""]',
            'has-[input:disabled:not(:checked)]:before:shr-border-[theme(textColor.disabled)] has-[input:disabled:not(:checked)]:before:shr-bg-[theme(textColor.disabled)]',
            'has-[:checked]:before:shr-border-shorthand has-[:checked]:before:shr-ms-[theme(fontSize.base)] has-[:checked]:before:shr-scale-100 has-[:checked]:before:shr-bg-white',
            'forced-colors:has-[input:not(:disabled)]:before:shr-bg-[ButtonBorder]',
            'forced-colors:has-[:disabled:not(:checked)]:before:shr-border-solid forced-colors:has-[:disabled:not(:checked)]:before:shr-border-[GrayText]',
            'forced-colors:has-[:disabled:checked]:before:shr-border-[GrayText]',
            'supports-[not_selector(:has(+_*))]:before:hidden',
        ],
        input: [
            'shr-absolute shr-inset-0 shr-m-0 shr-h-full shr-w-full shr-cursor-pointer shr-appearance-none shr-rounded-full shr-opacity-0',
            'disabled:shr-cursor-[revert]',
            'supports-[not_selector(:has(+_*))]:shr-static supports-[not_selector(:has(+_*))]:shr-appearance-auto supports-[not_selector(:has(+_*))]:shr-opacity-100 supports-[not_selector(:has(+_*))]:shr-outline-[revert]',
        ],
        iconWrapper: [
            'smarthr-ui-Switch-iconWrapper',
            'shr-pointer-events-none shr-absolute shr-hidden shr-size-[theme(fontSize.base)] shr-items-center shr-justify-center',
            '[:checked~&]:shr-flex',
        ],
        icon: [
            'shr-fill-white',
            'forced-colors:shr-fill-[ButtonText]',
            'forced-colors:[:disabled~.smarthr-ui-Switch-iconWrapper_&]:shr-fill-[GrayText]',
        ],
    },
});
const Switch = forwardRef(({ children, dangerouslyLabelHidden, className, id, ...props }, ref) => {
    const defaultId = useId();
    const inputId = id || defaultId;
    const classNames = useMemo(() => {
        const { wrapper, input, icon, iconWrapper } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            input: input(),
            icon: icon(),
            iconWrapper: iconWrapper(),
        };
    }, [className]);
    return (jsxs(Cluster, { align: "center", children: [jsx(MemoizedLabel, { htmlFor: inputId, dangerouslyLabelHidden: dangerouslyLabelHidden, children: children }), jsxs("span", { className: classNames.wrapper, children: [jsx("input", { ...props, type: "checkbox", role: "switch", id: inputId, className: classNames.input, ref: ref }), jsx(MemoizedSuffixIcon, { className: classNames.iconWrapper, iconClassName: classNames.icon })] })] }));
});
const MemoizedLabel = memo(({ dangerouslyLabelHidden, htmlFor, children }) => {
    const Component = dangerouslyLabelHidden ? VisuallyHiddenText : Text;
    return (jsx(Component, { as: "label", htmlFor: htmlFor, children: children }));
});
const MemoizedSuffixIcon = memo(({ className, iconClassName }) => (jsx("span", { className: className, children: jsx(FaCheckIcon, { className: iconClassName, size: "XXS" }) })));

export { Switch };
//# sourceMappingURL=Switch.js.map
