import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo, useCallback } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { isTouchDevice } from '../../libs/ua.js';
import '../Button/Button.js';
import '../Button/AnchorButton.js';
import { UnstyledButton } from '../Button/UnstyledButton.js';
import { FaCircleInfoIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import { Tooltip } from '../Tooltip/Tooltip.js';

const classNameGenerator = ce({
    slots: {
        wrapper: [
            'smarthr-ui-TabItem',
            'shr-group/tabitem',
            'shr-relative shr-inline-flex shr-items-center shr-gap-0.5 shr-px-1 shr-py-0.75',
            'hover:shr-bg-white-darken',
            'focus-visible:shr-focus-indicator--inner focus-visible:shr-z-1',
            'disabled:shr-cursor-not-allowed disabled:shr-bg-transparent',
            'aria-selected:before:shr-absolute aria-selected:before:shr-inset-x-0 aria-selected:before:shr-bottom-0 aria-selected:before:shr-z-1 aria-selected:before:shr-block aria-selected:before:shr-h-0.25 aria-selected:before:shr-bg-main aria-selected:before:shr-content-[""]',
            'forced-colors:aria-selected:before:shr-bg-[Highlight]',
        ],
        label: [
            'shr-font-bold shr-leading-none shr-text-grey',
            'group-hover/tabitem:shr-text-black',
            'group-disabled/tabitem:shr-text-grey/50',
            'group-aria-selected/tabitem:shr-text-black',
        ],
        suffixWrapper: [
            // Badge など内包要素に依って高さが変わらないようにするため、ネガティブマージンを指定
            '-shr-my-0.25',
            // 内包アイコンの leading を詰める
            '[&_.smarthr-ui-Icon]:shr-block',
        ],
    },
    variants: {
        isTouchDevice: {
            false: {
                wrapper: 'shr-transition-colors',
            },
        },
    },
});
const TabItem = ({ selected = false, disabledDetail, ...rest }) => {
    const tabAttrs = {
        role: 'tab',
        'aria-selected': selected,
    };
    if (rest.disabled && disabledDetail) {
        const Icon = disabledDetail.icon || jsx(FaCircleInfoIcon, { color: "TEXT_GREY" });
        return (jsx(Tooltip, { ...tabAttrs, message: disabledDetail.message, ariaDescribedbyTarget: "inner", "aria-disabled": rest.disabled, className: "focus-visible:shr-focus-indicator--inner", children: jsx(TabButton, { ...rest, suffix: Icon }) }));
    }
    return jsx(TabButton, { ...rest, ...tabAttrs });
};
const TabButton = ({ id, children, suffix, onClick, className, ...rest }) => {
    const classNames = useMemo(() => {
        const { wrapper, label, suffixWrapper } = classNameGenerator({ isTouchDevice });
        return {
            wrapper: wrapper({ className }),
            label: label(),
            suffixWrapper: suffixWrapper(),
        };
    }, [className]);
    const actualOnClick = useCallback((e) => onClick(e.currentTarget.value), [onClick]);
    return (jsxs(UnstyledButton, { ...rest, type: "button", value: id, id: id, className: classNames.wrapper, onClick: actualOnClick, children: [jsx(TabLabel, { className: classNames.label, children: children }), jsx(TabButtonSuffix, { className: classNames.suffixWrapper, children: suffix })] }));
};
const TabLabel = memo(({ children, className }) => (jsx("span", { className: className, children: children })));
const TabButtonSuffix = memo(({ children, className }) => children && jsx("span", { className: className, children: children }));

export { TabItem };
//# sourceMappingURL=TabItem.js.map
