import { jsx } from 'react/jsx-runtime';
import { useMemo, Fragment } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Base } from '../Base/Base.js';
import '../Base/BaseColumn/BaseColumn.js';
import { TableReel } from './TableReel.js';

const classNameGenerator = ce({
    slots: {
        wrapper: '',
        table: [
            'smarthr-ui-Table',
            'shr-w-full shr-border-collapse',
            '[&_tbody]:shr-bg-white',
            '[&_th]:contrast-more:shr-border-shorthand [&_th]:shr-bg-head [&_th]:contrast-more:shr-border-high-contrast',
            '[&_td]:contrast-more:shr-border-shorthand [&_td]:contrast-more:shr-border-high-contrast',
            'contrast-more:shr-border-shorthand contrast-more:shr-border-high-contrast',
        ],
    },
    variants: {
        borderType: {
            vertical: {},
            horizontal: {},
            both: {},
            outer: {
                table: 'shr-border-shorthand',
            },
            all: {
                table: 'shr-border-shorthand',
            },
        },
        borderStyle: {
            solid: {
                table: '[&_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-solid',
            },
            dotted: {
                table: '[&_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-dotted',
            },
            dashed: {
                table: '[&_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-dashed',
            },
        },
        rounded: {
            true: {},
        },
        layout: {
            auto: {},
            fixed: {
                table: 'shr-table-fixed',
            },
        },
        fixedHead: {
            true: {
                table: '[&_tbody]:shr-relative [&_tbody]:shr-z-1 [&_thead]:shr-sticky [&_thead]:shr-start-0 [&_thead]:shr-top-0 [&_thead]:shr-z-[2]',
            },
        },
    },
    compoundVariants: [
        {
            // rounded のとき Wrapper である Base に装飾するため、Table には装飾しない
            borderType: ['outer', 'all'],
            rounded: true,
            className: {
                table: 'shr-border-none',
                wrapper: 'shr-border-shorthand',
            },
        },
        {
            borderType: ['vertical', 'both', 'all'],
            className: {
                table: [
                    '[&_:is(.smarthr-ui-Th:not(:first-child),.smarthr-ui-Td:not(:first-child))]:shr-border-l',
                    '[&_:is(.smarthr-ui-Th:not(:first-child),.smarthr-ui-Td:not(:first-child))]:shr-border-l-default',
                ],
            },
        },
        {
            borderType: ['horizontal', 'both', 'all'],
            className: {
                table: [
                    // thead がある場合は、thead 配下以外の th と td に border-t を適用
                    [
                        '[&:has(thead)_tr:not(:where(thead_tr))_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-t',
                        '[&:has(thead)_tr:not(:where(thead_tr))_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-t-default',
                    ],
                    // thead がない場合は、最初以外の tr 配下の th と td に border-t を適用
                    [
                        '[&:not(:has(thead))_tr:not(:first-of-type)_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-t',
                        '[&:not(:has(thead))_tr:not(:first-of-type)_:is(.smarthr-ui-Th,.smarthr-ui-Td)]:shr-border-t-default',
                    ],
                ],
            },
        },
    ],
    defaultVariants: {
        borderType: 'horizontal',
        borderStyle: 'solid',
        layout: 'auto',
        fixedHead: false,
    },
});
const Table = ({ borderType, borderStyle, fixedHead, layout, rounded, className, ...rest }) => {
    const classNames = useMemo(() => {
        const { table, wrapper } = classNameGenerator({
            borderType,
            borderStyle,
            fixedHead,
            layout,
            rounded,
            className,
        });
        return { table: table({ className }), wrapper: wrapper() };
    }, [borderType, borderStyle, className, fixedHead, layout, rounded]);
    const [Wrapper, wrapperProps] = useMemo(() => (rounded ? [RoundedWrapper, { className: classNames.wrapper }] : [Fragment]), [rounded, classNames.wrapper]);
    return (jsx(Wrapper, { ...wrapperProps, children: jsx("table", { ...rest, className: classNames.table }) }));
};
const RoundedWrapper = ({ children, className }) => (jsx(Base, { className: className, overflow: "hidden", layer: 0, children: jsx(TableReel, { children: children }) }));

export { Table };
//# sourceMappingURL=Table.js.map
