"use client";
import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import { forwardRef, useId, useRef, useState, useCallback, useMemo, useImperativeHandle, startTransition, useEffect } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../hooks/useDecorators.js';
import { debounce } from '../../libs/debounce.js';
import { lineHeight } from '../../themes/tailwind/TailwindConfig.js';
import { defaultHtmlFontSize } from '../../themes/createFontSize.js';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';

const getStringLength = (value) => {
    const formattedValue = typeof value === 'number' || typeof value === 'string'
        ? `${value}`
        : Array.isArray(value)
            ? value.join(',')
            : '';
    // https://developer.mozilla.org/ja/docs/Web/JavaScript/Reference/Global_Objects/String/charCodeAt
    const surrogatePairs = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g;
    return formattedValue.length - (formattedValue.match(surrogatePairs) || []).length;
};
const DECORATOR_DEFAULT_TEXTS = {
    beforeMaxLettersCount: 'あと',
    afterMaxLettersCount: '文字',
    afterMaxLettersCountExceeded: 'オーバー',
    beforeScreenReaderMaxLettersDescription: '最大',
    afterScreenReaderMaxLettersDescription: '文字入力できます',
};
const classNameGenerator = ce({
    slots: {
        textareaEl: [
            'smarthr-ui-Textarea-textarea',
            'shr-border-shorthand shr-my-[unset] shr-box-border shr-rounded-m shr-bg-white shr-p-0.5 shr-text-base shr-leading-normal shr-text-black shr-opacity-100',
            'contrast-more:shr-border-high-contrast',
            'placeholder:shr-text-grey',
            'focus-visible:shr-focus-indicator',
            'disabled:shr-pointer-events-none disabled:shr-bg-column disabled:shr-text-disabled disabled:placeholder:shr-text-disabled',
            'aria-[invalid]:shr-border-danger',
        ],
        counter: 'smarthr-ui-Textarea-counter shr-block shr-text-sm shr-text-black',
    },
    variants: {
        error: {
            true: {
                counter: 'shr-text-danger',
            },
        },
    },
    defaultVariants: {
        error: false,
    },
});
const calculateIdealRows = (element, maxRows = Number.MAX_SAFE_INTEGER) => {
    if (!element) {
        return 0;
    }
    // 現在の入力値に応じた行数
    const currentInputValueRows = Math.floor(element.scrollHeight / (defaultHtmlFontSize * Number(lineHeight.normal)));
    return currentInputValueRows < maxRows ? currentInputValueRows : maxRows;
};
const Textarea = forwardRef(({ autoFocus, maxLetters, width, className, autoResize = false, maxRows = Infinity, rows = 2, onInput, decorators, error, onChange, value, ...props }, ref) => {
    const maxLettersId = useId();
    const maxLettersNoticeId = `${maxLettersId}-notice`;
    const actualMaxLettersId = maxLetters ? maxLettersId : undefined;
    const textareaRef = useRef(null);
    const currentValue = props.defaultValue || value;
    const [interimRows, setInterimRows] = useState(rows);
    const [count, setCount] = useState(currentValue ? getStringLength(currentValue) : 0);
    const [srCounterMessage, setSrCounterMessage] = useState('');
    const decorated = useDecorators(DECORATOR_DEFAULT_TEXTS, decorators);
    const getCounterMessage = useCallback((counterValue) => {
        if (maxLetters === undefined)
            return;
        if (counterValue > maxLetters) {
            // {count}文字オーバー
            return (jsxs(Fragment, { children: [counterValue - maxLetters, decorated.afterMaxLettersCount, decorated.afterMaxLettersCountExceeded] }));
        }
        // あと{count}文字
        return (jsxs(Fragment, { children: [decorated.beforeMaxLettersCount, maxLetters - counterValue, decorated.afterMaxLettersCount] }));
    }, [
        maxLetters,
        decorated.afterMaxLettersCountExceeded,
        decorated.afterMaxLettersCount,
        decorated.beforeMaxLettersCount,
    ]);
    const counterVisualMessage = useMemo(() => getCounterMessage(count), [count, getCounterMessage]);
    useImperativeHandle(ref, () => textareaRef.current);
    const debouncedUpdateCount = useMemo(() => maxLetters
        ? debounce((newValue) => {
            startTransition(() => {
                setCount(getStringLength(newValue));
            });
        }, 200)
        : undefined, [maxLetters]);
    // countが連続で更新されると、スクリーンリーダーが古い値を読み上げてしまうため、メッセージの更新を遅延しています
    const debouncedUpdateSrCounterMessage = useMemo(() => maxLetters
        ? debounce((newValue) => {
            startTransition(() => {
                const counterText = getCounterMessage(getStringLength(newValue));
                if (counterText) {
                    setSrCounterMessage(counterText);
                }
            });
        }, 1000)
        : undefined, [maxLetters, getCounterMessage]);
    const handleChange = useCallback((e) => {
        const newValue = e.target.value;
        debouncedUpdateCount?.(newValue);
        debouncedUpdateSrCounterMessage?.(newValue);
        onChange?.(e);
    }, [onChange, debouncedUpdateCount, debouncedUpdateSrCounterMessage]);
    // autoFocus時に、フォーカスを当てる
    useEffect(() => {
        if (autoFocus && textareaRef && textareaRef.current) {
            textareaRef.current.focus();
        }
    }, [autoFocus]);
    // autoResize時に、初期値での高さを指定
    useEffect(() => {
        if (autoResize && textareaRef.current) {
            setInterimRows(calculateIdealRows(textareaRef.current, maxRows));
        }
    }, [setInterimRows, maxRows, autoResize]);
    // value 変更時にもカウントを更新する
    useEffect(() => {
        if (value && maxLetters) {
            debouncedUpdateCount?.(value);
            debouncedUpdateSrCounterMessage?.(value);
        }
    }, [maxLetters, debouncedUpdateCount, debouncedUpdateSrCounterMessage, value]);
    const handleInput = useCallback((e) => {
        // rowsを初期化 TextareaのscrollHeightが文字列削除時に変更されないため
        e.target.rows = rows;
        if (autoResize) {
            const currentRows = calculateIdealRows(e.target, maxRows);
            // rowsを直接反映 Textareaのrows propsが状態を変更しても反映されないため
            e.target.rows = currentRows;
            setInterimRows(currentRows);
        }
        onInput?.(e);
    }, [autoResize, maxRows, onInput, rows]);
    const textareaStyle = useMemo(() => ({ width: typeof width === 'number' ? `${width}px` : width }), [width]);
    const countError = maxLetters && count > maxLetters;
    const classNames = useMemo(() => {
        const { textareaEl, counter } = classNameGenerator();
        return {
            textarea: textareaEl({ className }),
            counter: counter({ error: !!countError }),
        };
    }, [countError, className]);
    const body = (jsx("textarea", { ...props, ...(maxLetters && { 'aria-describedby': `${maxLettersNoticeId} ${actualMaxLettersId}` }), "data-smarthr-ui-input": "true", value: value, onChange: handleChange, ref: textareaRef, "aria-invalid": error || countError || undefined, rows: interimRows, onInput: handleInput, className: classNames.textarea, style: textareaStyle }));
    return maxLetters ? (jsxs("span", { children: [body, jsxs(VisuallyHiddenText, { id: maxLettersNoticeId, children: [decorated.beforeScreenReaderMaxLettersDescription, maxLetters, decorated.afterScreenReaderMaxLettersDescription] }), jsx(VisuallyHiddenText, { "aria-live": "polite", children: srCounterMessage }), jsx("span", { id: actualMaxLettersId, "aria-hidden": true, className: classNames.counter, children: counterVisualMessage })] })) : (body);
});

export { Textarea };
//# sourceMappingURL=Textarea.js.map
