import { jsxs, jsx } from 'react/jsx-runtime';
import dayjs from '../../_virtual/dayjs.min.js';
import { useMemo, useId } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { Stack } from '../Layout/Stack/Stack.js';
import { Cluster } from '../Layout/Cluster/Cluster.js';
import '../Layout/Reel/Reel.js';
import { Sidebar } from '../Layout/Sidebar/Sidebar.js';
import '../Layout/Center/Center.js';
import { Section } from '../SectioningContent/SectioningContent.js';
import '../SectioningContent/levelContext.js';
import { Text } from '../Text/Text.js';

const classNameGenerator = ce({
    slots: {
        wrapper: [
            'smarthr-ui-TimelineItem',
            // mark(1) + 余白(0.75) の分だけ padding
            'shr-relative shr-pl-[calc(theme(fontSize.sm)+theme(spacing[0.75]))]',
            'has-[+_&]:shr-pb-2',
            // 繋ぎ線: 欠けたりはみ出たりしないように bottom で調整
            'before:shr-absolute before:-shr-bottom-0.75 before:shr-left-[calc((theme(fontSize.sm)/2)-1px)] before:shr-h-full before:shr-w-[2px] before:shr-bg-border',
            // 最後のアイテムには線を引かない
            '[&:not(:last-child)]:before:shr-content-[""]',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
        dateArea: 'shr-grow',
        title: [
            // 日付と中央寄せにしやすくするために mark は title に生やす
            'before:shr-absolute before:shr-left-0 before:shr-size-[theme(fontSize.sm)] before:shr-rounded-full before:shr-bg-border before:shr-content-[""]',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
    },
    variants: {
        current: {
            true: {
                title: [
                    'before:shr-left-[calc(theme(fontSize.sm)-theme(spacing[0.75]))] before:shr-z-1 before:shr-size-0.75 before:shr-bg-main before:shr-shadow-[0_0_0_2px_white,0_0_0_4px_theme(colors.main)]',
                    'forced-colors:before:shr-bg-[Mark]',
                ],
            },
        },
    },
});
const TimelineItem = ({ datetime, dateLabel, timeFormat = 'HH:mm', dateSuffixArea, sideActionArea, children, current, className, ...rest }) => {
    const classNames = useMemo(() => {
        const { wrapper, dateArea, title } = classNameGenerator({
            current: !!current,
        });
        return {
            wrapper: wrapper({ className }),
            dateArea: dateArea(),
            title: title(),
        };
    }, [current, className]);
    const { date, time, isoString } = useMemo(() => {
        const d = dayjs(datetime);
        return {
            date: d.format('YYYY/MM/DD'),
            time: timeFormat !== 'none' && d.format(timeFormat),
            isoString: d.toISOString(),
        };
    }, [datetime, timeFormat]);
    const id = useId();
    return (jsxs(Stack, { ...rest, as: "li", gap: 0.5, "aria-current": current, className: classNames.wrapper, children: [jsxs(Cluster, { align: "center", justify: "space-between", children: [jsxs(Sidebar, { align: "center", gap: 0.5, className: classNames.dateArea, children: [jsxs(Cluster, { align: "center", as: "time", dateTime: isoString, id: id, className: classNames.title, children: [jsx(Text, { styleType: "blockTitle", leading: "NONE", children: dateLabel || date }), time && jsx(Text, { leading: "NONE", children: time })] }), dateSuffixArea && jsx("div", { children: dateSuffixArea })] }), sideActionArea] }), children && (
            // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
            jsx(Section, { "aria-labelledby": id, children: children }))] }));
};

export { TimelineItem };
//# sourceMappingURL=TimelineItem.js.map
