"use client";
import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo, useState, useRef, useId, useSyncExternalStore, useCallback, cloneElement } from 'react';
import { createPortal } from 'react-dom';
import innerText from '../../_virtual/index.js';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useEnhancedEffect } from '../../hooks/useEnhancedEffect.js';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';
import { TooltipPortal } from './TooltipPortal.js';

const subscribeFullscreenChange = (callback) => {
    window.addEventListener('fullscreenchange', callback);
    return () => {
        window.removeEventListener('fullscreenchange', callback);
    };
};
const getFullscreenElement = () => document.fullscreenElement;
const getFullscreenElementOnSSR = () => null;
const classNameGenerator = ce({
    base: [
        'smarthr-ui-Tooltip',
        'shr-inline-block shr-max-w-full shr-align-bottom',
        'focus-visible:shr-focus-indicator',
    ],
    variants: {
        isIcon: {
            true: 'shr-leading-[0]',
        },
    },
});
const Tooltip = ({ message, children, triggerType, ellipsisOnly, tabIndex = 0, ariaDescribedbyTarget = 'wrapper', className, onPointerEnter, onPointerLeave, onTouchStart, onTouchEnd, onFocus, onBlur, ...props }) => {
    const [portalRoot, setPortalRoot] = useState(null);
    const [isVisible, setIsVisible] = useState(false);
    const [rect, setRect] = useState(null);
    const ref = useRef(null);
    const messageId = useId();
    const fullscreenElement = useSyncExternalStore(subscribeFullscreenChange, getFullscreenElement, getFullscreenElementOnSSR);
    useEnhancedEffect(() => {
        setPortalRoot(fullscreenElement ?? document.body);
    }, [fullscreenElement]);
    const toShowAction = useCallback((e) => {
        // Tooltipのtriggerの他の要素(Dropwdown menu buttonで開いたmenu contentとか)に移動されたらtooltipを表示しない
        if (!ref.current?.contains(e.target)) {
            return;
        }
        if (ellipsisOnly) {
            const outerWidth = parseInt(window
                .getComputedStyle(ref.current.parentNode, null)
                .width.match(/\d+/)[0], 10);
            if (outerWidth < 0 || outerWidth > ref.current.clientWidth) {
                return;
            }
        }
        setRect(ref.current.getBoundingClientRect());
        setIsVisible(true);
    }, [ellipsisOnly]);
    const actualOnPointerEnter = useMemo(() => onPointerEnter
        ? (e) => {
            onPointerEnter(e);
            toShowAction(e);
        }
        : toShowAction, [onPointerEnter, toShowAction]);
    const actualOnTouchStart = useMemo(() => onTouchStart
        ? (e) => {
            onTouchStart(e);
            toShowAction(e);
        }
        : toShowAction, [onTouchStart, toShowAction]);
    const actualOnFocus = useMemo(() => onFocus
        ? (e) => {
            onFocus(e);
            toShowAction(e);
        }
        : toShowAction, [onFocus, toShowAction]);
    const toCloseAction = useCallback(() => setIsVisible(false), []);
    const actualOnPointerLeave = useMemo(() => onPointerLeave
        ? (e) => {
            onPointerLeave(e);
            toCloseAction();
        }
        : toCloseAction, [onPointerLeave, toCloseAction]);
    const actualOnTouchEnd = useMemo(() => onTouchEnd
        ? (e) => {
            onTouchEnd(e);
            toCloseAction();
        }
        : toCloseAction, [onTouchEnd, toCloseAction]);
    const actualOnBlur = useMemo(() => onBlur
        ? (e) => {
            onBlur(e);
            toCloseAction();
        }
        : toCloseAction, [onBlur, toCloseAction]);
    const isIcon = triggerType === 'icon';
    const actualClassName = useMemo(() => classNameGenerator({ isIcon, className }), [isIcon, className]);
    const isInnerTarget = ariaDescribedbyTarget === 'inner';
    const childrenWithProps = useMemo(() => isInnerTarget
        ? cloneElement(children, { 'aria-describedby': messageId })
        : children, [children, isInnerTarget, messageId]);
    return (
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions,smarthr/a11y-delegate-element-has-role-presentation
    jsxs("span", { ...props, ref: ref, tabIndex: tabIndex, "aria-describedby": isInnerTarget ? undefined : messageId, onPointerEnter: actualOnPointerEnter, onTouchStart: actualOnTouchStart, onFocus: actualOnFocus, onPointerLeave: actualOnPointerLeave, onTouchEnd: actualOnTouchEnd, onBlur: actualOnBlur, className: actualClassName, children: [portalRoot &&
                createPortal(jsx(TooltipPortal, { message: message, isVisible: isVisible, parentRect: rect, isIcon: isIcon }), portalRoot), childrenWithProps, jsx(MemoizedVisuallyHiddenText, { id: messageId, visible: isVisible, children: message })] }));
};
const MemoizedVisuallyHiddenText = memo(({ id, visible, children }) => {
    const hiddenText = useMemo(() => innerText(children), [children]);
    return (jsx(VisuallyHiddenText, { id: id, "aria-hidden": !visible, children: hiddenText }));
});

export { Tooltip };
//# sourceMappingURL=Tooltip.js.map
