import { jsx } from 'react/jsx-runtime';
import { useRef, useState, useEffect, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.12.5_@types_node@20.19.1_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { debounce } from '../../libs/debounce.js';
import { spacing } from '../../themes/tailwind/TailwindConfig.js';
import { Balloon } from '../Balloon/Balloon.js';

const classNameGenerator = ce({
    slots: {
        container: 'smarthr-ui-Tooltip-popup shr-absolute shr-z-overlap aria-hidden:shr-hidden',
        balloon: 'shr-max-w-full [&&&]:shr-whitespace-normal',
        balloonText: 'shr-m-0 shr-px-1 shr-py-0.5',
    },
});
const OUTER_MARGIN = 10;
const SPACING = 5;
const TooltipPortal = ({ message, isVisible, parentRect, isIcon }) => {
    const portalRef = useRef(null);
    const [style, setStyle] = useState({});
    const [actualHorizontal, setActualHorizontal] = useState('center');
    const [actualVertical, setActualVertical] = useState('bottom');
    useEffect(() => {
        if (!portalRef.current || !parentRect) {
            return;
        }
        const portal = portalRef.current;
        const action = () => {
            const vertical = calculateVertical(portal.offsetHeight, parentRect);
            const horizontal = calculateHorizontal(portal.offsetWidth, parentRect);
            setStyle({
                insetBlockStart: vertical.insetBlockStart,
                insetInlineStart: horizontal.insetInlineStart,
                insetInlineEnd: horizontal.insetInlineEnd,
                maxWidth: horizontal.maxWidth,
                maxHeight: vertical.maxHeight,
            });
            setActualVertical(vertical.alignment);
            setActualHorizontal(horizontal.alignment);
        };
        const debouncedAction = debounce(action, 100);
        action();
        window.addEventListener('resize', debouncedAction);
        return () => {
            window.removeEventListener('resize', debouncedAction);
        };
    }, [parentRect]);
    const classNames = useMemo(() => {
        const { container, balloon, balloonText } = classNameGenerator();
        return {
            container: container(),
            balloon: balloon(),
            balloonText: balloonText(),
        };
    }, []);
    return (jsx("div", { ref: portalRef, role: "tooltip", "aria-hidden": !isVisible, className: classNames.container, style: style, children: jsx(Balloon, { horizontal: actualHorizontal, vertical: actualVertical, triggerIcon: isIcon, className: classNames.balloon, children: jsx("div", { className: classNames.balloonText, children: message }) }) }));
};
const calculateVertical = (portalHeight, parentRect) => {
    // トリガの上側の領域に収まる場合
    if (parentRect.top - portalHeight >= 0) {
        return {
            insetBlockStart: `${scrollY + parentRect.top - portalHeight - SPACING}px`,
            maxHeight: undefined,
            alignment: 'bottom',
        };
    }
    // トリガの下側の領域に収まる場合
    if (parentRect.bottom + portalHeight <= innerHeight) {
        return {
            insetBlockStart: `${scrollY + parentRect.bottom + SPACING}px`,
            maxHeight: undefined,
            alignment: 'top',
        };
    }
    const triggerHeight = parentRect.bottom - parentRect.top;
    // 上側の領域のほうが広い場合
    if (parentRect.top + triggerHeight / 2 >= innerHeight / 2) {
        return {
            insetBlockStart: `${scrollY + OUTER_MARGIN - SPACING}px`,
            maxHeight: `${parentRect.top - OUTER_MARGIN}px`,
            alignment: 'bottom',
        };
    }
    // 下側の領域のほうが広い場合
    return {
        insetBlockStart: `${scrollY + parentRect.bottom + SPACING}px`,
        maxHeight: `${innerHeight - parentRect.bottom - OUTER_MARGIN}px`,
        alignment: 'top',
    };
};
const calculateHorizontal = (portalWidth, parentRect) => {
    const triggerAlignCenter = parentRect.left + parentRect.width / 2;
    const portalHalfWidth = portalWidth / 2;
    // トリガを中心に左右に十分な余白がある場合
    if (triggerAlignCenter - portalHalfWidth > SPACING &&
        triggerAlignCenter + portalHalfWidth < document.body.clientWidth - SPACING) {
        const insetInlineStart = `${triggerAlignCenter - portalHalfWidth}px`;
        return {
            insetInlineStart,
            insetInlineEnd: undefined,
            maxWidth: `calc(100% - max(${insetInlineStart}, 0px) - ${spacing[0.5]})`,
            alignment: 'center',
        };
    }
    // トリガが画面左寄りの場合
    if (triggerAlignCenter <= document.body.clientWidth / 2) {
        const insetInlineStart = `${scrollX + parentRect.left - SPACING}px`;
        return {
            insetInlineStart,
            insetInlineEnd: undefined,
            maxWidth: `calc(100% - max(${insetInlineStart}, 0px) - ${spacing[0.5]})`,
            alignment: 'left',
        };
    }
    // トリガが画面右寄りの場合
    const insetInlineEnd = `${document.body.clientWidth - parentRect.right - scrollX - SPACING}px`;
    return {
        insetInlineStart: undefined,
        insetInlineEnd,
        maxWidth: `calc(100% - ${spacing[0.5]} - max(${insetInlineEnd}, 0px))`,
        alignment: 'right',
    };
};

export { TooltipPortal };
//# sourceMappingURL=TooltipPortal.js.map
