import { useEffect } from 'react';

function useClick(innerRefs, innerCallback, outerCallback) {
    useEffect(() => {
        const handleClick = (e) => {
            if (innerRefs.some((target) => isEventIncludedParent(e, target.current))) {
                innerCallback(e);
                return;
            }
            outerCallback(e);
        };
        window.addEventListener('click', handleClick);
        return () => {
            window.removeEventListener('click', handleClick);
        };
    }, [innerRefs, innerCallback, outerCallback]);
}
function isEventIncludedParent(e, parent) {
    if (!parent)
        return false;
    const path = e.composedPath();
    if (path.length === 0)
        return false;
    return path.includes(parent);
}

export { useClick };
//# sourceMappingURL=useClick.js.map
