import { useEffect } from 'react';

function useOuterClick(targets, callback) {
    useEffect(() => {
        const handleOuterClick = (e) => {
            if (targets.every((target) => isEventExcludedParent(e, target.current))) {
                callback(e);
            }
        };
        window.addEventListener('click', handleOuterClick);
        return () => {
            window.removeEventListener('click', handleOuterClick);
        };
    }, [callback, targets]);
}
function isEventExcludedParent(e, parent) {
    if (!parent)
        return false;
    const path = e.composedPath();
    if (path.length === 0)
        return false;
    return !path.includes(parent);
}

export { useOuterClick };
//# sourceMappingURL=useOuterClick.js.map
