import { jsx } from 'react/jsx-runtime';
import { createContext, useState, useMemo, useContext, useCallback } from 'react';
import { createPortal } from 'react-dom';
import { useEnhancedEffect } from './useEnhancedEffect.js';

const ParentContext = createContext({
    seqs: [],
});
let portalSeq = 0;
function usePortal() {
    const [portalRoot, setPortalRoot] = useState(null);
    const currentSeq = useMemo(() => ++portalSeq, []);
    const parent = useContext(ParentContext);
    const calculatedSeqs = useMemo(() => {
        const parentSeqs = parent.seqs.concat(currentSeq);
        return {
            parentSeqs,
            portalChildOf: parentSeqs.join(','),
        };
    }, [currentSeq, parent.seqs]);
    useEnhancedEffect(() => {
        // Next.jsのhydration error回避のため、初回レンダリング時にdivを作成する
        setPortalRoot(document.createElement('div'));
    }, []);
    useEnhancedEffect(() => {
        if (!portalRoot) {
            return;
        }
        portalRoot.dataset.portalChildOf = calculatedSeqs.portalChildOf;
        document.body.appendChild(portalRoot);
        return () => {
            document.body.removeChild(portalRoot);
        };
    }, [portalRoot, calculatedSeqs.portalChildOf]);
    const isChildPortal = useCallback((element) => _isChildPortal(element, new RegExp(`(^|,)${currentSeq}(,|$)`)), [currentSeq]);
    const PortalParentProvider = useCallback(({ children }) => {
        const value = {
            seqs: calculatedSeqs.parentSeqs,
        };
        return jsx(ParentContext.Provider, { value: value, children: children });
    }, [calculatedSeqs.parentSeqs]);
    const wrappedCreatePortal = useCallback((children) => {
        if (portalRoot === null) {
            return null;
        }
        return createPortal(children, portalRoot);
    }, [portalRoot]);
    const isPortalRootMounted = useCallback(() => portalRoot !== null, [portalRoot]);
    return {
        portalRoot,
        isPortalRootMounted,
        isChildPortal,
        PortalParentProvider,
        createPortal: wrappedCreatePortal,
    };
}
function _isChildPortal(element, seqRegex) {
    if (!element)
        return false;
    let includesSeq = false;
    const childOf = element.dataset?.portalChildOf;
    if (childOf) {
        includesSeq = seqRegex.test(childOf);
    }
    return includesSeq || _isChildPortal(element.parentElement, seqRegex);
}

export { usePortal };
//# sourceMappingURL=usePortal.js.map
