import { useMemo } from 'react';

const useResponseStatus = (responseStatus) => {
    const calculated = useMemo(() => {
        if (!responseStatus) {
            return {
                isProcessing: false,
                status: undefined,
                message: '',
            };
        }
        if (responseStatus.status === 'processing') {
            return {
                isProcessing: true,
                status: undefined,
                message: '',
            };
        }
        return {
            isProcessing: false,
            // HINT: statusがprocessingではない === success or errorであることが確定する
            // success or error の場合、text属性も必ず存在する
            status: responseStatus.status,
            message: responseStatus.text,
        };
    }, [responseStatus]);
    return calculated;
};

export { useResponseStatus };
//# sourceMappingURL=useResponseStatus.js.map
