"use client";
import { jsx } from 'react/jsx-runtime';
import { createContext, useContext, useMemo } from 'react';
import { IntlContext, IntlProvider as IntlProvider$1 } from 'react-intl';
import * as intl_locales_index from './locales/index.js';

// Object.keys は常に string[] を返却するが、locales は実行時に変更されないため、as 型キャストを使用することは自明に安全なので使用している
const allLocaleKeys = Object.keys(intl_locales_index);
const AvailableLocalesContext = createContext(allLocaleKeys);
const useAvailableLocales = () => useContext(AvailableLocalesContext);
const IntlProvider = ({ availableLocales, locale, children, }) => {
    // プロダクト側でIntlProviderを使っている場合、プロダクト側のmessagesとマージして提供するためにContextから取得している
    const intl = useContext(IntlContext);
    const actualMessages = useMemo(() => ({ ...intl?.messages, ...intl_locales_index[locale] }), [intl, locale]);
    return (jsx(AvailableLocalesContext.Provider, { value: availableLocales ?? allLocaleKeys, children: jsx(IntlProvider$1, { locale: locale, messages: actualMessages, children: children }) }));
};

export { IntlProvider, useAvailableLocales };
//# sourceMappingURL=IntlProvider.js.map
