"use client";
import { useCallback } from 'react';
import { useIntl as useIntl$1 } from 'react-intl';
import { useAvailableLocales } from './IntlProvider.js';
import * as intl_locales_index from './locales/index.js';

const DATE_FORMATS = {
    // localeがja, ja-easyの場合、フォーマットを YYYY/MM/DD 形式にする
    // 参考: https://smarthr.design/products/contents/idiomatic-usage/count/#h2-3
    ja: {
        year: 'numeric',
        month: '2-digit',
        day: '2-digit',
    },
    'ja-easy': {
        year: 'numeric',
        month: '2-digit',
        day: '2-digit',
    },
    'en-us': undefined,
    'id-id': undefined,
    ko: undefined,
    pt: undefined,
    vi: undefined,
    'zh-cn': undefined,
    'zh-tw': undefined,
};
const isValidLocale = (locale) => locale in intl_locales_index;
const useIntl = () => {
    const intl = useIntl$1();
    const locale = isValidLocale(intl.locale) ? intl.locale : 'ja';
    const availableLocales = useAvailableLocales();
    const localize = useCallback((descriptor, values, opts) => intl.formatMessage({ ...descriptor, defaultMessage: descriptor.defaultText }, values, opts), [intl]);
    const formatDate = useCallback((date, opts) => intl.formatDate(date, { ...DATE_FORMATS[locale], ...opts }), [intl, locale]);
    return { availableLocales, localize, formatDate };
};

export { useIntl };
//# sourceMappingURL=useIntl.js.map
