import { defaultHtmlFontSize } from './createFontSize.js';

const defaultBaseSize = defaultHtmlFontSize / 2;
const primitiveTokens = [
    0, 0.25, 0.5, 0.75, 1, 1.25, 1.5, 2, 2.5, 3, 3.5, 4, 8, -0.25, -0.5, -0.75, -1, -1.25, -1.5, -2,
    -2.5, -3, -3.5, -4, -8,
];
const getSpacing = (baseSize) => {
    const spacings = getSpacingByChar(baseSize);
    return {
        X3S: spacings[0.25],
        XXS: spacings[0.5],
        XS: spacings[1],
        S: spacings[1.5],
        M: spacings[2],
        L: spacings[2.5],
        XL: spacings[3],
        XXL: spacings[3.5],
        X3L: spacings[4],
        NONE: spacings[0],
    };
};
const getSpacingByChar = (baseSize) => {
    const charSize = baseSize * 2;
    return primitiveTokens.reduce((prev, size) => {
        prev[size] = size ? `${charSize * size}px` : '0';
        return prev;
    }, {});
};
const createSpacing = (userBaseSize = defaultBaseSize) => getSpacing(userBaseSize);
const createSpacingByChar = (userBaseSize = defaultBaseSize) => {
    const spacings = getSpacingByChar(userBaseSize);
    return (size) => spacings[size];
};
const defaultSpacing = createSpacing();

export { createSpacing, createSpacingByChar, defaultBaseSize, defaultSpacing, primitiveTokens };
//# sourceMappingURL=createSpacing.js.map
