import { createBorder } from './createBorder.js';
import { createBreakpoint } from './createBreakpoint.js';
import { createColor } from './createColor.js';
import { createFontSize } from './createFontSize.js';
import { createInteraction } from './createInteraction.js';
import { createLeading } from './createLeading.js';
import { createRadius } from './createRadius.js';
import { createShadow } from './createShadow/createShadow.js';
import './createShadow/defaultShadow.js';
import { createSpacingByChar, createSpacing } from './createSpacing.js';
import { createZIndex } from './createZIndex.js';

const createTheme = (theme = {}) => {
    const colorProperty = theme.color;
    const baseSize = theme.spacing?.baseSize;
    const spacingByChar = createSpacingByChar(baseSize);
    return {
        color: createColor(colorProperty),
        fontSize: createFontSize(theme.fontSize),
        spacing: createSpacing(baseSize),
        spacingByChar,
        space: spacingByChar,
        leading: createLeading(theme.leading),
        breakpoint: createBreakpoint(theme.breakpoint),
        border: createBorder(theme.border, colorProperty),
        radius: createRadius(theme.radius),
        interaction: createInteraction(theme.interaction),
        shadow: createShadow(theme.shadow, colorProperty),
        zIndex: createZIndex(theme.zIndex),
    };
};

export { createTheme };
//# sourceMappingURL=createTheme.js.map
