"use strict";
import { __exports as lib } from '../../../../../../../_virtual/index6.js';

var hasRequiredLib;

function requireLib () {
	if (hasRequiredLib) return lib;
	hasRequiredLib = 1;
	Object.defineProperty(lib, "__esModule", { value: true });
	lib.dateToWareki = dateToWareki;
	lib.warekiToDate = warekiToDate;
	var _a = (function () {
	    var _a;
	    var REIWA = '令和';
	    var HEISEI = '平成';
	    var SHOWA = '昭和';
	    var TAISHO = '大正';
	    var MEIJI = '明治';
	    var REIWA_START_YEAR = 2019;
	    var HEISEI_START_YEAR = 1989;
	    var SHOWA_START_YEAR = 1926;
	    var TAISHO_START_YEAR = 1912;
	    var MEIJI_START_YEAR = 1868;
	    var SEPARATOR = '[:\\/\\-\\.\\s．年月日]';
	    var WAREKI_BOUNDARYS = [
	        [REIWA, REIWA_START_YEAR, 4, 30, HEISEI],
	        [HEISEI, HEISEI_START_YEAR, 1, 7, SHOWA],
	        [SHOWA, SHOWA_START_YEAR, 12, 24, TAISHO],
	        [TAISHO, TAISHO_START_YEAR, 7, 29, MEIJI],
	    ];
	    var YEARS = (_a = {
	            r: REIWA_START_YEAR,
	            R: REIWA_START_YEAR
	        },
	        _a[REIWA] = REIWA_START_YEAR,
	        _a.h = HEISEI_START_YEAR,
	        _a.H = HEISEI_START_YEAR,
	        _a[HEISEI] = HEISEI_START_YEAR,
	        _a.s = SHOWA_START_YEAR,
	        _a.S = SHOWA_START_YEAR,
	        _a[SHOWA] = SHOWA_START_YEAR,
	        _a.t = TAISHO_START_YEAR,
	        _a.T = TAISHO_START_YEAR,
	        _a[TAISHO] = TAISHO_START_YEAR,
	        _a.m = MEIJI_START_YEAR,
	        _a.M = MEIJI_START_YEAR,
	        _a[MEIJI] = MEIJI_START_YEAR,
	        _a);
	    return {
	        WAREKI_START_YEARS: YEARS,
	        reg: {
	            dateString: new RegExp("^([0-9]{4})(".concat(SEPARATOR, ")?([0-9]{1,2})(").concat(SEPARATOR, ")?([0-9]{1,2})([\\s\uFF0E]([0-9]{2}):([0-9]{2})$)?")),
	            wareki: new RegExp("^(".concat(Object.keys(YEARS).join('|'), ")([0-9]{1,2})(").concat(SEPARATOR, ")([0-9]{1,2})(").concat(SEPARATOR, ")([0-9]{1,2})(").concat(SEPARATOR, "?)$")),
	        },
	        selectGengo: function (year, month, date) {
	            for (var _i = 0, WAREKI_BOUNDARYS_1 = WAREKI_BOUNDARYS; _i < WAREKI_BOUNDARYS_1.length; _i++) {
	                var _a = WAREKI_BOUNDARYS_1[_i], modern = _a[0], boundaryYear = _a[1], boundaryMonth = _a[2], boundaryDay = _a[3], ancient = _a[4];
	                if (year > boundaryYear) {
	                    return modern;
	                }
	                else if (year === boundaryYear) {
	                    if (month > boundaryMonth || (month === boundaryMonth && date > boundaryDay)) {
	                        return modern;
	                    }
	                    return ancient;
	                }
	            }
	            return MEIJI;
	        },
	    };
	})(), WAREKI_START_YEARS = _a.WAREKI_START_YEARS, reg = _a.reg, selectGengo = _a.selectGengo;
	// TODO: ほかの全角文字も半角に治す必要があるかも？
	var fullWidthToHalfWidth = function (dateString) {
	    return dateString.replace(/[ａ-ｚＡ-Ｚ０-９．]/g, function (s) { return String.fromCharCode(s.charCodeAt(0) - 0xfee0); });
	};
	function dateToWareki(d) {
	    var dateString = d instanceof Date ? "".concat(d.getFullYear(), "/").concat(d.getMonth() + 1, "/").concat(d.getDate()) : d;
	    var formatted = fullWidthToHalfWidth(dateString);
	    var matcher = formatted.match(reg.dateString);
	    if (!matcher) {
	        return {
	            isValid: false,
	            result: dateString,
	            formatted: formatted,
	        };
	    }
	    var year = Number(matcher[1]);
	    var month = Number(matcher[3]);
	    var date = Number(matcher[5]);
	    var gengo = selectGengo(year, month, date);
	    // 和暦は1年から始まるので + 1 が必要
	    var warekiYear = year - WAREKI_START_YEARS[gengo] + 1;
	    return {
	        isValid: true,
	        result: "".concat(gengo).concat(warekiYear === 1 ? '元' : warekiYear, "\u5E74").concat(month, "\u6708").concat(date, "\u65E5"),
	        formatted: formatted,
	    };
	}
	function warekiToDate(wareki) {
	    var formatted = fullWidthToHalfWidth(wareki);
	    // parse as japanese era
	    var matchedWareki = formatted.match(reg.wareki);
	    if (matchedWareki) {
	        var baseYear = WAREKI_START_YEARS[matchedWareki[1]];
	        return {
	            isValid: true,
	            // 和暦は1年から始まるので - 1 が必要
	            result: new Date(baseYear + Number(matchedWareki[2]) - 1, Number(matchedWareki[4]) - 1, Number(matchedWareki[6])),
	            formatted: formatted,
	        };
	    }
	    // parse as A.D.
	    var matchedDate = formatted.match(reg.dateString);
	    if (matchedDate) {
	        return {
	            isValid: true,
	            result: new Date(Number(matchedDate[1]), Number(matchedDate[3]) - 1, Number(matchedDate[5])),
	            formatted: formatted,
	        };
	    }
	    return {
	        isValid: false,
	        result: new Date(formatted),
	        formatted: formatted,
	    };
	}
	
	return lib;
}

export { requireLib as __require };
//# sourceMappingURL=index.js.map
