"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccordionPanelTrigger = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const map_1 = require("../../libs/map");
const Heading_1 = require("../Heading");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const AccordionPanel_1 = require("./AccordionPanel");
const AccordionPanelItem_1 = require("./AccordionPanelItem");
const accordionPanelHelper_1 = require("./accordionPanelHelper");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        title: 'shr-grow shr-leading-tight',
        titleWrapper: 'shr-flex-nowrap',
        button: [
            'smarthr-ui-AccordionPanel-trigger',
            'shr-group shr-w-full shr-cursor-pointer shr-appearance-none shr-border-none shr-bg-transparent shr-px-1 shr-py-0.75 shr-text-left shr-text-inherit shr-text-color-inherit',
            'disabled:shr-cursor-not-allowed disabled:shr-bg-white-darken disabled:shr-text-disabled',
            'hover:shr-bg-white-darken',
            'focus-visible:shr-focus-indicator',
            // Base 直下に AccordionPanel がある場合、背景が付き抜けないように角丸を指定（Base に overflow: hidden を与えるとフォーカスリングが表示されなくなる）
            '[.smarthr-ui-Base_>_.smarthr-ui-AccordionPanel_.smarthr-ui-AccordionPanel-item:first-child_&]:shr-rounded-t-l [.smarthr-ui-Base_>_.smarthr-ui-AccordionPanel_.smarthr-ui-AccordionPanel-item:last-child_&]:shr-rounded-b-l',
        ],
        leftIcon: 'shr-transition-transform shr-duration-100 group-aria-expanded:shr-rotate-90',
        rightIcon: 'group-aria-expanded:-shr-rotate-180',
    },
    compoundSlots: [
        {
            slots: ['leftIcon', 'rightIcon'],
            className: 'shr-shrink-0',
        },
    ],
});
const AccordionPanelTrigger = ({ children, className, headingType = 'blockTitle', headingTag, ...props }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { title, titleWrapper, button, leftIcon, rightIcon } = classNameGenerator();
        return {
            title: title(),
            titleWrapper: titleWrapper(),
            button: button({ className }),
            leftIcon: leftIcon(),
            rightIcon: rightIcon(),
        };
    }, [className]);
    const { name } = (0, react_1.useContext)(AccordionPanelItem_1.AccordionPanelItemContext);
    const { iconPosition, expandedItems, onClickTrigger, onClickProps, expandableMultiply, parentRef, } = (0, react_1.useContext)(AccordionPanel_1.AccordionPanelContext);
    const isExpanded = (0, react_1.useMemo)(() => (0, map_1.getIsInclude)(expandedItems, name), [expandedItems, name]);
    const actualOnClickTrigger = (0, react_1.useMemo)(() => onClickTrigger
        ? (e) => onClickTrigger(e.currentTarget.value, !isExpanded)
        : undefined, [isExpanded, onClickTrigger]);
    const actualOnClickProps = (0, react_1.useMemo)(() => onClickProps
        ? (e) => {
            const newExpandedItems = (0, accordionPanelHelper_1.getNewExpandedItems)(expandedItems, e.currentTarget.value, !isExpanded, expandableMultiply);
            onClickProps((0, map_1.mapToKeyArray)(newExpandedItems));
        }
        : undefined, [isExpanded, expandedItems, expandableMultiply, onClickProps]);
    const handleClick = (0, react_1.useMemo)(() => {
        if (actualOnClickTrigger) {
            if (actualOnClickProps) {
                return (e) => {
                    actualOnClickTrigger(e);
                    actualOnClickProps(e);
                };
            }
            return actualOnClickTrigger;
        }
        else if (actualOnClickProps) {
            return actualOnClickProps;
        }
        return undefined;
    }, [actualOnClickProps, actualOnClickTrigger]);
    const handleKeyDown = (0, react_1.useCallback)((e) => {
        if (!parentRef?.current) {
            return;
        }
        const item = e.target;
        switch (e.key) {
            case 'Home': {
                e.preventDefault();
                (0, accordionPanelHelper_1.focusFirstSibling)(parentRef.current);
                break;
            }
            case 'End': {
                e.preventDefault();
                (0, accordionPanelHelper_1.focusLastSibling)(parentRef.current);
                break;
            }
            case 'ArrowLeft':
            case 'ArrowUp': {
                e.preventDefault();
                (0, accordionPanelHelper_1.focusPreviousSibling)(item, parentRef.current);
                break;
            }
            case 'ArrowRight':
            case 'ArrowDown': {
                e.preventDefault();
                (0, accordionPanelHelper_1.focusNextSibling)(item, parentRef.current);
                break;
            }
        }
    }, [parentRef]);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    (0, jsx_runtime_1.jsx)(Heading_1.Heading, { tag: headingTag, type: headingType, children: (0, jsx_runtime_1.jsx)("button", { ...props, type: "button", value: name, id: `${name}-trigger`, "aria-expanded": isExpanded, "aria-controls": `${name}-content`, onClick: handleClick, onKeyDown: handleKeyDown, className: classNames.button, "data-component": "AccordionHeaderButton", children: (0, jsx_runtime_1.jsx)(MemoizedTitle, { iconPosition: iconPosition, classNames: classNames, children: children }) }) }));
};
exports.AccordionPanelTrigger = AccordionPanelTrigger;
const MemoizedTitle = (0, react_1.memo)(({ classNames, iconPosition, children }) => ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { className: classNames.titleWrapper, align: "center", as: "span", children: [iconPosition === 'left' && (0, jsx_runtime_1.jsx)(Icon_1.FaCaretRightIcon, { className: classNames.leftIcon }), (0, jsx_runtime_1.jsx)("span", { className: classNames.title, children: children }), iconPosition === 'right' && (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, { className: classNames.rightIcon })] })));
//# sourceMappingURL=AccordionPanelTrigger.js.map