"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppHeader = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const DesktopHeader_1 = require("./components/desktop/DesktopHeader");
const MobileHeader_1 = require("./components/mobile/MobileHeader");
const useLocale_1 = require("./hooks/useLocale");
const useMediaQuery_1 = require("./hooks/useMediaQuery");
const AppHeader = ({ locale, children, ...props }) => {
    // NOTE: ヘッダーの出し分けは CSS によって行われているので、useMediaQuery による children の出し分けは本来不要ですが、
    //  wovn の言語切替カスタム UI の挿入対象となる DOM ("wovn-embedded-widget-anchor" クラスを持った div) が複数描画されていると、
    //  wovn のスクリプトの仕様上1つ目の DOM にしか UI が挿入されないため、やむを得ず children のみ React のレンダリングレベルでの出し分けをしています。
    const isDesktop = (0, useMediaQuery_1.useMediaQuery)(useMediaQuery_1.mediaQuery.desktop);
    // HINT: Desktop,Mobileの両ヘッダーは常にHTML上に存在し、cssでvisibleを切り替えることでSSR環境でのレイアウトシフトが発生しないようにしています
    // 表示切替は画面幅によって決まり、SSR環境では判定出来ないためです
    return ((0, jsx_runtime_1.jsxs)(useLocale_1.LocaleContextProvider, { locale: locale, children: [(0, jsx_runtime_1.jsx)(DesktopHeader_1.DesktopHeader, { ...props, children: isDesktop ? children : undefined }), (0, jsx_runtime_1.jsx)(MobileHeader_1.MobileHeader, { ...props, children: isDesktop ? undefined : children })] }));
};
exports.AppHeader = AppHeader;
//# sourceMappingURL=AppHeader.js.map