"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppLauncherFeatures = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../../Button");
const Icon_1 = require("../../../Icon");
const LineClamp_1 = require("../../../LineClamp");
const Text_1 = require("../../../Text");
const useMediaQuery_1 = require("../../hooks/useMediaQuery");
const useTranslate_1 = require("../../hooks/useTranslate");
const Translate_1 = require("./Translate");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        empty: ['shr-p-1 shr-text-center'],
        list: ['shr-list-none', '[&>li]:shr-px-0.5 [&>li]:shr-py-0.25'],
        listItem: [
            'smarthr-ui-AppLauncher-listItem',
            'shr-grid shr-min-h-[2.5rem] shr-grid-cols-[1rem_1fr_1rem] shr-gap-0.75 shr-whitespace-normal shr-px-1 shr-py-0 shr-text-left shr-leading-tight',
            'data-[favorite="false"]:shr-grid-cols-[1fr_1rem]',
        ],
    },
});
const AppLauncherFeatures = ({ features, page }) => features.length === 0 ? (0, jsx_runtime_1.jsx)(EmptyList, {}) : (0, jsx_runtime_1.jsx)(FeatureList, { features: features, page: page });
exports.AppLauncherFeatures = AppLauncherFeatures;
const EmptyList = (0, react_1.memo)(() => {
    const className = (0, react_1.useMemo)(() => {
        const { empty } = classNameGenerator();
        return empty();
    }, []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => translate('Launcher/emptyText'), [translate]);
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(Text_1.Text, { size: "S", children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated }) }) }));
});
const FeatureList = ({ features, page }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { list, listItem } = classNameGenerator();
        return {
            list: list(),
            listItem: listItem(),
        };
    }, []);
    const isFavorite = page === 'favorite';
    return ((0, jsx_runtime_1.jsx)("ul", { className: classNames.list, children: features.map((feature) => ((0, jsx_runtime_1.jsx)(FeatureListItem, { href: feature.url, isFavorite: isFavorite, className: classNames.listItem, children: feature.name }, feature.id))) }));
};
const FeatureListItem = (0, react_1.memo)(({ href, children, isFavorite, className }) => ((0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)(Button_1.AnchorButton, { href: href, target: "_blank", prefix: isFavorite && (0, jsx_runtime_1.jsx)(Icon_1.FaStarIcon, {}), suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaArrowRightIcon, {}), variant: "text", wide: true, "data-favorite": isFavorite, className: className, children: (0, jsx_runtime_1.jsx)(FeatureName, { children: children }) }) })));
const FeatureName = ({ children }) => {
    const isDesktop = (0, useMediaQuery_1.useMediaQuery)(useMediaQuery_1.mediaQuery.desktop);
    return isDesktop ? (0, jsx_runtime_1.jsx)(LineClamp_1.LineClamp, { maxLines: 2, children: children }) : children;
};
//# sourceMappingURL=AppLauncherFeatures.js.map