"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppLauncherSortDropdown = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const themes_1 = require("../../../../themes");
const Button_1 = require("../../../Button");
const Dropdown_1 = require("../../../Dropdown");
const Icon_1 = require("../../../Icon");
const useTranslate_1 = require("../../hooks/useTranslate");
const Translate_1 = require("../common/Translate");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        trigger: [
            'smarthr-ui-AppLauncher-SortDropdown-trigger',
            'shr-gap-0.25 shr-text-grey',
            '[&[aria-expanded="true"]_.smarthr-ui-Icon]:shr-rotate-180',
        ],
        contentBody: ['shr-px-0.25 shr-py-0.5', 'shr-flex shr-flex-col shr-items-stretch'],
        contentButton: [
            'shr-justify-start shr-border-none shr-py-0.75 shr-pl-2.5 shr-font-normal',
            'aria-selected:shr-pl-1',
        ],
    },
});
const AppLauncherSortDropdown = ({ sortType, onSelectSortType }) => {
    const triggerRef = (0, react_1.useRef)(null);
    const classNames = (0, react_1.useMemo)(() => {
        const { trigger, contentBody, contentButton } = classNameGenerator();
        return {
            trigger: trigger(),
            contentBody: contentBody(),
            contentButton: contentButton(),
        };
    }, []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        label: translate('Launcher/sortDropdownLabel'),
        selected: translate('Launcher/sortDropdownSelected'),
        default: translate('Launcher/sortDropdownOrderDefault'),
        asc: translate('Launcher/sortDropdownOrderNameAsc'),
        desc: translate('Launcher/sortDropdownOrderNameDesc'),
    }), [translate]);
    const options = (0, react_1.useMemo)(() => [
        ['default', translated.default],
        ['name/asc', translated.asc],
        ['name/desc', translated.desc],
    ], [translated]);
    const onClickOption = (0, react_1.useCallback)((e) => {
        onSelectSortType(e.currentTarget.value);
        // Dropdown がネストしており、この Dropdown のみ閉じて親の Dropdown は開いたままというのができない
        // そのため、無理矢理クリックイベントを発生させて実現している
        setTimeout(() => {
            if (triggerRef.current) {
                triggerRef.current.click();
                triggerRef.current.focus();
            }
        }, 0);
    }, [onSelectSortType]);
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { children: [(0, jsx_runtime_1.jsx)(TriggerButton, { triggerRef: triggerRef, className: classNames.trigger, children: translated.label }), (0, jsx_runtime_1.jsx)(Dropdown_1.DropdownContent, { controllable: true, children: (0, jsx_runtime_1.jsx)("div", { role: "listbox", className: classNames.contentBody, children: options.map(([value, children], i) => ((0, jsx_runtime_1.jsx)(OptionButton, { value: value, selected: value === sortType, selectedAlt: translated.selected, onClick: onClickOption, className: classNames.contentButton, children: children }, i))) }) })] }));
};
exports.AppLauncherSortDropdown = AppLauncherSortDropdown;
const TriggerButton = (0, react_1.memo)(({ triggerRef, children, className }) => ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { ref: triggerRef, size: "s", variant: "text", suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}), className: className, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }) })));
const OptionButton = (0, react_1.memo)(({ value, selected, selectedAlt, onClick, children, className }) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { value: value, role: "option", "aria-selected": selected, className: className, prefix: selected && (0, jsx_runtime_1.jsx)(Icon_1.FaCheckIcon, { color: themes_1.textColor.main, alt: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: selectedAlt }) }), onClick: onClick, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) })));
//# sourceMappingURL=AppLauncherSortDropdown.js.map