"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppLauncher = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const themes_1 = require("../../../../themes");
const Button_1 = require("../../../Button");
const Heading_1 = require("../../../Heading");
const Icon_1 = require("../../../Icon");
const Input_1 = require("../../../Input");
const Layout_1 = require("../../../Layout");
const SectioningContent_1 = require("../../../SectioningContent");
const SideNav_1 = require("../../../SideNav");
const TextLink_1 = require("../../../TextLink");
const useAppLauncher_1 = require("../../hooks/useAppLauncher");
const useTranslate_1 = require("../../hooks/useTranslate");
const AppLauncherFeatures_1 = require("../common/AppLauncherFeatures");
const AppLauncherSortDropdown_1 = require("../common/AppLauncherSortDropdown");
const Translate_1 = require("../common/Translate");
const appLauncher = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-AppLauncher',
            'shr-grid shr-h-[40rem] shr-w-[38rem] shr-grid-rows-[auto_1fr]',
        ],
        searchArea: [
            'smarthr-ui-AppLauncher-searchArea',
            'shr-border-b-shorthand shr-p-1',
            '[&_.smarthr-ui-Input]:shr-h-[42px]',
        ],
        inner: ['smarthr-ui-AppLauncher-inner', 'shr-grid shr-min-h-0 shr-grid-cols-[11rem_1fr]'],
        side: [
            'smarthr-ui-AppLauncher-side',
            'shr-border-r-shorthand shr-flex shr-flex-col shr-bg-column shr-pb-1 shr-pt-0.5',
            '[&_hr]:shr-m-0.5 [&_hr]:shr-h-[1px] [&_hr]:shr-border-none [&_hr]:shr-bg-border',
        ],
        sideNav: [
            '[&_.smarthr-ui-SideNav-item>button]:shr-px-1 [&_.smarthr-ui-SideNav-item>button]:shr-py-0.75',
            '[&_.smarthr-ui-SideNav-item>button>span]:shr-flex-nowrap',
            '[&_.smarthr-ui-SideNav-item>button_.smarthr-ui-Icon]:shr-shrink-0 [&_.smarthr-ui-SideNav-item>button_.smarthr-ui-Icon]:shr-align-bottom',
        ],
        sideNavHeading: ['shr-px-1 shr-py-0.75 shr-text-xs shr-text-black'],
        help: ['smarthr-ui-AppLauncher-help', 'shr-mt-auto shr-px-1 shr-text-xs'],
        main: ['smarthr-ui-AppLauncher-main', 'shr-grid shr-min-h-0'],
        mainInner: ['shr-grid shr-min-h-0 shr-grid-rows-[auto_1fr]'],
        contentHead: [
            'shr-min-h-[2rem] shr-px-1 shr-py-0.75',
            '[&_.smarthr-ui-Heading]:shr-text-black',
        ],
        scrollArea: ['shr-h-[509px] shr-overflow-y-scroll'],
    },
    variants: {
        noIcon: {
            true: {
                sideNav: ['[&_.smarthr-ui-SideNav-item>button]:shr-pl-1.5'],
            },
        },
        selected: {
            false: {
                sideNav: ['[&_.smarthr-ui-SideNav-item>button_.smarthr-ui-Icon]:shr-text-grey'],
            },
        },
    },
});
const AppLauncher = ({ features: baseFeatures }) => {
    const { features, page, mode, sortType, searchQuery, changePage, setSortType, onChangeSearchQuery, onClickClearSearchQuery, } = (0, useAppLauncher_1.useAppLauncher)(baseFeatures);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, searchArea, inner, side, sideNav, sideNavHeading, help, main, mainInner, contentHead, scrollArea, } = appLauncher();
        return {
            wrapper: wrapper(),
            searchArea: searchArea(),
            inner: inner(),
            side: side(),
            unselectedSideNav: sideNav({ selected: false }),
            selectedSideNav: sideNav({ noIcon: true, selected: true }),
            sideNavHeading: sideNavHeading(),
            help: help(),
            main: main(),
            mainInner: mainInner(),
            contentHead: contentHead(),
            scrollArea: scrollArea(),
        };
    }, []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        favorite: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translate('Launcher/favoriteModeText') }),
        all: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translate('Launcher/allModeText') }),
        listText: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translate('Launcher/listText') }),
        searchInputTitle: translate('Launcher/searchInputTitle'),
        helpText: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translate('Launcher/helpText') }),
        searchResultText: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translate('Launcher/searchResultText') }),
    }), [translate]);
    return ((0, jsx_runtime_1.jsxs)("div", { className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.searchArea, children: (0, jsx_runtime_1.jsx)(Input_1.SearchInput, { name: "search", title: translated.searchInputTitle, tooltipMessage: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.searchInputTitle }), width: "100%", value: searchQuery, suffix: mode === 'search' && (0, jsx_runtime_1.jsx)(ClearSearchButton, { onClick: onClickClearSearchQuery }), onChange: onChangeSearchQuery }) }), (0, jsx_runtime_1.jsxs)("div", { className: classNames.inner, children: [(0, jsx_runtime_1.jsx)(SideNavs, { mode: mode, page: page, changePage: changePage, translated: translated, classNames: classNames }), (0, jsx_runtime_1.jsx)("main", { className: classNames.main, children: (0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { className: classNames.mainInner, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { className: classNames.contentHead, align: "center", justify: "space-between", children: [(0, jsx_runtime_1.jsx)(MemoizedSubSubBlockHeading, { children: mode === 'search' ? translated.searchResultText : translated[page] }), (mode === 'search' || page === 'all') && ((0, jsx_runtime_1.jsx)(AppLauncherSortDropdown_1.AppLauncherSortDropdown, { sortType: sortType, onSelectSortType: setSortType }))] }), (0, jsx_runtime_1.jsx)("div", { className: classNames.scrollArea, children: (0, jsx_runtime_1.jsx)(AppLauncherFeatures_1.AppLauncherFeatures, { features: features, page: page }) })] }) })] })] }));
};
exports.AppLauncher = AppLauncher;
const ClearSearchButton = (0, react_1.memo)(({ onClick }) => ((0, jsx_runtime_1.jsx)(Button_1.UnstyledButton, { onClick: onClick, children: (0, jsx_runtime_1.jsx)(Icon_1.FaCircleXmarkIcon, {}) })));
const SideNavs = (0, react_1.memo)(({ mode, page, changePage, translated, classNames }) => {
    const isNotSearch = mode !== 'search';
    const isFavorite = isNotSearch && page === 'favorite';
    const isAll = isNotSearch && page === 'all';
    const unselectedItems = (0, react_1.useMemo)(() => [
        {
            id: 'favorite',
            title: translated.favorite,
            prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaStarIcon, { color: isFavorite ? themes_1.textColor.white : undefined }),
            current: isFavorite,
        },
    ], [isFavorite, translated]);
    const selectedItems = (0, react_1.useMemo)(() => [
        {
            id: 'all',
            title: translated.all,
            current: isAll,
        },
    ], [isAll, translated]);
    const onClick = (0, react_1.useCallback)((_, id) => {
        changePage(id);
    }, [changePage]);
    return ((0, jsx_runtime_1.jsxs)("div", { className: classNames.side, children: [(0, jsx_runtime_1.jsx)(SideNav_1.SideNav, { className: classNames.unselectedSideNav, size: "s", items: unselectedItems, onClick: onClick }), (0, jsx_runtime_1.jsx)("hr", {}), (0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { children: [(0, jsx_runtime_1.jsx)(MemoizedSubSubBlockHeading, { className: classNames.sideNavHeading, children: translated.listText }), (0, jsx_runtime_1.jsx)(SideNav_1.SideNav, { className: classNames.selectedSideNav, size: "s", items: selectedItems, onClick: onClick })] }), (0, jsx_runtime_1.jsx)(HelpLinkArea, { className: classNames.help, children: translated.helpText })] }));
});
const HelpLinkArea = (0, react_1.memo)(({ children, className }) => ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(TextLink_1.HelpLink, { href: "https://support.smarthr.jp/ja/help/articles/2bfd350d-8e8b-4bbd-a209-426d2eb302cc/", target: "_blank", children: children }) })));
const MemoizedSubSubBlockHeading = (0, react_1.memo)(({ children, className }) => ((0, jsx_runtime_1.jsx)(Heading_1.Heading, { type: "subSubBlockTitle", className: className, children: children })));
//# sourceMappingURL=AppLauncher.js.map