"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DesktopHeader = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../../Button");
const Dropdown_1 = require("../../../Dropdown");
const Header_1 = require("../../../Header");
const Icon_1 = require("../../../Icon");
const Layout_1 = require("../../../Layout");
const useLocale_1 = require("../../hooks/useLocale");
const useTranslate_1 = require("../../hooks/useTranslate");
const multilingualization_1 = require("../../multilingualization");
const Translate_1 = require("../common/Translate");
const AppLauncher_1 = require("./AppLauncher");
const Navigation_1 = require("./Navigation");
const UserInfo_1 = require("./UserInfo");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'max-[751px]:!shr-hidden',
        appsButton: [
            'shr-border-none shr-bg-transparent shr-px-0.25 shr-font-normal shr-text-white',
            'hover:shr-border-transparent hover:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:shr-bg-transparent',
            'forced-colors:shr-border-shorthand',
        ],
    },
});
const DesktopHeader = ({ enableNew, className = '', appName, tenants, currentTenantId, schoolUrl, helpPageUrl, children, userInfo, desktopAdditionalContent, navigations, desktopNavigationAdditionalContent, releaseNote, features, ...props }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, appsButton } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            appsButton: appsButton(),
        };
    }, [className]);
    const { locale } = (0, useLocale_1.useLocale)();
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        appLauncherLabel: translate('DesktopHeader/DesktopHeader/appLauncherLabel'),
        school: translate('common/school'),
        help: translate('common/help'),
    }), [translate]);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(Header_1.Header, { ...props, enableNew: enableNew, className: classNames.wrapper, featureName: appName, tenants: tenants, currentTenantId: currentTenantId, children: (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", className: "shr--me-0.25", children: [!enableNew && ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [features && features.length > 0 && ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { children: [(0, jsx_runtime_1.jsx)(AppLauncherButton, { enableNew: enableNew, className: classNames.appsButton, children: translated.appLauncherLabel }), (0, jsx_runtime_1.jsx)(Dropdown_1.DropdownContent, { controllable: true, children: (0, jsx_runtime_1.jsx)(AppLauncher_1.AppLauncher, { features: features }) })] })), schoolUrl && ((0, jsx_runtime_1.jsx)(Header_1.HeaderLink, { href: schoolUrl, prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaGraduationCapIcon, {}), className: "shr-flex shr-items-center shr-py-0.75 shr-leading-none", children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.school }) }))] })), helpPageUrl && ((0, jsx_runtime_1.jsx)(Header_1.HeaderLink, { href: helpPageUrl, prefix: enableNew ? (0, jsx_runtime_1.jsx)(Icon_1.FaRegCircleQuestionIcon, {}) : (0, jsx_runtime_1.jsx)(Icon_1.FaCircleQuestionIcon, {}), className: enableNew ? undefined : 'shr-flex shr-items-center shr-py-0.75 shr-leading-none', enableNew: enableNew, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.help }) })), locale && ((0, jsx_runtime_1.jsx)(Header_1.LanguageSwitcher, { localeMap: multilingualization_1.localeMap, locale: locale.selectedLocale, onLanguageSelect: locale.onSelectLocale, enableNew: enableNew })), children, userInfo && ((0, jsx_runtime_1.jsx)(UserInfo_1.UserInfo, { ...userInfo, tenants: tenants, currentTenantId: currentTenantId, desktopAdditionalContent: desktopAdditionalContent, enableNew: enableNew }))] }) }), navigations && ((0, jsx_runtime_1.jsx)(Navigation_1.Navigation, { appName: appName, navigations: navigations, additionalContent: desktopNavigationAdditionalContent, releaseNote: releaseNote, enableNew: enableNew }))] }));
};
exports.DesktopHeader = DesktopHeader;
const AppLauncherButton = (0, react_1.memo)(({ enableNew, children, className }) => ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { prefix: enableNew ?? (0, jsx_runtime_1.jsx)(Icon_1.FaToolboxIcon, {}), className: className, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }) })));
//# sourceMappingURL=DesktopHeader.js.map