"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Navigation = void 0;
const react_1 = require("react");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_2 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const AppNavi_1 = require("../../../AppNavi");
const Button_1 = require("../../../Button");
const Dropdown_1 = require("../../../Dropdown");
const Layout_1 = require("../../../Layout");
const CommonButton_1 = require("../common/CommonButton");
const ReleaseNotesDropdown_1 = require("./ReleaseNotesDropdown");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'shr-min-w-[auto] shr-overflow-x-auto',
        'max-[751px]:!shr-hidden',
        'data-[with-releasenote="true"]:shr-pe-0',
    ],
});
const Navigation = ({ appName, navigations, additionalContent, releaseNote, enableNew, }) => {
    const className = (0, react_2.useMemo)(() => classNameGenerator(), []);
    const actualNavigations = (0, react_2.useMemo)(() => buildNavigations(navigations), [navigations]);
    return ((0, jsx_runtime_1.jsx)(AppNavi_1.AppNavi, { label: enableNew ? undefined : appName, displayDropdownCaret: true, additionalArea: (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", className: "shr-flex-nowrap shr-ps-1", children: [additionalContent, releaseNote && (0, jsx_runtime_1.jsx)(ReleaseNotesDropdown_1.ReleaseNotesDropdown, { ...releaseNote })] }), "data-with-releasenote": !!releaseNote, className: className, children: actualNavigations }));
};
exports.Navigation = Navigation;
const buildNavigations = (navigations) => navigations.map((navigation, index) => {
    if ('elementAs' in navigation) {
        const { elementAs, ...rest } = navigation;
        return (0, react_1.createElement)(AppNavi_1.AppNaviCustomTag, { ...rest, key: index, tag: elementAs });
    }
    if ('href' in navigation) {
        return (0, react_1.createElement)(AppNavi_1.AppNaviAnchor, { ...navigation, key: index });
    }
    if ('childNavigations' in navigation) {
        return ((0, jsx_runtime_1.jsx)(AppNavi_1.AppNaviDropdownMenuButton, { label: navigation.children, children: buildDropdownMenu(navigation.childNavigations) }, index));
    }
    return (0, react_1.createElement)(AppNavi_1.AppNaviButton, { ...navigation, key: index });
});
const buildDropdownMenu = (navigations) => navigations.map((navigation, index) => {
    if ('elementAs' in navigation) {
        return (0, react_1.createElement)(DropdownCustomTag, { ...navigation, key: index });
    }
    if ('href' in navigation) {
        return (0, react_1.createElement)(DropdownMenuAnchorButton, { ...navigation, key: index });
    }
    if ('title' in navigation) {
        return ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownMenuGroup, { name: navigation.title, children: buildDropdownMenu(navigation.childNavigations) }, index));
    }
    return (0, react_1.createElement)(DropdownNavigationButton, { ...navigation, key: index });
});
const DropdownCustomTag = (0, react_2.memo)(({ elementAs: Component, current, className, ...rest }) => {
    const actualClassName = (0, react_2.useMemo)(() => (0, CommonButton_1.commonButtonClassNameGenerator)({
        current,
        className,
    }), [current, className]);
    return (0, jsx_runtime_1.jsx)(Component, { ...rest, "aria-current": current || undefined, className: actualClassName });
});
const DropdownMenuAnchorButton = (0, react_2.memo)(({ current, ...rest }) => ((0, jsx_runtime_1.jsx)(Button_1.AnchorButton, { ...rest, "aria-current": current ? 'page' : undefined })));
const DropdownNavigationButton = (0, react_2.memo)(({ current, ...rest }) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { ...rest, "aria-current": current ? 'page' : undefined })));
//# sourceMappingURL=Navigation.js.map