"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActualUserInfo = exports.UserInfo = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../../Button");
const Dropdown_1 = require("../../../Dropdown");
const Icon_1 = require("../../../Icon");
const Layout_1 = require("../../../Layout");
const Text_1 = require("../../../Text");
const useTranslate_1 = require("../../hooks/useTranslate");
const utils_1 = require("../../utils");
const CommonButton_1 = require("../common/CommonButton");
const Translate_1 = require("../common/Translate");
// HeaderDropdownMenuButton と同じスタイルを適用
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        userSummary: [
            'shr-relative -shr-mx-0.25 -shr-mt-0.5 shr-p-1',
            // FIXME: smarthr-ui で DropdownMenuButton のグルーピングができるようになったら修正しましょう
            'after:shr-absolute after:shr-inset-x-0.5 after:shr-bottom-0 after:shr-block after:shr-h-px after:shr-bg-border after:shr-content-[""]',
        ],
        dropdownMenuButton: [
            '[&_.smarthr-ui-DropdownMenuButton-trigger]:shr-border-transparent [&_.smarthr-ui-DropdownMenuButton-trigger]:shr-px-0.5 [&_.smarthr-ui-DropdownMenuButton-trigger]:shr-font-normal',
        ],
        dropdownContentButton: [
            '[&&.smarthr-ui-AnchorButton]:shr-p-0.75 [&&.smarthr-ui-AnchorButton]:shr-py-0.75',
            '[&&.smarthr-ui-Button]:shr-p-0.75 [&&.smarthr-ui-Button]:shr-py-0.75',
        ],
        button: [
            '[&&]:shr-border-transparent [&&]:shr-font-normal [&&]:last-of-type:-shr-me-0.25',
            '[&&]:focus-visible:shr-bg-transparent',
            "[&[aria-expanded='true']_.smarthr-ui-Icon:last-child]:shr-rotate-180",
        ],
        dropdownContent: '[&&]:shr-whitespace-pre [&&]:shr-p-0.5',
        accountImage: '',
        placeholderImage: 'shr-p-0.5',
    },
    variants: {
        enableNew: {
            true: {
                button: '[&&]:shr-px-0.5',
            },
            false: {
                button: '[&&]:shr-bg-transparent [&&]:shr-px-0.25 [&&]:shr-text-white [&&]:hover:shr-bg-transparent',
            },
        },
    },
    compoundSlots: [
        {
            slots: ['accountImage', 'placeholderImage'],
            className: 'shr-border-shorthand -shr-my-1 shr-box-border shr-flex shr-size-2 shr-items-center shr-justify-center shr-rounded-full shr-bg-white',
        },
    ],
});
const UserInfo = ({ arbitraryDisplayName, email, empCode, firstName, lastName, accountUrl, desktopAdditionalContent, ...rest }) => {
    const displayName = (0, react_1.useMemo)(() => arbitraryDisplayName ??
        (0, utils_1.buildDisplayName)({
            email,
            empCode,
            firstName,
            lastName,
        }), [arbitraryDisplayName, email, empCode, firstName, lastName]);
    if (!displayName) {
        return null;
    }
    if (!accountUrl && !desktopAdditionalContent) {
        return (0, jsx_runtime_1.jsx)("span", { className: "shr-text-white", children: displayName });
    }
    return ((0, jsx_runtime_1.jsx)(exports.ActualUserInfo, { ...rest, email: email, empCode: empCode, firstName: firstName, lastName: lastName, accountUrl: accountUrl, desktopAdditionalContent: desktopAdditionalContent, displayName: displayName }));
};
exports.UserInfo = UserInfo;
const ActualUserInfo = ({ email, empCode, firstName, lastName, tenants, currentTenantId, accountUrl, accountImageUrl, desktopAdditionalContent, enableNew, displayName, }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { userSummary, dropdownMenuButton, dropdownContentButton, button, dropdownContent, accountImage, placeholderImage, } = classNameGenerator({
            enableNew,
        });
        return {
            userSummary: userSummary(),
            dropdownMenuButton: dropdownMenuButton(),
            dropdownContentButton: dropdownContentButton(),
            button: button(),
            dropdownContent: dropdownContent(),
            accountImage: accountImage(),
            placeholderImage: placeholderImage(),
        };
    }, [enableNew]);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        userSetting: translate('common/userSetting'),
    }), [translate]);
    const currentTenantName = (0, react_1.useMemo)(() => tenants?.find((tenant) => tenant.id === currentTenantId)?.name, [tenants, currentTenantId]);
    if (enableNew) {
        return ((0, jsx_runtime_1.jsxs)(Dropdown_1.DropdownMenuButton, { className: classNames.dropdownMenuButton, label: (0, jsx_runtime_1.jsx)(DropdownMenuLabel, { firstName: firstName, lastName: lastName, email: email, accountImageUrl: accountImageUrl, currentTenantName: currentTenantName, accountImageClassName: classNames.accountImage, placeHolderImageClassName: classNames.placeholderImage }), children: [(0, jsx_runtime_1.jsx)(UserSummaryStack, { currentTenantName: currentTenantName, empCode: empCode, firstName: firstName, lastName: lastName, email: email, className: classNames.userSummary }), (0, jsx_runtime_1.jsx)(DropdownContentButton, { href: accountUrl, className: classNames.dropdownContentButton, children: translated.userSetting }), desktopAdditionalContent] }));
    }
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { children: [(0, jsx_runtime_1.jsx)(DisplayNameDropdownTrigger, { className: classNames.button, children: displayName }), (0, jsx_runtime_1.jsxs)(Dropdown_1.DropdownContent, { className: classNames.dropdownContent, children: [(0, jsx_runtime_1.jsx)(AccountLink, { href: accountUrl, children: translated.userSetting }), desktopAdditionalContent] })] }));
};
exports.ActualUserInfo = ActualUserInfo;
const DropdownMenuLabel = (0, react_1.memo)(({ firstName, lastName, email, accountImageUrl, currentTenantName, accountImageClassName, placeHolderImageClassName, }) => {
    const body = [];
    if (currentTenantName) {
        body.push(currentTenantName);
    }
    if (firstName && lastName) {
        body.push(`${firstName} ${lastName}`);
    }
    else if (email) {
        body.push(email);
    }
    if (body.length === 2) {
        body.splice(1, 0, (0, jsx_runtime_1.jsx)("br", {}));
    }
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { as: "span", align: "flex-start", children: [accountImageUrl ? (
            // eslint-disable-next-line smarthr/a11y-image-has-alt-attribute, jsx-a11y/alt-text
            (0, jsx_runtime_1.jsx)("img", { src: accountImageUrl, className: accountImageClassName, "aria-hidden": true })) : ((0, jsx_runtime_1.jsx)("span", { className: placeHolderImageClassName, children: (0, jsx_runtime_1.jsx)(Icon_1.FaUserIcon, { color: "TEXT_GREY" }) })), (0, jsx_runtime_1.jsx)(Text_1.Text, { size: "XS", leading: "NORMAL", className: "-shr-my-1 shr-text-left", children: body })] }));
});
const UserSummaryStack = (0, react_1.memo)(({ currentTenantName, empCode, firstName, lastName, email, className }) => ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: className, children: [(0, jsx_runtime_1.jsx)(Text_1.Text, { size: "S", color: "TEXT_GREY", weight: "bold", leading: "TIGHT", children: currentTenantName }), empCode || (firstName && lastName) ? ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", children: [empCode && ((0, jsx_runtime_1.jsx)(Text_1.Text, { size: "S", color: "TEXT_GREY", leading: "TIGHT", children: empCode })), firstName && lastName && (0, jsx_runtime_1.jsx)(Text_1.Text, { leading: "TIGHT", children: `${lastName} ${firstName}` })] })) : ((0, jsx_runtime_1.jsx)(Text_1.Text, { leading: "TIGHT", children: email }))] })));
const DropdownContentButton = (0, react_1.memo)(({ href, children, className }) => href && ((0, jsx_runtime_1.jsx)(Button_1.AnchorButton, { href: href, target: "_blank", rel: "noopener noreferrer", prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaGearIcon, {}), className: className, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) })));
const DisplayNameDropdownTrigger = (0, react_1.memo)(({ children, className }) => ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "text", suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}), className: className, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }) })));
const AccountLink = (0, react_1.memo)(({ href, children }) => href && ((0, jsx_runtime_1.jsx)(CommonButton_1.CommonButton, { elementAs: "a", href: href, target: "_blank", rel: "noopener noreferrer", prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaGearIcon, {}), children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) })));
//# sourceMappingURL=UserInfo.js.map