"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppLauncher = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../../Button");
const Icon_1 = require("../../../Icon");
const Input_1 = require("../../../Input");
const Layout_1 = require("../../../Layout");
const Text_1 = require("../../../Text");
const TextLink_1 = require("../../../TextLink");
const useAppLauncher_1 = require("../../hooks/useAppLauncher");
const useTranslate_1 = require("../../hooks/useTranslate");
const AppLauncherFeatures_1 = require("../common/AppLauncherFeatures");
const AppLauncherSortDropdown_1 = require("../common/AppLauncherSortDropdown");
const Translate_1 = require("../common/Translate");
const AppLauncherFilterDropdown_1 = require("./AppLauncherFilterDropdown");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: ['smarthr-ui-AppLauncher', 'shr-flex shr-h-full shr-flex-col'],
        searchArea: [
            'smarthr-ui-AppLauncher-searchArea',
            'shr-border-b-shorthand shr-px-1 shr-py-0.75',
            '[&_.smarthr-ui-Input]:shr-h-[42px]',
        ],
        headArea: 'shr-px-1 shr-py-0.75',
        scrollArea: 'shr-flex-1 shr-basis-0 shr-overflow-y-scroll',
        bottomArea: 'shr-border-t-shorthand shr-px-1 shr-py-0.75',
    },
});
const AppLauncher = ({ features: baseFeatures }) => {
    const { features, page, mode, sortType, searchQuery, changePage, setSortType, onChangeSearchQuery, onClickClearSearchQuery, } = (0, useAppLauncher_1.useAppLauncher)(baseFeatures);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, searchArea, headArea, scrollArea, bottomArea } = classNameGenerator();
        return {
            wrapper: wrapper(),
            searchArea: searchArea(),
            headArea: headArea(),
            scrollArea: scrollArea(),
            bottomArea: bottomArea(),
        };
    }, []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        searchInputTitle: translate('Launcher/searchInputTitle'),
        searchResultText: translate('Launcher/searchResultText'),
        helpText: translate('Launcher/helpText'),
    }), [translate]);
    return ((0, jsx_runtime_1.jsxs)("div", { className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.searchArea, children: (0, jsx_runtime_1.jsx)(Input_1.SearchInput, { name: "search", title: translated.searchInputTitle, tooltipMessage: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.searchInputTitle }), width: "100%", value: searchQuery, suffix: mode === 'search' && (0, jsx_runtime_1.jsx)(ClearSearchButton, { onClick: onClickClearSearchQuery }), onChange: onChangeSearchQuery }) }), (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { className: classNames.headArea, justify: "space-between", align: "center", children: [mode === 'search' ? ((0, jsx_runtime_1.jsx)(SearchResultText, { children: translated.searchResultText })) : ((0, jsx_runtime_1.jsx)(AppLauncherFilterDropdown_1.AppLauncherFilterDropdown, { page: page, onSelectPage: changePage })), (mode === 'search' || page === 'all') && ((0, jsx_runtime_1.jsx)(AppLauncherSortDropdown_1.AppLauncherSortDropdown, { sortType: sortType, onSelectSortType: setSortType }))] }), (0, jsx_runtime_1.jsx)("div", { className: classNames.scrollArea, children: (0, jsx_runtime_1.jsx)(AppLauncherFeatures_1.AppLauncherFeatures, { features: features, page: page }) }), (0, jsx_runtime_1.jsx)(BottomArea, { className: classNames.bottomArea, children: translated.helpText })] }));
};
exports.AppLauncher = AppLauncher;
const ClearSearchButton = (0, react_1.memo)(({ onClick }) => ((0, jsx_runtime_1.jsx)(Button_1.UnstyledButton, { onClick: onClick, children: (0, jsx_runtime_1.jsx)(Icon_1.FaCircleXmarkIcon, {}) })));
const SearchResultText = (0, react_1.memo)(({ children }) => ((0, jsx_runtime_1.jsx)(Text_1.Text, { size: "S", weight: "bold", children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) })));
const BottomArea = (0, react_1.memo)(({ children, className }) => ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(Text_1.Text, { size: "XS", children: (0, jsx_runtime_1.jsx)(TextLink_1.HelpLink, { href: "https://support.smarthr.jp/ja/help/articles/2bfd350d-8e8b-4bbd-a209-426d2eb302cc/", target: "_blank", children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }) }) })));
//# sourceMappingURL=AppLauncher.js.map