"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppLauncherFilterDropdown = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const themes_1 = require("../../../../themes");
const Button_1 = require("../../../Button");
const Dropdown_1 = require("../../../Dropdown");
const Icon_1 = require("../../../Icon");
const useTranslate_1 = require("../../hooks/useTranslate");
const Translate_1 = require("../common/Translate");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        trigger: [
            'smarthr-ui-AppLauncher-SortDropdown-trigger',
            'shr-gap-0.25 shr-text-grey',
            '[&[aria-expanded="true"]_.smarthr-ui-Icon]:shr-rotate-180',
        ],
        contentBody: ['shr-flex shr-flex-col shr-items-stretch shr-px-0.25 shr-py-0.5'],
        contentButton: [
            'shr-justify-start shr-border-none shr-py-0.75 shr-pl-2.5 shr-font-normal',
            'aria-selected:shr-pl-1',
        ],
    },
});
exports.AppLauncherFilterDropdown = (0, react_1.memo)(({ page, onSelectPage }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { trigger, contentBody, contentButton } = classNameGenerator();
        return {
            trigger: trigger(),
            contentBody: contentBody(),
            contentButton: contentButton(),
        };
    }, []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        favorite: translate('Launcher/favoriteModeText'),
        all: translate('MobileHeader/Menu/allAppButton'),
        checkIconAlt: translate('Launcher/sortDropdownSelected'),
    }), [translate]);
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { children: [(0, jsx_runtime_1.jsx)(MemoizedDropdownTrigger, { className: classNames.trigger, children: translated[page] }), (0, jsx_runtime_1.jsx)(Dropdown_1.DropdownContent, { children: (0, jsx_runtime_1.jsx)(ContentBody, { page: page, onSelectPage: onSelectPage, translated: translated, className: classNames.contentBody, buttonClassName: classNames.contentButton }) })] }));
});
const MemoizedDropdownTrigger = (0, react_1.memo)(({ children, className }) => ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { className: className, size: "s", suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}), children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }) })));
const ContentBody = (0, react_1.memo)(({ page, onSelectPage, translated, className, buttonClassName }) => {
    const isFavorite = page === 'favorite';
    const onClickButton = (0, react_1.useCallback)((e) => {
        onSelectPage(e.currentTarget.value);
    }, [onSelectPage]);
    const buttonPrefix = ((0, jsx_runtime_1.jsx)(Icon_1.FaCheckIcon, { color: themes_1.textColor.main, alt: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.checkIconAlt }) }));
    return ((0, jsx_runtime_1.jsxs)("div", { role: "listbox", className: className, children: [(0, jsx_runtime_1.jsx)(Button_1.Button, { value: "favorite", role: "option", "aria-selected": isFavorite, onClick: onClickButton, className: buttonClassName, prefix: isFavorite && buttonPrefix, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.favorite }) }), (0, jsx_runtime_1.jsx)(Button_1.Button, { value: "all", role: "option", "aria-selected": !isFavorite, onClick: onClickButton, className: buttonClassName, prefix: !isFavorite && buttonPrefix, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.all }) })] }));
});
//# sourceMappingURL=AppLauncherFilterDropdown.js.map