"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Menu = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useHandleEscape_1 = require("../../../../hooks/useHandleEscape");
const usePortal_1 = require("../../../../hooks/usePortal");
const Button_1 = require("../../../Button");
const Icon_1 = require("../../../Icon");
const useTranslate_1 = require("../../hooks/useTranslate");
const Translate_1 = require("../common/Translate");
const AppLauncherContext_1 = require("./AppLauncherContext");
const MenuAccordion_1 = require("./MenuAccordion");
const MenuButton_1 = require("./MenuButton");
const MenuDialog_1 = require("./MenuDialog");
const Navigation_1 = require("./Navigation");
const NavigationContext_1 = require("./NavigationContext");
const ReleaseNoteContext_1 = require("./ReleaseNoteContext");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: ['shr-border-t-shorthand shr-py-1', 'first:shr-border-t-0 first:shr-pt-0'],
});
let scrollPosition = 0;
const Menu = ({ appName, tenantSelector, additionalContent }) => {
    const [isOpen, setIsOpen] = (0, react_1.useState)(false);
    const open = (0, react_1.useCallback)(() => setIsOpen(true), []);
    const close = (0, react_1.useCallback)(() => setIsOpen(false), []);
    const { createPortal } = (0, usePortal_1.usePortal)();
    (0, react_1.useEffect)(() => {
        if (isOpen) {
            scrollPosition = window.scrollY;
            document.body.style.overflow = 'hidden';
        }
        else {
            document.body.style.overflow = 'auto';
            setTimeout(() => window.scrollTo(0, scrollPosition), 0);
        }
    }, [isOpen]);
    (0, useHandleEscape_1.useHandleEscape)(close);
    const className = (0, react_1.useMemo)(() => classNameGenerator(), []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        open: translate('MobileHeader/Menu/openMenu'),
        launcherListText: translate('Launcher/listText'),
        management: translate('MobileHeader/Menu/managementMenu'),
        releaseNote: translate('common/releaseNote'),
    }), [translate]);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(OpenButton, { onClick: open, alt: translated.open }), createPortal((0, jsx_runtime_1.jsxs)(MenuDialog_1.MenuDialog, { isOpen: isOpen, setIsOpen: setIsOpen, tenantSelector: tenantSelector, children: [(0, jsx_runtime_1.jsx)(FeatureButton, { className: className, children: translated.launcherListText }), (0, jsx_runtime_1.jsx)(NavigationAccordion, { appName: appName, menuClose: close, className: className }), additionalContent && ((0, jsx_runtime_1.jsx)(AdditionalContent, { title: translated.management, className: className, children: additionalContent })), (0, jsx_runtime_1.jsx)(ReleaseNoteButton, { className: className, children: translated.releaseNote })] }))] }));
};
exports.Menu = Menu;
const OpenButton = (0, react_1.memo)(({ onClick, alt }) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { size: "s", onClick: onClick, "aria-haspopup": "true", children: (0, jsx_runtime_1.jsx)(Icon_1.FaBarsIcon, { alt: alt }) })));
const FeatureButton = (0, react_1.memo)(({ children, className }) => {
    const { features, setIsAppLauncherSelected } = (0, react_1.useContext)(AppLauncherContext_1.AppLauncherContext);
    return (features &&
        features.length > 0 && ((0, jsx_runtime_1.jsx)(ActualFeatureButton, { setIsAppLauncherSelected: setIsAppLauncherSelected, className: className, children: children })));
});
const ActualFeatureButton = ({ setIsAppLauncherSelected, children, className }) => {
    const onClick = (0, react_1.useCallback)(() => setIsAppLauncherSelected(true), [setIsAppLauncherSelected]);
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "secondary", wide: true, prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaToolboxIcon, {}), suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaAngleRightIcon, { className: "shr-ms-auto" }), onClick: onClick, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }) }));
};
const NavigationAccordion = (0, react_1.memo)(({ appName, menuClose, className }) => {
    const { navigations } = (0, react_1.useContext)(NavigationContext_1.NavigationContext);
    const children = (0, jsx_runtime_1.jsx)(Navigation_1.Navigation, { navigations: navigations, onClickNavigation: menuClose });
    return navigations.length > 0 && appName ? ((0, jsx_runtime_1.jsx)(ActualNavigationAccordion, { appName: appName, className: className, children: children })) : ((0, jsx_runtime_1.jsx)("div", { className: className, children: children }));
});
const ActualNavigationAccordion = ({ appName, children, className }) => {
    const [isOpen, setIsOpen] = (0, react_1.useState)(true);
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(MenuAccordion_1.MenuAccordion, { isOpen: isOpen, setIsOpen: setIsOpen, title: appName, children: children }) }));
};
const AdditionalContent = ({ title, children, className, }) => {
    const [isOpen, setIsOpen] = (0, react_1.useState)(true);
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(MenuAccordion_1.MenuAccordion, { isOpen: isOpen, setIsOpen: setIsOpen, title: title, children: children }) }));
};
const ReleaseNoteButton = (0, react_1.memo)(({ children, className }) => {
    const { releaseNote, setIsReleaseNoteSelected } = (0, react_1.useContext)(ReleaseNoteContext_1.ReleaseNoteContext);
    return (releaseNote && ((0, jsx_runtime_1.jsx)(ActualReleaseNoteButton, { setIsReleaseNoteSelected: setIsReleaseNoteSelected, className: className, children: children })));
});
const ActualReleaseNoteButton = (0, react_1.memo)(({ setIsReleaseNoteSelected, children, className }) => {
    const onClick = (0, react_1.useCallback)(() => setIsReleaseNoteSelected(true), [setIsReleaseNoteSelected]);
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(MenuButton_1.MenuButton, { onClick: onClick, children: children }) }));
});
//# sourceMappingURL=Menu.js.map