"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Content = exports.MenuDialog = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_transition_group_1 = require("react-transition-group");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../../Button");
const FocusTrap_1 = require("../../../Dialog/FocusTrap");
const Icon_1 = require("../../../Icon");
const Layout_1 = require("../../../Layout");
const SectioningContent_1 = require("../../../SectioningContent");
const useTranslate_1 = require("../../hooks/useTranslate");
const AppLauncher_1 = require("./AppLauncher");
const AppLauncherContext_1 = require("./AppLauncherContext");
const MenuSubHeading_1 = require("./MenuSubHeading");
const Navigation_1 = require("./Navigation");
const NavigationContext_1 = require("./NavigationContext");
const ReleaseNote_1 = require("./ReleaseNote");
const ReleaseNoteContext_1 = require("./ReleaseNoteContext");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'shr-fixed shr-left-0 shr-top-0 shr-flex shr-h-full shr-w-full shr-flex-col shr-bg-white',
            'shr-translate-opacity shr-opacity-0 shr-duration-150',
            '[&&.shr-sp-menu-enter-active]:shr-opacity-100',
            '[&&.shr-sp-menu-enter-done]:shr-opacity-100',
            '[&&.shr-sp-menu-exit-active]:shr-opacity-0',
            '[&&.shr-sp-menu-exit-done]:shr-opacity-0',
        ],
        header: 'shr-border-b-shorthand shr-sticky shr-top-0 shr-px-0.75 shr-py-0.5',
        content: 'shr-overflow-auto shr-p-1',
    },
});
const MenuDialog = ({ isOpen, ...rest }) => {
    const domRef = (0, react_1.useRef)(null);
    return ((0, jsx_runtime_1.jsx)(react_transition_group_1.CSSTransition, { classNames: "shr-sp-menu", in: isOpen, timeout: 300, unmountOnExit: true, nodeRef: domRef, children: (0, jsx_runtime_1.jsx)("div", { className: "shr-fixed shr-z-overlap-base", children: (0, jsx_runtime_1.jsx)(FocusTrap_1.FocusTrap, { children: (0, jsx_runtime_1.jsx)(exports.Content, { ...rest, domRef: domRef }) }) }) }));
};
exports.MenuDialog = MenuDialog;
const Content = ({ domRef, children, setIsOpen, tenantSelector }) => {
    const { selectedNavigationGroup, setSelectedNavigationGroup } = (0, react_1.useContext)(NavigationContext_1.NavigationContext);
    const { isReleaseNoteSelected, setIsReleaseNoteSelected } = (0, react_1.useContext)(ReleaseNoteContext_1.ReleaseNoteContext);
    const { features, isAppLauncherSelected, setIsAppLauncherSelected } = (0, react_1.useContext)(AppLauncherContext_1.AppLauncherContext);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, header, content } = classNameGenerator();
        return {
            wrapper: wrapper(),
            header: header(),
            content: content(),
        };
    }, []);
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        launcherListText: translate('Launcher/listText'),
        latestReleaseNotes: translate('MobileHeader/Menu/latestReleaseNotes'),
        closeMenu: translate('MobileHeader/Menu/closeMenu'),
    }), [translate]);
    const dialogClose = (0, react_1.useCallback)(() => setIsOpen(false), [setIsOpen]);
    const clearAppLauncher = (0, react_1.useCallback)(() => setIsAppLauncherSelected(false), [setIsAppLauncherSelected]);
    const clearReleaseNote = (0, react_1.useCallback)(() => setIsReleaseNoteSelected(false), [setIsReleaseNoteSelected]);
    const clearNavigationGroup = (0, react_1.useCallback)(() => setSelectedNavigationGroup(null), [setSelectedNavigationGroup]);
    // HINT: Contentをanimationで非表示にしたい
    // アニメーションが終われば、CSSTransitionのchildrenはunmountされるため、
    // unmount時に操作内容のclearを行う
    (0, react_1.useEffect)(() => () => {
        clearReleaseNote();
        clearAppLauncher();
        clearNavigationGroup();
    }, [clearAppLauncher, clearReleaseNote, clearNavigationGroup]);
    return ((0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { role: "dialog", "aria-modal": "true", className: classNames.wrapper, ref: domRef, children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.header, children: (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { justify: "space-between", align: "center", children: [isAppLauncherSelected ? ((0, jsx_runtime_1.jsx)(MenuSubHeading_1.MenuSubHeading, { title: translated.launcherListText, onClickBack: clearAppLauncher })) : isReleaseNoteSelected ? (
                        // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
                        (0, jsx_runtime_1.jsx)(MenuSubHeading_1.MenuSubHeading, { title: translated.latestReleaseNotes, onClickBack: clearReleaseNote })) : selectedNavigationGroup ? (
                        // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
                        (0, jsx_runtime_1.jsx)(MenuSubHeading_1.MenuSubHeading, { title: selectedNavigationGroup.children, onClickBack: clearNavigationGroup })) : ((0, jsx_runtime_1.jsx)("div", { children: tenantSelector })), (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "secondary", size: "s", onClick: dialogClose, children: (0, jsx_runtime_1.jsx)(Icon_1.FaXmarkIcon, { alt: translated.closeMenu }) })] }) }), isAppLauncherSelected && features && features.length > 0 ? ((0, jsx_runtime_1.jsx)(AppLauncher_1.AppLauncher, { features: features })) : ((0, jsx_runtime_1.jsx)("div", { className: classNames.content, children: isReleaseNoteSelected ? ((0, jsx_runtime_1.jsx)(ReleaseNote_1.ReleaseNote, {})) : selectedNavigationGroup ? ((0, jsx_runtime_1.jsx)(Navigation_1.Navigation, { navigations: selectedNavigationGroup.childNavigations, onClickNavigation: dialogClose })) : (children) }))] }));
};
exports.Content = Content;
//# sourceMappingURL=MenuDialog.js.map