"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NavigationItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const utils_1 = require("../../utils");
const CommonButton_1 = require("../common/CommonButton");
const Translate_1 = require("../common/Translate");
const MenuButton_1 = require("./MenuButton");
const NavigationContext_1 = require("./NavigationContext");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: ['[&&]:shr-px-0.5'],
});
const NavigationItem = ({ navigation, onClickNavigation }) => {
    const className = classNameGenerator();
    if ('elementAs' in navigation) {
        return ((0, jsx_runtime_1.jsx)(NavigationCustomTag, { ...navigation, onClickNavigation: onClickNavigation, className: `${className} ${navigation.className}` }));
    }
    if ('href' in navigation) {
        return (0, jsx_runtime_1.jsx)(NavigationLink, { ...navigation, className: className });
    }
    if ('onClick' in navigation) {
        return ((0, jsx_runtime_1.jsx)(NavigationButton, { navigation: navigation, onClickNavigation: onClickNavigation, className: className }));
    }
    return (0, jsx_runtime_1.jsx)(NavigationGroupMenuButton, { navigation: navigation });
};
exports.NavigationItem = NavigationItem;
const NavigationCustomTag = (0, react_1.memo)(({ children, elementAs: Tag, current, className, onClickNavigation, ...rest }) => {
    const actualClassName = (0, react_1.useMemo)(() => (0, CommonButton_1.commonButtonClassNameGenerator)({
        current,
        boldWhenCurrent: true,
        className,
    }), [current, className]);
    return (
    // eslint-disable-next-line smarthr/a11y-delegate-element-has-role-presentation
    (0, jsx_runtime_1.jsx)(Tag, { ...rest, onClick: onClickNavigation, className: actualClassName, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) }));
});
const NavigationLink = (0, react_1.memo)(({ href, current, children, className }) => ((0, jsx_runtime_1.jsx)(CommonButton_1.CommonButton, { elementAs: "a", href: href, current: current, boldWhenCurrent: true, className: className, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: children }) })));
const NavigationButton = ({ navigation, onClickNavigation, className }) => {
    const onClick = (0, react_1.useCallback)((e) => {
        navigation.onClick(e);
        onClickNavigation();
    }, [navigation, onClickNavigation]);
    return ((0, jsx_runtime_1.jsx)(CommonButton_1.CommonButton, { elementAs: "button", type: "button", onClick: onClick, current: navigation.current, boldWhenCurrent: true, className: className, children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: navigation.children }) }));
};
const NavigationGroupMenuButton = ({ navigation }) => {
    const { setSelectedNavigationGroup } = (0, react_1.useContext)(NavigationContext_1.NavigationContext);
    const onClick = (0, react_1.useCallback)(() => setSelectedNavigationGroup(navigation), [navigation, setSelectedNavigationGroup]);
    // 子要素に current を持っているものがあるかどうか
    const isCurrent = (0, react_1.useMemo)(() => navigation.current ||
        navigation.childNavigations.some((child) => {
            if ((0, utils_1.isChildNavigation)(child)) {
                return child.current;
            }
            return child.childNavigations.some((c) => c.current);
        }), [navigation]);
    return ((0, jsx_runtime_1.jsx)(MenuButton_1.MenuButton, { onClick: onClick, isCurrent: isCurrent, children: navigation.children }));
};
//# sourceMappingURL=NavigationItem.js.map