"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReleaseNote = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Icon_1 = require("../../../Icon");
const Layout_1 = require("../../../Layout");
const Loader_1 = require("../../../Loader");
const Text_1 = require("../../../Text");
const useTranslate_1 = require("../../hooks/useTranslate");
const Translate_1 = require("../common/Translate");
const ReleaseNoteContext_1 = require("./ReleaseNoteContext");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        anchor: ['shr-text-base shr-text-link [&&]:shr-underline', '[&&]:hover:shr-no-underline'],
        icon: ['shr-ms-0.5'],
        indexLinkWrapper: ['shr-mt-2 shr-text-end'],
        indexLinkAnchor: [
            'shr-text-base shr-text-link [&&]:shr-no-underline',
            '[&&]:hover:shr-underline',
        ],
    },
});
exports.ReleaseNote = (0, react_1.memo)(() => {
    const { releaseNote } = (0, react_1.useContext)(ReleaseNoteContext_1.ReleaseNoteContext);
    return releaseNote ? (0, jsx_runtime_1.jsx)(ActualReleaseNote, { data: releaseNote }) : null;
});
const ActualReleaseNote = ({ data }) => {
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        error: translate('common/releaseNotesLoadError'),
        seeAll: translate('common/seeAllReleaseNotes'),
    }), [translate]);
    const classNames = (0, react_1.useMemo)(() => {
        const { anchor, icon, indexLinkWrapper, indexLinkAnchor } = classNameGenerator();
        return {
            anchor: anchor(),
            icon: icon(),
            indexLinkWrapper: indexLinkWrapper(),
            indexLinkAnchor: indexLinkAnchor(),
        };
    }, []);
    return ((0, jsx_runtime_1.jsxs)("div", { children: [data.loading ? ((0, jsx_runtime_1.jsx)(Layout_1.Center, { children: (0, jsx_runtime_1.jsx)(Loader_1.Loader, {}) })) : data.error ? ((0, jsx_runtime_1.jsx)(Text_1.Text, { children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.error }) })) : ((0, jsx_runtime_1.jsx)(Layout_1.Stack, { children: data.links.slice(0, 5).map((link) => ((0, jsx_runtime_1.jsx)("div", { children: (0, jsx_runtime_1.jsxs)("a", { href: link.url, target: "_blank", rel: "noopener noreferrer", className: classNames.anchor, children: [link.title, (0, jsx_runtime_1.jsx)(Icon_1.FaUpRightFromSquareIcon, { className: classNames.icon })] }) }, link.url))) })), (0, jsx_runtime_1.jsx)("div", { className: classNames.indexLinkWrapper, children: (0, jsx_runtime_1.jsxs)("a", { href: data.indexUrl, target: "_blank", rel: "noopener noreferrer", className: classNames.indexLinkAnchor, children: [(0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.seeAll }), (0, jsx_runtime_1.jsx)(Icon_1.FaUpRightFromSquareIcon, { className: classNames.icon })] }) })] }));
};
//# sourceMappingURL=ReleaseNote.js.map