"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TenantSelector = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Dropdown_1 = require("../../../Dropdown");
const Icon_1 = require("../../../Icon");
const Text_1 = require("../../../Text");
const CommonButton_1 = require("../common/CommonButton");
const tenantDropdownTriggerButton = (0, tailwind_variants_1.tv)({
    base: [
        'shr-cursor-pointer shr-rounded-s shr-border-none shr-bg-white shr-px-0.5 shr-py-0.25 shr-text-start shr-text-sm',
        'hover:shr-bg-white-darken',
        '[&[aria-expanded="true"]_.smarthr-ui-Icon:last-child]:shr-rotate-180',
    ],
});
const TenantSelector = ({ tenants, currentTenantId, onTenantSelect }) => {
    const tenantName = (0, react_1.useMemo)(() => {
        if (!tenants || !currentTenantId || tenants.length === 0) {
            return null;
        }
        return tenants.find((tenant) => tenant.id === currentTenantId)?.name;
    }, [tenants, currentTenantId]);
    return tenantName ? ((0, jsx_runtime_1.jsx)(ActualTenantSelector, { tenants: tenants, currentTenantId: currentTenantId, onTenantSelect: onTenantSelect, tenantName: tenantName })) : null;
};
exports.TenantSelector = TenantSelector;
const ActualTenantSelector = ({ tenants, currentTenantId, onTenantSelect, tenantName, }) => {
    if (tenants.length === 1 || !onTenantSelect) {
        return (0, jsx_runtime_1.jsx)(Text_1.Text, { as: "p", children: tenantName });
    }
    return ((0, jsx_runtime_1.jsx)(TenantDropdown, { tenants: tenants, currentTenantId: currentTenantId, onTenantSelect: onTenantSelect, tenantName: tenantName }));
};
const TenantDropdown = ({ tenants, currentTenantId, onTenantSelect, tenantName }) => {
    const onClickTenantName = (0, react_1.useCallback)((e) => {
        onTenantSelect(e.currentTarget.value);
    }, [onTenantSelect]);
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { children: [(0, jsx_runtime_1.jsx)(MemoizedTenantDropdownTrigger, { children: tenantName }), (0, jsx_runtime_1.jsx)(Dropdown_1.DropdownContent, { controllable: true, children: (0, jsx_runtime_1.jsx)("div", { className: "shr-p-0.5", children: tenants.map((tenant) => {
                        const isCurrent = tenant.id === currentTenantId;
                        return ((0, jsx_runtime_1.jsx)(CommonButton_1.CommonButton, { elementAs: "button", type: "button", value: tenant.id, current: isCurrent, onClick: isCurrent ? undefined : onClickTenantName, children: tenant.name }, tenant.id));
                    }) }) })] }));
};
const MemoizedTenantDropdownTrigger = (0, react_1.memo)(({ children }) => {
    const actualClassName = (0, react_1.useMemo)(() => tenantDropdownTriggerButton(), []);
    return ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsxs)("button", { type: "button", className: actualClassName, children: [children, (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, { className: "shr-ms-0.5", color: "TEXT_BLACK" })] }) }));
});
//# sourceMappingURL=TenantSelector.js.map