"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserInfo = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../../../Button");
const Dialog_1 = require("../../../Dialog");
const Dropdown_1 = require("../../../Dropdown");
const Icon_1 = require("../../../Icon");
const useLocale_1 = require("../../hooks/useLocale");
const useTranslate_1 = require("../../hooks/useTranslate");
const utils_1 = require("../../utils");
const CommonButton_1 = require("../common/CommonButton");
const Translate_1 = require("../common/Translate");
const LanguageSelector_1 = require("./LanguageSelector");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        iconButton: ['[&&&]:shr-border-transparent [&&]:shr-p-0.25'],
        iconButtonInner: [
            'shr-border-shorthand shr-block shr-flex shr-items-center shr-justify-center shr-rounded-full shr-bg-white shr-p-0.25',
        ],
        dropdownUserName: ['shr-box-border shr-min-w-[246px] shr-px-1 shr-py-0.75 shr-text-sm'],
        dropdownButtonArea: ['shr-border-t-shorthand shr-p-0.5'],
    },
});
exports.UserInfo = (0, react_1.memo)(({ arbitraryDisplayName, email, empCode, firstName, lastName, accountUrl }) => {
    const displayName = (0, react_1.useMemo)(() => arbitraryDisplayName ??
        (0, utils_1.buildDisplayName)({
            email,
            empCode,
            firstName,
            lastName,
        }), [arbitraryDisplayName, email, empCode, firstName, lastName]);
    return displayName ? (0, jsx_runtime_1.jsx)(ActualUserInfo, { accountUrl: accountUrl, displayName: displayName }) : null;
});
const ActualUserInfo = ({ displayName, accountUrl, }) => {
    const [languageDialogOpen, setLanguageDialogOpen] = (0, react_1.useState)(false);
    const dialogOpen = (0, react_1.useCallback)(() => setLanguageDialogOpen(true), []);
    const dialogClose = (0, react_1.useCallback)(() => setLanguageDialogOpen(false), []);
    const { locale } = (0, useLocale_1.useLocale)();
    const translate = (0, useTranslate_1.useTranslate)();
    const translated = (0, react_1.useMemo)(() => ({
        account: translate('MobileHeader/UserInfo/account'),
        userSetting: translate('common/userSetting'),
    }), [translate]);
    const classNames = (0, react_1.useMemo)(() => {
        const { iconButton, iconButtonInner, dropdownUserName, dropdownButtonArea } = classNameGenerator();
        return {
            iconButton: iconButton(),
            iconButtonInner: iconButtonInner(),
            dropdownUserName: dropdownUserName(),
            dropdownButtonArea: dropdownButtonArea(),
        };
    }, []);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { children: [(0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "skeleton", size: "s", className: classNames.iconButton, children: (0, jsx_runtime_1.jsx)("span", { className: classNames.iconButtonInner, children: (0, jsx_runtime_1.jsx)(Icon_1.FaUserLargeIcon, { alt: translated.account, className: "shr-fill-grey" }) }) }) }), (0, jsx_runtime_1.jsxs)(Dropdown_1.DropdownContent, { children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.dropdownUserName, children: (0, jsx_runtime_1.jsx)("p", { children: displayName }) }), (locale || accountUrl) && ((0, jsx_runtime_1.jsxs)("div", { className: classNames.dropdownButtonArea, children: [locale && ((0, jsx_runtime_1.jsx)(CommonButton_1.CommonButton, { elementAs: "button", type: "button", onClick: dialogOpen, prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaGlobeIcon, {}), children: "Language" })), accountUrl && ((0, jsx_runtime_1.jsx)(CommonButton_1.CommonButton, { elementAs: "a", href: accountUrl, target: "_blank", rel: "noopener noreferrer", prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaGearIcon, {}), children: (0, jsx_runtime_1.jsx)(Translate_1.Translate, { children: translated.userSetting }) }))] }))] })] }), locale && ((0, jsx_runtime_1.jsx)(Dialog_1.Dialog, { isOpen: languageDialogOpen, onClickOverlay: dialogClose, width: 246, children: (0, jsx_runtime_1.jsx)(LanguageSelector_1.LanguageSelector, { locale: locale, onClickClose: dialogClose }) }))] }));
};
//# sourceMappingURL=UserInfo.js.map