"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Badge = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Text_1 = require("../Text");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Badge shr-relative shr-inline-flex',
        pill: ['shr-h-[1.75em] shr-min-w-[1.75em] shr-px-[0.5em] shr-tabular-nums'],
        dotElement: ['shr-h-[0.625em] shr-w-[0.625em]'],
    },
    variants: {
        color: {
            grey: {},
            blue: {},
            yellow: {},
            red: {},
        },
        withChildren: {
            true: {},
        },
    },
    compoundSlots: [
        {
            slots: ['pill', 'dotElement'],
            className: [
                'shr-box-border shr-flex shr-items-center shr-justify-center',
                'shr-rounded-full',
            ],
        },
        {
            slots: ['pill', 'dotElement'],
            withChildren: true,
            className: [
                'shr-absolute -shr-translate-y-1/2 shr-translate-x-1/2 [inset-block-start:0] [inset-inline-end:0]',
            ],
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'blue',
            className: 'shr-bg-main',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'yellow',
            className: 'shr-bg-warning-yellow',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'red',
            className: 'shr-bg-danger',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'grey',
            className: 'shr-bg-[theme(colors.grey.65)]',
        },
        {
            slots: ['pill', 'dotElement'],
            color: ['grey', 'blue', 'red'],
            className: 'shr-shadow-[0_0_0_1px_theme(colors.white)]',
        },
        {
            slots: ['pill', 'dotElement'],
            color: 'yellow',
            className: 'shr-shadow-[0_0_0_1px_theme(colors.black)]',
        },
        {
            slots: ['pill'],
            color: ['grey', 'blue', 'red'],
            className: 'shr-text-white',
        },
        {
            slots: ['pill'],
            color: ['yellow'],
            className: 'shr-text-black',
        },
    ],
});
exports.Badge = (0, react_1.memo)(({ count, showZero, ...rest }) => {
    // ドット表示の場合、数値表示は無いため、早期returnする
    if (rest.dot) {
        return (0, jsx_runtime_1.jsx)(ActualBadge, { ...rest });
    }
    const actualCount = count && count > 0 ? count : showZero ? 0 : undefined;
    // 0値を表示するでもない場合は何も表示しない
    if (actualCount === undefined && !rest.children) {
        return null;
    }
    return (0, jsx_runtime_1.jsx)(ActualBadge, { ...rest, count: actualCount });
});
const ActualBadge = ({ count, overflowCount, type, dot, children, className, ...rest }) => {
    // HINT: boolean化することでmemoが有効になる可能性を高くする
    const withChildren = !!children;
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, pill, dotElement } = classNameGenerator({
            color: type || 'blue',
            withChildren,
        });
        return {
            wrapper: wrapper({ className }),
            pill: pill(),
            dot: dotElement(),
        };
    }, [withChildren, type, className]);
    return ((0, jsx_runtime_1.jsxs)("span", { ...rest, className: classNames.wrapper, children: [children, dot ? ((0, jsx_runtime_1.jsx)(Dot, { className: classNames.dot })) : ((0, jsx_runtime_1.jsx)(CountText, { count: count, overflowCount: overflowCount, className: classNames.pill }))] }));
};
const Dot = (0, react_1.memo)(({ className }) => (0, jsx_runtime_1.jsx)("span", { className: className }));
const CountText = (0, react_1.memo)(({ count, overflowCount = 99, className }) => count !== undefined && ((0, jsx_runtime_1.jsx)(Text_1.Text, { size: "XS", className: className, children: count > overflowCount ? `${overflowCount}+` : count })));
//# sourceMappingURL=Badge.js.map