"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Browser = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../hooks/useDecorators");
const intl_1 = require("../../intl");
const Text_1 = require("../Text");
const BrowserColumn_1 = require("./BrowserColumn");
const models_1 = require("./models");
const utils_1 = require("./utils");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: 'smarthr-ui-Browser shr-flex shr-min-h-[355px] shr-flex-row shr-flex-nowrap',
    variants: {
        columnCount: {
            0: 'shr-items-center shr-justify-center',
            1: '[&>div]:shr-flex-1',
            2: '[&>div:nth-child(1)]:shr-flex-1 [&>div:nth-child(2)]:shr-flex-[2]',
            3: '[&>div]:shr-flex-1',
        },
    },
    defaultVariants: {
        columnCount: 0,
    },
});
const Browser = ({ value, items, decorators, onSelectItem }) => {
    const { localize } = (0, intl_1.useIntl)();
    const rootNode = (0, react_1.useMemo)(() => models_1.RootNode.from({ children: items }), [items]);
    const columns = (0, react_1.useMemo)(() => rootNode.toViewData(value), [rootNode, value]);
    const className = (0, react_1.useMemo)(() => classNameGenerator({ columnCount: columns.length }), [columns.length]);
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        notFoundTitle: localize({
            id: 'smarthr-ui/Browser/notFoundTitle',
            defaultText: '該当する項目がありません。',
        }),
        notFoundDescription: localize({
            id: 'smarthr-ui/Browser/notFoundDescription',
            defaultText: '別の条件を試してください。',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    const selectedNode = (0, react_1.useMemo)(() => (value ? rootNode.findByValue(value) : undefined), [value, rootNode]);
    // FIXME: focusメソッドのfocusVisibleが主要ブラウザでサポートされたら使うようにしたい(現状ではマウスクリックでもfocusのoutlineが出てしまう)
    // https://developer.mozilla.org/ja/docs/Web/API/HTMLElement/focus
    const handleKeyDown = (0, react_1.useCallback)((e) => {
        if (!selectedNode) {
            return;
        }
        let target = undefined;
        switch (e.key) {
            case 'ArrowUp': {
                target = selectedNode.getPrev() ?? selectedNode.parent?.getLastChild();
                break;
            }
            case 'ArrowDown': {
                target = selectedNode.getNext() ?? selectedNode.parent?.getFirstChild();
                break;
            }
            case 'ArrowLeft': {
                const node = selectedNode.parent;
                if (node instanceof models_1.ItemNode) {
                    target = node;
                }
                break;
            }
            case 'ArrowRight':
            case 'Enter':
            case ' ': {
                target = selectedNode.getFirstChild();
                break;
            }
        }
        if (target) {
            e.preventDefault();
            onSelectItem?.(target.value);
            document.getElementById((0, utils_1.getElementIdFromNode)(target.value))?.focus();
        }
    }, [selectedNode, onSelectItem]);
    const onChangeInput = (0, react_1.useMemo)(() => onSelectItem
        ? (e) => onSelectItem(e.currentTarget.value)
        : undefined, [onSelectItem]);
    return (
    // eslint-disable-next-line smarthr/a11y-delegate-element-has-role-presentation, jsx-a11y/no-noninteractive-element-interactions
    (0, jsx_runtime_1.jsx)("div", { role: "application", onKeyDown: handleKeyDown, className: className, children: columns.length > 0 ? (columns.map((colItems, index) => ((0, jsx_runtime_1.jsx)(BrowserColumn_1.BrowserColumn, { items: colItems, index: index, value: value, onChangeInput: onChangeInput }, index)))) : ((0, jsx_runtime_1.jsxs)(Text_1.Text, { children: [decorated.notFoundTitle, (0, jsx_runtime_1.jsx)("br", {}), decorated.notFoundDescription] })) }));
};
exports.Browser = Browser;
//# sourceMappingURL=Browser.js.map