"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RootNode = void 0;
const ItemNode_1 = require("./ItemNode");
const NodeContext_1 = require("./NodeContext");
class RootNode {
    context;
    constructor(children) {
        this.context = new NodeContext_1.NodeContext(this);
        for (const child of children) {
            this.append(child);
        }
    }
    static from(rootNodeLike) {
        return new RootNode(rootNodeLike.children.map((itemNodeLike) => ItemNode_1.ItemNode.from(itemNodeLike)));
    }
    get children() {
        return this.context.children.map((child) => child.node);
    }
    append(that) {
        this.context.append(that.context);
    }
    getFirstChild() {
        return this.children.at(0);
    }
    getLastChild() {
        return this.children.at(-1);
    }
    findByValue(value) {
        for (const child of this.children) {
            const found = child.findByValue(value);
            if (found) {
                return found;
            }
        }
        return;
    }
    toViewData(value) {
        if (this.children.length <= 0) {
            return [];
        }
        if (!value) {
            return [this.children];
        }
        const pivot = this.findByValue(value);
        if (!pivot) {
            return [this.children];
        }
        const viewData = [
            ...pivot.getAncestors().map((ancestor) => ancestor.getSiblings()),
            pivot.getSiblings(),
        ];
        if (pivot.children.length > 0) {
            viewData.push(pivot.children);
        }
        return viewData;
    }
}
exports.RootNode = RootNode;
//# sourceMappingURL=RootNode.js.map