"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Button = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const usePortal_1 = require("../../hooks/usePortal");
const intl_1 = require("../../intl");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const ButtonWrapper_1 = require("./ButtonWrapper");
const DisabledDetail_1 = require("./DisabledDetail");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Button',
    },
});
exports.Button = (0, react_1.forwardRef)(({ type = 'button', size = 'default', prefix, suffix, wide = false, variant = 'secondary', disabled, disabledDetail, className, children, loading = false, ...props }, ref) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
        };
    }, [className]);
    const button = ((0, jsx_runtime_1.jsxs)(ButtonWrapper_1.ButtonWrapper, { ...props, buttonRef: ref, type: type, size: size, wide: wide, variant: variant, className: classNames.wrapper, "$loading": loading, prefix: prefix, suffix: suffix, disabled: disabled, children: [(0, jsx_runtime_1.jsx)(LoadingStatus, { loading: loading }), children] }));
    if (disabled && disabledDetail) {
        return (0, jsx_runtime_1.jsx)(DisabledDetail_1.DisabledDetail, { button: button, disabledDetail: disabledDetail });
    }
    return button;
});
// BottomFixedArea での判定に用いるために displayName を明示的に設定する
exports.Button.displayName = 'Button';
const LoadingStatus = (0, react_1.memo)(({ loading }) => {
    const { createPortal } = (0, usePortal_1.usePortal)();
    // `button` 要素内で live region を使うことはできないので、`role="status"` を持つ要素を外側に配置している。 https://github.com/kufu/smarthr-ui/pull/4558
    return createPortal((0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { role: "status", children: loading && (0, jsx_runtime_1.jsx)(intl_1.Localizer, { id: "smarthr-ui/Button/loading", defaultText: "\u51E6\u7406\u4E2D" }) }));
});
//# sourceMappingURL=Button.js.map