"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Calendar = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const dayjs_1 = __importDefault(require("dayjs"));
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const CalendarTable_1 = require("./CalendarTable");
const YearPicker_1 = require("./YearPicker");
const calendarHelper_1 = require("./calendarHelper");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'smarthr-ui-Calendar shr-inline-block shr-overflow-hidden shr-rounded-m shr-bg-white shr-text-black shr-shadow-layer-3 forced-colors:shr-border-shorthand forced-colors:shr-shadow-none',
        header: 'smarthr-ui-Calendar-header shr-border-b-shorthand shr-flex shr-items-center shr-p-1',
        yearMonth: 'smarthr-ui-Calendar-yearMonth shr-me-0.5 shr-text-base shr-font-bold',
        monthButtons: 'smarthr-ui-Calendar-monthButtons shr-ms-auto shr-flex',
        tableLayout: 'shr-relative',
        yearSelectButton: 'smarthr-ui-Calendar-selectingYear [&[aria-expanded="true"]_.smarthr-ui-Icon]:shr-rotate-180',
    },
});
exports.Calendar = (0, react_1.forwardRef)(({ from = calendarHelper_1.minDate, to, onSelectDate, value, className, ...props }, ref) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { container, yearMonth, header, monthButtons, tableLayout, yearSelectButton } = classNameGenerator();
        return {
            container: container({ className }),
            header: header(),
            yearMonth: yearMonth(),
            monthButtons: monthButtons(),
            tableLayout: tableLayout(),
            yearSelectButton: yearSelectButton(),
        };
    }, [className]);
    const formattedFrom = (0, react_1.useMemo)(() => {
        const date = (0, calendarHelper_1.getFromDate)(from);
        const day = (0, dayjs_1.default)(date);
        return {
            day,
            date,
            year: day.year(),
        };
    }, [from]);
    const formattedTo = (0, react_1.useMemo)(() => {
        const date = (0, calendarHelper_1.getToDate)(to);
        const day = (0, dayjs_1.default)(date);
        return {
            day,
            date,
            year: day.year(),
        };
    }, [to]);
    const isValidValue = (0, react_1.useMemo)(() => value && (0, calendarHelper_1.isBetween)(value, formattedFrom.date, formattedTo.date), [value, formattedFrom.date, formattedTo.date]);
    const [currentMonth, setCurrentMonth] = (0, react_1.useState)((() => {
        if (isValidValue) {
            return (0, dayjs_1.default)(value);
        }
        const today = (0, dayjs_1.default)();
        return formattedTo.day.isBefore(today)
            ? formattedTo.day
            : formattedFrom.day.isAfter(today)
                ? formattedFrom.day
                : today;
    })());
    const [isSelectingYear, setIsSelectingYear] = (0, react_1.useState)(false);
    const yearPickerId = (0, react_1.useId)();
    (0, react_1.useEffect)(() => {
        if (isValidValue) {
            setCurrentMonth((0, dayjs_1.default)(value));
        }
    }, [value, isValidValue]);
    const calculatedCurrentMonth = (0, react_1.useMemo)(() => ({
        prev: currentMonth.subtract(1, 'month'),
        next: currentMonth.add(1, 'month'),
        day: currentMonth,
        months: (0, calendarHelper_1.getMonthArray)(currentMonth.toDate()),
        yearMonthText: `${currentMonth.year()}年${currentMonth.month() + 1}月`,
        selectedText: currentMonth.toString(),
    }), [currentMonth]);
    const onSelectYear = (0, react_1.useCallback)((e) => {
        setCurrentMonth(currentMonth.year(parseInt(e.currentTarget.value, 10)));
        setIsSelectingYear(false);
    }, [currentMonth]);
    const onClickSelectYear = (0, react_1.useCallback)((e) => {
        e.stopPropagation();
        setIsSelectingYear((current) => !current);
    }, []);
    return ((0, jsx_runtime_1.jsxs)("div", { ...props, ref: ref, className: classNames.container, children: [(0, jsx_runtime_1.jsxs)("header", { className: classNames.header, children: [(0, jsx_runtime_1.jsx)(YearMonthRender, { className: classNames.yearMonth, children: calculatedCurrentMonth.yearMonthText }), (0, jsx_runtime_1.jsx)(YearSelectButton, { "aria-expanded": isSelectingYear, "aria-controls": yearPickerId, onClick: onClickSelectYear, className: classNames.yearSelectButton }), (0, jsx_runtime_1.jsx)(MonthDirectionCluster, { isSelectingYear: isSelectingYear, directionMonth: calculatedCurrentMonth, from: formattedFrom.day, to: formattedTo.day, setCurrentMonth: setCurrentMonth, className: classNames.monthButtons })] }), (0, jsx_runtime_1.jsxs)("div", { className: classNames.tableLayout, children: [(0, jsx_runtime_1.jsx)(YearPicker_1.YearPicker, { fromYear: formattedFrom.year, toYear: formattedTo.year, selectedYear: value?.getFullYear(), onSelectYear: onSelectYear, isDisplayed: isSelectingYear, id: yearPickerId }), (0, jsx_runtime_1.jsx)(CalendarTable_1.CalendarTable, { current: calculatedCurrentMonth, from: formattedFrom.date, to: formattedTo.date, onSelectDate: onSelectDate, selectedDayText: isValidValue ? calculatedCurrentMonth.selectedText : '' })] })] }));
});
const YearMonthRender = (0, react_1.memo)(({ children, className }) => (0, jsx_runtime_1.jsx)("div", { className: className, children: children }));
const YearSelectButton = (0, react_1.memo)((rest) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { ...rest, size: "s", children: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, { alt: "\u5E74\u3092\u9078\u629E\u3059\u308B" }) })));
const MonthDirectionCluster = (0, react_1.memo)(({ isSelectingYear, directionMonth: { prev, next }, from, to, setCurrentMonth, className }) => {
    const onClickMonthPrev = (0, react_1.useCallback)(() => setCurrentMonth(prev), [prev, setCurrentMonth]);
    const onClickMonthNext = (0, react_1.useCallback)(() => setCurrentMonth(next), [next, setCurrentMonth]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: 0.5, className: className, children: [(0, jsx_runtime_1.jsx)(Button_1.Button, { disabled: isSelectingYear || prev.isBefore(from, 'month'), onClick: onClickMonthPrev, size: "s", className: "smarthr-ui-Calendar-monthButtonPrev", children: (0, jsx_runtime_1.jsx)(Icon_1.FaChevronLeftIcon, { alt: "\u524D\u306E\u6708\u3078" }) }), (0, jsx_runtime_1.jsx)(Button_1.Button, { disabled: isSelectingYear || next.isAfter(to, 'month'), onClick: onClickMonthNext, size: "s", className: "smarthr-ui-Calendar-monthButtonNext", children: (0, jsx_runtime_1.jsx)(Icon_1.FaChevronRightIcon, { alt: "\u6B21\u306E\u6708\u3078" }) })] }));
});
//# sourceMappingURL=Calendar.js.map