"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CalendarTable = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const dayjs_1 = __importDefault(require("dayjs"));
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const calendarHelper_1 = require("./calendarHelper");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'shr-px-0.75 shr-pb-1 shr-pt-0.25',
        table: 'smarthr-ui-CalendarTable shr-border-spacing-0 shr-text-base shr-text-black',
        th: 'smarthr-ui-CalendarTable-headCell shr-px-0 shr-py-0.5 shr-text-center shr-align-middle shr-font-normal shr-text-grey',
        td: 'smarthr-ui-CalendarTable-dataCell shr-p-0 shr-align-middle',
        cellButton: 'shr-group shr-flex shr-items-center shr-justify-center shr-px-0.5 shr-py-0.25 disabled:shr-cursor-not-allowed disabled:shr-text-disabled',
        dateCell: [
            'shr-box-border shr-flex shr-h-[1.75rem] shr-w-[1.75rem] shr-items-center shr-justify-center shr-rounded-[50%] shr-leading-[0] group-[:not(:disabled)]:group-hover:shr-bg-base-grey group-[:not(:disabled)]:group-hover:shr-text-black',
            '[[aria-pressed="true"]>&&&]:shr-bg-main [[aria-pressed="true"]>&&&]:shr-text-white',
            '[[data-is-today="true"]>&&&]:shr-border-shorthand [[aria-pressed="true"]>&&&]:contrast-more:shr-border-high-contrast',
        ],
    },
});
const CalendarTable = ({ current, from, to, onSelectDate, selectedDayText, className, ...props }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, table, th, td, cellButton, dateCell } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            table: table(),
            th: th(),
            td: td(),
            cellButton: cellButton(),
            dateCell: dateCell(),
        };
    }, [className]);
    // HINT: dayjsのisSameは文字列でも比較可能なため、cacheが効きやすいstringにする
    const nowDateText = (0, dayjs_1.default)().startOf('date').toString();
    return ((0, jsx_runtime_1.jsx)("div", { className: classNames.wrapper, children: (0, jsx_runtime_1.jsxs)("table", { ...props, className: classNames.table, children: [(0, jsx_runtime_1.jsx)(MemoizedThead, { thStyle: classNames.th }), (0, jsx_runtime_1.jsx)("tbody", { children: current.months.map((week, weekIndex) => ((0, jsx_runtime_1.jsx)("tr", { children: week.map((date, dateIndex) => date ? ((0, jsx_runtime_1.jsx)(SelectTdButton, { date: date, currentDay: current.day, selectedDayText: selectedDayText, from: from, to: to, nowDateText: nowDateText, onClick: onSelectDate, classNames: classNames }, dateIndex)) : ((0, jsx_runtime_1.jsx)(NullTd, { className: classNames.td }, dateIndex))) }, weekIndex))) })] }) }));
};
exports.CalendarTable = CalendarTable;
const MemoizedThead = (0, react_1.memo)(({ thStyle }) => ((0, jsx_runtime_1.jsx)("thead", { children: (0, jsx_runtime_1.jsx)("tr", { children: calendarHelper_1.daysInWeek.map((day) => ((0, jsx_runtime_1.jsx)("th", { className: thStyle, children: day }, day))) }) })));
const NullTd = (0, react_1.memo)(({ className }) => (0, jsx_runtime_1.jsx)("td", { className: className }));
const SelectTdButton = (0, react_1.memo)(({ date, currentDay, selectedDayText, from, to, nowDateText, onClick, classNames }) => {
    const target = (0, react_1.useMemo)(() => {
        const day = currentDay.date(date);
        return {
            day,
            date: day.toDate(),
        };
    }, [currentDay, date]);
    const disabled = (0, react_1.useMemo)(() => !(0, calendarHelper_1.isBetween)(target.date, from, to), [target.date, from, to]);
    const ariaPressed = (0, react_1.useMemo)(() => target.day.isSame(selectedDayText, 'date'), [selectedDayText, target.day]);
    const dataIsToday = (0, react_1.useMemo)(() => target.day.isSame(nowDateText, 'date'), [nowDateText, target.day]);
    const actualOnClick = (0, react_1.useCallback)((e) => {
        onClick(e, target.date);
    }, [onClick, target.date]);
    return ((0, jsx_runtime_1.jsx)("td", { className: classNames.td, children: (0, jsx_runtime_1.jsx)(Button_1.UnstyledButton, { type: "button", disabled: disabled, "aria-pressed": ariaPressed, onClick: actualOnClick, className: classNames.cellButton, "data-is-today": dataIsToday, children: (0, jsx_runtime_1.jsx)(SelectButtonTdDateCell, { className: classNames.dateCell, children: date }) }) }));
});
const SelectButtonTdDateCell = (0, react_1.memo)(({ children, className }) => (0, jsx_runtime_1.jsx)("span", { className: className, children: children }));
//# sourceMappingURL=CalendarTable.js.map