"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.YearPicker = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        overlay: 'smarthr-ui-YearPicker shr-absolute shr-inset-0 shr-bg-white',
        container: 'shr-box-border shr-flex shr-h-full shr-w-full shr-flex-wrap shr-items-start shr-overflow-y-auto shr-px-0.25 shr-py-0.5',
        yearButton: 'smarthr-ui-YearPicker-selectYear shr-group shr-flex shr-w-1/4 shr-items-center shr-justify-center shr-px-0 shr-py-0.5 shr-leading-none',
        yearWrapper: [
            'shr-box-border shr-inline-block shr-rounded-full shr-px-0.75 shr-py-0.5 shr-text-base shr-leading-none group-hover:shr-bg-base-grey group-hover:shr-text-black',
            '[[data-this-year="true"]>&]:shr-border-shorthand',
            '[[aria-pressed="true"]>&]:shr-bg-main [[aria-pressed="true"]>&]:shr-text-white',
        ],
    },
});
const YearPicker = ({ isDisplayed, ...rest }) => isDisplayed ? (0, jsx_runtime_1.jsx)(ActualYearPicker, { ...rest }) : null;
exports.YearPicker = YearPicker;
const ActualYearPicker = ({ selectedYear, fromYear, toYear, onSelectYear, id, ...props }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { overlay, container, yearButton, yearWrapper } = classNameGenerator();
        return {
            overlay: overlay(),
            container: container(),
            yearButton: yearButton(),
            yearWrapper: yearWrapper(),
        };
    }, []);
    const focusingRef = (0, react_1.useRef)(null);
    const thisYear = (0, react_1.useMemo)(() => new Date().getFullYear(), []);
    const yearArray = (0, react_1.useMemo)(() => {
        const length = Math.max(Math.min(toYear, 9999) - fromYear + 1, 0);
        const result = [];
        for (let i = 0; i < length; i++) {
            result[i] = fromYear + i;
        }
        return result;
    }, [toYear, fromYear]);
    (0, react_1.useEffect)(() => {
        if (focusingRef.current) {
            // HINT: 現在の年に一度focusを当てることでtab移動をしやすくする
            // focusを当てたままでは違和感があるため、blurで解除している
            focusingRef.current.focus();
            focusingRef.current.blur();
        }
    }, []);
    return ((0, jsx_runtime_1.jsx)("div", { ...props, id: id, className: classNames.overlay, children: (0, jsx_runtime_1.jsx)("div", { className: classNames.container, children: yearArray.map((year) => ((0, jsx_runtime_1.jsx)(YearButton, { year: year, thisYear: thisYear, selected: selectedYear === year, focusingRef: focusingRef, className: classNames.yearButton, childrenStyle: classNames.yearWrapper, onClick: onSelectYear }, year))) }) }));
};
const YearButton = (0, react_1.memo)(({ year, thisYear, selected, focusingRef, onClick, className, childrenStyle }) => {
    const isThisYear = thisYear === year;
    return ((0, jsx_runtime_1.jsx)(Button_1.UnstyledButton, { ref: isThisYear ? focusingRef : null, value: year, "aria-pressed": selected, onClick: onClick, className: className, "data-this-year": isThisYear, children: (0, jsx_runtime_1.jsx)("span", { className: childrenStyle, children: year }) }));
});
//# sourceMappingURL=YearPicker.js.map