"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Checkbox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Icon_1 = require("../Icon");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Checkbox shr-inline-flex shr-items-baseline',
        box: [
            'shr-border-shorthand shr-pointer-events-none shr-absolute shr-box-border shr-h-full shr-w-full shr-rounded-s shr-bg-white',
            'contrast-more:shr-border-high-contrast',
            /* 強制カラーモードのときは、ブラウザ標準のUIを表示する */
            'forced-colors:shr-hidden',
            'peer-checked:shr-border-main peer-checked:shr-bg-main contrast-more:peer-checked:shr-border-high-contrast',
            'peer-indeterminate:shr-border-main peer-indeterminate:shr-bg-main contrast-more:peer-indeterminate:shr-border-high-contrast',
            'peer-disabled:shr-border-disabled peer-disabled:shr-bg-white-darken',
            'peer-disabled:peer-checked:shr-border-default peer-disabled:peer-checked:shr-bg-border',
            'peer-disabled:peer-indeterminate:shr-border-default peer-disabled:peer-indeterminate:shr-bg-border',
            'peer-focus-visible:shr-focus-indicator',
            'peer-hover:shr-shadow-input-hover',
            'shr-border-default',
            'peer-[[aria-invalid]]:shr-border-danger',
        ],
        input: [
            'smarthr-ui-Checkbox-checkbox shr-peer shr-absolute shr-left-0 shr-top-0 shr-m-0 shr-h-full shr-w-full shr-cursor-pointer shr-opacity-0 disabled:shr-pointer-events-none',
            /* 強制カラーモードのときは、ブラウザ標準のUIを表示する */
            'forced-colors:shr-static forced-colors:shr-opacity-100',
        ],
        icon: 'shr-fill-current',
        iconWrap: [
            'shr-pointer-events-none shr-absolute shr-left-1/2 shr-top-1/2 shr-inline-block shr-h-[theme(fontSize.2xs)] shr-w-[theme(fontSize.2xs)] -shr-translate-x-1/2 -shr-translate-y-1/2 shr-text-2xs',
            'shr-text-transparent peer-checked:shr-text-white peer-indeterminate:shr-text-white',
            'peer-disabled:peer-checked:shr-text-white-darken peer-disabled:peer-indeterminate:shr-text-white-darken',
            'forced-colors:shr-hidden',
        ],
        innerWrapper: 'shr-relative shr-box-border shr-inline-block shr-h-[theme(fontSize.base)] shr-w-[theme(fontSize.base)] shr-shrink-0 shr-translate-y-[0.125em] shr-leading-none',
        label: [
            'smarthr-ui-Checkbox-label shr-ms-0.5 shr-cursor-pointer shr-text-base shr-leading-tight',
            '[[data-disabled=true]>&]:shr-pointer-events-none [[data-disabled=true]>&]:shr-cursor-not-allowed [[data-disabled=true]>&]:shr-text-disabled',
        ],
    },
});
exports.Checkbox = (0, react_1.forwardRef)(({ checked, mixed, error, className, children, disabled, ...props }, ref) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, innerWrapper, box, input, iconWrap, icon, label } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            innerWrapper: innerWrapper(),
            box: box(),
            input: input(),
            iconWrap: iconWrap(),
            icon: icon(),
            label: label(),
        };
    }, [className]);
    const inputRef = (0, react_1.useRef)(null);
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    (0, react_1.useEffect)(() => {
        if (inputRef.current) {
            inputRef.current.indeterminate = !!(checked && mixed);
        }
    }, [checked, mixed]);
    const defaultId = (0, react_1.useId)();
    const checkBoxId = props.id || defaultId;
    return ((0, jsx_runtime_1.jsxs)("span", { "data-disabled": disabled, className: classNames.wrapper, children: [(0, jsx_runtime_1.jsxs)("span", { className: classNames.innerWrapper, children: [(0, jsx_runtime_1.jsx)("input", { ...props, ref: inputRef, type: "checkbox", id: checkBoxId, checked: checked, disabled: disabled, "aria-invalid": error || undefined, className: classNames.input, "data-smarthr-ui-input": "true" }), (0, jsx_runtime_1.jsx)(AriaHiddenBox, { className: classNames.box }), (0, jsx_runtime_1.jsx)(CheckIconArea, { mixed: mixed, className: classNames.iconWrap, iconClassName: classNames.icon })] }), (0, jsx_runtime_1.jsx)(LabeledChildren, { htmlFor: checkBoxId, className: classNames.label, children: children })] }));
});
const AriaHiddenBox = (0, react_1.memo)(({ className }) => ((0, jsx_runtime_1.jsx)("span", { className: className, "aria-hidden": "true" })));
const CheckIconArea = (0, react_1.memo)(({ mixed, className, iconClassName }) => ((0, jsx_runtime_1.jsx)("span", { className: className, children: mixed ? ((0, jsx_runtime_1.jsx)(Icon_1.FaMinusIcon, { className: iconClassName })) : ((0, jsx_runtime_1.jsx)(Icon_1.FaCheckIcon, { className: iconClassName })) })));
const LabeledChildren = (0, react_1.memo)(({ children, htmlFor, className }) => children && ((0, jsx_runtime_1.jsx)("label", { htmlFor: htmlFor, className: className, children: children })));
//# sourceMappingURL=Checkbox.js.map