"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ItemButton = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Icon_1 = require("../Icon");
const Text_1 = require("../Text");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'shr-block shr-min-w-full shr-cursor-pointer shr-border-none shr-px-1 shr-py-0.5 shr-text-left shr-text-base shr-leading-tight',
        'aria-selected:shr-text-white',
        'disabled:shr-cursor-not-allowed disabled:shr-text-disabled',
        'data-[active=true]:shr-bg-white-darken data-[active=true]:aria-selected:shr-bg-main-darken',
        'data-[active=false]:shr-bg-white data-[active=false]:aria-selected:shr-bg-main',
    ],
    variants: {
        new: {
            true: 'smarthr-ui-Combobox-addButton shr-flex shr-items-center',
            false: 'smarthr-ui-Combobox-selectButton',
        },
    },
});
const ItemButton = ({ option, onAdd, onSelect, onMouseOver, activeRef }) => {
    const handleMouseOver = (0, react_1.useCallback)(() => {
        onMouseOver(option);
    }, [onMouseOver, option]);
    const commonProps = {
        option,
        onMouseOver: handleMouseOver,
        activeRef,
    };
    return option.isNew ? ((0, jsx_runtime_1.jsx)(AddButton, { ...commonProps, onAdd: onAdd })) : ((0, jsx_runtime_1.jsx)(SelectButton, { ...commonProps, onSelect: onSelect }));
};
const typedMemo = react_1.memo;
const Memoized = typedMemo(ItemButton);
exports.ItemButton = Memoized;
const AddButton = ({ activeRef, option, onAdd, onMouseOver, }) => {
    const className = (0, react_1.useMemo)(() => classNameGenerator({
        new: true,
    }), []);
    const onClick = (0, react_1.useMemo)(() => onAdd
        ? () => {
            onAdd(option);
        }
        : undefined, [option, onAdd]);
    return ((0, jsx_runtime_1.jsx)("button", { ref: activeRef, type: "button", role: "option", "aria-selected": false, id: option.id, "data-active": !!activeRef, onClick: onClick, 
        // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
        onMouseOver: onMouseOver, className: className, children: (0, jsx_runtime_1.jsx)(MemoizedNewIconWithText, { label: option.item.label }) }));
};
const MemoizedNewIconWithText = (0, react_1.memo)(({ label }) => ((0, jsx_runtime_1.jsx)(Icon_1.FaCirclePlusIcon, { color: "TEXT_LINK", text: (0, jsx_runtime_1.jsxs)(Text_1.Text, { color: "TEXT_LINK", children: ["\u300C", label, "\u300D\u3092\u8FFD\u52A0"] }) })));
const SelectButton = ({ activeRef, option, onSelect, onMouseOver, }) => {
    const className = (0, react_1.useMemo)(() => classNameGenerator({
        new: false,
    }), []);
    const handleSelect = (0, react_1.useCallback)(() => {
        onSelect(option);
    }, [onSelect, option]);
    return ((0, jsx_runtime_1.jsx)("button", { ref: activeRef, type: "button", role: "option", id: option.id, disabled: option.item.disabled, "aria-selected": option.selected, "data-active": !!activeRef, onClick: handleSelect, 
        // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
        onMouseOver: onMouseOver, className: className, children: option.item.label }));
};
//# sourceMappingURL=ItemButton.js.map