import { type ComponentProps, type ComponentPropsWithoutRef } from 'react';
import { MultiSelectedItem } from './MultiSelectedItem';
import type { DecoratorsType } from '../../../hooks/useDecorators';
import type { BaseProps, ComboboxItem } from '../types';
type Props<T> = BaseProps<T> & {
    /**
     * 選択されているアイテムのリスト
     */
    selectedItems: Array<ComboboxItem<T> & {
        deletable?: boolean;
    }>;
    /**
     * 選択されているアイテムのラベルを省略表示するかどうか
     */
    selectedItemEllipsis?: boolean;
    /**
     * テキストボックスの `value` 属性の値。
     * `onChangeInput` と併せて設定することで、テキストボックスの挙動が制御可能になる。
     */
    inputValue?: string;
    /**
     * 選択されているアイテムの削除ボタンがクリックされた時に発火するコールバック関数
     */
    onDelete?: (item: ComboboxItem<T>) => void;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: (selectedItems: Array<ComboboxItem<T>>) => void;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: () => void;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: () => void;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: DecoratorsType<'noResultText'> & Exclude<ComponentProps<typeof MultiSelectedItem>['decorators'], undefined> & {
        selectedListAriaLabel?: (text: string) => string;
    };
    /**
     * アイテムが選択されたときに選択済みかどうかを判定するコールバック関数/
     */
    isItemSelected?: (targetItem: ComboboxItem<T>, selectedItems: Array<ComboboxItem<T>>) => boolean;
};
type ElementProps = Omit<ComponentPropsWithoutRef<'input'>, keyof Props<unknown>>;
export declare const MultiCombobox: <T>(props: BaseProps<T> & {
    /**
     * 選択されているアイテムのリスト
     */
    selectedItems: (ComboboxItem<T> & {
        deletable?: boolean;
    })[];
    /**
     * 選択されているアイテムのラベルを省略表示するかどうか
     */
    selectedItemEllipsis?: boolean;
    /**
     * テキストボックスの `value` 属性の値。
     * `onChangeInput` と併せて設定することで、テキストボックスの挙動が制御可能になる。
     */
    inputValue?: string;
    /**
     * 選択されているアイテムの削除ボタンがクリックされた時に発火するコールバック関数
     */
    onDelete?: ((item: ComboboxItem<T>) => void) | undefined;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: ((selectedItems: ComboboxItem<T>[]) => void) | undefined;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: () => void;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: () => void;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: DecoratorsType<"noResultText"> & Exclude<ComponentProps<typeof MultiSelectedItem>["decorators"], undefined> & {
        selectedListAriaLabel?: (text: string) => string;
    };
    /**
     * アイテムが選択されたときに選択済みかどうかを判定するコールバック関数/
     */
    isItemSelected?: ((targetItem: ComboboxItem<T>, selectedItems: ComboboxItem<T>[]) => boolean) | undefined;
} & ElementProps & import("react").RefAttributes<HTMLInputElement>) => import("react").ReactNode;
export {};
