"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiCombobox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("react");
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const useOuterClick_1 = require("../../../hooks/useOuterClick");
const intl_1 = require("../../../intl");
const util_1 = require("../../../libs/util");
const themes_1 = require("../../../themes");
const Icon_1 = require("../../Icon");
const helper_1 = require("../helper");
const useFocusControl_1 = require("../useFocusControl");
const useListbox_1 = require("../useListbox");
const useOptions_1 = require("../useOptions");
const MultiSelectedItem_1 = require("./MultiSelectedItem");
const NOOP = () => undefined;
const preventDefaultWithPressEnter = (e) => {
    if (e.key === 'Enter') {
        e.preventDefault();
    }
};
const ESCAPE_KEY_REGEX = /^Esc(ape)?$/;
const ARROW_LEFT_KEY_REGEX = /^(Arrow)?Left$/;
const ARROW_RIGHT_KEY_REGEX = /^(Arrow)?Right/;
const ARROW_UP_AND_DOWN_KEY_REGEX = /^(Arrow)?(Up|Down)$/;
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-MultiCombobox',
            'shr-box-border shr-inline-flex shr-min-w-[15em] shr-rounded-m shr-border shr-border-solid shr-px-0.5 shr-py-0.25 shr-align-bottom',
            'contrast-more:shr-border-high-contrast',
            'has-[[aria-invalid]]:shr-border-danger',
        ],
        inputArea: 'shr-flex shr-flex-1 shr-flex-wrap shr-gap-0.5 shr-overflow-y-auto',
        selectedList: 'smarthr-ui-MultiCombobox-selectedList shr-contents shr-list-none [&_li]:shr-min-w-0',
        inputWrapper: 'shr-flex shr-flex-1 shr-items-center',
        input: [
            'smarthr-ui-MultiCombobox-input',
            'shr-w-full shr-min-w-[5em] shr-border-none shr-text-base shr-text-black shr-outline-none shr-outline-0',
            'disabled:shr-hidden',
        ],
        placeholderEl: 'smarthr-ui-MultiCombobox-placeholder shr-my-0 shr-self-center',
        suffixWrapper: [
            'shr-relative -shr-me-0.5 shr-ms-0.5 shr-p-0.5',
            'before:shr-absolute before:shr-inset-x-0 before:shr-inset-y-0.25 before:shr-w-0 before:shr-border-0 before:shr-border-l before:shr-border-solid before:shr-border-default before:shr-content-[""]',
        ],
        suffixIcon: 'shr-block',
    },
    variants: {
        focused: {
            true: {
                wrapper: 'shr-focus-indicator',
            },
        },
        disabled: {
            true: {
                wrapper: 'shr-cursor-not-allowed shr-border-default/50 shr-bg-white-darken shr-text-disabled',
            },
            false: {
                wrapper: 'shr-cursor-text shr-bg-white',
            },
        },
        hidden: {
            true: {
                inputWrapper: 'shr-pointer-events-none shr-absolute shr-opacity-0',
            },
        },
    },
    compoundVariants: [
        {
            disabled: false,
            className: {
                wrapper: 'shr-border-default',
            },
        },
    ],
});
const ActualMultiCombobox = ({ items, selectedItems, name, disabled = false, required = false, error = false, creatable = false, placeholder = '', autoComplete, dropdownHelpMessage, isLoading, selectedItemEllipsis, width, dropdownWidth = 'auto', inputValue: controlledInputValue, className, onChange, onChangeInput, onAdd, onDelete, onSelect, onChangeSelected, onFocus, onBlur, onKeyPress, decorators, isItemSelected, style, ...rest }, ref) => {
    const { localize } = (0, intl_1.useIntl)();
    const outerRef = (0, react_1.useRef)(null);
    const [isFocused, setIsFocused] = (0, react_1.useState)(false);
    const [highlighted, setHighlighted] = (0, react_1.useState)(false);
    const isInputControlled = controlledInputValue !== undefined;
    const [uncontrolledInputValue, setUncontrolledInputValue] = (0, react_1.useState)('');
    const inputValue = isInputControlled ? controlledInputValue : uncontrolledInputValue;
    const [isComposing, setIsComposing] = (0, react_1.useState)(false);
    const { options } = (0, useOptions_1.useMultiOptions)({
        items,
        selected: selectedItems,
        creatable,
        inputValue,
        isItemSelected,
    });
    const setInputValueIfUncontrolled = isInputControlled ? NOOP : setUncontrolledInputValue;
    const actualOnDelete = (0, react_1.useMemo)(() => {
        const handlers = [];
        if (onDelete) {
            handlers.push((item) => onDelete(item));
        }
        if (onChangeSelected) {
            handlers.push((item) => onChangeSelected(selectedItems.filter((selected) => !(0, helper_1.areItemsEqual)(selected, item))));
        }
        if (handlers.length === 0) {
            return NOOP;
        }
        return (item) => {
            // HINT: Dropdown系コンポーネント内でComboboxを使うと、選択肢がportalで表現されている関係上Dropdownが閉じてしまう
            // requestAnimationFrameを追加、処理を遅延させることで正常に閉じる/閉じないの判定を行えるようにする
            requestAnimationFrame(() => {
                handlers.forEach((h) => h(item));
            });
        };
    }, [selectedItems, onChangeSelected, onDelete]);
    const actualOnSelect = (0, react_1.useCallback)((selected) => {
        // HINT: Dropdown系コンポーネント内でComboboxを使うと、選択肢がportalで表現されている関係上Dropdownが閉じてしまう
        // requestAnimationFrameを追加、処理を遅延させることで正常に閉じる/閉じないの判定を行えるようにする
        requestAnimationFrame(() => {
            const matchedSelectedItem = selectedItems.find((item) => (0, helper_1.areItemsEqual)(item, selected));
            if (matchedSelectedItem === undefined) {
                onSelect?.(selected);
                onChangeSelected?.(selectedItems.concat(selected));
            }
            else if (matchedSelectedItem.deletable !== false) {
                actualOnDelete(selected);
            }
        });
    }, [selectedItems, actualOnDelete, onChangeSelected, onSelect]);
    const { renderListBox, activeOption, onKeyDownListBox, listBoxId, listBoxRef } = (0, useListbox_1.useListbox)({
        options,
        dropdownHelpMessage,
        dropdownWidth,
        onAdd,
        onSelect: actualOnSelect,
        isExpanded: isFocused,
        isLoading,
        triggerRef: outerRef,
        decorators,
    });
    const { deletionButtonRefs, inputRef, focusPrevDeletionButton, focusNextDeletionButton, resetDeletionButtonFocus, } = (0, useFocusControl_1.useFocusControl)(selectedItems.length);
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    const focus = (0, react_1.useMemo)(() => {
        const baseAction = () => {
            setIsFocused(true);
        };
        if (onFocus) {
            return () => {
                onFocus();
                baseAction();
            };
        }
        return baseAction;
    }, [onFocus]);
    const blur = (0, react_1.useMemo)(() => {
        if (!isFocused) {
            return NOOP;
        }
        const baseAction = () => {
            setIsFocused(false);
            resetDeletionButtonFocus();
        };
        if (onBlur) {
            return () => {
                onBlur();
                baseAction();
            };
        }
        return baseAction;
    }, [isFocused, onBlur, resetDeletionButtonFocus]);
    const outerClickRef = (0, react_1.useMemo)(() => [outerRef, listBoxRef], [outerRef, listBoxRef]);
    (0, useOuterClick_1.useOuterClick)(outerClickRef, blur);
    const highlightedRef = (0, react_1.useRef)(highlighted);
    (0, react_1.useEffect)(() => {
        highlightedRef.current = highlighted;
    }, [highlighted]);
    (0, react_1.useEffect)(() => {
        if (highlightedRef.current) {
            setHighlighted(false);
            inputRef.current?.select();
        }
        else {
            setInputValueIfUncontrolled('');
        }
    }, [selectedItems, inputRef, setInputValueIfUncontrolled]);
    (0, react_1.useEffect)(() => {
        if (isFocused) {
            inputRef.current?.focus();
        }
    }, [inputRef, isFocused, setInputValueIfUncontrolled, selectedItems]);
    const onKeyDown = (0, react_1.useMemo)(() => isComposing
        ? undefined
        : (e) => {
            if (ESCAPE_KEY_REGEX.test(e.key)) {
                e.stopPropagation();
                blur();
            }
            else if (e.key === 'Tab') {
                if (isFocused) {
                    // フォーカスがコンポーネントを抜けるように先に input をフォーカスしておく
                    inputRef.current?.focus();
                }
                blur();
            }
            else if (ARROW_LEFT_KEY_REGEX.test(e.key)) {
                e.stopPropagation();
                focusPrevDeletionButton();
            }
            else if (ARROW_RIGHT_KEY_REGEX.test(e.key)) {
                e.stopPropagation();
                focusNextDeletionButton();
            }
            else if (e.key === 'Backspace' &&
                !inputValue &&
                selectedItems.length > 0 &&
                selectedItems[selectedItems.length - 1].deletable !== false) {
                e.preventDefault();
                e.stopPropagation();
                const lastItem = selectedItems[selectedItems.length - 1];
                actualOnDelete(lastItem);
                setHighlighted(true);
                setInputValueIfUncontrolled((0, react_innertext_1.default)(lastItem.label));
            }
            else {
                e.stopPropagation();
                inputRef.current?.focus();
                resetDeletionButtonFocus();
            }
            onKeyDownListBox(e);
        }, [
        blur,
        focusNextDeletionButton,
        focusPrevDeletionButton,
        onKeyDownListBox,
        inputRef,
        isComposing,
        isFocused,
        resetDeletionButtonFocus,
        actualOnDelete,
        inputValue,
        selectedItems,
        setInputValueIfUncontrolled,
    ]);
    const onClick = (0, react_1.useMemo)(() => disabled || isFocused
        ? undefined
        : (e) => {
            if (!e.target.closest('.smarthr-ui-MultiCombobox-deleteButton')) {
                focus();
            }
        }, [isFocused, disabled, focus]);
    const actualOnChangeInput = (0, react_1.useMemo)(() => {
        const handlers = [onChange, onChangeInput].filter((h) => !!h);
        const onSetValue = (e) => {
            setInputValueIfUncontrolled(e.currentTarget.value);
        };
        if (handlers.length === 0) {
            return onSetValue;
        }
        return (e) => {
            handlers.forEach((h) => h(e));
            onSetValue(e);
        };
    }, [onChange, onChangeInput, setInputValueIfUncontrolled]);
    const onFocusInput = (0, react_1.useMemo)(() => isFocused
        ? resetDeletionButtonFocus
        : () => {
            resetDeletionButtonFocus();
            focus();
        }, [isFocused, focus, resetDeletionButtonFocus]);
    const onCompositionStartInput = (0, react_1.useCallback)(() => setIsComposing(true), []);
    const onCompositionEndInput = (0, react_1.useCallback)(() => setIsComposing(false), []);
    const onKeyDownInput = (0, react_1.useCallback)((e) => {
        if (ARROW_UP_AND_DOWN_KEY_REGEX.test(e.key)) {
            // 上下キー入力はリストボックスの activeDescendant の移動に用いるため、input 内では作用させない
            e.preventDefault();
        }
    }, []);
    // HINT: form内にcomboboxを設置 & 検索inputにfocusした状態で
    // アイテムをキーボードで選択し、Enterを押すとinput上でEnterを押したことになるため、
    // submitイベントが発生し、formが送信される場合がある
    const actualOnKeyPress = (0, react_1.useMemo)(() => onKeyPress
        ? (e) => {
            preventDefaultWithPressEnter(e);
            onKeyPress(e);
        }
        : preventDefaultWithPressEnter, [onKeyPress]);
    const selectedListId = (0, react_2.useId)();
    const wrapperStyle = (0, react_1.useMemo)(() => ({
        ...style,
        width: typeof width === 'number' ? `${width}px` : width,
    }), [style, width]);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, inputArea, selectedList, inputWrapper, input, placeholderEl, suffixWrapper, suffixIcon, } = classNameGenerator();
        return {
            wrapper: wrapper({ focused: isFocused, disabled, className }),
            inputArea: inputArea(),
            selectedList: selectedList(),
            inputWrapper: inputWrapper({ hidden: !isFocused }),
            input: input(),
            placeholder: placeholderEl(),
            suffixWrapper: suffixWrapper({ disabled }),
            suffixIcon: suffixIcon(),
        };
    }, [isFocused, disabled, className]);
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        selectedListAriaLabel: localize({
            id: 'smarthr-ui/MultiCombobox/selectedListAriaLabel',
            defaultText: '選択済みアイテム',
        }),
    }), [localize]);
    const decoratedAriaLabel = (0, react_1.useMemo)(() => decorators?.selectedListAriaLabel?.(decoratorDefaultTexts.selectedListAriaLabel) ||
        decoratorDefaultTexts.selectedListAriaLabel, [decorators, decoratorDefaultTexts]);
    return (
    // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
    (0, jsx_runtime_1.jsxs)("div", { ref: outerRef, role: "group", onClick: onClick, onKeyDown: onKeyDown, onKeyPress: actualOnKeyPress, className: classNames.wrapper, style: wrapperStyle, children: [(0, jsx_runtime_1.jsxs)("div", { className: classNames.inputArea, children: [(0, jsx_runtime_1.jsx)("ul", { id: selectedListId, "aria-label": decoratedAriaLabel, className: classNames.selectedList, children: selectedItems.map((selectedItem, i) => ((0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)(MultiSelectedItem_1.MultiSelectedItem, { item: selectedItem, disabled: disabled, onDelete: actualOnDelete, enableEllipsis: selectedItemEllipsis, buttonRef: deletionButtonRefs[i], decorators: decorators }) }, `${selectedItem.label}-${(0, react_innertext_1.default)(selectedItem.value)}`))) }), (0, jsx_runtime_1.jsx)("div", { className: classNames.inputWrapper, children: (0, jsx_runtime_1.jsx)("input", { ...rest, "data-smarthr-ui-input": "true", type: "text", name: name, value: inputValue, disabled: disabled, required: required && selectedItems.length === 0, ref: inputRef, onChange: actualOnChangeInput, onFocus: onFocusInput, onCompositionStart: onCompositionStartInput, onCompositionEnd: onCompositionEndInput, onKeyDown: onKeyDownInput, autoComplete: autoComplete ?? 'off', tabIndex: 0, role: "combobox", "aria-activedescendant": activeOption?.id, "aria-controls": `${listBoxId} ${selectedListId}`, "aria-haspopup": "listbox", "aria-expanded": isFocused, "aria-invalid": error || undefined, "aria-disabled": disabled, "aria-autocomplete": "list", className: classNames.input }) }), selectedItems.length === 0 && placeholder && !isFocused && ((0, jsx_runtime_1.jsx)("p", { className: classNames.placeholder, children: placeholder }))] }), (0, jsx_runtime_1.jsx)(MemoizedCaretDown, { disabled: disabled, isFocused: isFocused, className: classNames.suffixWrapper, iconStyle: classNames.suffixIcon }), renderListBox()] }));
};
exports.MultiCombobox = (0, util_1.genericsForwardRef)(ActualMultiCombobox);
const MemoizedCaretDown = (0, react_1.memo)(({ className, iconStyle, disabled, isFocused }) => {
    const caretIconColor = (0, react_1.useMemo)(() => {
        if (isFocused)
            return themes_1.textColor.black;
        if (disabled)
            return themes_1.textColor.disabled;
        return themes_1.textColor.grey;
    }, [disabled, isFocused]);
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, { color: caretIconColor, className: iconStyle }) }));
});
//# sourceMappingURL=MultiCombobox.js.map