"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiSelectedItem = MultiSelectedItem;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const intl_1 = require("../../../intl");
const Button_1 = require("../../Button");
const Chip_1 = require("../../Chip");
const Icon_1 = require("../../Icon");
const Tooltip_1 = require("../../Tooltip");
const VisuallyHiddenText_1 = require("../../VisuallyHiddenText");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-MultiCombobox-selectedItem shr-flex shr-items-center shr-gap-0.75 shr-leading-normal [&]:shr-rounded-em',
        itemLabel: 'smarthr-ui-MultiCombobox-selectedItemLabel',
        deleteButton: [
            'smarthr-ui-MultiCombobox-deleteButton',
            'shr-group/deleteButton',
            'shr-shrink shr-rounded-full shr-leading-[0] shr-text-black',
            'focus-visible:shr-shadow-[unset]',
        ],
        deleteButtonIcon: 'group-focus-visible/deleteButton:shr-focus-indicator group-focus-visible/deleteButton:shr-rounded-full',
    },
    variants: {
        enableEllipsis: {
            true: {
                itemLabel: 'shr-overflow-hidden shr-overflow-ellipsis shr-whitespace-nowrap',
            },
        },
        disabled: {
            true: {
                deleteButton: 'shr-cursor-not-allowed',
            },
            false: {},
        },
    },
});
function MultiSelectedItem({ item, disabled, onDelete, enableEllipsis, buttonRef, decorators, }) {
    const [needsTooltip, setNeedsTooltip] = (0, react_1.useState)(false);
    const { deletable = true } = item;
    const idPrefix = (0, react_1.useId)();
    const labelId = `${idPrefix}-item-label`;
    const destroySuffixTextId = `${idPrefix}-item-destroy-button-suffix`;
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, itemLabel, deleteButton, deleteButtonIcon } = classNameGenerator();
        return {
            wrapper: wrapper(),
            itemLabel: itemLabel({ enableEllipsis }),
            deleteButton: deleteButton({ disabled }),
            deleteButtonIcon: deleteButtonIcon(),
        };
    }, [disabled, enableEllipsis]);
    const body = ((0, jsx_runtime_1.jsxs)(Chip_1.Chip, { disabled: disabled, className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)(ItemLabel, { id: labelId, className: classNames.itemLabel, setNeedsTooltip: setNeedsTooltip, children: item.label }), deletable && ((0, jsx_runtime_1.jsx)(DestroyButton, { labelId: labelId, suffixTextId: destroySuffixTextId, item: item, onDelete: onDelete, disabled: disabled, buttonRef: buttonRef, decorators: decorators, className: classNames.deleteButton, iconStyle: classNames.deleteButtonIcon }))] }));
    if (needsTooltip) {
        return (0, jsx_runtime_1.jsx)(Tooltip_1.Tooltip, { message: item.label, children: body });
    }
    return body;
}
const ItemLabel = (0, react_1.memo)(({ children, id, enableEllipsis, setNeedsTooltip, className }) => {
    const labelRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        if (enableEllipsis && labelRef.current) {
            const elem = labelRef.current;
            setNeedsTooltip(elem.offsetWidth < elem.scrollWidth);
        }
    }, [enableEllipsis, setNeedsTooltip]);
    return ((0, jsx_runtime_1.jsx)("span", { ref: labelRef, id: id, className: className, children: children }));
});
const typedMemo = react_1.memo;
const EXEC_DESTROY_KEY = /^(Enter|Backspace| )$/;
const BaseDestroyButton = ({ labelId, suffixTextId, item, onDelete, disabled, buttonRef, decorators, className, iconStyle, }) => {
    const { localize } = (0, intl_1.useIntl)();
    const onClick = (0, react_1.useCallback)(() => {
        onDelete(item);
    }, [item, onDelete]);
    const onKeyDown = (0, react_1.useCallback)((e) => {
        if (EXEC_DESTROY_KEY.test(e.key)) {
            e.stopPropagation();
            // HINT: イベントの伝播が止まる関係でonClickに設定したonDeleteは実行されない
            // このタイミングで明示的に削除処理を実行する
            onClick();
        }
    }, [onClick]);
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        destroyButtonIconAltSuffix: localize({
            id: 'smarthr-ui/MultiCombobox/destroyButtonIconAltSuffix',
            defaultText: 'を削除',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    return ((0, jsx_runtime_1.jsxs)(Button_1.UnstyledButton, { ref: buttonRef, disabled: disabled, tabIndex: -1, "aria-labelledby": `${labelId} ${suffixTextId}`, onClick: onClick, onKeyDown: onKeyDown, className: className, children: [(0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { id: suffixTextId, children: decorated.destroyButtonIconAltSuffix }), (0, jsx_runtime_1.jsx)(Icon_1.FaTimesCircleIcon, { color: disabled ? 'TEXT_DISABLED' : 'inherit', className: iconStyle })] }));
};
const DestroyButton = typedMemo(BaseDestroyButton);
//# sourceMappingURL=MultiSelectedItem.js.map