import { type ComponentPropsWithoutRef, type MouseEvent, type ReactNode } from 'react';
import { type DecoratorsType } from '../../../hooks/useDecorators';
import type { BaseProps, ComboboxItem } from '../types';
type Props<T> = BaseProps<T> & {
    /**
     * 選択されているアイテム
     */
    selectedItem: ComboboxItem<T> | null;
    /**
     * デフォルトで選択されるアイテム
     */
    defaultItem?: ComboboxItem<T>;
    /**
     * コンポーネント内の先頭に表示する内容
     */
    prefix?: ReactNode;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     */
    onClear?: () => void;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     * 指定している場合、クリア時にonClickを実行せずにonClearClickのみ実行する
     */
    onClearClick?: (e: MouseEvent) => void;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: (selectedItem: ComboboxItem<T> | null) => void;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: () => void;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: () => void;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: DecoratorsType<DecoratorKeyTypes | 'noResultText' | 'loadingText'>;
};
type ElementProps = Omit<ComponentPropsWithoutRef<'input'>, keyof Props<unknown>>;
type DecoratorKeyTypes = 'destroyButtonIconAlt';
export declare const SingleCombobox: <T>(props: BaseProps<T> & {
    /**
     * 選択されているアイテム
     */
    selectedItem: ComboboxItem<T> | null;
    /**
     * デフォルトで選択されるアイテム
     */
    defaultItem?: ComboboxItem<T> | undefined;
    /**
     * コンポーネント内の先頭に表示する内容
     */
    prefix?: ReactNode;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     */
    onClear?: () => void;
    /**
     * 選択されているアイテムがクリアされた時に発火するコールバック関数
     * 指定している場合、クリア時にonClickを実行せずにonClearClickのみ実行する
     */
    onClearClick?: (e: MouseEvent) => void;
    /**
     * 選択されているアイテムのリストが変わった時に発火するコールバック関数
     */
    onChangeSelected?: ((selectedItem: ComboboxItem<T> | null) => void) | undefined;
    /**
     * コンポーネントがフォーカスされたときに発火するコールバック関数
     */
    onFocus?: () => void;
    /**
     * コンポーネントからフォーカスが外れた時に発火するコールバック関数
     */
    onBlur?: () => void;
    /**
     * コンポーネント内のテキストを変更する関数/
     */
    decorators?: DecoratorsType<DecoratorKeyTypes | "noResultText" | "loadingText">;
} & ElementProps & import("react").RefAttributes<HTMLInputElement>) => ReactNode;
export {};
