"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SingleCombobox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const useClick_1 = require("../../../hooks/useClick");
const useDecorators_1 = require("../../../hooks/useDecorators");
const intl_1 = require("../../../intl");
const util_1 = require("../../../libs/util");
const themes_1 = require("../../../themes");
const Button_1 = require("../../Button");
const Icon_1 = require("../../Icon");
const Input_1 = require("../../Input");
const useListbox_1 = require("../useListbox");
const useOptions_1 = require("../useOptions");
const NOOP = () => undefined;
const ESCAPE_KEY_REGEX = /^Esc(ape)?$/;
const ARROW_UP_DOWN_REGEX = /^(Arrow)?(Up|Down)$/;
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-SingleCombobox shr-inline-block',
        input: 'smarthr-ui-SingleCombobox-input shr-w-full',
        caretDownLayout: [
            'shr-relative -shr-me-0.5 shr-p-0.5',
            'before:shr-border-0',
            'before:shr-absolute before:shr-inset-x-0 before:shr-inset-y-0.25 before:shr-w-0 before:shr-border-l before:shr-border-solid before:shr-border-default before:shr-content-[""]',
        ],
        caretDownIcon: 'shr-block',
        clearButton: [
            'smarthr-ui-SingleCombobox-clearButton',
            'shr-group/clearButton',
            'shr-me-0.5',
            'focus-visible:shr-shadow-none',
        ],
        clearButtonIcon: [
            'shr-block',
            'group-focus-visible/clearButton:shr-focus-indicator group-focus-visible/clearButton:shr-rounded-full',
        ],
    },
    variants: {
        disabled: {
            true: {
                wrapper: 'shr-cursor-not-allowed',
            },
        },
        hidden: {
            true: {
                clearButton: 'shr-hidden',
            },
        },
    },
});
const ActualSingleCombobox = ({ items, selectedItem, defaultItem, name, disabled, readOnly, required, prefix, error, creatable, placeholder, autoComplete, dropdownHelpMessage, isLoading, width, dropdownWidth = 'auto', className, onChange, onChangeInput, onAdd, onSelect, onClear, onClearClick, onChangeSelected, onFocus, onBlur, onKeyPress, decorators, style, ...rest }, ref) => {
    const { localize } = (0, intl_1.useIntl)();
    const outerRef = (0, react_1.useRef)(null);
    const inputRef = (0, react_1.useRef)(null);
    const clearButtonRef = (0, react_1.useRef)(null);
    const [isFocused, setIsFocused] = (0, react_1.useState)(false);
    const [isExpanded, setIsExpanded] = (0, react_1.useState)(false);
    const [inputValue, setInputValue] = (0, react_1.useState)('');
    const [isComposing, setIsComposing] = (0, react_1.useState)(false);
    const [isEditing, setIsEditing] = (0, react_1.useState)(false);
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    const { options } = (0, useOptions_1.useSingleOptions)({
        items,
        selected: selectedItem,
        creatable,
        inputValue,
        isFilteringDisabled: !isEditing,
    });
    const { renderListBox, activeOption, onKeyDownListBox, listBoxId, listBoxRef } = (0, useListbox_1.useListbox)({
        options,
        dropdownHelpMessage,
        dropdownWidth,
        onAdd,
        onSelect: (0, react_1.useCallback)((selected) => {
            onSelect?.(selected);
            onChangeSelected?.(selected);
            // HINT: Dropdown系コンポーネント内でComboboxを使うと、選択肢がportalで表現されている関係上Dropdownが閉じてしまう
            // requestAnimationFrameを追加、処理を遅延させることで正常に閉じる/閉じないの判定を行えるようにする
            requestAnimationFrame(() => {
                setIsExpanded(false);
            });
            setIsEditing(false);
        }, [onChangeSelected, onSelect]),
        isExpanded,
        isLoading,
        triggerRef: outerRef,
        decorators,
    });
    const selectDefaultItem = (0, react_1.useMemo)(() => (onSelect && defaultItem ? () => onSelect(defaultItem) : NOOP), [onSelect, defaultItem]);
    const focus = (0, react_1.useCallback)(() => {
        onFocus?.();
        setIsFocused(true);
        if (!isFocused) {
            setIsExpanded(true);
        }
    }, [onFocus, isFocused]);
    const unfocus = (0, react_1.useCallback)(() => {
        if (!isFocused)
            return;
        onBlur?.();
        setIsFocused(false);
        setIsExpanded(false);
        setIsEditing(false);
        if (!selectedItem && defaultItem) {
            setInputValue((0, react_innertext_1.default)(defaultItem.label));
            selectDefaultItem();
        }
    }, [isFocused, onBlur, selectedItem, defaultItem, selectDefaultItem]);
    const onClickClear = (0, react_1.useCallback)((e) => {
        e.stopPropagation();
        let isExecutedPreventDefault = false;
        onClearClick?.({
            ...e,
            preventDefault: () => {
                e.preventDefault();
                isExecutedPreventDefault = true;
            },
        });
        if (!isExecutedPreventDefault) {
            onClear?.();
            onChangeSelected?.(null);
            inputRef.current?.focus();
            setIsFocused(true);
            setIsExpanded(true);
        }
    }, [onClearClick, onClear, onChangeSelected]);
    const onClickInput = (0, react_1.useCallback)((e) => {
        if (disabled || readOnly) {
            e.stopPropagation();
            return;
        }
        inputRef.current?.focus();
        if (!isExpanded) {
            setIsExpanded(true);
        }
    }, [disabled, readOnly, inputRef, isExpanded]);
    const actualOnChangeInput = (0, react_1.useCallback)((e) => {
        onChange?.(e);
        onChangeInput?.(e);
        if (!isEditing)
            setIsEditing(true);
        const { value } = e.currentTarget;
        setInputValue(value);
        if (value === '') {
            onClear?.();
            onChangeSelected?.(null);
        }
    }, [isEditing, onChange, onChangeInput, onClear, onChangeSelected]);
    const onCompositionStart = (0, react_1.useCallback)(() => setIsComposing(true), []);
    const onCompositionEnd = (0, react_1.useCallback)(() => setIsComposing(false), []);
    const onKeyDownInput = (0, react_1.useCallback)((e) => {
        if (isComposing) {
            return;
        }
        if (ESCAPE_KEY_REGEX.test(e.key)) {
            if (isExpanded) {
                e.stopPropagation();
                setIsExpanded(false);
            }
        }
        else if (e.key === 'Tab') {
            unfocus();
        }
        else {
            if (ARROW_UP_DOWN_REGEX.test(e.key)) {
                e.preventDefault();
            }
            inputRef.current?.focus();
            if (!isExpanded) {
                setIsExpanded(true);
            }
        }
        onKeyDownListBox(e);
    }, [isComposing, isExpanded, unfocus, onKeyDownListBox]);
    // HINT: form内にcomboboxを設置 & 検索inputにfocusした状態で
    // アイテムをキーボードで選択し、Enterを押すとinput上でEnterを押したことになるため、
    // submitイベントが発生し、formが送信される場合がある
    const handleKeyPress = (0, react_1.useCallback)((e) => {
        if (e.key === 'Enter')
            e.preventDefault();
        onKeyPress?.(e);
    }, [onKeyPress]);
    const caretIconColor = (0, react_1.useMemo)(() => {
        if (isFocused)
            return themes_1.textColor.black;
        if (disabled || readOnly)
            return themes_1.textColor.disabled;
        return themes_1.textColor.grey;
    }, [disabled, readOnly, isFocused]);
    (0, useClick_1.useClick)((0, react_1.useMemo)(() => [outerRef, listBoxRef, clearButtonRef], [outerRef, listBoxRef, clearButtonRef]), isFocused || selectedItem ? NOOP : selectDefaultItem, unfocus);
    (0, react_1.useEffect)(() => {
        setInputValue(selectedItem ? (0, react_innertext_1.default)(selectedItem.label) : '');
        if (isFocused && inputRef.current) {
            inputRef.current.focus();
        }
        else if (!selectedItem) {
            selectDefaultItem();
        }
    }, [isFocused, selectedItem, selectDefaultItem]);
    const wrapperStyle = (0, react_1.useMemo)(() => ({
        ...style,
        width: typeof width === 'number' ? `${width}px` : width,
    }), [style, width]);
    const notSelected = selectedItem === null;
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, input, caretDownLayout, caretDownIcon, clearButton, clearButtonIcon } = classNameGenerator();
        return {
            wrapper: wrapper({ disabled, className }),
            input: input(),
            caretDownLayout: caretDownLayout(),
            caretDownIcon: caretDownIcon(),
            clearButton: clearButton({ hidden: notSelected || disabled || readOnly }),
            clearButtonIcon: clearButtonIcon(),
        };
    }, [notSelected, disabled, readOnly, className]);
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        destroyButtonIconAlt: localize({
            id: 'smarthr-ui/SingleCombobox/destroyButtonIconAlt',
            defaultText: '削除',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    return ((0, jsx_runtime_1.jsxs)("div", { className: classNames.wrapper, style: wrapperStyle, ref: outerRef, children: [(0, jsx_runtime_1.jsx)(Input_1.Input, { ...rest, ref: inputRef, type: "text", role: "combobox", name: name, value: inputValue, disabled: disabled, readOnly: readOnly, required: required, autoComplete: autoComplete ?? 'off', "aria-haspopup": "listbox", "aria-controls": listBoxId, "aria-expanded": isFocused, "aria-activedescendant": activeOption?.id, "aria-autocomplete": "list", 
                /* eslint-disable-next-line smarthr/a11y-prohibit-input-placeholder */
                placeholder: placeholder, onClick: onClickInput, onChange: actualOnChangeInput, onFocus: isFocused ? undefined : focus, onCompositionStart: onCompositionStart, onCompositionEnd: onCompositionEnd, onKeyDown: onKeyDownInput, onKeyPress: handleKeyPress, error: error, prefix: prefix, suffix: (0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(Button_1.UnstyledButton, { onClick: onClickClear, ref: clearButtonRef, className: classNames.clearButton, children: (0, jsx_runtime_1.jsx)(Icon_1.FaCircleXmarkIcon, { color: "TEXT_BLACK", alt: decorated.destroyButtonIconAlt, className: classNames.clearButtonIcon }) }), (0, jsx_runtime_1.jsx)("span", { onClick: onClickInput, role: "presentation", className: classNames.caretDownLayout, children: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, { color: caretIconColor, className: classNames.caretDownIcon }) })] }), className: classNames.input, "data-smarthr-ui-input": "true" }), !readOnly && renderListBox()] }));
};
exports.SingleCombobox = (0, util_1.genericsForwardRef)(ActualSingleCombobox);
//# sourceMappingURL=SingleCombobox.js.map