"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useActiveOption = useActiveOption;
const react_1 = require("react");
function useActiveOption({ options }) {
    const [activeOption, setActiveOption] = (0, react_1.useState)(null);
    (0, react_1.useEffect)(() => {
        // props の変更によって activeOption の状態が変わりうるので、実態を反映する
        setActiveOption((current) => {
            if (current === null) {
                return null;
            }
            return options.find((option) => current.id === option.id) ?? null;
        });
    }, [options]);
    const moveActiveOptionIndex = (0, react_1.useCallback)((currentActive, delta) => {
        if (options.every((option) => option.item.disabled)) {
            return;
        }
        const currentActiveIndex = currentActive === null ? -1 : options.findIndex((option) => option.id === currentActive.id);
        let nextIndex = 0;
        if (currentActiveIndex !== -1) {
            nextIndex = (currentActiveIndex + delta + options.length) % options.length;
        }
        else if (delta !== 1) {
            nextIndex = options.length - 1;
        }
        const nextActive = options[nextIndex];
        if (nextActive) {
            if (nextActive.item.disabled) {
                // skip disabled item
                moveActiveOptionIndex(nextActive, delta);
            }
            else {
                setActiveOption(nextActive);
            }
        }
    }, [options]);
    return {
        activeOption,
        setActiveOption,
        moveActiveOptionIndex,
    };
}
//# sourceMappingURL=useActiveOption.js.map