"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMultiOptions = exports.useSingleOptions = void 0;
const react_1 = require("react");
const react_innertext_1 = __importDefault(require("react-innertext"));
const helper_1 = require("./helper");
const defaultIsItemSelected = (targetItem, selectedItems) => selectedItems.some((item) => (0, helper_1.areItemsEqual)(item, targetItem));
const useSingleOptions = ({ selected, ...rest }) => {
    const isSelected = (0, react_1.useCallback)((item) => selected !== null && (0, helper_1.areItemsEqual)(selected, item), [selected]);
    return useOptions(rest, isSelected);
};
exports.useSingleOptions = useSingleOptions;
const useMultiOptions = ({ selected, isItemSelected = defaultIsItemSelected, ...rest }) => {
    const isSelected = (0, react_1.useCallback)((item) => isItemSelected(item, selected), [selected, isItemSelected]);
    return useOptions(rest, isSelected);
};
exports.useMultiOptions = useMultiOptions;
function useOptions({ items, creatable, inputValue = '', isFilteringDisabled = false }, isSelected) {
    const newItemId = (0, react_1.useId)();
    const optionIdPrefix = (0, react_1.useId)();
    const existedOptions = (0, react_1.useMemo)(() => items.map((item, i) => ({
        id: `${optionIdPrefix}-${i}`,
        selected: isSelected(item),
        isNew: false,
        item,
    })), [isSelected, items, optionIdPrefix]);
    const addingOption = (0, react_1.useMemo)(() => creatable && inputValue && items.every((item) => item.label !== inputValue)
        ? {
            id: newItemId,
            isNew: true,
            selected: false,
            item: { label: inputValue, value: inputValue },
        }
        : null, [inputValue, items, creatable, newItemId]);
    const allOptions = (0, react_1.useMemo)(() => (addingOption ? [addingOption, ...existedOptions] : existedOptions), [existedOptions, addingOption]);
    const options = (0, react_1.useMemo)(() => {
        if (isFilteringDisabled || !inputValue) {
            return allOptions;
        }
        return allOptions.filter(({ item: { label } }) => (0, helper_1.convertMatchableString)((0, react_innertext_1.default)(label)).includes((0, helper_1.convertMatchableString)(inputValue)));
    }, [allOptions, inputValue, isFilteringDisabled]);
    return {
        options,
    };
}
//# sourceMappingURL=useOptions.js.map