"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePartialRendering = usePartialRendering;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const OPTION_INCREMENT_AMOUNT = 100;
const RETURN_NULL = () => null;
function usePartialRendering({ items, minLength = 0, }) {
    const limiter = (0, react_1.useCallback)((length) => Math.max(length, minLength), [minLength]);
    const [currentItemLength, setCurrentItemLength] = (0, react_1.useState)(limiter(OPTION_INCREMENT_AMOUNT));
    (0, react_1.useEffect)(() => {
        setCurrentItemLength((current) => limiter(current));
    }, [limiter]);
    // minLength も考慮した実際のアイテム数を算出
    const partialItems = (0, react_1.useMemo)(() => items.slice(0, currentItemLength), [currentItemLength, items]);
    const renderIntersection = (0, react_1.useCallback)(() => ((0, jsx_runtime_1.jsx)(Intersection, { onIntersect: () => {
            setCurrentItemLength((current) => limiter(current + OPTION_INCREMENT_AMOUNT));
        } })), [limiter]);
    return {
        items: partialItems,
        renderIntersection: currentItemLength >= items.length ? RETURN_NULL : renderIntersection,
    };
}
const Intersection = ({ onIntersect }) => {
    const ref = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        const target = ref.current;
        if (target === null) {
            return;
        }
        // スクロール最下部に到達する度に表示するアイテム数を増加させるための IntersectionObserver
        const observer = new IntersectionObserver(([entry]) => {
            if (entry.isIntersecting) {
                onIntersect();
            }
        });
        observer.observe(target);
        return () => observer.disconnect();
    }, [onIntersect]);
    return (0, jsx_runtime_1.jsx)("div", { ref: ref });
};
//# sourceMappingURL=usePartialRendering.js.map