"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePicker = exports.DEFAULT_FROM = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const dayjs_1 = __importDefault(require("dayjs"));
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useOuterClick_1 = require("../../hooks/useOuterClick");
const themes_1 = require("../../themes");
const Calendar_1 = require("../Calendar");
const Icon_1 = require("../Icon");
const Input_1 = require("../Input");
const Portal_1 = require("./Portal");
const datePickerHelper_1 = require("./datePickerHelper");
const useGlobalKeyDown_1 = require("./useGlobalKeyDown");
exports.DEFAULT_FROM = new Date(1900, 0, 1);
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'smarthr-ui-DatePicker shr-inline-block',
        inputSuffixLayout: 'shr-box-border shr-h-full shr-py-0.5',
        inputSuffixWrapper: 'shr-border-l-shorthand shr-box-border shr-flex shr-h-full shr-items-center shr-justify-center shr-ps-0.5 shr-text-base',
        inputSuffixText: 'shr-text-gray shr-me-0.5 shr-text-sm',
    },
});
const DEFAULT_DATE_TO_STRING_FORMAT = 'YYYY/MM/DD';
const DEFAULT_DATE_TO_STRING = (d) => d ? (0, dayjs_1.default)(d).format(DEFAULT_DATE_TO_STRING_FORMAT) : '';
const RETURN_NULL = () => null;
const ESCAPE_KEY_REGEX = /^Esc(ape)?$/;
/** @deprecated DatePicker は非推奨です。Input[type=date] を使ってください。 */
exports.DatePicker = (0, react_1.forwardRef)(({ value, name, from = exports.DEFAULT_FROM, to, disabled, width, error, className, parseInput, formatDate, showAlternative, onChangeDate, onBlur, ...inputAttrs }, ref) => {
    const containerStyle = (0, react_1.useMemo)(() => ({
        width: typeof width === 'number' ? `${width}px` : width,
    }), [width]);
    const classNames = (0, react_1.useMemo)(() => {
        const { container, inputSuffixLayout, inputSuffixWrapper, inputSuffixText } = classNameGenerator();
        return {
            container: container({ className }),
            inputSuffixLayout: inputSuffixLayout(),
            inputSuffixWrapper: inputSuffixWrapper(),
            inputSuffixText: inputSuffixText(),
        };
    }, [className]);
    const stringToDate = (0, react_1.useMemo)(() => parseInput
        ? (str) => (str ? parseInput(str) : null)
        : (str) => (str ? (0, datePickerHelper_1.parseJpnDateString)(str) : null), [parseInput]);
    const dateToString = (0, react_1.useMemo)(() => formatDate || DEFAULT_DATE_TO_STRING, [formatDate]);
    const dateToAlternativeFormat = (0, react_1.useMemo)(() => (showAlternative ? (d) => (d ? showAlternative(d) : null) : RETURN_NULL), [showAlternative]);
    const [selectedDate, setSelectedDate] = (0, react_1.useState)(stringToDate(value));
    const inputRef = (0, react_1.useRef)(null);
    const inputWrapperRef = (0, react_1.useRef)(null);
    const calendarPortalRef = (0, react_1.useRef)(null);
    const [inputRect, setInputRect] = (0, react_1.useState)(null);
    const [isInputFocused, setIsInputFocused] = (0, react_1.useState)(false);
    const [isCalendarShown, setIsCalendarShown] = (0, react_1.useState)(false);
    const [alternativeFormat, setAlternativeFormat] = (0, react_1.useState)(null);
    const calenderId = (0, react_1.useId)();
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    const baseUpdateDate = (0, react_1.useCallback)((newDate) => {
        if (!inputRef.current ||
            newDate === selectedDate ||
            (newDate && selectedDate && newDate.getTime() === selectedDate.getTime())) {
            // Do not update date if the new date is same with the old one.
            return;
        }
        const isValid = !newDate || (0, dayjs_1.default)(newDate).isValid();
        const errors = [];
        if (!isValid) {
            errors.push('INVALID_DATE');
        }
        const nextDate = isValid ? newDate : null;
        const currentValue = dateToString(nextDate);
        inputRef.current.value = currentValue;
        setAlternativeFormat(dateToAlternativeFormat(nextDate));
        setSelectedDate(nextDate);
        return [nextDate, currentValue, errors];
    }, [selectedDate, dateToString, dateToAlternativeFormat]);
    const updateDate = (0, react_1.useMemo)(() => onChangeDate
        ? (newDate) => {
            const result = baseUpdateDate(newDate);
            if (result) {
                const [nextDate, currentValue, errors] = result;
                onChangeDate(nextDate, currentValue, { errors });
            }
        }
        : baseUpdateDate, [onChangeDate, baseUpdateDate]);
    const closeCalendar = (0, react_1.useCallback)(() => setIsCalendarShown(false), []);
    const openCalendar = (0, react_1.useCallback)(() => {
        if (inputWrapperRef.current) {
            setIsCalendarShown(true);
            setInputRect(inputWrapperRef.current.getBoundingClientRect());
        }
    }, []);
    (0, react_1.useEffect)(() => {
        if (value === undefined || !inputRef.current) {
            return;
        }
        /**
         * Do not format the given value in the following cases
         * - while input element is focused.
         * - if the given value is not date formattable.
         */
        if (!isInputFocused) {
            const newDate = stringToDate(value);
            if (newDate && (0, dayjs_1.default)(newDate).isValid()) {
                inputRef.current.value = dateToString(newDate);
                setAlternativeFormat(dateToAlternativeFormat(newDate));
                setSelectedDate(newDate);
                return;
            }
            setSelectedDate(null);
        }
        inputRef.current.value = value || '';
    }, [value, isInputFocused, dateToString, dateToAlternativeFormat, stringToDate]);
    (0, useOuterClick_1.useOuterClick)((0, react_1.useMemo)(() => [inputWrapperRef, calendarPortalRef], [inputWrapperRef, calendarPortalRef]), closeCalendar);
    const handleKeyDown = (0, react_1.useCallback)((e) => {
        if (!inputRef.current || !calendarPortalRef.current || e.key !== 'Tab') {
            return;
        }
        const calendarButtons = calendarPortalRef.current.querySelectorAll('button');
        if (calendarButtons.length === 0) {
            return;
        }
        const firstCalendarButton = calendarButtons[0];
        if (isInputFocused) {
            if (e.shiftKey) {
                // move focus from Input to previous elements of DatePicker
                closeCalendar();
                return;
            }
            // move focus from Input to Calendar
            e.preventDefault();
            firstCalendarButton.focus();
            return;
        }
        const calendarButtonAry = Array.from(calendarButtons);
        const currentFocused = calendarButtonAry.find((button) => button === e.target);
        if (e.shiftKey) {
            if (currentFocused === firstCalendarButton) {
                // move focus from Calendar to Input
                inputRef.current.focus();
                e.preventDefault();
            }
        }
        else if (currentFocused === calendarButtonAry.at(-1)) {
            // move focus from Calendar to next elements of DatePicker
            inputRef.current.focus();
            closeCalendar();
        }
    }, [isInputFocused, closeCalendar]);
    const baseHandleBlur = (0, react_1.useCallback)((e) => {
        setIsInputFocused(false);
        updateDate(e.target.value ? stringToDate(e.target.value) : null);
    }, [stringToDate, updateDate]);
    const handleBlur = (0, react_1.useMemo)(() => onBlur
        ? (e) => {
            baseHandleBlur(e);
            onBlur(e);
        }
        : baseHandleBlur, [onBlur, baseHandleBlur]);
    (0, useGlobalKeyDown_1.useGlobalKeyDown)(handleKeyDown);
    const caretIconColor = (0, react_1.useMemo)(() => {
        if (isInputFocused || isCalendarShown)
            return themes_1.textColor.black;
        if (disabled)
            return themes_1.textColor.disabled;
        return themes_1.textColor.grey;
    }, [isInputFocused, isCalendarShown, disabled]);
    const onDelegateKeyDown = (0, react_1.useCallback)((e) => {
        if (ESCAPE_KEY_REGEX.test(e.key)) {
            e.stopPropagation();
            // delay hiding calendar because calendar will be displayed when input is focused
            requestAnimationFrame(closeCalendar);
            if (inputRef.current)
                inputRef.current.focus();
        }
    }, [closeCalendar]);
    const onKeyPressInput = (0, react_1.useCallback)((e) => {
        if (e.key === 'Enter') {
            ;
            (isCalendarShown ? openCalendar : closeCalendar)();
            updateDate(stringToDate(e.currentTarget.value));
        }
    }, [isCalendarShown, updateDate, closeCalendar, openCalendar, stringToDate]);
    const onFocusInput = (0, react_1.useCallback)(() => {
        setIsInputFocused(true);
        openCalendar();
    }, [openCalendar]);
    const onSelectDateCalendar = (0, react_1.useCallback)((_, selected) => {
        updateDate(selected);
        // delay hiding calendar because calendar will be displayed when input is focused
        requestAnimationFrame(closeCalendar);
        if (inputRef.current)
            inputRef.current.focus();
    }, [updateDate, closeCalendar]);
    return ((0, jsx_runtime_1.jsxs)("div", { onClick: !isCalendarShown && !disabled ? openCalendar : undefined, onKeyDown: isCalendarShown ? onDelegateKeyDown : undefined, role: "presentation", className: classNames.container, style: containerStyle, children: [(0, jsx_runtime_1.jsx)("div", { ref: inputWrapperRef, children: (0, jsx_runtime_1.jsx)(Input_1.Input, { ...inputAttrs, "data-smarthr-ui-input": "true", width: "100%", name: name, onChange: isCalendarShown ? closeCalendar : undefined, onKeyPress: onKeyPressInput, onFocus: onFocusInput, onBlur: handleBlur, suffix: (0, jsx_runtime_1.jsx)(InputSuffixIcon, { alternativeFormat: showAlternative ? alternativeFormat : null, caretIconColor: caretIconColor, classNames: classNames }), disabled: disabled, error: error, ref: inputRef, className: "smarthr-ui-DatePicker-inputContainer", "aria-expanded": isCalendarShown, "aria-controls": calenderId, "aria-haspopup": true }) }), isCalendarShown && inputRect && ((0, jsx_runtime_1.jsx)(Portal_1.Portal, { inputRect: inputRect, ref: calendarPortalRef, children: (0, jsx_runtime_1.jsx)(Calendar_1.Calendar, { id: calenderId, value: selectedDate || undefined, from: from, to: to, onSelectDate: onSelectDateCalendar }) }))] }));
});
const InputSuffixIcon = (0, react_1.memo)(({ classNames, alternativeFormat, caretIconColor }) => ((0, jsx_runtime_1.jsx)("span", { className: classNames.inputSuffixLayout, children: (0, jsx_runtime_1.jsxs)("span", { className: classNames.inputSuffixWrapper, children: [alternativeFormat && (0, jsx_runtime_1.jsx)("span", { className: classNames.inputSuffixText, children: alternativeFormat }), (0, jsx_runtime_1.jsx)(Icon_1.FaCalendarAltIcon, { color: caretIconColor })] }) })));
//# sourceMappingURL=DatePicker.js.map