"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefinitionListItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const themes_1 = require("../../themes");
const Layout_1 = require("../Layout");
const Text_1 = require("../Text");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-DefinitionListItem shr-border-b-shorthand shr-min-w-[12em] shr-grow shr-border-dotted',
            'contrast-more:shr-border-b-high-contrast',
        ],
        termEl: 'smarthr-ui-DefinitionListItem-term',
        descriptionEl: 'smarthr-ui-DefinitionListItem-description shr-ms-[initial] shr-min-h-[calc(1em*theme(lineHeight.normal))] shr-pb-0.25',
    },
    variants: {
        fullWidth: {
            true: {
                wrapper: 'shr-basis-full',
            },
        },
    },
});
const DefinitionListItem = ({ maxColumns, fullWidth, term, termStyleType = 'subBlockTitle', description, children, className, }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, termEl, descriptionEl } = classNameGenerator();
        return {
            wrapper: wrapper({ fullWidth, className }),
            term: termEl(),
            description: descriptionEl(),
        };
    }, [className, fullWidth]);
    const style = (0, react_1.useMemo)(() => ({
        flexBasis: 
        // fullWidth の方が強い
        !fullWidth && maxColumns
            ? `calc((100% - ${themes_1.spacing[1.5]} * ${maxColumns - 1}) / ${maxColumns})`
            : undefined,
    }), [fullWidth, maxColumns]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.25, className: classNames.wrapper, style: style, children: [(0, jsx_runtime_1.jsx)(DefinitionTerm, { styleType: termStyleType, className: classNames.term, children: term }), (0, jsx_runtime_1.jsx)(Text_1.Text, { as: "dd", size: "M", color: "TEXT_BLACK", leading: "NORMAL", className: classNames.description, children: children ?? description })] }));
};
exports.DefinitionListItem = DefinitionListItem;
const DefinitionTerm = (0, react_1.memo)(({ styleType, className, children }) => ((0, jsx_runtime_1.jsx)(Text_1.Text, { as: "dt", leading: "TIGHT", styleType: styleType, className: className, children: children })));
//# sourceMappingURL=DefinitionListItem.js.map