"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionDialogContentInner = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const useDecorators_1 = require("../../../hooks/useDecorators");
const useResponseStatus_1 = require("../../../hooks/useResponseStatus");
const intl_1 = require("../../../intl");
const Button_1 = require("../../Button");
const Layout_1 = require("../../Layout");
const SectioningContent_1 = require("../../SectioningContent");
const DialogBody_1 = require("../DialogBody");
const DialogContentResponseStatusMessage_1 = require("../DialogContentResponseStatusMessage");
const DialogHeader_1 = require("../DialogHeader");
const dialogInnerStyle_1 = require("../dialogInnerStyle");
const ACTION_AREA_CLUSTER_GAP = { row: 0.5, column: 1 };
const ActionDialogContentInner = ({ children, title, titleId, subtitle, titleTag, contentBgColor, contentPadding, actionText, actionTheme, onClickAction, onClickClose, responseStatus, actionDisabled, closeDisabled, subActionArea, decorators, }) => {
    const calcedResponseStatus = (0, useResponseStatus_1.useResponseStatus)(responseStatus);
    const styles = (0, react_1.useMemo)(() => {
        const { wrapper, actionArea, buttonArea, message } = (0, dialogInnerStyle_1.dialogContentInner)();
        return {
            wrapper: wrapper(),
            actionArea: actionArea(),
            buttonArea: buttonArea(),
            message: message(),
        };
    }, []);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
    (0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { className: styles.wrapper, children: [(0, jsx_runtime_1.jsx)(DialogHeader_1.DialogHeader, { title: title, subtitle: subtitle, titleTag: titleTag, titleId: titleId }), (0, jsx_runtime_1.jsx)(DialogBody_1.DialogBody, { contentPadding: contentPadding, contentBgColor: contentBgColor, children: children }), (0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: styles.actionArea, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { justify: "space-between", children: [subActionArea, (0, jsx_runtime_1.jsx)(ActionAreaCluster, { onClickClose: onClickClose, onClickAction: onClickAction, closeDisabled: closeDisabled, actionDisabled: actionDisabled, loading: calcedResponseStatus.isProcessing, actionTheme: actionTheme, decorators: decorators, actionText: actionText, className: styles.buttonArea })] }), (0, jsx_runtime_1.jsx)(DialogContentResponseStatusMessage_1.DialogContentResponseStatusMessage, { responseStatus: calcedResponseStatus, className: styles.message })] })] }));
};
exports.ActionDialogContentInner = ActionDialogContentInner;
const ActionAreaCluster = (0, react_1.memo)(({ onClickClose, onClickAction, closeDisabled, actionDisabled, loading, actionTheme, decorators, actionText, className, }) => {
    const handleClickAction = (0, react_1.useCallback)(() => {
        onClickAction(onClickClose);
    }, [onClickAction, onClickClose]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: ACTION_AREA_CLUSTER_GAP, className: className, children: [(0, jsx_runtime_1.jsx)(CloseButton, { onClick: onClickClose, disabled: closeDisabled || loading, decorators: decorators }), (0, jsx_runtime_1.jsx)(ActionButton, { variant: actionTheme, disabled: actionDisabled, loading: loading, onClick: handleClickAction, children: actionText })] }));
});
const ActionButton = (0, react_1.memo)(({ variant = 'primary', disabled, loading, onClick, children }) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { type: "submit", variant: variant, disabled: disabled, loading: loading, onClick: onClick, className: "smarthr-ui-Dialog-actionButton", children: children })));
const CloseButton = (0, react_1.memo)(({ onClick, disabled, decorators }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        closeButtonLabel: localize({
            id: 'smarthr-ui/ActionDialog/closeButtonLabel',
            defaultText: 'キャンセル',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    return ((0, jsx_runtime_1.jsx)(Button_1.Button, { onClick: onClick, disabled: disabled, className: "smarthr-ui-Dialog-closeButton", children: decorated.closeButtonLabel }));
});
//# sourceMappingURL=ActionDialogContentInner.js.map