import { type FC, type FormEvent, type PropsWithChildren, type ReactNode } from 'react';
import { type DecoratorsType } from '../../../hooks/useDecorators';
import { type ResponseStatus } from '../../../hooks/useResponseStatus';
import { type Props as DialogBodyProps } from '../DialogBody';
import { type Props as DialogHeaderProps } from '../DialogHeader';
export type BaseProps = PropsWithChildren<DialogHeaderProps & DialogBodyProps & {
    /** アクションボタンのラベル */
    actionText: ReactNode;
    /** アクションボタンのスタイル */
    actionTheme?: 'primary' | 'secondary' | 'danger';
    /**
     * アクションボタンをクリックした時に発火するコールバック関数
     * @param closeDialog ダイアログを閉じる関数
     */
    onSubmit: (closeDialog: () => void, e: FormEvent<HTMLFormElement>) => void;
    /** アクションボタンを無効にするかどうか */
    actionDisabled?: boolean;
    /** 閉じるボタンを無効にするかどうか */
    closeDisabled?: boolean;
    /** ダイアログフッターの左端操作領域 */
    subActionArea?: ReactNode;
    /** コンポーネント内の文言を変更するための関数を設定 */
    decorators?: DecoratorsType<'closeButtonLabel'>;
}>;
export type FormDialogContentInnerProps = BaseProps & {
    onClickClose: () => void;
    responseStatus?: ResponseStatus;
};
export declare const FormDialogContentInner: FC<FormDialogContentInnerProps>;
