"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormDialogContentInner = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const useResponseStatus_1 = require("../../../hooks/useResponseStatus");
const intl_1 = require("../../../intl");
const Button_1 = require("../../Button");
const Layout_1 = require("../../Layout");
const SectioningContent_1 = require("../../SectioningContent");
const DialogBody_1 = require("../DialogBody");
const DialogContentResponseStatusMessage_1 = require("../DialogContentResponseStatusMessage");
const DialogHeader_1 = require("../DialogHeader");
const dialogInnerStyle_1 = require("../dialogInnerStyle");
const ACTION_AREA_CLUSTER_GAP = { row: 0.5, column: 1 };
const formDialogContentInner = (0, tailwind_variants_1.tv)({
    extend: dialogInnerStyle_1.dialogContentInner,
    slots: {
        form: 'shr-contents',
    },
});
const FormDialogContentInner = ({ children, title, titleId, subtitle, titleTag, contentBgColor, contentPadding, actionText, actionTheme, onSubmit, onClickClose, responseStatus, actionDisabled, closeDisabled, subActionArea, decorators, }) => {
    const handleSubmitAction = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        // HINT: React Portals などで擬似的にformがネストしている場合など、stopPropagationを実行しないと
        // 親formが意図せずsubmitされてしまう場合がある
        e.stopPropagation();
        onSubmit(onClickClose, e);
    }, [onSubmit, onClickClose]);
    const calculatedResponseStatus = (0, useResponseStatus_1.useResponseStatus)(responseStatus);
    const styles = (0, react_1.useMemo)(() => {
        const { form, wrapper, actionArea, buttonArea, message } = formDialogContentInner();
        return {
            form: form(),
            wrapper: wrapper(),
            actionArea: actionArea(),
            buttonArea: buttonArea(),
            message: message(),
        };
    }, []);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content, smarthr/a11y-prohibit-sectioning-content-in-form
    (0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { className: styles.wrapper, children: [(0, jsx_runtime_1.jsx)(DialogHeader_1.DialogHeader, { title: title, subtitle: subtitle, titleTag: titleTag, titleId: titleId }), (0, jsx_runtime_1.jsxs)("form", { onSubmit: handleSubmitAction, className: styles.form, children: [(0, jsx_runtime_1.jsx)(DialogBody_1.DialogBody, { contentPadding: contentPadding, contentBgColor: contentBgColor, children: children }), (0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: styles.actionArea, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { justify: "space-between", children: [subActionArea, (0, jsx_runtime_1.jsx)(ActionAreaCluster, { onClickClose: onClickClose, closeDisabled: closeDisabled, actionDisabled: actionDisabled, loading: calculatedResponseStatus.isProcessing, actionTheme: actionTheme, decorators: decorators, actionText: actionText, className: styles.buttonArea })] }), (0, jsx_runtime_1.jsx)(DialogContentResponseStatusMessage_1.DialogContentResponseStatusMessage, { responseStatus: calculatedResponseStatus, className: styles.message })] })] })] }));
};
exports.FormDialogContentInner = FormDialogContentInner;
const ActionAreaCluster = (0, react_1.memo)(({ onClickClose, closeDisabled, actionDisabled, loading, actionTheme, decorators, actionText, className, }) => ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: ACTION_AREA_CLUSTER_GAP, className: className, children: [(0, jsx_runtime_1.jsx)(CloseButton, { onClick: onClickClose, disabled: closeDisabled || loading, decorators: decorators }), (0, jsx_runtime_1.jsx)(ActionButton, { variant: actionTheme, disabled: actionDisabled, loading: loading, children: actionText })] })));
const ActionButton = (0, react_1.memo)(({ variant = 'primary', disabled, loading, children }) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { type: "submit", variant: variant, disabled: disabled, loading: loading, className: "smarthr-ui-Dialog-actionButton", children: children })));
const CloseButton = (0, react_1.memo)(({ onClick, disabled, decorators }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        closeButtonLabel: localize({
            id: 'smarthr-ui/FormDialog/closeButtonLabel',
            defaultText: 'キャンセル',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    return ((0, jsx_runtime_1.jsx)(Button_1.Button, { onClick: onClick, disabled: disabled, className: "smarthr-ui-Dialog-closeButton", children: decorated.closeButtonLabel }));
});
//# sourceMappingURL=FormDialogContentInner.js.map