"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteDialogTrigger = void 0;
const react_1 = require("react");
const useRemoteTrigger_1 = require("../useRemoteTrigger");
const onClickRemoteDialogTrigger = (ariaControls) => {
    document.dispatchEvent(new CustomEvent(useRemoteTrigger_1.TRIGGER_EVENT, {
        detail: { id: ariaControls },
    }));
};
const RemoteDialogTrigger = ({ targetId, children, onClick, ...rest }) => {
    const actualOnClick = (0, react_1.useCallback)((e) => {
        // HINT: onClick内で非同期処理される場合、e.currentTargetがnullになってしまう可能性があるため
        // 先にariaControlsを取得しておく
        const ariaControls = e.currentTarget.getAttribute('aria-controls');
        if (onClick) {
            return onClick(() => {
                onClickRemoteDialogTrigger(ariaControls);
            });
        }
        onClickRemoteDialogTrigger(ariaControls);
    }, [onClick]);
    const actualTrigger = (0, react_1.useMemo)(() => (0, react_1.cloneElement)(children, {
        onClick: actualOnClick,
        'aria-haspopup': 'dialog',
        'aria-controls': targetId,
        ...rest,
    }), [children, actualOnClick, targetId, rest]);
    return actualTrigger;
};
exports.RemoteDialogTrigger = RemoteDialogTrigger;
//# sourceMappingURL=RemoteDialogTrigger.js.map