import { type FC, type FormEvent, type PropsWithChildren, type ReactNode } from 'react';
import { type DecoratorsType } from '../../../hooks/useDecorators';
import { type ResponseStatus } from '../../../hooks/useResponseStatus';
import { type Props as DialogBodyProps } from '../DialogBody';
import { type Props as DialogHeaderProps } from '../DialogHeader';
import { type StepItem } from './StepFormDialogProvider';
export type BaseProps = PropsWithChildren<DialogHeaderProps & DialogBodyProps & {
    /** アクションボタンのラベル */
    submitLabel: ReactNode;
    /** アクションボタンのスタイル */
    actionTheme?: 'primary' | 'secondary' | 'danger';
    /**
     * アクションボタンをクリックした時に発火するコールバック関数
     * @param closeDialog ダイアログを閉じる関数
     * @param currentStep onSubmitが発火した時のステップ
     * @returns 次のステップに遷移する場合は次のステップ、遷移しない場合はundefined
     */
    onSubmit: (closeDialog: () => void, e: FormEvent<HTMLFormElement>, currentStep: StepItem) => StepItem | undefined;
    /** アクションボタンを無効にするかどうか */
    actionDisabled?: boolean;
    /** 閉じるボタンを無効にするかどうか */
    closeDisabled?: boolean;
    /** コンポーネント内の文言を変更するための関数を設定 */
    decorators?: DecoratorsType<DecoratorKeyTypes>;
}>;
export type StepFormDialogContentInnerProps = BaseProps & {
    firstStep: StepItem;
    onClickClose: () => void;
    responseStatus?: ResponseStatus;
    /** ステップの総数 */
    stepLength: number;
    onClickBack?: () => void;
};
declare const DECORATOR_DEFAULT_TEXTS: {
    readonly closeButtonLabel: "キャンセル";
    readonly nextButtonLabel: "次へ";
    readonly backButtonLabel: "戻る";
};
type DecoratorKeyTypes = keyof typeof DECORATOR_DEFAULT_TEXTS;
export declare const StepFormDialogContentInner: FC<StepFormDialogContentInnerProps>;
export {};
