"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepFormDialogContentInner = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const useDecorators_1 = require("../../../hooks/useDecorators");
const useResponseStatus_1 = require("../../../hooks/useResponseStatus");
const Button_1 = require("../../Button");
const Layout_1 = require("../../Layout");
const SectioningContent_1 = require("../../SectioningContent");
const DialogBody_1 = require("../DialogBody");
const DialogContentResponseStatusMessage_1 = require("../DialogContentResponseStatusMessage");
const DialogHeader_1 = require("../DialogHeader");
const dialogInnerStyle_1 = require("../dialogInnerStyle");
const StepFormDialogProvider_1 = require("./StepFormDialogProvider");
const DECORATOR_DEFAULT_TEXTS = {
    closeButtonLabel: 'キャンセル',
    nextButtonLabel: '次へ',
    backButtonLabel: '戻る',
};
const BUTTON_COLUMN_GAP = {
    row: 0.5,
    column: 1,
};
const StepFormDialogContentInner = ({ children, title, titleId, subtitle, titleTag, contentBgColor, contentPadding, submitLabel, actionTheme = 'primary', stepLength, firstStep, onSubmit, onClickClose, responseStatus, actionDisabled, closeDisabled, decorators, onClickBack, }) => {
    const { currentStep, stepQueue, setCurrentStep, scrollerRef } = (0, react_1.useContext)(StepFormDialogProvider_1.StepFormDialogContext);
    const activeStep = (0, react_1.useMemo)(() => currentStep?.stepNumber ?? 1, [currentStep]);
    const handleCloseAction = (0, react_1.useCallback)(() => {
        onClickClose();
        setTimeout(() => {
            // HINT: ダイアログが閉じるtransitionが完了してから初期化をしている
            stepQueue.current = [];
            setCurrentStep(firstStep);
        }, 300);
    }, [firstStep, stepQueue, setCurrentStep, onClickClose]);
    const changeCurrentStep = (0, react_1.useCallback)((step) => {
        setCurrentStep(step);
        // HINT: stepが切り替わるごとにbodyのscroll位置を先頭に戻す処理
        if (scrollerRef.current) {
            scrollerRef.current.scroll(0, 0);
        }
    }, [setCurrentStep, scrollerRef]);
    const handleSubmitAction = (0, react_1.useCallback)((e) => {
        e.preventDefault();
        // HINT: React Potals などで擬似的にformがネストしている場合など、stopPropagationを実行しないと
        // 親formが意図せずsubmitされてしまう場合がある
        e.stopPropagation();
        const next = onSubmit(handleCloseAction, e, currentStep);
        if (next) {
            stepQueue.current.push(currentStep);
            changeCurrentStep(next);
        }
    }, [currentStep, stepQueue, onSubmit, handleCloseAction, changeCurrentStep]);
    const handleBackAction = (0, react_1.useCallback)(() => {
        onClickBack?.();
        changeCurrentStep(stepQueue.current.pop() ?? firstStep);
    }, [firstStep, stepQueue, onClickBack, changeCurrentStep]);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, actionArea, buttonArea, message } = (0, dialogInnerStyle_1.dialogContentInner)();
        return {
            wrapper: wrapper(),
            actionArea: actionArea(),
            buttonArea: buttonArea(),
            message: message(),
        };
    }, []);
    const decorated = (0, useDecorators_1.useDecorators)(DECORATOR_DEFAULT_TEXTS, decorators);
    const actionText = activeStep === stepLength ? submitLabel : decorated.nextButtonLabel;
    const stepText = `（${activeStep}/${stepLength}）`;
    const calcedResponseStatus = (0, useResponseStatus_1.useResponseStatus)(responseStatus);
    return (
    // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content, smarthr/a11y-prohibit-sectioning-content-in-form
    (0, jsx_runtime_1.jsx)(SectioningContent_1.Section, { children: (0, jsx_runtime_1.jsx)("form", { onSubmit: handleSubmitAction, children: (0, jsx_runtime_1.jsxs)("div", { className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)(DialogHeader_1.DialogHeader, { title: subtitle ? title : `${title}${stepText}`, subtitle: subtitle ? `${subtitle}${stepText}` : undefined, titleTag: titleTag, titleId: titleId }), (0, jsx_runtime_1.jsx)(DialogBody_1.DialogBody, { contentPadding: contentPadding, contentBgColor: contentBgColor, ref: scrollerRef, children: children }), (0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: classNames.actionArea, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { justify: "space-between", gap: { row: 0.5, column: 2 }, children: [activeStep > 1 && ((0, jsx_runtime_1.jsx)(Button_1.Button, { onClick: handleBackAction, disabled: calcedResponseStatus.isProcessing, className: "smarthr-ui-Dialog-backButton", children: decorated.backButtonLabel })), (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: BUTTON_COLUMN_GAP, className: classNames.buttonArea, children: [(0, jsx_runtime_1.jsx)(Button_1.Button, { onClick: handleCloseAction, disabled: closeDisabled || calcedResponseStatus.isProcessing, className: "smarthr-ui-Dialog-closeButton", children: decorated.closeButtonLabel }), (0, jsx_runtime_1.jsx)(Button_1.Button, { type: "submit", variant: actionTheme, disabled: actionDisabled, loading: calcedResponseStatus.isProcessing, className: "smarthr-ui-Dialog-actionButton", children: actionText })] })] }), (0, jsx_runtime_1.jsx)(DialogContentResponseStatusMessage_1.DialogContentResponseStatusMessage, { responseStatus: calcedResponseStatus, className: classNames.message })] })] }) }) }));
};
exports.StepFormDialogContentInner = StepFormDialogContentInner;
//# sourceMappingURL=StepFormDialogContentInner.js.map