"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.DisclosureContent = exports.DisclosureTrigger = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const TRIGGER_EVENT = 'smarthr-ui:disclosure-trigger-dispatch';
const CONTENT_TOGGLE_EVENT = 'smarthr-ui:disclosure-content-toggle-dispatch';
const toggleEffectListener = (event_key, callback) => {
    document.addEventListener(event_key, callback);
    return () => {
        document.removeEventListener(event_key, callback);
    };
};
const DisclosureTrigger = ({ targetId, children, onClick, ...rest }) => {
    const [expanded, setExpanded] = (0, react_1.useState)(false);
    const actualOnClick = (0, react_1.useCallback)((e) => {
        const toggleExpanded = () => {
            setExpanded((current) => !current);
        };
        if (onClick) {
            return onClick(toggleExpanded, e);
        }
        toggleExpanded();
    }, [onClick]);
    const actualTrigger = (0, react_1.useMemo)(() => {
        const actualChildren = children instanceof Function ? children({ expanded }) : children;
        return (0, react_1.cloneElement)(actualChildren, {
            onClick: actualOnClick,
            'aria-expanded': expanded.toString(),
            'aria-controls': targetId,
            ...rest,
        });
    }, [expanded, children, actualOnClick, targetId, rest]);
    (0, react_1.useEffect)(() => toggleEffectListener(CONTENT_TOGGLE_EVENT, (e) => {
        if (targetId === e.detail.id) {
            setExpanded(e.detail.expanded);
        }
    }), [targetId]);
    (0, react_1.useEffect)(() => {
        // HINT: 基本的にtriggerはcontentより先にレンダリングされる
        // そのため、contentがレンダリングされたあとになることを期待して
        // requestAnimationFrameでイベント発火を遅延させる
        requestAnimationFrame(() => {
            document.dispatchEvent(new CustomEvent(TRIGGER_EVENT, {
                detail: { id: targetId, expanded },
            }));
        });
    }, [expanded, targetId]);
    return actualTrigger;
};
exports.DisclosureTrigger = DisclosureTrigger;
const DisclosureContent = ({ id, isOpen, visuallyHidden, children, ...rest }) => {
    const [expanded, setExpanded] = (0, react_1.useState)(isOpen || false);
    (0, react_1.useEffect)(() => {
        document.dispatchEvent(new CustomEvent(CONTENT_TOGGLE_EVENT, {
            detail: { id, expanded: isOpen || false },
        }));
    }, [isOpen, id]);
    (0, react_1.useEffect)(() => toggleEffectListener(TRIGGER_EVENT, (e) => {
        if (id === e.detail.id) {
            setExpanded(e.detail.expanded);
        }
    }), [id]);
    if (expanded) {
        return ((0, jsx_runtime_1.jsx)("div", { ...rest, id: id, children: children }));
    }
    if (visuallyHidden) {
        return ((0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { ...rest, id: id, as: "div", children: children }));
    }
    return null;
};
exports.DisclosureContent = DisclosureContent;
//# sourceMappingURL=Disclosure.js.map