"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderButtonList = exports.DropdownMenuButton = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const __1 = require("..");
const intl_1 = require("../../../intl");
const Button_1 = require("../../Button");
const Icon_1 = require("../../Icon");
const Dropdown_1 = require("../Dropdown");
const useKeyboardNavigation_1 = __importDefault(require("./useKeyboardNavigation"));
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        triggerWrapper: 'smarthr-ui-DropdownMenuButton',
        triggerButton: 'smarthr-ui-DropdownMenuButton-trigger [&[aria-expanded="true"]_.smarthr-ui-Icon:last-child]:shr-rotate-180',
        actionList: [
            'smarthr-ui-DropdownMenuButton-panel',
            'shr-list-none shr-py-0.5',
            [
                /* unset した Button の右 padding 分 */
                '[&_.smarthr-ui-Button-disabledWrapper]:shr-pe-1',
                '[&_.smarthr-ui-Button-disabledWrapper]:shr-gap-x-0.5',
                '[&_.smarthr-ui-Button-disabledWrapper_>_.smarthr-ui-Button]:shr-w-[unset] [&_.smarthr-ui-Button-disabledWrapper_>_.smarthr-ui-Button]:shr-bg-transparent [&_.smarthr-ui-Button-disabledWrapper_>_.smarthr-ui-Button]:shr-pe-[unset]',
            ],
        ],
        actionListItemButton: [
            'shr-justify-start shr-rounded-none shr-border-none shr-py-0.5 shr-font-normal',
            'focus-visible:shr-focus-indicator--inner',
        ],
    },
});
const { triggerWrapper, triggerButton, actionList, actionListItemButton } = classNameGenerator();
const DropdownMenuButton = ({ label, children, triggerSize, onlyIconTrigger, triggerIcon, onOpen, onClose, className, ...rest }) => {
    const containerRef = (0, react_1.useRef)(null);
    (0, useKeyboardNavigation_1.default)(containerRef);
    const classNames = (0, react_1.useMemo)(() => ({
        triggerWrapper: triggerWrapper({ className }),
        triggerButton: triggerButton(),
        actionList: actionList(),
    }), [className]);
    return ((0, jsx_runtime_1.jsxs)(__1.Dropdown, { onOpen: onOpen, onClose: onClose, children: [(0, jsx_runtime_1.jsx)(MemoizedTriggerButton, { ...rest, label: label, onlyIconTrigger: onlyIconTrigger, triggerIcon: triggerIcon, triggerSize: triggerSize, classNames: classNames }), (0, jsx_runtime_1.jsx)(__1.DropdownContent, { controllable: true, children: (0, jsx_runtime_1.jsx)("menu", { ref: containerRef, role: "menu", className: classNames.actionList, children: (0, exports.renderButtonList)(children) }) })] }));
};
exports.DropdownMenuButton = DropdownMenuButton;
const MemoizedTriggerButton = (0, react_1.memo)(({ onlyIconTrigger, triggerSize, label, triggerIcon, classNames, ...rest }) => {
    const { localize } = (0, intl_1.useIntl)();
    const { active } = (0, react_1.useContext)(Dropdown_1.DropdownContext);
    const tooltip = (0, react_1.useMemo)(() => ({ show: onlyIconTrigger, message: label }), [label, onlyIconTrigger]);
    return ((0, jsx_runtime_1.jsx)(__1.DropdownTrigger, { className: classNames.triggerWrapper, tooltip: tooltip, children: (0, jsx_runtime_1.jsx)(Button_1.Button, { ...rest, suffix: !onlyIconTrigger && ((0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, { alt: active
                    ? localize({
                        id: 'smarthr-ui/DropdownMenuButton/triggerActive',
                        defaultText: '候補を閉じる',
                    })
                    : localize({
                        id: 'smarthr-ui/DropdownMenuButton/triggerInactive',
                        defaultText: '候補を開く',
                    }) })), size: triggerSize, className: classNames.triggerButton, children: (0, jsx_runtime_1.jsx)(TriggerLabelText, { label: label, onlyIconTrigger: onlyIconTrigger, triggerIcon: triggerIcon }) }) }));
});
const TriggerLabelText = (0, react_1.memo)(({ label, onlyIconTrigger, triggerIcon }) => {
    if (!onlyIconTrigger) {
        return label;
    }
    const Icon = triggerIcon || Icon_1.FaEllipsisIcon;
    return (0, jsx_runtime_1.jsx)(Icon, { alt: typeof label === 'string' ? label : (0, react_innertext_1.default)(label) });
});
const renderButtonList = (children) => react_1.Children.map(children, (item) => {
    if (!item || !(0, react_1.isValidElement)(item)) {
        return null;
    }
    switch (item.type) {
        case react_1.Fragment:
            return (0, exports.renderButtonList)(item.props.children);
        case __1.DropdownMenuGroup:
            return item;
    }
    return ((0, jsx_runtime_1.jsx)("li", { role: "presentation", children: (0, jsx_runtime_1.jsx)(__1.DropdownCloser, { children: (0, react_1.cloneElement)(item, {
                wide: true,
                role: 'menuitem',
                className: actionListItemButton({ className: item.props.className }),
            }) }) }));
});
exports.renderButtonList = renderButtonList;
//# sourceMappingURL=DropdownMenuButton.js.map