"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterDropdown = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const useResponseStatus_1 = require("../../../hooks/useResponseStatus");
const intl_1 = require("../../../intl");
const Button_1 = require("../../Button");
const Icon_1 = require("../../Icon");
const Layout_1 = require("../../Layout");
const ResponseMessage_1 = require("../../ResponseMessage");
const Dropdown_1 = require("../Dropdown");
const DropdownCloser_1 = require("../DropdownCloser");
const DropdownContent_1 = require("../DropdownContent");
const DropdownTrigger_1 = require("../DropdownTrigger");
const CONTROL_CLUSTER_GAP = { column: 1, row: 0.5 };
const ON_SUBMIT = (e) => {
    e.preventDefault();
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        iconWrapper: ['smarthr-ui-Icon-extended', 'shr-relative shr-leading-none'],
        filteredIcon: 'shr-absolute shr-bottom-[2px] shr-right-[-4px] shr-h-[0.5em] shr-w-[0.5em]',
        inner: 'shr-p-1.5',
        actionArea: 'shr-border-t-shorthand shr-sticky shr-bottom-0 shr-bg-white shr-px-1.5 shr-py-1',
        resetButtonArea: '-shr-ms-0.5',
        rightButtonArea: 'shr-ms-auto',
        message: 'shr-text-right',
    },
    variants: {
        filtered: {
            true: {
                iconWrapper: 'shr-text-main',
            },
        },
        triggerSize: {
            default: {},
            s: {
                iconWrapper: '-shr-translate-x-0.25',
            },
        },
    },
});
const FilterDropdown = ({ isFiltered, onApply, onCancel, onReset, onOpen, onClose, children, decorators, responseStatus, triggerSize, onlyIconTrigger = false, ...props }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        status: localize({
            id: 'smarthr-ui/FilterDropdown/status',
            defaultText: '適用中',
        }),
        triggerButton: localize({
            id: 'smarthr-ui/FilterDropdown/triggerButton',
            defaultText: '絞り込み',
        }),
        applyButton: localize({
            id: 'smarthr-ui/FilterDropdown/applyButton',
            defaultText: '適用',
        }),
        cancelButton: localize({
            id: 'smarthr-ui/FilterDropdown/cancelButton',
            defaultText: 'キャンセル',
        }),
        resetButton: localize({
            id: 'smarthr-ui/FilterDropdown/resetButton',
            defaultText: '絞り込み条件を解除',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    const filteredIconAriaLabel = (0, react_1.useMemo)(() => (0, react_innertext_1.default)(decorated.status), [decorated.status]);
    const calcedResponseStatus = (0, useResponseStatus_1.useResponseStatus)(responseStatus);
    const classNamesMapper = (0, react_1.useMemo)(() => {
        const { iconWrapper, filteredIcon, inner, actionArea, resetButtonArea, rightButtonArea, message, } = classNameGenerator();
        const commonStyles = {
            filteredIcon: filteredIcon(),
            inner: inner(),
            actionArea: actionArea(),
            resetButtonArea: resetButtonArea(),
            rightButtonArea: rightButtonArea(),
            message: message(),
        };
        return {
            filtered: {
                ...commonStyles,
                iconWrapper: iconWrapper({ filtered: true, triggerSize }),
            },
            unfiltered: {
                ...commonStyles,
                iconWrapper: iconWrapper({ filtered: false, triggerSize }),
            },
        };
    }, [triggerSize]);
    const classNames = classNamesMapper[isFiltered ? 'filtered' : 'unfiltered'];
    const { buttonSuffix, buttonContent } = (0, react_1.useMemo)(() => {
        const FilterIcon = ((0, jsx_runtime_1.jsxs)("span", { className: classNames.iconWrapper, children: [(0, jsx_runtime_1.jsx)(Icon_1.FaFilterIcon, { alt: onlyIconTrigger ? decorated.triggerButton : undefined }), isFiltered && ((0, jsx_runtime_1.jsx)(Icon_1.FaCircleCheckIcon, { "aria-label": filteredIconAriaLabel, className: classNames.filteredIcon }))] }));
        if (onlyIconTrigger) {
            return {
                buttonSuffix: undefined,
                buttonContent: FilterIcon,
            };
        }
        return {
            buttonSuffix: FilterIcon,
            buttonContent: decorated.triggerButton,
        };
    }, [isFiltered, decorated.triggerButton, onlyIconTrigger, filteredIconAriaLabel, classNames]);
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { onOpen: onOpen, onClose: onClose, children: [(0, jsx_runtime_1.jsx)(DropdownTrigger_1.DropdownTrigger, { tooltip: { show: onlyIconTrigger, message: decorated.triggerButton }, children: (0, jsx_runtime_1.jsx)(Button_1.Button, { ...props, suffix: buttonSuffix, size: triggerSize, children: buttonContent }) }), (0, jsx_runtime_1.jsx)(DropdownContent_1.DropdownContent, { controllable: true, children: (0, jsx_runtime_1.jsxs)("form", { onSubmit: ON_SUBMIT, children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.inner, children: children }), (0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: classNames.actionArea, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: 1, align: "center", justify: "space-between", children: [onReset && ((0, jsx_runtime_1.jsx)("div", { className: classNames.resetButtonArea, children: (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "text", size: "s", prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaRotateLeftIcon, {}), onClick: onReset, disabled: calcedResponseStatus.isProcessing, children: decorated.resetButton }) })), (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: CONTROL_CLUSTER_GAP, justify: "flex-end", className: classNames.rightButtonArea, children: [(0, jsx_runtime_1.jsx)(DropdownCloser_1.DropdownCloser, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { onClick: onCancel, disabled: calcedResponseStatus.isProcessing, children: decorated.cancelButton }) }), (0, jsx_runtime_1.jsx)(DropdownCloser_1.DropdownCloser, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "primary", onClick: onApply, loading: calcedResponseStatus.isProcessing, children: decorated.applyButton }) })] })] }), calcedResponseStatus.message && ((0, jsx_runtime_1.jsx)("div", { className: classNames.message, children: (0, jsx_runtime_1.jsx)(ResponseMessage_1.ResponseMessage, { type: calcedResponseStatus.status, role: "alert", children: calcedResponseStatus.message }) }))] })] }) })] }));
};
exports.FilterDropdown = FilterDropdown;
//# sourceMappingURL=FilterDropdown.js.map