"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSortDropdown = void 0;
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const intl_1 = require("../../../intl");
const Icon_1 = require("../../Icon");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        body: 'shr-p-1.5',
        select: 'shr-min-w-[16em]',
        footer: 'shr-border-t-shorthand shr-px-1.5 shr-py-1',
    },
});
const useSortDropdown = ({ sortFields, defaultOrder, onApply, decorators }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        sortFieldLabel: localize({
            id: 'smarthr-ui/SortDropdown/sortFieldLabel',
            defaultText: '並べ替え項目',
        }),
        sortOrderLabel: localize({
            id: 'smarthr-ui/SortDropdown/sortOrderLabel',
            defaultText: '並び順',
        }),
        ascLabel: localize({
            id: 'smarthr-ui/SortDropdown/ascLabel',
            defaultText: '昇順',
        }),
        descLabel: localize({
            id: 'smarthr-ui/SortDropdown/descLabel',
            defaultText: '降順',
        }),
        applyButtonLabel: localize({
            id: 'smarthr-ui/SortDropdown/applyButtonLabel',
            defaultText: '適用',
        }),
        cancelButtonLabel: localize({
            id: 'smarthr-ui/SortDropdown/cancelButtonLabel',
            defaultText: 'キャンセル',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    // 外向きの値
    const [selectedLabel, setSelectedLabel] = (0, react_1.useState)();
    const [checkedOrder, setCheckedOrder] = (0, react_1.useState)(defaultOrder);
    // 内部的な値
    const [innerFields, setInnerFields] = (0, react_1.useState)(sortFields);
    const [innerSelectedField, setInnerSelectedField] = (0, react_1.useState)();
    const [innerCheckedOrder, setCheckedInnerOrder] = (0, react_1.useState)(defaultOrder);
    (0, react_1.useEffect)(() => {
        if (selectedLabel)
            return;
        // 初期値は option に紛れているので、選択されている項目を取得
        const defaultField = sortFields.find((field) => 'selected' in field && field.selected) || sortFields[0];
        setSelectedLabel(defaultField.label);
        setInnerSelectedField(defaultField.label);
    }, [selectedLabel, sortFields]);
    // 外向きな値で構成
    const triggerLabel = (0, react_1.useMemo)(() => {
        const sortLabel = checkedOrder === 'asc' ? decorated.ascLabel : decorated.descLabel;
        return `${selectedLabel}（${sortLabel}）`;
    }, [decorated.ascLabel, decorated.descLabel, selectedLabel, checkedOrder]);
    const SortIcon = (0, react_1.useMemo)(() => (checkedOrder === 'asc' ? Icon_1.FaArrowUpWideShortIcon : Icon_1.FaArrowDownWideShortIcon), [checkedOrder]);
    const handleChange = (0, react_1.useCallback)((e) => {
        const select = e.currentTarget;
        const newLabel = select.options[select.selectedIndex].label;
        const newFields = innerFields.map((field) => {
            if (field.label !== newLabel && field.selected) {
                return {
                    ...field,
                    selected: false,
                };
            }
            if (field.label === newLabel && !field.selected) {
                return {
                    ...field,
                    selected: true,
                };
            }
            return field;
        });
        setInnerFields(newFields);
        setInnerSelectedField(newLabel);
    }, [innerFields]);
    const handleApply = (0, react_1.useCallback)(() => {
        setSelectedLabel(innerSelectedField);
        setCheckedOrder(innerCheckedOrder);
        onApply({ field: innerSelectedField || '', order: innerCheckedOrder, newfields: innerFields });
    }, [innerCheckedOrder, innerFields, innerSelectedField, onApply]);
    const onChangeSortOrderRadio = (0, react_1.useCallback)((e) => {
        setCheckedInnerOrder(e.currentTarget.value);
    }, []);
    const classNames = (0, react_1.useMemo)(() => {
        const { body, select, footer } = classNameGenerator();
        return {
            body: body(),
            select: select(),
            footer: footer(),
        };
    }, []);
    return {
        onChangeSortOrderRadio,
        labels: {
            triggerLabel,
            ...decorated,
        },
        handler: { handleApply, handleChange },
        innerValues: { innerFields, innerSelectedField, innerCheckedOrder },
        SortIcon,
        classNames,
    };
};
exports.useSortDropdown = useSortDropdown;
//# sourceMappingURL=useSortDropdown.js.map