"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useKeyboardNavigation = useKeyboardNavigation;
const react_1 = require("react");
const tabbable_1 = require("../../libs/tabbable");
const Dropdown_1 = require("./Dropdown");
const dropdownHelper_1 = require("./dropdownHelper");
const KEY_ESCAPE = /^Esc(ape)?$/;
function useKeyboardNavigation(wrapperRef, dummyFocusRef) {
    const { triggerElementRef, rootTriggerRef, onClickCloser } = (0, react_1.useContext)(Dropdown_1.DropdownContext);
    const handleKeyDown = (0, react_1.useCallback)((e) => {
        if (e.key === 'Tab') {
            if (!wrapperRef.current || !triggerElementRef.current || !rootTriggerRef?.current) {
                return;
            }
            const tabbablesInContent = (0, tabbable_1.tabbable)(wrapperRef.current);
            if (tabbablesInContent.length === 0) {
                return;
            }
            const trigger = (0, tabbable_1.tabbable)(triggerElementRef.current).at(-1);
            const firstTabbable = tabbablesInContent[0];
            if (e.target === trigger) {
                if (e.shiftKey) {
                    // move focus previous of the Trigger
                    return;
                }
                // focus a first tabbable element in the dropdown content
                e.preventDefault();
                firstTabbable.focus();
                return;
            }
            else if (e.shiftKey) {
                if (e.target === firstTabbable || e.target === dummyFocusRef.current) {
                    // focus the Trigger
                    e.preventDefault();
                    trigger.focus();
                    onClickCloser();
                }
            }
            else if (e.target === tabbablesInContent.at(-1)) {
                // move focus next of the Trigger
                const rootTrigger = (0, tabbable_1.tabbable)(rootTriggerRef.current).at(-1);
                if (rootTrigger) {
                    rootTrigger.focus();
                    onClickCloser();
                }
            }
        }
        else if (KEY_ESCAPE.test(e.key)) {
            if (e.target && e.target === dummyFocusRef.current) {
                onClickCloser();
                return;
            }
            const trigger = (0, dropdownHelper_1.getFirstTabbable)(triggerElementRef);
            if (trigger && e.target === trigger) {
                // close the dropdown when the Trigger is focused and Esc key is pressed
                onClickCloser();
                return;
            }
            if (wrapperRef.current) {
                for (const inner of (0, tabbable_1.tabbable)(wrapperRef.current)) {
                    if (inner === e.target) {
                        // close the dropdown when an element that is included in dropdown content is focused and Esc key is pressed
                        onClickCloser();
                        break;
                    }
                }
            }
        }
    }, [wrapperRef, triggerElementRef, rootTriggerRef, dummyFocusRef, onClickCloser]);
    (0, react_1.useEffect)(() => {
        window.addEventListener('keydown', handleKeyDown);
        return () => {
            window.removeEventListener('keydown', handleKeyDown);
        };
    }, [handleKeyDown]);
}
//# sourceMappingURL=useKeyboardNavigation.js.map