"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileViewer = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const decimal_js_1 = __importDefault(require("decimal.js"));
const react_1 = require("react");
const __1 = require("../..");
const ImageViewer_1 = require("./ImageViewer");
const PDFViewer_1 = require("./PDFViewer");
const defaultScaleStep = new decimal_js_1.default(0.2);
const defaultScaleSteps = [0.2, 0.6, 1, 1.6, 2, 3];
const FileViewer = ({ file, scaleStep, scaleSteps, width: fixedWidth }) => {
    const ref = (0, react_1.useRef)(null);
    const [scale, setScale] = (0, react_1.useState)(1);
    const [loaded, setLoaded] = (0, react_1.useState)(false);
    const [rotation, setRotation] = (0, react_1.useState)(0);
    const [width, setWidth] = (0, react_1.useState)(fixedWidth ?? 0);
    const internalScaleStep = (0, react_1.useMemo)(() => (scaleStep ? new decimal_js_1.default(scaleStep) : defaultScaleStep), [scaleStep]);
    const scaleUp = (0, react_1.useCallback)(() => {
        setScale((currentScale) => new decimal_js_1.default(currentScale).add(internalScaleStep).toNumber());
    }, [internalScaleStep]);
    const scaleDown = (0, react_1.useCallback)(() => {
        setScale((currentScale) => new decimal_js_1.default(currentScale).sub(internalScaleStep).toNumber());
    }, [internalScaleStep]);
    const rotate = (0, react_1.useCallback)(() => {
        setRotation((currentRotation) => currentRotation - 90);
    }, []);
    const handleLoaded = (0, react_1.useCallback)(() => {
        setLoaded(true);
    }, []);
    (0, react_1.useEffect)(() => {
        if (!ref.current || fixedWidth !== undefined) {
            return;
        }
        const resizeObserver = new ResizeObserver(() => {
            setWidth((ref.current?.clientWidth ?? 0) - 64);
        });
        resizeObserver.observe(ref.current);
        return () => {
            resizeObserver.disconnect();
        };
    }, [fixedWidth]);
    return ((0, jsx_runtime_1.jsxs)("div", { className: "shr-flex shr-h-full shr-w-full shr-flex-col shr-gap-2 shr-overflow-auto shr-bg-scrim shr-bg-[radial-gradient(theme(textColor.black)_1px,_transparent_0)] shr-bg-[length:16px_16px]", ref: ref, children: [(0, jsx_runtime_1.jsx)("div", { className: "shr-sticky shr-start-0 shr-top-0 shr-z-[1] shr-flex shr-w-full shr-flex-shrink-0 shr-gap-0.5", children: (0, jsx_runtime_1.jsx)(Controller, { scale: scale, setScale: setScale, scaleSteps: scaleSteps || defaultScaleSteps, onClickScaleUpButton: scaleUp, onClickScaleDownButton: scaleDown, onClickRotateButton: rotate }) }), (0, jsx_runtime_1.jsxs)("div", { className: "shr-z-[0] shr-mx-auto shr-my-0 shr-box-border shr-flex shr-w-fit shr-flex-shrink-0 shr-grow shr-items-center shr-justify-center shr-px-2 shr-pb-2", children: [!loaded && ((0, jsx_runtime_1.jsx)("div", { className: "shr-pointer-events-none shr-fixed shr-inset-0 shr-flex shr-h-full shr-w-full shr-items-center shr-justify-center", children: (0, jsx_runtime_1.jsx)(__1.Loader, { type: "light", size: "m" }) })), (0, jsx_runtime_1.jsx)("div", { className: !loaded ? 'shr-invisible' : '', children: file.contentType === 'application/pdf' ? ((0, jsx_runtime_1.jsx)(PDFViewer_1.PDFViewer, { scale: scale, rotation: rotation, file: file, width: width, onLoad: handleLoaded })) : file.contentType.startsWith('image/') ? ((0, jsx_runtime_1.jsx)(ImageViewer_1.ImageViewer, { scale: scale, rotation: rotation, file: file, width: width, onLoad: handleLoaded })) : ((0, jsx_runtime_1.jsx)(__1.Text, { children: "\u30B5\u30DD\u30FC\u30C8\u3055\u308C\u3066\u3044\u306A\u3044\u5F62\u5F0F\u306E\u30D5\u30A1\u30A4\u30EB\u3067\u3059\u3002" })) })] })] }));
};
exports.FileViewer = FileViewer;
const Controller = (0, react_1.memo)(({ scale, setScale, scaleSteps, onClickScaleUpButton, onClickScaleDownButton, onClickRotateButton, }) => ((0, jsx_runtime_1.jsx)("div", { className: "shr-sticky shr-flex shr-w-full shr-items-center shr-justify-center shr-justify-items-center shr-gap-0.5 shr-bg-scrim shr-p-0.5 shr-shadow-layer-1", children: (0, jsx_runtime_1.jsxs)(__1.Cluster, { gap: 0.5, children: [(0, jsx_runtime_1.jsxs)("div", { className: "shr-border-shorthand shr-flex shr-divide-x shr-divide-solid shr-overflow-hidden shr-rounded-m", children: [(0, jsx_runtime_1.jsx)(__1.Button, { onClick: onClickScaleDownButton, disabled: scale <= scaleSteps[0], className: "shr-rounded-none shr-border-none", children: (0, jsx_runtime_1.jsx)(__1.FaMagnifyingGlassMinusIcon, { alt: "\u7E2E\u5C0F" }) }), (0, jsx_runtime_1.jsx)(__1.DropdownMenuButton, { label: (0, jsx_runtime_1.jsxs)(__1.Text, { children: [(0, jsx_runtime_1.jsx)(__1.VisuallyHiddenText, { children: "\u62E1\u5927\u7387" }), `${(scale * 100).toFixed(0)}%`] }), className: "shr-border-y-0 shr-border-[theme(borderColor.default)] [&_.smarthr-ui-Button]:shr-rounded-none [&_.smarthr-ui-Button]:shr-border-[transparent]", children: scaleSteps.map((step) => ((0, jsx_runtime_1.jsx)(__1.Button, { onClick: () => setScale(step), className: "shr-rounded-none shr-border-0", children: `${(step * 100).toFixed(0)}%` }, step.toString()))) }), (0, jsx_runtime_1.jsx)(__1.Button, { onClick: onClickScaleUpButton, className: "shr-rounded-none shr-border-0", children: (0, jsx_runtime_1.jsx)(__1.FaMagnifyingGlassPlusIcon, { alt: "\u62E1\u5927" }) })] }), (0, jsx_runtime_1.jsx)(__1.Button, { onClick: onClickRotateButton, className: "shr-p-0.75", children: (0, jsx_runtime_1.jsx)(__1.FaArrowRotateLeftIcon, { alt: "\u5DE6\u56DE\u8EE2" }) })] }) })));
//# sourceMappingURL=FileViewer.js.map