"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormControl = exports.ActualFormControl = void 0;
const react_1 = require("react");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_2 = require("react");
const react_3 = require("react");
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const StatusLabel_1 = require("../StatusLabel");
const Text_1 = require("../Text");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-FormControl',
            'shr-mx-[unset] shr-border-none shr-p-[unset]',
            'disabled:shr-text-disabled',
            '[&:disabled_.smarthr-ui-FormControl-label_>_span]:shr-text-disabled',
            '[&:disabled_.smarthr-ui-FormControl-exampleMessage]:shr-text-color-inherit',
            '[&:disabled_.smarthr-ui-FormControl-errorMessage]:shr-text-color-inherit',
            '[&:disabled_.smarthr-ui-FormControl-supplementaryMessage]:shr-text-color-inherit',
            '[&:disabled_.smarthr-ui-Input]:shr-border-default/50 [&:disabled_.smarthr-ui-Input]:shr-bg-white-darken',
        ],
        label: ['smarthr-ui-FormControl-label'],
        errorList: ['shr-list-none'],
        errorIcon: ['smarthr-ui-FormControl-errorMessage', 'shr-text-danger'],
        underTitleStack: ['[&&&]:shr-mt-0'],
        childrenWrapper: [],
    },
    variants: {
        innerMargin: {
            0: {},
            0.25: {},
            0.5: {},
            0.75: {},
            1: {},
            1.25: {},
            1.5: {},
            2: {},
            2.5: {},
            3: {},
            3.5: {},
            4: {},
            8: {},
            X3S: {},
            XXS: {},
            XS: {},
            S: {},
            M: {},
            L: {},
            XL: {},
            XXL: {},
            X3L: {},
        },
        isFieldset: {
            true: {},
            false: {},
        },
    },
    compoundVariants: [
        // TODO: innerMarginが未指定、初期値の場合、かつFieldsetの場合、childrenの上部の余白を広げることで
        // FormControltとの差をわかりやすくしている
        // 微妙な方法ではあるので、必要に応じてinnerMarginではない属性を用意する
        // https://kufuinc.slack.com/archives/CGC58MW01/p1737944965871159?thread_ts=1737541173.404369&cid=CGC58MW01
        {
            innerMargin: undefined,
            isFieldset: true,
            class: {
                childrenWrapper: '[:not([hidden])_~_&&&]:shr-mt-1',
            },
        },
        {
            innerMargin: undefined,
            isFieldset: false,
            class: {
                childrenWrapper: '[:not([hidden])_~_&&&]:shr-mt-0.5',
            },
        },
    ],
});
const SMARTHR_UI_INPUT_SELECTOR = '[data-smarthr-ui-input="true"]';
const ActualFormControl = ({ title, titleType = 'blockTitle', subActionArea, dangerouslyTitleHidden = false, htmlFor, labelId, innerMargin, statusLabels, statusLabelProps, helpMessage, exampleMessage, errorMessages, autoBindErrorInput = true, supplementaryMessage, as = 'div', className, children, ...props }) => {
    const defaultHtmlFor = (0, react_3.useId)();
    const defaultLabelId = (0, react_3.useId)();
    const managedHtmlFor = htmlFor || defaultHtmlFor;
    const managedLabelId = labelId || defaultLabelId;
    const inputWrapperRef = (0, react_2.useRef)(null);
    const isFieldset = as === 'fieldset';
    const describedbyIds = (0, react_2.useMemo)(() => {
        const temp = [];
        if (helpMessage) {
            temp.push(`${managedHtmlFor}_helpMessage`);
        }
        if (exampleMessage) {
            temp.push(`${managedHtmlFor}_exampleMessage`);
        }
        if (supplementaryMessage) {
            temp.push(`${managedHtmlFor}_supplementaryMessage`);
        }
        if (errorMessages) {
            temp.push(`${managedHtmlFor}_errorMessages`);
        }
        return temp.join(' ');
    }, [helpMessage, exampleMessage, supplementaryMessage, errorMessages, managedHtmlFor]);
    const actualStatusLabels = (0, react_2.useMemo)(() => {
        if (statusLabels) {
            return (Array.isArray(statusLabels) ? statusLabels : [statusLabels]).map((statusLabel, index) => (0, jsx_runtime_1.jsx)(react_2.Fragment, { children: statusLabel }, index));
        }
        if (!statusLabelProps) {
            return [];
        }
        const labelProps = Array.isArray(statusLabelProps) ? statusLabelProps : [statusLabelProps];
        return labelProps.map((prop, index) => (0, react_1.createElement)(StatusLabel_1.StatusLabel, { ...prop, key: index }));
    }, [statusLabels, statusLabelProps]);
    const actualErrorMessages = (0, react_2.useMemo)(() => {
        if (!errorMessages) {
            return [];
        }
        return Array.isArray(errorMessages) ? errorMessages : [errorMessages];
    }, [errorMessages]);
    const actualInnerMargin = (0, react_2.useMemo)(() => innerMargin ?? 0.5, [innerMargin]);
    const classNames = (0, react_2.useMemo)(() => {
        const { wrapper, label, errorList, errorIcon, underTitleStack, childrenWrapper } = classNameGenerator({ innerMargin, isFieldset });
        return {
            wrapper: wrapper({ className }),
            label: label({
                className: dangerouslyTitleHidden ? (0, VisuallyHiddenText_1.visuallyHiddenTextClassNameGenerator)() : '',
            }),
            errorList: errorList(),
            errorIcon: errorIcon(),
            underTitleStack: underTitleStack(),
            childrenWrapper: childrenWrapper(),
        };
    }, [innerMargin, isFieldset, dangerouslyTitleHidden, className]);
    (0, react_2.useEffect)(() => {
        if (isFieldset ||
            !inputWrapperRef?.current ||
            // HINT: 対象idを持つ要素が既に存在する場合、何もしない
            document.getElementById(managedHtmlFor)) {
            return;
        }
        const input = inputWrapperRef.current.querySelector(SMARTHR_UI_INPUT_SELECTOR);
        if (!input) {
            return;
        }
        if (!input.getAttribute('id')) {
            input.setAttribute('id', managedHtmlFor);
        }
        if (input instanceof HTMLInputElement && input.type === 'file') {
            const attrName = 'aria-labelledby';
            const inputLabelledByIds = input.getAttribute(attrName);
            if (inputLabelledByIds) {
                // InputFileの場合はlabel要素の可視ラベルをアクセシブルネームに含める
                input.setAttribute(attrName, `${inputLabelledByIds} ${managedLabelId}`);
            }
        }
    }, [managedHtmlFor, isFieldset, managedLabelId]);
    (0, react_2.useEffect)(() => {
        if (!describedbyIds || !inputWrapperRef?.current) {
            return;
        }
        const inputWrapper = inputWrapperRef.current;
        const attrName = 'aria-describedby';
        if (inputWrapper.querySelector(`[${attrName}="${describedbyIds}"]`)) {
            return;
        }
        const input = inputWrapper.querySelector(SMARTHR_UI_INPUT_SELECTOR);
        if (input) {
            const attribute = input.getAttribute(attrName);
            input.setAttribute(attrName, attribute ? `${attribute} ${describedbyIds}` : describedbyIds);
        }
    }, [describedbyIds]);
    (0, react_2.useEffect)(() => {
        if (!autoBindErrorInput || !inputWrapperRef?.current) {
            return;
        }
        const input = inputWrapperRef.current.querySelector(SMARTHR_UI_INPUT_SELECTOR);
        if (input) {
            const attrName = 'aria-invalid';
            if (actualErrorMessages.length > 0) {
                input.setAttribute(attrName, 'true');
            }
            else {
                input.removeAttribute(attrName);
            }
        }
    }, [actualErrorMessages.length, autoBindErrorInput]);
    let body = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(HelpMessageParagraph, { helpMessage: helpMessage, managedHtmlFor: managedHtmlFor }), (0, jsx_runtime_1.jsx)(ExampleMessageText, { exampleMessage: exampleMessage, managedHtmlFor: managedHtmlFor }), (0, jsx_runtime_1.jsx)(ErrorMessageList, { errorMessages: actualErrorMessages, managedHtmlFor: managedHtmlFor, classNames: classNames }), (0, jsx_runtime_1.jsx)("div", { className: classNames.childrenWrapper, ref: inputWrapperRef, children: children }), (0, jsx_runtime_1.jsx)(SupplementaryMessageText, { supplementaryMessage: supplementaryMessage, managedHtmlFor: managedHtmlFor })] }));
    // HINT: dangerouslyTitleHiddenの場合、body以下の余白の計算を簡略化するため
    // Stackをネストし、そのStackに対してmargin-top: 0を指定する
    // こうすることでinner Stack以下の要素は擬似的にStackの最初の要素になる
    if (dangerouslyTitleHidden) {
        body = ((0, jsx_runtime_1.jsx)(Layout_1.Stack, { gap: actualInnerMargin, className: classNames.underTitleStack, children: body }));
    }
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { ...props, as: as, gap: actualInnerMargin, "aria-describedby": isFieldset && describedbyIds ? describedbyIds : undefined, className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)(TitleCluster, { isFieldset: isFieldset, managedHtmlFor: managedHtmlFor, managedLabelId: managedLabelId, dangerouslyTitleHidden: dangerouslyTitleHidden, titleType: titleType, title: title, statusLabels: actualStatusLabels, subActionArea: subActionArea, labelClassName: classNames.label }), body] }));
};
exports.ActualFormControl = ActualFormControl;
const TitleCluster = (0, react_2.memo)(({ isFieldset, managedHtmlFor, managedLabelId, dangerouslyTitleHidden, titleType, title, subActionArea, labelClassName, statusLabels, }) => {
    const body = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(Text_1.Text, { styleType: titleType, children: title }), (0, jsx_runtime_1.jsx)(StatusLabelCluster, { statusLabels: statusLabels })] }));
    const attrs = (0, react_2.useMemo)(() => {
        if (dangerouslyTitleHidden) {
            return {
                label: null,
                visuallyHidden: isFieldset
                    ? {
                        as: 'legend',
                    }
                    : {
                        as: 'label',
                        htmlFor: managedHtmlFor,
                        id: managedLabelId,
                    },
            };
        }
        if (isFieldset) {
            return {
                label: { 'aria-hidden': 'true' },
                visuallyHidden: { as: 'legend' },
            };
        }
        return {
            label: {
                as: 'label',
                htmlFor: managedHtmlFor,
                id: managedLabelId,
            },
            visuallyHidden: null,
        };
    }, [managedLabelId, managedHtmlFor, dangerouslyTitleHidden, isFieldset]);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [attrs.visuallyHidden && ((0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { ...attrs.visuallyHidden, children: 
                // HINT: innerTextでは正しく文字が取得できない場合がある
                // 安全策としてinnerTextが空を取得してきたらbody自体を埋めこみます
                (0, react_innertext_1.default)(body) || body })), attrs.label && ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { justify: "space-between", 
                // HINT: UI上、常にトップの要素になるため、Stackの計算が狂わないよう、
                // 常にmargin-topを0にする
                className: "[&&&]:shr--mt-0", children: [(0, jsx_runtime_1.jsx)(Layout_1.Cluster, { ...attrs.label, align: "center", className: labelClassName, children: body }), subActionArea && (0, jsx_runtime_1.jsx)("div", { className: "shr-grow", children: subActionArea })] }))] }));
});
const StatusLabelCluster = (0, react_2.memo)(({ statusLabels }) => statusLabels.length === 0 ? null : ((0, jsx_runtime_1.jsx)(Layout_1.Cluster, { gap: 0.25, as: "span", children: statusLabels })));
const HelpMessageParagraph = (0, react_2.memo)(({ helpMessage, managedHtmlFor }) => helpMessage ? ((0, jsx_runtime_1.jsx)("p", { className: "smarthr-ui-FormControl-helpMessage", id: `${managedHtmlFor}_helpMessage`, children: helpMessage })) : null);
const ExampleMessageText = (0, react_2.memo)(({ exampleMessage, managedHtmlFor }) => exampleMessage ? ((0, jsx_runtime_1.jsx)(Text_1.Text, { as: "p", color: "TEXT_GREY", italic: true, id: `${managedHtmlFor}_exampleMessage`, className: "smarthr-ui-FormControl-exampleMessage", children: exampleMessage })) : null);
const ErrorMessageList = (0, react_2.memo)(({ errorMessages, managedHtmlFor, classNames }) => errorMessages.length > 0 ? ((0, jsx_runtime_1.jsx)("div", { id: `${managedHtmlFor}_errorMessages`, className: classNames.errorList, role: "alert", children: errorMessages.map((message, index) => ((0, jsx_runtime_1.jsx)("p", { children: (0, jsx_runtime_1.jsx)(Icon_1.FaCircleExclamationIcon, { text: message, className: classNames.errorIcon }) }, index))) })) : null);
const SupplementaryMessageText = (0, react_2.memo)(({ supplementaryMessage, managedHtmlFor }) => supplementaryMessage ? ((0, jsx_runtime_1.jsx)(Text_1.Text, { as: "p", size: "S", color: "TEXT_GREY", id: `${managedHtmlFor}_supplementaryMessage`, className: "smarthr-ui-FormControl-supplementaryMessage", children: supplementaryMessage })) : null);
exports.FormControl = exports.ActualFormControl;
//# sourceMappingURL=FormControl.js.map