"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppLauncher = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const intl_1 = require("../../../intl");
const Button_1 = require("../../Button");
const Dropdown_1 = require("../../Dropdown");
const Heading_1 = require("../../Heading");
const Icon_1 = require("../../Icon");
const Layout_1 = require("../../Layout");
const TextLink_1 = require("../../TextLink");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        appsButton: [
            'shr-border-none shr-bg-transparent shr-px-0.25 shr-font-normal shr-text-white',
            'hover:shr-border-transparent hover:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:shr-bg-transparent',
            'forced-colors:shr-border-shorthand',
        ],
        contentWrapper: ['smarthr-ui-AppLauncher', 'shr-p-1.5 shr-leading-normal'],
        category: 'smarthr-ui-AppLauncher-category',
        appList: 'shr-list-none',
        link: 'smarthr-ui-AppLauncher-link',
        footer: [
            'smarthr-ui-AppLauncher-footer',
            'shr-border-t-shorthand -shr-mx-0.75 -shr-mb-0.25 shr-px-0.75 shr-pt-1',
        ],
    },
    variants: {
        enableNew: {
            true: {
                appsButton: [
                    'shr-px-0.5 shr-font-bold shr-text-black',
                    '[&_.smarthr-ui-Icon]:aria-expanded:shr-rotate-180',
                    'hover:shr-bg-white-darken',
                    'focus-visible:shr-bg-white-darken',
                ],
            },
        },
    },
});
const AppLauncher = ({ apps, urlToShowAll, decorators, enableNew, ...props }) => {
    const calculatedApps = (0, react_1.useMemo)(() => {
        const result = { base: undefined, others: [] };
        apps.forEach((app) => {
            if (app.type === 'base') {
                result.base = app;
            }
            else {
                result.others.push(app);
            }
        });
        return result;
    }, [apps]);
    const classNames = (0, react_1.useMemo)(() => {
        const { appsButton, contentWrapper, category, appList, link, footer } = classNameGenerator({
            enableNew,
        });
        return {
            appsButton: appsButton(),
            contentWrapper: contentWrapper(),
            category: category(),
            appList: appList(),
            link: link(),
            footer: footer(),
        };
    }, [enableNew]);
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { ...props, children: [(0, jsx_runtime_1.jsx)(MemoizedDropdownTrigger, { enableNew: enableNew, decorators: decorators, className: classNames.appsButton }), (0, jsx_runtime_1.jsx)(Dropdown_1.DropdownContent, { controllable: true, children: (0, jsx_runtime_1.jsxs)(Layout_1.Stack, { as: "nav", gap: 1.5, className: classNames.contentWrapper, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 1.5, children: [calculatedApps.base && ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: classNames.category, as: "section", children: [(0, jsx_runtime_1.jsx)(Heading_1.Heading, { type: "subSubBlockTitle", children: calculatedApps.base.heading }), (0, jsx_runtime_1.jsx)(Layout_1.Cluster, { as: "ul", gap: 1, className: classNames.appList, children: calculatedApps.base.items.map((item, index) => ((0, jsx_runtime_1.jsx)(LinkListItem, { href: item.url, target: item.target, className: classNames.link, children: item.label }, index))) })] })), (0, jsx_runtime_1.jsx)(Layout_1.Cluster, { gap: 1.5, children: calculatedApps.others.map(({ heading, items }, i) => ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { gap: 0.5, className: classNames.category, as: "section", children: [(0, jsx_runtime_1.jsx)(Heading_1.Heading, { type: "subSubBlockTitle", children: heading }), (0, jsx_runtime_1.jsx)(Layout_1.Stack, { gap: 0.5, as: "ul", className: classNames.appList, children: items.map((item, index) => ((0, jsx_runtime_1.jsx)(LinkListItem, { href: item.url, target: item.target, className: classNames.link, children: item.label }, index))) })] }, i))) })] }), (0, jsx_runtime_1.jsx)(TextLinkToShowAll, { href: urlToShowAll, className: classNames.footer })] }) })] }));
};
exports.AppLauncher = AppLauncher;
const MemoizedDropdownTrigger = (0, react_1.memo)(({ enableNew, className, decorators }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        triggerLabel: localize({
            id: 'smarthr-ui/AppLauncher/triggerLabel',
            defaultText: 'アプリ',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    return ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: (0, jsx_runtime_1.jsx)(Button_1.Button, { prefix: enableNew ?? (0, jsx_runtime_1.jsx)(Icon_1.FaToolboxIcon, {}), suffix: enableNew ? (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}) : undefined, className: className, children: decorated.triggerLabel }) }));
});
const TextLinkToShowAll = (0, react_1.memo)(({ href, className }) => {
    const { localize } = (0, intl_1.useIntl)();
    if (!href)
        return null;
    return ((0, jsx_runtime_1.jsx)("div", { className: className, children: (0, jsx_runtime_1.jsx)(TextLink_1.TextLink, { href: href, style: { width: 'fit-content' }, children: localize({
                id: 'smarthr-ui/AppLauncher/showAllText',
                defaultText: 'すべて見る',
            }) }) }));
});
const LinkListItem = (0, react_1.memo)(({ href, target, children, className }) => ((0, jsx_runtime_1.jsx)("li", { children: (0, jsx_runtime_1.jsx)(TextLink_1.TextLink, { href: href, target: target, className: className, children: children }) })));
//# sourceMappingURL=AppLauncher.js.map