"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Header = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const Layout_1 = require("../Layout");
const SmartHRLogo_1 = require("../SmartHRLogo");
const Text_1 = require("../Text");
const _1 = require(".");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: ['smarthr-ui-Header', 'shr-bg-brand shr-px-1.25', 'max-md:shr-px-0.75'],
        logoLink: [
            'smarthr-ui-Header-logoLink',
            /* ロゴが持つ padding 分だけ調整 */
            '-shr-ms-0.75',
            'focus-visible:shr-focus-indicator',
        ],
        tenantInfo: ['smarthr-ui-Header-tenantInfo', 'shr-ms-auto'],
        tenantNameText: 'shr-px-0.25',
        actions: ['smarthr-ui-Header-actions', 'shr-ms-auto'],
    },
    variants: {
        enableNew: {
            true: {
                wrapper: [
                    'shr-border-0 shr-border-b shr-border-t-6 shr-border-solid shr-border-b-default shr-border-t-brand shr-bg-white shr-px-1.5',
                ],
                logoLink: '',
                tenantInfo: '',
                tenantNameText: '',
                actions: 'shr-py-0.5',
            },
        },
    },
});
const COMMON_GAP = { column: 0.25, row: 0 };
const CHILDREN_GAP = { column: 0.5, row: 0.25 };
const Header = ({ enableNew, logo, logoHref, featureName, apps, tenants, currentTenantId, onTenantSelect, children, className, }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, logoLink, tenantInfo: tenantInfoStyle, tenantNameText, actions, } = classNameGenerator({ enableNew });
        return {
            wrapper: wrapper({ className }),
            logoLink: logoLink(),
            tenantInfo: tenantInfoStyle(),
            tenantNameText: tenantNameText(),
            actions: actions(),
        };
    }, [enableNew, className]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { as: "header", justify: "space-between", gap: COMMON_GAP, className: classNames.wrapper, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", gap: COMMON_GAP, children: [(0, jsx_runtime_1.jsx)(Logo, { href: logoHref, enableNew: enableNew, className: classNames.logoLink, children: logo }), enableNew ? ((0, jsx_runtime_1.jsx)(MemoizedAppLauncher, { featureName: featureName, apps: apps, enableNew: enableNew })) : ((0, jsx_runtime_1.jsx)(TenantSwitcher, { currentTenantId: currentTenantId, tenants: tenants, classNames: classNames, onTenantSelect: onTenantSelect }))] }), (0, jsx_runtime_1.jsx)(Layout_1.Cluster, { align: "center", justify: "flex-end", gap: CHILDREN_GAP, className: classNames.actions, children: children })] }));
};
exports.Header = Header;
const Logo = (0, react_1.memo)(({ children, href, enableNew, className }) => ((0, jsx_runtime_1.jsx)("a", { href: href || '/', className: className, children: children || (0, jsx_runtime_1.jsx)(SmartHRLogo_1.SmartHRLogo, { fill: enableNew ? 'brand' : undefined, className: "shr-p-0.75" }) })));
const MemoizedAppLauncher = (0, react_1.memo)(({ featureName, apps = [], enableNew }) => {
    const decorators = (0, react_1.useMemo)(() => {
        if (!featureName) {
            return undefined;
        }
        return { triggerLabel: () => featureName };
    }, [featureName]);
    return featureName && (0, jsx_runtime_1.jsx)(_1.AppLauncher, { apps: apps, enableNew: enableNew, decorators: decorators });
});
const TenantSwitcher = (0, react_1.memo)(({ currentTenantId, tenants, classNames, onTenantSelect }) => {
    const currentTenantName = (0, react_1.useMemo)(() => {
        if (tenants && tenants.length >= 1) {
            const current = tenants.find(({ id }) => id === currentTenantId);
            return current ? current.name : tenants[0].name;
        }
        return undefined;
    }, [currentTenantId, tenants]);
    return (currentTenantName && ((0, jsx_runtime_1.jsx)("div", { className: classNames.tenantInfo, children: tenants && tenants.length > 1 ? ((0, jsx_runtime_1.jsx)(MultiTenantDropdownMenuButton, { label: currentTenantName, tenants: tenants, onTenantSelect: onTenantSelect })) : ((0, jsx_runtime_1.jsx)(Text_1.Text, { color: "TEXT_WHITE", className: classNames.tenantNameText, children: currentTenantName })) })));
});
const MultiTenantDropdownMenuButton = (0, react_1.memo)(({ label, tenants, onTenantSelect }) => {
    const onClick = (0, react_1.useMemo)(() => onTenantSelect
        ? (e) => {
            onTenantSelect(e.currentTarget.value);
        }
        : undefined, [onTenantSelect]);
    return ((0, jsx_runtime_1.jsx)(_1.HeaderDropdownMenuButton, { label: label, children: tenants.map(({ id, name }) => ((0, jsx_runtime_1.jsx)(Button_1.Button, { value: id, onClick: onClick, children: name }, id))) }));
});
//# sourceMappingURL=Header.js.map