"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguageSwitcher = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const tabbable_1 = require("../../../libs/tabbable");
const Button_1 = require("../../Button");
const Dropdown_1 = require("../../Dropdown");
const Icon_1 = require("../../Icon");
const DECORATOR_DEFAULT_TEXTS = {
    triggerLabel: 'Language',
    checkIconAlt: '選択中',
};
const ARROW_KEY_REGEX = /^Arrow(Up|Down|Left|Right)$/;
const ARROW_UPS_REGEX = /^Arrow(Up|Left)$/;
const onKeyDownContent = (e) => {
    if (!ARROW_KEY_REGEX.test(e.key)) {
        return;
    }
    e.preventDefault();
    const buttons = (0, tabbable_1.tabbable)(e.currentTarget);
    const i = buttons.indexOf(e.target);
    let buttonAt = 0;
    if (ARROW_UPS_REGEX.test(e.key)) {
        buttonAt = i - 1;
    }
    else if (i + 1 === buttons.length) {
        buttonAt = i + 1;
    }
    buttons.at(buttonAt)?.focus();
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        switchButton: [
            'shr-border-none shr-bg-transparent shr-px-0.25 shr-font-normal shr-text-white shr-transition-transform shr-duration-100',
            'hover:shr-border-transparent hover:shr-bg-transparent',
            'focus-visible:shr-border-transparent focus-visible:shr-bg-transparent',
            'forced-colors:shr-border-shorthand',
            '[&_.smarthr-ui-Icon]:aria-expanded:shr-rotate-180',
        ],
        languageItemsList: ['shr-p-0.5'],
        languageItem: ['shr-flex shr-items-center'],
        languageButton: [
            'shr-justify-start shr-border-transparent shr-px-0.5 shr-font-normal',
            '[&:not(:has(svg))]:shr-ps-2',
            'hover:shr-border-transparent',
        ],
    },
    variants: {
        invert: {
            true: {
                switchButton: [
                    'shr-text-black',
                    'hover:shr-bg-white-darken',
                    'focus-visible:shr-bg-white-darken',
                ],
            },
        },
        enableNew: {
            true: {
                switchButton: 'shr-px-0.5',
            },
        },
    },
});
const LanguageSwitcher = ({ narrow, enableNew, invert = enableNew, decorators, localeMap, locale, defaultLocale, onLanguageSelect, ...rest }) => {
    const { locales, defaultCurrentLang } = (0, react_1.useMemo)(() => ({
        locales: Object.entries(localeMap),
        defaultCurrentLang: Object.keys(localeMap)[0],
    }), [localeMap]);
    const decorated = (0, useDecorators_1.useDecorators)(DECORATOR_DEFAULT_TEXTS, decorators);
    const currentLang = locale || defaultLocale || defaultCurrentLang;
    const classNames = (0, react_1.useMemo)(() => {
        const { languageButton, languageItemsList, languageItem, switchButton } = classNameGenerator();
        return {
            languageButton: languageButton(),
            languageItemsList: languageItemsList(),
            languageItem: languageItem(),
            switchButton: switchButton({ invert, enableNew }),
        };
    }, [enableNew, invert]);
    const onClickLanguageSelect = (0, react_1.useMemo)(() => onLanguageSelect
        ? (e) => {
            onLanguageSelect(e.currentTarget.value);
        }
        : undefined, [onLanguageSelect]);
    return ((0, jsx_runtime_1.jsxs)(Dropdown_1.Dropdown, { ...rest, children: [(0, jsx_runtime_1.jsx)(MemoizedDropdownTrigger, { narrow: narrow, invert: invert, className: classNames.switchButton, label: decorated.triggerLabel }), (0, jsx_runtime_1.jsx)(Dropdown_1.DropdownContent, { role: "presentation", onKeyDown: onKeyDownContent, children: (0, jsx_runtime_1.jsx)("ul", { className: classNames.languageItemsList, children: locales.map(([code, label]) => ((0, jsx_runtime_1.jsx)(LanguageListItemButton, { code: code, className: classNames.languageItem, buttonStyle: classNames.languageButton, current: currentLang === code, onClick: onClickLanguageSelect, iconAlt: decorated.checkIconAlt, children: label }, code))) }) })] }));
};
exports.LanguageSwitcher = LanguageSwitcher;
const LanguageListItemButton = (0, react_1.memo)(({ code, children, buttonStyle, className, current, iconAlt, onClick }) => ((0, jsx_runtime_1.jsx)("li", { className: className, "aria-current": current, lang: code, children: (0, jsx_runtime_1.jsx)(Button_1.Button, { value: code, onClick: onClick, wide: true, prefix: current ? (0, jsx_runtime_1.jsx)(Icon_1.FaCheckIcon, { color: "MAIN", alt: iconAlt }) : null, className: buttonStyle, children: children }) }, code)));
const MemoizedDropdownTrigger = (0, react_1.memo)(({ narrow, invert, className, label }) => ((0, jsx_runtime_1.jsx)(Dropdown_1.DropdownTrigger, { children: narrow ? ((0, jsx_runtime_1.jsx)(Button_1.Button, { suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}), className: className, children: invert ? (0, jsx_runtime_1.jsx)(Icon_1.LanguageIcon, { alt: label }) : (0, jsx_runtime_1.jsx)(Icon_1.FaGlobeIcon, { alt: label }) })) : ((0, jsx_runtime_1.jsx)(Button_1.Button, { prefix: invert ? (0, jsx_runtime_1.jsx)(Icon_1.LanguageIcon, {}) : (0, jsx_runtime_1.jsx)(Icon_1.FaGlobeIcon, {}), suffix: (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}), className: className, children: label })) })));
//# sourceMappingURL=LanguageSwitcher.js.map