"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.PageHeading = exports.Heading = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const SectioningContent_1 = require("../SectioningContent");
const Text_1 = require("../Text");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const generateTagProps = (level, tag) => {
    let role = undefined;
    let ariaLevel = undefined;
    // TODO: h1はPageHeadingで設定するため、自動計算では必ずh2以下になるようにする
    if (!tag && level > 6) {
        role = 'heading';
        ariaLevel = level;
    }
    return {
        as: tag || (level <= 6 ? `h${level}` : 'span'),
        role,
        'aria-level': ariaLevel,
    };
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: 'smarthr-ui-Heading',
    variants: {
        visuallyHidden: {
            false: 'shr-m-[unset]',
        },
    },
    defaultVariants: {
        visuallyHidden: false,
    },
});
exports.Heading = (0, react_1.memo)(({ tag, type = 'sectionTitle', className, visuallyHidden, ...props }) => {
    const level = (0, react_1.useContext)(SectioningContent_1.LevelContext);
    const tagProps = (0, react_1.useMemo)(() => generateTagProps(level, tag), [level, tag]);
    const actualClassName = (0, react_1.useMemo)(() => classNameGenerator({ visuallyHidden, className }), [className, visuallyHidden]);
    const Component = visuallyHidden ? VisuallyHiddenText_1.VisuallyHiddenText : Text_1.Text;
    return ((0, jsx_runtime_1.jsx)(Component, { ...props, ...Text_1.STYLE_TYPE_MAP[type], ...tagProps, className: actualClassName }));
});
exports.PageHeading = (0, react_1.memo)(({ type = 'screenTitle', ...props }) => (
// eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
(0, jsx_runtime_1.jsx)(exports.Heading, { ...props, type: type, tag: "h1" })));
//# sourceMappingURL=Heading.js.map