import { type ComponentProps, type ReactNode } from 'react';
import type { FontSizes } from '../../themes/createFontSize';
import type { AbstractSize, CharRelativeSize } from '../../themes/createSpacing';
import type { IconType } from 'react-icons';
/**
 * literal union type に補完を効かせるためのハック
 * https://github.com/microsoft/TypeScript/issues/29729
 */
type LiteralUnion<T extends U, U = string> = T | (U & Record<never, never>);
export declare const colorSet: {
    readonly TEXT_BLACK: "black";
    readonly TEXT_WHITE: "white";
    readonly TEXT_GREY: "grey";
    readonly TEXT_DISABLED: "disabled";
    readonly TEXT_LINK: "link";
    readonly MAIN: "main";
    readonly DANGER: "danger";
    readonly WARNING: "warning-yellow";
    readonly BRAND: "brand";
};
type IconProps = {
    /**
     * アイコンの色
     * @type string | 'TEXT_BLACK' | 'TEXT_GREY' | 'TEXT_DISABLED' | 'TEXT_LINK' | 'MAIN' | 'DANGER' | 'WARNING' | 'BRAND'
     */
    color?: LiteralUnion<keyof typeof colorSet>;
    /**
     * アイコンの大きさ（フォントサイズの抽象値）
     * @deprecated 親要素やデフォルトフォントサイズが継承されるため固定値の指定は非推奨
     */
    size?: FontSizes;
};
type ElementProps = Omit<ComponentProps<'svg'>, keyof IconProps>;
type BaseComponentProps = {
    /**アイコンの説明テキスト*/
    alt?: ReactNode;
    /** アイコンと並べるテキスト */
    text?: ReactNode;
    /** アイコンと並べるテキストとの溝 */
    iconGap?: CharRelativeSize | AbstractSize;
    /** `true` のとき、アイコンを右側に表示する */
    right?: boolean;
};
export type Props = Omit<IconProps & ElementProps, keyof BaseComponentProps> & BaseComponentProps;
export declare const generateIcon: (SvgIcon: IconType) => import("react").NamedExoticComponent<Props>;
export {};
