"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.InformationPanel = exports.classNameGenerator = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../hooks/useDecorators");
const intl_1 = require("../../intl");
const Base_1 = require("../Base");
const Button_1 = require("../Button");
const Heading_1 = require("../Heading");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const ResponseMessage_1 = require("../ResponseMessage");
exports.classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-InformationPanel shr-shadow-layer-3',
        header: 'shr-p-1.5',
        heading: 'smarthr-ui-InformationPanel-title',
        togglableButton: 'smarthr-ui-InformationPanel-closeButton -shr-my-0.5 shr-ms-auto',
        content: [
            'smarthr-ui-InformationPanel-content',
            'shr-p-1.5 shr-pt-0 shr-text-base aria-hidden:shr-hidden',
        ],
    },
    variants: {
        type: {
            success: {},
            info: {},
            warning: {},
            error: {},
            sync: {},
        },
        active: {
            true: {},
            false: {
                header: 'shr-py-1',
            },
        },
        bold: {
            true: {
                header: 'shr-py-1',
                content: 'shr-pt-1',
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            type: ['success', 'warning', 'error'],
            bold: true,
            className: {
                header: 'shr-text-white',
                heading: '[&_.smarthr-ui-Icon]:shr-fill-white',
            },
        },
        {
            type: 'success',
            bold: true,
            className: {
                header: 'shr-bg-main',
            },
        },
        {
            type: 'warning',
            bold: true,
            className: {
                header: 'shr-bg-warning-yellow shr-text-black',
                heading: [
                    '[&_.smarthr-ui-WarningIcon-wrapper]:shr-fill-black',
                    '[&_.smarthr-ui-WarningIcon-mark]:shr-fill-warning-yellow',
                ],
            },
        },
        {
            type: 'error',
            bold: true,
            className: {
                header: 'shr-bg-danger',
            },
        },
    ],
});
const InformationPanel = ({ title, titleTag, type = 'info', togglable, active: activeProps = true, bold, className, children, onClickTrigger, decorators, ...props }) => {
    const [active, setActive] = (0, react_1.useState)(activeProps);
    const id = (0, react_1.useId)();
    const titleId = `${id}-title`;
    const contentId = `${id}-content`;
    (0, react_1.useEffect)(() => {
        setActive(activeProps);
    }, [activeProps]);
    const classNamesMapper = (0, react_1.useMemo)(() => {
        const withActive = (0, exports.classNameGenerator)({
            type,
            active: true,
            bold,
        });
        const withInactive = (0, exports.classNameGenerator)({
            type,
            active: false,
            bold,
        });
        const wrapperProps = { className };
        return {
            active: {
                wrapper: withActive.wrapper(wrapperProps),
                header: withActive.header(),
                heading: withActive.heading(),
                togglableButton: withActive.togglableButton(),
                content: withActive.content(),
            },
            inactive: {
                wrapper: withInactive.wrapper(wrapperProps),
                header: withInactive.header(),
                heading: withInactive.heading(),
                togglableButton: withInactive.togglableButton(),
                content: withInactive.content(),
            },
        };
    }, [bold, type, className]);
    const classNames = classNamesMapper[active ? 'active' : 'inactive'];
    return ((0, jsx_runtime_1.jsxs)(Base_1.Base, { ...props, overflow: "hidden", as: "section", className: classNames.wrapper, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Sidebar, { align: "baseline", right: true, className: classNames.header, children: [(0, jsx_runtime_1.jsx)(MemoizedHeading, { tag: titleTag, id: titleId, className: classNames.heading, type: type, children: title }), togglable && ((0, jsx_runtime_1.jsx)(TogglableButton, { active: active, onClickTrigger: onClickTrigger, setActive: setActive, contentId: contentId, className: classNames.togglableButton, decorators: decorators }))] }), (0, jsx_runtime_1.jsx)("div", { id: contentId, "aria-hidden": !active, className: classNames.content, children: children })] }));
};
exports.InformationPanel = InformationPanel;
const MemoizedHeading = (0, react_1.memo)(({ type, children, ...rest }) => ((0, jsx_runtime_1.jsx)(Heading_1.Heading, { ...rest, type: "blockTitle", children: (0, jsx_runtime_1.jsx)(ResponseMessage_1.ResponseMessage, { type: type, iconGap: 0.5, children: children }) })));
const TogglableButton = ({ active, onClickTrigger, setActive, contentId, className, decorators }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        openButtonLabel: localize({
            id: 'smarthr-ui/InformationPanel/openButtonLabel',
            defaultText: '開く',
        }),
        closeButtonLabel: localize({
            id: 'smarthr-ui/InformationPanel/closeButtonLabel',
            defaultText: '閉じる',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    const onClick = (0, react_1.useMemo)(() => (onClickTrigger ? () => onClickTrigger(active) : () => setActive(!active)), [active, onClickTrigger, setActive]);
    return ((0, jsx_runtime_1.jsx)(Button_1.Button, { "aria-expanded": active, "aria-controls": contentId, onClick: onClick, suffix: active ? (0, jsx_runtime_1.jsx)(Icon_1.FaCaretUpIcon, {}) : (0, jsx_runtime_1.jsx)(Icon_1.FaCaretDownIcon, {}), size: "s", className: className, children: decorated[active ? 'closeButtonLabel' : 'openButtonLabel'] }));
};
//# sourceMappingURL=InformationPanel.js.map