"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.CurrencyInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const Input_1 = require("../Input");
const currencyInputHelper_1 = require("./currencyInputHelper");
exports.CurrencyInput = (0, react_1.forwardRef)(({ onFormatValue, onFocus, onBlur, className = '', ...props }, ref) => {
    const innerRef = (0, react_1.useRef)(null);
    const [isFocused, setIsFocused] = (0, react_1.useState)(false);
    (0, react_1.useImperativeHandle)(ref, () => innerRef.current);
    const formatValue = (0, react_1.useCallback)((formatted = '') => {
        if (!innerRef.current || formatted === innerRef.current.value) {
            return;
        }
        innerRef.current.value = formatted;
        if (onFormatValue) {
            onFormatValue(formatted);
        }
    }, [onFormatValue]);
    (0, react_1.useEffect)(() => {
        if (props.value === undefined && props.defaultValue !== undefined) {
            formatValue((0, currencyInputHelper_1.formatCurrency)(props.defaultValue));
        }
        // when component did mount
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    (0, react_1.useEffect)(() => {
        if (!isFocused) {
            if (props.value !== undefined) {
                // for controlled component
                formatValue((0, currencyInputHelper_1.formatCurrency)(props.value));
            }
            else if (innerRef.current) {
                // for uncontrolled component
                formatValue((0, currencyInputHelper_1.formatCurrency)(innerRef.current.value));
            }
        }
    }, [isFocused, props.value, formatValue]);
    const handleFocus = (0, react_1.useCallback)((e) => {
        setIsFocused(true);
        if (innerRef.current) {
            const commaExcluded = innerRef.current.value.replace(/,/g, '');
            formatValue(commaExcluded);
        }
        if (onFocus) {
            onFocus(e);
        }
    }, [formatValue, onFocus]);
    const handleBlur = (0, react_1.useCallback)((e) => {
        setIsFocused(false);
        if (onBlur) {
            onBlur(e);
        }
    }, [onBlur]);
    return ((0, jsx_runtime_1.jsx)(Input_1.Input, { ...props, type: "text", onFocus: handleFocus, onBlur: handleBlur, ref: innerRef, className: `smarthr-ui-CurrencyInput${className ? ` ${className}` : ''}` }));
});
//# sourceMappingURL=CurrencyInput.js.map