"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Input = exports.bgColors = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const themes_1 = require("../../themes");
exports.bgColors = {
    BACKGROUND: 'background',
    COLUMN: 'column',
    BASE_GREY: 'base-grey',
    OVER_BACKGROUND: 'over-background',
    HEAD: 'head',
    BORDER: 'border',
    ACTION_BACKGROUND: 'action-background',
};
const wrapperClassNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-Input',
        'shr-border-shorthand shr-box-border shr-inline-flex shr-cursor-text shr-items-center shr-gap-0.5 shr-rounded-m shr-bg-white shr-px-0.5',
        'contrast-more:shr-border-high-contrast',
        'focus-within:shr-focus-indicator',
        'has-[[aria-invalid]]:shr-border-danger',
    ],
    variants: {
        disabled: {
            true: 'shr-pointer-events-none shr-bg-white-darken [&&&]:shr-border-default/50',
        },
        readOnly: {
            true: '[&&&]:shr-border-[theme(backgroundColor.background)] [&&&]:shr-bg-background',
        },
    },
});
const innerClassNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        input: [
            'smarthr-ui-Input-input',
            'shr-inline-block shr-w-full shr-grow shr-border-none shr-bg-transparent shr-py-0.75 shr-text-base shr-leading-none shr-text-black shr-outline-none shr-outline-0',
            'placeholder:shr-text-grey',
            'disabled:shr-text-disabled disabled:shr-opacity-100',
            'shr-h-[theme(fontSize.base)]',
            // HINT: 日付系inputがsafariなどで対応されていないため、input要素内が空白になりフォームが潰れる場合がある
            // マジックナンバーになるが、ほかに適切なプロパティがないため、min-widthで最低幅を指定することで防ぐ
            '[&[type="datetime-local"]]:shr-min-w-[11em] [&[type="month"]]:shr-min-w-[8em] [&[type="time"]]:shr-min-w-[5em]',
        ],
        affix: 'shr-flex shr-shrink-0 shr-items-center shr-text-grey',
    },
    variants: {
        disabled: {
            true: {
                affix: 'shr-text-disabled shr-opacity-100',
            },
        },
    },
});
exports.Input = (0, react_1.forwardRef)(({ onFocus, onBlur, autoFocus, prefix, suffix, className, width, disabled, error, readOnly, bgColor, ...props }, ref) => {
    const innerRef = (0, react_1.useRef)(null);
    (0, react_1.useImperativeHandle)(ref, () => innerRef.current);
    const handleWheel = (0, react_1.useMemo)(() => (props.type === 'number' ? disableWheel : undefined), [props.type]);
    const onClickFocus = (0, react_1.useCallback)(() => innerRef.current?.focus(), []);
    (0, react_1.useEffect)(() => {
        if (autoFocus && innerRef.current) {
            innerRef.current.focus();
        }
    }, [autoFocus]);
    const wrapperClassName = (0, react_1.useMemo)(() => wrapperClassNameGenerator({ disabled, readOnly, className }), [disabled, readOnly, className]);
    const wrapperStyle = (0, react_1.useMemo)(() => {
        const color = bgColor
            ? themes_1.backgroundColor[exports.bgColors[bgColor]]
            : undefined;
        const maxWidth = typeof width === 'number' ? `${width}px` : width;
        return {
            borderColor: color,
            backgroundColor: color,
            maxWidth,
            width: maxWidth ? '100%' : undefined,
        };
    }, [width, bgColor]);
    const innerClassNames = (0, react_1.useMemo)(() => {
        const { input, affix } = innerClassNameGenerator({ disabled });
        return {
            input: input(),
            prefix: affix({ className: 'smarthr-ui-Input-prefix' }),
            suffix: affix({ className: 'smarthr-ui-Input-suffix' }),
        };
    }, [disabled]);
    return ((0, jsx_runtime_1.jsxs)("span", { role: "presentation", onClick: onClickFocus, className: wrapperClassName, style: wrapperStyle, children: [prefix && (0, jsx_runtime_1.jsx)("span", { className: innerClassNames.prefix, children: prefix }), (0, jsx_runtime_1.jsx)("input", { ...props, "data-smarthr-ui-input": "true", onFocus: onFocus, onBlur: onBlur, onWheel: handleWheel, disabled: disabled, readOnly: readOnly, ref: innerRef, "aria-invalid": error || undefined, className: innerClassNames.input }), suffix && (0, jsx_runtime_1.jsx)("span", { className: innerClassNames.suffix, children: suffix })] }));
});
const disableWheel = (e) => {
    // wheel イベントに preventDefault はないため
    if (e.target) {
        ;
        e.target.blur();
    }
};
//# sourceMappingURL=Input.js.map