"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../../hooks/useDecorators");
const Icon_1 = require("../../Icon");
const InputWithTooltip_1 = require("../InputWithTooltip");
const DECORATOR_DEFAULT_TEXTS = {
    iconAlt: '検索',
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        label: 'shr-inline-block',
        input: '',
    },
    variants: {
        existsWidth: {
            true: {
                // Tooltip > Input の構成になっているため、内部の幅を広げる
                input: 'shr-w-full [&_.smarthr-ui-Input]:shr-w-full',
            },
        },
    },
});
exports.SearchInput = (0, react_1.forwardRef)(({ decorators, width, className, ...rest }, ref) => {
    const labelStyle = (0, react_1.useMemo)(() => ({
        width: typeof width === 'number' ? `${width}px` : width,
    }), [width]);
    const classNames = (0, react_1.useMemo)(() => {
        const { label, input } = classNameGenerator({ existsWidth: !!labelStyle.width });
        return {
            label: label({ className }),
            input: input(),
        };
    }, [labelStyle.width, className]);
    const decorated = (0, useDecorators_1.useDecorators)(DECORATOR_DEFAULT_TEXTS, decorators);
    return ((0, jsx_runtime_1.jsx)("label", { className: classNames.label, style: labelStyle, children: (0, jsx_runtime_1.jsx)(InputWithTooltip_1.InputWithTooltip, { ...rest, ref: ref, prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaMagnifyingGlassIcon, { alt: decorated.iconAlt, color: "TEXT_GREY" }), className: classNames.input }) }));
});
//# sourceMappingURL=SearchInput.js.map