"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputFile = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../hooks/useDecorators");
const intl_1 = require("../../intl");
const Base_1 = require("../Base");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-InputFile shr-block',
        fileList: ['smarthr-ui-InputFile-fileList', 'shr-list-none shr-self-stretch shr-text-base'],
        fileItem: 'shr-flex shr-items-center',
        inputWrapper: [
            'shr-border-shorthand shr-relative shr-inline-flex shr-rounded-m shr-bg-white shr-font-bold shr-leading-none',
            'contrast-more:shr-border-high-contrast',
            'focus-within:shr-focus-indicator',
            'has-[[aria-invalid]]:shr-border-danger',
        ],
        input: [
            'smarthr-ui-InputFile-input',
            'shr-absolute shr-left-0 shr-top-0 shr-h-full shr-w-full shr-opacity-0',
            'file:shr-h-full file:shr-w-full file:shr-cursor-pointer',
            'file:disabled:shr-cursor-not-allowed',
        ],
        prefix: 'shr-me-0.5 shr-inline-flex',
    },
    variants: {
        size: {
            default: {
                inputWrapper: 'shr-px-1 shr-py-0.75 shr-text-base',
            },
            s: {
                inputWrapper: 'shr-p-0.5 shr-text-sm',
            },
        },
        disabled: {
            true: {
                inputWrapper: 'shr-border-disabled shr-bg-white-darken shr-text-disabled',
            },
            false: {
                inputWrapper: 'hover:shr-border-darken hover:shr-bg-white-darken hover:shr-text-black',
            },
        },
    },
    defaultVariants: {
        size: 'default',
    },
});
const BASE_COLUMN_PADDING = { block: 0.5, inline: 1 };
exports.InputFile = (0, react_1.forwardRef)(({ className, size, label, hasFileList = true, onChange, disabled = false, multiple, multiplyAppendable = false, error, decorators, ...props }, ref) => {
    const [files, setFiles] = (0, react_1.useState)([]);
    const labelId = (0, react_1.useId)();
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        destroy: localize({
            id: 'smarthr-ui/InputFile/destroy',
            defaultText: '削除',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, fileList, fileItem, inputWrapper, input, prefix } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            inputWrapper: inputWrapper({ size, disabled }),
            fileList: fileList(),
            fileItem: fileItem(),
            input: input(),
            prefix: prefix(),
        };
    }, [disabled, size, className]);
    // Safari において、input.files への直接代入時に onChange が発火することを防ぐためのフラグ
    const isUpdatingFilesDirectly = (0, react_1.useRef)(false);
    const inputRef = (0, react_1.useRef)(null);
    (0, react_1.useImperativeHandle)(ref, () => inputRef.current);
    const updateInputValue = (0, react_1.useCallback)((newFiles) => {
        if (!inputRef.current) {
            return;
        }
        const buff = new DataTransfer();
        newFiles.forEach((file) => {
            buff.items.add(file);
        });
        isUpdatingFilesDirectly.current = true;
        inputRef.current.files = buff.files;
        isUpdatingFilesDirectly.current = false;
    }, [inputRef]);
    const updateFiles = (0, react_1.useMemo)(() => onChange
        ? (newFiles) => {
            onChange(newFiles);
            updateInputValue(newFiles);
            setFiles(newFiles);
        }
        : setFiles, [onChange, updateInputValue]);
    const handleChange = (0, react_1.useCallback)((e) => {
        // Safari において、input.files への直接代入時はonChangeを発火させない
        if (isUpdatingFilesDirectly.current) {
            return;
        }
        const newFiles = Array.from(e.target.files ?? []);
        if (multiplyAppendable) {
            // multiplyAppendableの場合、すでに選択済みのファイルと結合する
            updateFiles([...files, ...newFiles]);
        }
        else {
            updateFiles(newFiles);
        }
    }, [files, isUpdatingFilesDirectly, updateFiles, multiplyAppendable]);
    const handleDelete = (0, react_1.useCallback)((e) => {
        if (!inputRef.current) {
            return;
        }
        const index = parseInt(e.currentTarget.value, 10);
        const newFiles = files.filter((_, i) => index !== i);
        updateFiles(newFiles);
    }, [files, inputRef, updateFiles]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { align: "flex-start", className: classNames.wrapper, children: [!disabled && hasFileList && files.length > 0 && ((0, jsx_runtime_1.jsx)(Base_1.BaseColumn, { as: "ul", padding: BASE_COLUMN_PADDING, className: classNames.fileList, children: files.map((file, index) => ((0, jsx_runtime_1.jsxs)("li", { className: classNames.fileItem, children: [(0, jsx_runtime_1.jsx)("span", { className: "smarthr-ui-InputFile-fileName", children: file.name }), (0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "text", prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaTrashCanIcon, {}), value: index, onClick: handleDelete, className: "smarthr-ui-InputFile-deleteButton", children: decorated.destroy })] }, index))) })), (0, jsx_runtime_1.jsxs)("span", { className: classNames.inputWrapper, children: [(0, jsx_runtime_1.jsx)("input", { ...props, multiple: multiple || multiplyAppendable, "data-smarthr-ui-input": "true", type: "file", onChange: handleChange, disabled: disabled, ref: inputRef, "aria-invalid": error || undefined, "aria-labelledby": labelId, className: classNames.input }), (0, jsx_runtime_1.jsx)(StyledFaFolderOpenIcon, { className: classNames.prefix }), (0, jsx_runtime_1.jsx)(LabelRender, { id: labelId, label: label })] })] }));
});
const StyledFaFolderOpenIcon = (0, react_1.memo)(({ className }) => ((0, jsx_runtime_1.jsx)("span", { className: className, children: (0, jsx_runtime_1.jsx)(Icon_1.FaFolderOpenIcon, {}) })));
const LabelRender = (0, react_1.memo)(({ id, label }) => ((0, jsx_runtime_1.jsx)("span", { id: id, "aria-hidden": "true", children: label })));
//# sourceMappingURL=InputFile.js.map