"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cluster = exports.clusterClassNameGenerator = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const util_1 = require("../../../libs/util");
const useSectioningWrapper_1 = require("../../SectioningContent/useSectioningWrapper");
exports.clusterClassNameGenerator = (0, tailwind_variants_1.tv)({
    base: 'shr-flex-wrap [&:empty]:shr-gap-0',
    variants: {
        inline: {
            true: 'shr-inline-flex',
            false: 'shr-flex',
        },
        rowGap: {
            // 動的生成も考えたが、tailwindcss が検知できないためベタ書きしている
            0: 'shr-gap-y-0',
            0.25: 'shr-gap-y-0.25',
            0.5: 'shr-gap-y-0.5',
            0.75: 'shr-gap-y-0.75',
            1: 'shr-gap-y-1',
            1.25: 'shr-gap-y-1.25',
            1.5: 'shr-gap-y-1.5',
            2: 'shr-gap-y-2',
            2.5: 'shr-gap-y-2.5',
            3: 'shr-gap-y-3',
            3.5: 'shr-gap-y-3.5',
            4: 'shr-gap-y-4',
            8: 'shr-gap-y-8',
            X3S: 'shr-gap-y-0.25',
            XXS: 'shr-gap-y-0.5',
            XS: 'shr-gap-y-1',
            S: 'shr-gap-y-1.5',
            M: 'shr-gap-y-2',
            L: 'shr-gap-y-2.5',
            XL: 'shr-gap-y-3',
            XXL: 'shr-gap-y-3.5',
            X3L: 'shr-gap-y-4',
        },
        columnGap: {
            0: 'shr-gap-x-0',
            0.25: 'shr-gap-x-0.25',
            0.5: 'shr-gap-x-0.5',
            0.75: 'shr-gap-x-0.75',
            1: 'shr-gap-x-1',
            1.25: 'shr-gap-x-1.25',
            1.5: 'shr-gap-x-1.5',
            2: 'shr-gap-x-2',
            2.5: 'shr-gap-x-2.5',
            3: 'shr-gap-x-3',
            3.5: 'shr-gap-x-3.5',
            4: 'shr-gap-x-4',
            8: 'shr-gap-x-8',
            X3S: 'shr-gap-x-0.25',
            XXS: 'shr-gap-x-0.5',
            XS: 'shr-gap-x-1',
            S: 'shr-gap-x-1.5',
            M: 'shr-gap-x-2',
            L: 'shr-gap-x-2.5',
            XL: 'shr-gap-x-3',
            XXL: 'shr-gap-x-3.5',
            X3L: 'shr-gap-x-4',
        },
        align: {
            start: 'shr-items-start',
            'flex-start': 'shr-items-start',
            end: 'shr-items-end',
            'flex-end': 'shr-items-end',
            center: 'shr-items-center',
            baseline: 'shr-items-baseline',
            stretch: 'shr-items-stretch',
        },
        justify: {
            normal: 'shr-justify-normal',
            start: 'shr-justify-start',
            'flex-start': 'shr-justify-start',
            end: 'shr-justify-end',
            'flex-end': 'shr-justify-end',
            center: 'shr-justify-center',
            'space-between': 'shr-justify-between',
            'space-around': 'shr-justify-around',
            'space-evenly': 'shr-justify-evenly',
            stretch: 'shr-justify-stretch',
        },
    },
});
const ActualCluster = ({ as, gap = 0.5, inline = false, align, justify, className, ...rest }, ref) => {
    const gaps = (0, react_1.useMemo)(() => {
        if (gap instanceof Object) {
            return gap;
        }
        return {
            row: gap,
            column: gap,
        };
    }, [gap]);
    const actualClassName = (0, react_1.useMemo)(() => (0, exports.clusterClassNameGenerator)({
        inline,
        rowGap: gaps.row,
        columnGap: gaps.column,
        align,
        justify,
        className,
    }), [inline, gaps.row, gaps.column, align, justify, className]);
    const Component = as || 'div';
    const Wrapper = (0, useSectioningWrapper_1.useSectionWrapper)(Component);
    const body = (0, jsx_runtime_1.jsx)(Component, { ...rest, ref: ref, className: actualClassName });
    if (Wrapper) {
        return (0, jsx_runtime_1.jsx)(Wrapper, { children: body });
    }
    return body;
};
exports.Cluster = (0, util_1.genericsForwardRef)(ActualCluster);
//# sourceMappingURL=Cluster.js.map