"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Reel = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useSectioningWrapper_1 = require("../../SectioningContent/useSectioningWrapper");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'shr-flex shr-overflow-x-auto shr-overflow-y-hidden',
        '[&_>_*]:shr-flex- [&_>_*]:shr-flex-shrink-0 [&_>_*]:shr-basis-auto',
        /*
          Chromeで空の要素にflex-gapがあると印刷時にレイアウトが崩れるので gap の値を0にする
          See https://bugs.chromium.org/p/chromium/issues/detail?id=1161709
        */
        'empty:shr-gap-0',
    ],
    variants: {
        gap: {
            0: 'shr-gap-0',
            0.25: 'shr-gap-0.25',
            0.5: 'shr-gap-0.5',
            0.75: 'shr-gap-0.75',
            1: 'shr-gap-1',
            1.25: 'shr-gap-1.25',
            1.5: 'shr-gap-1.5',
            2: 'shr-gap-2',
            2.5: 'shr-gap-2.5',
            3: 'shr-gap-3',
            3.5: 'shr-gap-3.5',
            4: 'shr-gap-4',
            8: 'shr-gap-8',
            X3S: 'shr-gap-0.25',
            XXS: 'shr-gap-0.5',
            XS: 'shr-gap-1',
            S: 'shr-gap-1.5',
            M: 'shr-gap-2',
            L: 'shr-gap-2.5',
            XL: 'shr-gap-3',
            XXL: 'shr-gap-3.5',
            X3L: 'shr-gap-4',
        },
        padding: {
            0: 'shr-p-0',
            0.25: 'shr-p-0.25',
            0.5: 'shr-p-0.5',
            0.75: 'shr-p-0.75',
            1: 'shr-p-1',
            1.25: 'shr-p-1.25',
            1.5: 'shr-p-1.5',
            2: 'shr-p-2',
            2.5: 'shr-p-2.5',
            3: 'shr-p-3',
            3.5: 'shr-p-3.5',
            4: 'shr-p-4',
            8: 'shr-p-8',
            X3S: 'shr-p-0.25',
            XXS: 'shr-p-0.5',
            XS: 'shr-p-1',
            S: 'shr-p-1.5',
            M: 'shr-p-2',
            L: 'shr-p-2.5',
            XL: 'shr-p-3',
            XXL: 'shr-p-3.5',
            X3L: 'shr-p-4',
        },
    },
});
exports.Reel = (0, react_1.forwardRef)(({ as: Component = 'div', gap = 0.5, padding = 0, className, ...props }, ref) => {
    const actualClassName = (0, react_1.useMemo)(() => classNameGenerator({ gap, padding, className }), [className, gap, padding]);
    const Wrapper = (0, useSectioningWrapper_1.useSectionWrapper)(Component);
    const body = (0, jsx_runtime_1.jsx)(Component, { ...props, ref: ref, className: actualClassName });
    if (Wrapper) {
        return (0, jsx_runtime_1.jsx)(Wrapper, { children: body });
    }
    return body;
});
//# sourceMappingURL=Reel.js.map