"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoaderSpinner = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const intl_1 = require("../../intl");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        spinner: [
            'smarthr-ui-Loader-spinner', // Button コンポーネントで使用
            'shr-relative',
            'shr-block',
            'shr-mx-auto',
            'shr-animate-[spin_1.6s_linear_infinite]',
        ],
        line: [
            'smarthr-ui-Loader-line', // Button コンポーネントで使用
            'shr-absolute',
            'shr-block',
            'shr-w-full',
            'shr-h-full',
            'shr-opacity-0',
        ],
        cog: [
            'shr-inline-block',
            'shr-relative',
            'shr-w-1/2',
            'shr-h-full',
            'shr-overflow-hidden',
            'shr-border-inherit',
        ],
        cogInner: [
            'shr-absolute',
            'shr-top-0',
            'shr-block',
            'shr-w-[200%]',
            'shr-h-full',
            'shr-box-border',
            'shr-border-solid',
            'shr-border-inherit',
            'shr-border-b-transparent',
            'shr-rounded-[50%]',
            'shr-forced-color-adjust-none',
        ],
    },
    variants: {
        size: {
            s: {
                spinner: ['shr-w-1.5', 'shr-h-1.5'],
                cogInner: ['shr-border-2'],
            },
            m: {
                spinner: ['shr-w-3', 'shr-h-3'],
                cogInner: ['shr-border-4'],
            },
        },
        type: {
            primary: {
                line: ['shr-border-main', 'forced-colors:shr-border-[ButtonBorder]'],
            },
            light: {
                line: ['shr-border-white', 'forced-colors:shr-border-[ButtonBorder]'],
            },
        },
        lineNum: {
            1: {
                line: [
                    'shr-animate-[loader-line-full-unfill-rotate_4.8s_ease-in-out_infinite_both,_loader-line1-fade-in-out_4.8s_ease-in-out_infinite_both]',
                ],
            },
            2: {
                line: [
                    'shr-animate-[loader-line-full-unfill-rotate_4.8s_ease-in-out_infinite_both,_loader-line2-fade-in-out_4.8s_ease-in-out_infinite_both]',
                ],
            },
            3: {
                line: [
                    'shr-animate-[loader-line-full-unfill-rotate_4.8s_ease-in-out_infinite_both,_loader-line3-fade-in-out_4.8s_ease-in-out_infinite_both]',
                ],
            },
            4: {
                line: [
                    'shr-animate-[loader-line-full-unfill-rotate_4.8s_ease-in-out_infinite_both,_loader-line4-fade-in-out_4.8s_ease-in-out_infinite_both]',
                ],
            },
        },
        position: {
            left: {
                cogInner: [
                    'shr-border-r-transparent',
                    'shr-rotate-[129deg]',
                    'shr-animate-[loader-left-spin_1.2s_ease-in-out_infinite_both]',
                    'shr-left-0',
                ],
            },
            right: {
                cogInner: [
                    'shr-border-l-transparent',
                    'shr-rotate-[-129deg]',
                    'shr-animate-[loader-right-spin_1.2s_ease-in-out_infinite_both]',
                    '-shr-left-full',
                ],
            },
        },
    },
});
exports.LoaderSpinner = (0, react_1.memo)(({ size = 'm', alt, type = 'primary' }) => {
    const { localize } = (0, intl_1.useIntl)();
    const classNames = (0, react_1.useMemo)(() => {
        const { spinner, line, cog, cogInner } = classNameGenerator({
            type,
            size,
        });
        return {
            spinner: spinner(),
            cog: cog(),
            cogInnerLeft: cogInner({ position: 'left' }),
            cogInnerRight: cogInner({ position: 'right' }),
            line1: line({ lineNum: 1 }),
            line2: line({ lineNum: 2 }),
            line3: line({ lineNum: 3 }),
            line4: line({ lineNum: 4 }),
        };
    }, [type, size]);
    const actualAlt = (0, react_1.useMemo)(() => alt ?? localize({ id: 'smarthr-ui/Loader/alt', defaultText: '処理中' }), [alt, localize]);
    const lineBody = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)("span", { className: classNames.cog, children: (0, jsx_runtime_1.jsx)("span", { className: classNames.cogInnerLeft }) }), (0, jsx_runtime_1.jsx)("span", { className: classNames.cog, children: (0, jsx_runtime_1.jsx)("span", { className: classNames.cogInnerRight }) })] }));
    return ((0, jsx_runtime_1.jsxs)("span", { className: classNames.spinner, children: [(0, jsx_runtime_1.jsx)("span", { className: classNames.line1, children: lineBody }), (0, jsx_runtime_1.jsx)("span", { className: classNames.line2, children: lineBody }), (0, jsx_runtime_1.jsx)("span", { className: classNames.line3, children: lineBody }), (0, jsx_runtime_1.jsx)("span", { className: classNames.line4, children: lineBody }), (0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { children: actualAlt })] }));
});
//# sourceMappingURL=LoaderSpinner.js.map