"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotificationBar = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const intl_1 = require("../../intl");
const Base_1 = require("../Base");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-NotificationBar shr-flex shr-items-baseline shr-justify-between shr-gap-0.5 shr-p-0.75',
        inner: 'shr-flex-grow',
        messageArea: [
            'smarthr-ui-NotificationBar-messageArea',
            'shr-flex shr-grow',
            '[&_.smarthr-ui-Icon-withText]:shr-leading-tight',
        ],
        icon: '',
        actionArea: 'smarthr-ui-NotificationBar-actionArea -shr-my-0.5 shr-shrink-0',
        closeButton: 'smarthr-ui-NotificationBar-closeButton -shr-mb-0.5 -shr-mr-0.5 -shr-mt-0.5 shr-flex-shrink-0 shr-text-black',
    },
    variants: {
        /** 下地 */
        base: {
            none: {},
            base: {
                wrapper: 'shr-py-1 shr-pe-1 shr-ps-1.5',
            },
        },
        /** メッセージの種類 */
        type: {
            info: {
                icon: 'shr-text-grey',
            },
            success: {},
            warning: {
                icon: 'shr-text-black',
            },
            error: {},
            sync: {
                icon: 'shr-text-main',
            },
        },
        /** 強調するかどうか */
        bold: {
            true: '',
            false: '',
        },
        /** スライドインするかどうか */
        animate: {
            true: {
                wrapper: 'shr-animate-[notification-bar-slide-in_0.2s_ease-out]',
            },
        },
    },
    compoundVariants: [
        {
            type: ['info', 'success', 'warning', 'error', 'sync'],
            bold: false,
            className: {
                wrapper: 'shr-bg-white shr-text-black',
            },
        },
        {
            type: 'success',
            bold: false,
            className: {
                icon: 'shr-text-main',
            },
        },
        {
            type: 'error',
            bold: false,
            className: {
                icon: 'shr-text-danger',
            },
        },
        {
            type: ['info', 'sync'],
            bold: true,
            className: {
                wrapper: 'shr-bg-white',
            },
        },
        {
            type: 'success',
            bold: true,
            className: {
                wrapper: 'shr-bg-main shr-text-white',
                icon: 'shr-text-white',
                closeButton: 'shr-text-white hover:[&]:shr-bg-main-darken focus-visible:[&]:shr-bg-main-darken',
            },
        },
        {
            type: 'warning',
            bold: true,
            className: {
                wrapper: 'shr-bg-warning-yellow shr-text-black',
                closeButton: 'shr-text-black hover:[&]:shr-bg-warning-yellow-darken focus-visible:[&]:shr-bg-warning-yellow-darken',
            },
        },
        {
            type: 'error',
            bold: true,
            className: {
                wrapper: 'shr-bg-danger shr-text-white',
                icon: 'shr-text-white',
                closeButton: 'shr-text-white hover:[&]:shr-bg-danger-darken focus-visible:[&]:shr-bg-danger-darken',
            },
        },
    ],
});
const ABSTRACT_ICON_MAPPER = {
    info: Icon_1.FaCircleInfoIcon,
    success: Icon_1.FaCircleCheckIcon,
    error: Icon_1.FaCircleExclamationIcon,
    sync: Icon_1.FaRotateIcon,
};
const ICON_MAPPER = {
    normal: {
        ...ABSTRACT_ICON_MAPPER,
        warning: Icon_1.WarningIcon,
    },
    bold: {
        ...ABSTRACT_ICON_MAPPER,
        warning: Icon_1.FaTriangleExclamationIcon,
    },
};
const ROLE_STATUS_TYPE_REGEX = /^(info|sync)$/;
const NotificationBar = ({ type, bold, animate, message, onClose, children, role, base, layer, className, ...props }) => {
    const actualRole = (0, react_1.useMemo)(() => {
        if (role) {
            return role;
        }
        return ROLE_STATUS_TYPE_REGEX.test(type) ? 'status' : 'alert';
    }, [role, type]);
    const { WrapBase, baseProps } = (0, react_1.useMemo)(() => base === 'base'
        ? {
            WrapBase: Base_1.Base,
            baseProps: {
                layer,
                overflow: 'hidden',
            },
        }
        : {
            WrapBase: react_1.Fragment,
            baseProps: {},
        }, [base, layer]);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, inner, messageArea, icon, actionArea, closeButton } = classNameGenerator({
            type,
            bold: !!bold,
            base: base || 'none',
        });
        return {
            wrapper: wrapper({ animate, className }),
            inner: inner(),
            messageArea: messageArea(),
            icon: icon(),
            actionArea: actionArea(),
            closeButton: closeButton(),
        };
    }, [animate, base, bold, type, className]);
    return ((0, jsx_runtime_1.jsx)(WrapBase, { ...baseProps, children: (0, jsx_runtime_1.jsxs)("div", { ...props, className: classNames.wrapper, role: actualRole, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { gap: 1, align: "center", justify: "flex-end", className: classNames.inner, children: [(0, jsx_runtime_1.jsx)(MessageArea, { message: message, bold: bold, type: type, classNames: classNames }), children && ((0, jsx_runtime_1.jsx)(Layout_1.Cluster, { align: "center", justify: "flex-end", className: classNames.actionArea, children: children }))] }), (0, jsx_runtime_1.jsx)(CloseButton, { onClose: onClose, className: classNames.closeButton })] }) }));
};
exports.NotificationBar = NotificationBar;
const MessageArea = (0, react_1.memo)(({ message, bold, type, classNames }) => {
    const Icon = ICON_MAPPER[bold ? 'bold' : 'normal'][type];
    return ((0, jsx_runtime_1.jsx)("div", { className: classNames.messageArea, children: (0, jsx_runtime_1.jsx)(Icon, { text: message, iconGap: 0.5, className: classNames.icon }) }));
});
const CloseButton = (0, react_1.memo)(({ onClose, className }) => onClose && ((0, jsx_runtime_1.jsx)(Button_1.Button, { variant: "text", size: "s", onClick: onClose, className: className, children: (0, jsx_runtime_1.jsx)(Icon_1.FaXmarkIcon, { alt: (0, jsx_runtime_1.jsx)(intl_1.Localizer, { id: "smarthr-ui/NotificationBar/closeButtonIconAlt", defaultText: "\u9589\u3058\u308B" }) }) })));
//# sourceMappingURL=NotificationBar.js.map