"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pagination = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const lodash_1 = require("../../libs/lodash");
const Layout_1 = require("../Layout");
const SectioningContent_1 = require("../SectioningContent");
const PaginationControllerItemButton_1 = require("./PaginationControllerItemButton");
const PaginationItemButton_1 = require("./PaginationItemButton");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Pagination shr-inline-block shr-max-w-full',
        list: 'shr-m-0.25 shr-list-none shr-ps-[unset]',
        firstListItem: 'smarthr-ui-Pagination-first',
        prevListItem: 'smarthr-ui-Pagination-prev',
        nextListItem: 'smarthr-ui-Pagination-next',
        lastListItem: 'smarthr-ui-Pagination-last',
    },
    variants: {
        withoutNumbers: {
            true: {
                firstListItem: 'shr-mr-0.5',
                prevListItem: 'shr-mr-0',
                nextListItem: 'shr-ml-0',
                lastListItem: 'shr-ml-0.5',
            },
            false: {
                prevListItem: 'shr-mr-0.5',
                nextListItem: 'shr-ml-0.5',
            },
        },
    },
});
const BUTTON_REGEX = /^button$/i;
const ANCHOR_REGEX = /^a/i;
const getTargetDelegateElement = (e, regex) => e.nativeEvent.composedPath().find((elm) => regex.test(elm.tagName));
const Pagination = (props) => props.total > 1 ? (0, jsx_runtime_1.jsx)(ActualPagination, { ...props }) : null;
exports.Pagination = Pagination;
const ActualPagination = ({ total, current, onClick, padding, className, withoutNumbers, hrefTemplate, linkAs, ...props }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, list, firstListItem, prevListItem, nextListItem, lastListItem } = classNameGenerator();
        const itemArg = { withoutNumbers: withoutNumbers || false };
        return {
            wrapper: wrapper({ className }),
            list: list(),
            firstListItem: firstListItem(itemArg),
            prevListItem: prevListItem(itemArg),
            nextListItem: nextListItem(itemArg),
            lastListItem: lastListItem(itemArg),
        };
    }, [className, withoutNumbers]);
    const actualOnClick = (0, react_1.useMemo)(() => {
        if (!onClick) {
            return undefined;
        }
        if (hrefTemplate) {
            return (e) => {
                const anchor = getTargetDelegateElement(e, ANCHOR_REGEX);
                if (!anchor) {
                    return;
                }
                const href = anchor.href;
                if (href) {
                    onClick(href, e);
                }
            };
        }
        return (e) => {
            const button = getTargetDelegateElement(e, BUTTON_REGEX);
            if (button) {
                onClick(parseInt(button.value, 10), e);
            }
        };
    }, [onClick, hrefTemplate]);
    return ((0, jsx_runtime_1.jsx)(SectioningContent_1.Nav, { ...props, className: classNames.wrapper, "aria-label": "\u30DA\u30FC\u30B8\u30CD\u30FC\u30B7\u30E7\u30F3", children: (0, jsx_runtime_1.jsx)(Layout_1.Reel, { onClick: actualOnClick, role: "presentation", children: (0, jsx_runtime_1.jsx)(ItemButtons, { total: total, current: current, padding: padding, withoutNumbers: withoutNumbers, hrefTemplate: hrefTemplate, classNames: classNames, linkAs: linkAs }) }) }));
};
const ItemButtons = (0, react_1.memo)(({ total, current, padding, withoutNumbers, hrefTemplate, classNames, linkAs }) => {
    const pageNumbers = (0, react_1.useMemo)(() => {
        if (withoutNumbers) {
            return [];
        }
        const actualPadding = padding ?? 4;
        return (0, lodash_1.range)(Math.max(current - actualPadding, 1), Math.min(current + actualPadding, total) + 1);
    }, [current, total, padding, withoutNumbers]);
    const controllerAttrs = (0, react_1.useMemo)(() => ({
        prev: {
            disabled: current === 1,
            direction: 'prev',
            hrefTemplate,
            linkAs,
        },
        next: {
            disabled: current === total,
            direction: 'next',
            hrefTemplate,
            linkAs,
        },
    }), [current, total, hrefTemplate, linkAs]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { as: "ul", className: classNames.list, children: [(0, jsx_runtime_1.jsx)(DoubleIconItemButton, { ...controllerAttrs.prev, targetPage: 1, className: classNames.firstListItem }), (0, jsx_runtime_1.jsx)("li", { className: classNames.prevListItem, children: (0, jsx_runtime_1.jsx)(PaginationControllerItemButton_1.PaginationControllerItemButton, { ...controllerAttrs.prev, targetPage: current - 1 }) }), pageNumbers.map((page) => ((0, jsx_runtime_1.jsx)(NumberItemButton, { page: page, disabled: page === current, hrefTemplate: hrefTemplate, linkAs: linkAs }, page))), (0, jsx_runtime_1.jsx)("li", { className: classNames.nextListItem, children: (0, jsx_runtime_1.jsx)(PaginationControllerItemButton_1.PaginationControllerItemButton, { ...controllerAttrs.next, targetPage: current + 1 }) }), (0, jsx_runtime_1.jsx)(DoubleIconItemButton, { ...controllerAttrs.next, targetPage: total, className: classNames.lastListItem })] }));
});
const NumberItemButton = (0, react_1.memo)(({ disabled, ...rest }) => ((0, jsx_runtime_1.jsx)("li", { className: `smarthr-ui-Pagination-${disabled ? 'current' : 'page'}`, children: (0, jsx_runtime_1.jsx)(PaginationItemButton_1.PaginationItemButton, { ...rest, disabled: disabled }) })));
const DoubleIconItemButton = (0, react_1.memo)(({ className, ...rest }) => ((0, jsx_runtime_1.jsx)("li", { className: className, children: (0, jsx_runtime_1.jsx)(PaginationControllerItemButton_1.PaginationControllerItemButton, { ...rest, double: true }) })));
//# sourceMappingURL=Pagination.js.map