"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PaginationItemButton = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'shr-rounded-s',
        'aria-current-page:[&&&]:shr-cursor-default aria-current-page:[&&&]:shr-bg-main aria-current-page:[&&&]:shr-text-white',
        'aria-current-page:[&&&]:shr-border-solid aria-current-page:[&&&]:shr-border-main',
    ],
});
const PaginationItemButton = ({ page, disabled, hrefTemplate, linkAs }) => {
    const className = (0, react_1.useMemo)(() => classNameGenerator(), []);
    const { Component, attrs } = (0, react_1.useMemo)(() => {
        const common = {
            'aria-label': `${page}ページ目`,
            'aria-current': disabled ? 'page' : undefined,
        };
        if (hrefTemplate) {
            return {
                Component: Button_1.AnchorButton,
                attrs: {
                    ...common,
                    // HINT: elementAsにnext/linkを設定した場合、hrefがundefinedでは
                    // エラーになってしまうため、undefinedで指定されていない状態にする
                    ...(disabled
                        ? {
                            href: undefined,
                            elementAs: undefined,
                        }
                        : {
                            href: hrefTemplate(page),
                            elementAs: linkAs,
                        }),
                },
            };
        }
        return {
            Component: Button_1.Button,
            attrs: {
                ...common,
                disabled,
                value: page,
            },
        };
    }, [disabled, page, hrefTemplate, linkAs]);
    return ((0, jsx_runtime_1.jsx)(Component, { ...attrs, size: "s", className: className, children: page }));
};
exports.PaginationItemButton = PaginationItemButton;
//# sourceMappingURL=PaginationItemButton.js.map