"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioButtonPanel = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Base_1 = require("../Base");
const Layout_1 = require("../Layout");
const RadioButton_1 = require("../RadioButton");
const NONE_ROLE_TAG_REGEX = /^(div|span)$/;
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        base: [
            'smarthr-ui-RadioButtonPanel',
            'shr-border-shorthand shr-cursor-pointer shr-list-none shr-shadow-none',
            'has-[:disabled]:shr-cursor-default',
            // FIX: なぜか storybook 上で :has が動作しないので重ねて書いている
            'has-[:focus-visible]:shr-focus-indicator [&:has(:focus-visible)]:shr-focus-indicator',
            '[&:has(:disabled)]:shr-text-disabled has-[:disabled]:[&_.smarthr-ui-RadioButtonPanel-description]:shr-text-disabled',
        ],
        radio: [
            '[&_.smarthr-ui-RadioButton-radioButton:focus-visible_+_span]:shr-shadow-none',
            '[&_.smarthr-ui-RadioButton-label]:shr-ms-0.75',
        ],
        // RadioButtonPanel で指定している shr-ms-0.75 + RadioButton のボタンの shr-w-em を足して shr-ms-[1.75em] にしている
        description: ['smarthr-ui-RadioButtonPanel-description', 'shr-ms-[1.75em] shr-mt-0.5'],
    },
    variants: {
        hasDescription: {
            true: {
                base: 'shr-flex shr-flex-col',
                radio: 'shr-font-bold',
            },
        },
    },
});
const RadioButtonPanel = ({ onClick, as, className, children, label, labelSuffix, 'aria-describedby': ariaDescribedby, ...props }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { base, description, radio } = classNameGenerator({
            className,
            hasDescription: !!children,
        });
        return { base: base(), description: description(), radio: radio() };
    }, [className, children]);
    const role = (0, react_1.useMemo)(() => (typeof as === 'string' && NONE_ROLE_TAG_REGEX.test(as) ? 'presentation' : undefined), [as]);
    // 外側の装飾を押しても内側のラジオボタンが押せるようにする
    const innerRef = (0, react_1.useRef)(null);
    const handleOuterClick = (0, react_1.useCallback)(() => {
        innerRef.current?.click();
    }, []);
    const descriptionId = (0, react_1.useId)();
    return (
    // eslint-disable-next-line smarthr/a11y-delegate-element-has-role-presentation
    (0, jsx_runtime_1.jsxs)(Base_1.Base, { padding: 1, role: role, onClick: handleOuterClick, as: as, className: classNames.base, children: [(0, jsx_runtime_1.jsx)(RadioButton_1.RadioButton, { ...props, ref: innerRef, "aria-describedby": `${descriptionId} ${ariaDescribedby ?? ''}`, className: classNames.radio, children: (0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", as: "span", children: [label, labelSuffix] }) }), children && ((0, jsx_runtime_1.jsx)("div", { id: descriptionId, className: classNames.description, children: children }))] }));
};
exports.RadioButtonPanel = RadioButtonPanel;
//# sourceMappingURL=RadioButtonPanel.js.map