"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.SegmentedControl = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        container: 'smarthr-ui-SegmentedControl shr-inline-flex',
        buttonGroup: '-shr-space-x-px',
        button: [
            'smarthr-ui-SegmentedControl-button',
            'shr-m-0 shr-rounded-none',
            'focus-visible:shr-focus-indicator',
            'first:shr-rounded-bl-m first:shr-rounded-tl-m',
            'last:shr-rounded-br-m last:shr-rounded-tr-m',
        ],
    },
    variants: {
        size: {
            default: {
                button: '[&:has(>_span_>_.smarthr-ui-Icon:only-child)]:shr-p-0.75',
            },
            s: {
                button: 'shr-p-0.5',
            },
        },
    },
});
const SegmentedControl = ({ options, value, onClickOption, size = 'default', className, ...props }) => {
    const [isFocused, setIsFocused] = (0, react_1.useState)(false);
    const containerRef = (0, react_1.useRef)(null);
    const classNames = (0, react_1.useMemo)(() => {
        const { container, buttonGroup, button } = classNameGenerator();
        return {
            container: container({ className }),
            buttonGroup: buttonGroup(),
            button: button({ size }),
        };
    }, [className, size]);
    const onFocus = (0, react_1.useCallback)(() => setIsFocused(true), []);
    const onBlur = (0, react_1.useCallback)(() => setIsFocused(false), []);
    (0, react_1.useEffect)(() => {
        const handleKeyDown = (e) => {
            if (!isFocused || !containerRef.current || !document.activeElement) {
                return;
            }
            const radios = Array.from(containerRef.current.querySelectorAll('[role="radio"]:not(:disabled)'));
            if (radios.length < 2) {
                return;
            }
            const focusedIndex = radios.indexOf(document.activeElement);
            if (focusedIndex === -1) {
                return;
            }
            switch (e.key) {
                case 'Down':
                case 'ArrowDown':
                case 'Right':
                case 'ArrowRight': {
                    const nextIndex = focusedIndex + 1;
                    const nextRadio = radios[nextIndex % radios.length];
                    if (nextRadio instanceof HTMLButtonElement) {
                        nextRadio.focus();
                    }
                    break;
                }
                case 'Up':
                case 'ArrowUp':
                case 'Left':
                case 'ArrowLeft': {
                    const nextIndex = focusedIndex - 1;
                    const nextRadio = radios[(nextIndex + radios.length) % radios.length];
                    if (nextRadio instanceof HTMLButtonElement) {
                        nextRadio.focus();
                    }
                    break;
                }
            }
        };
        document.addEventListener('keydown', handleKeyDown);
        return () => {
            document.removeEventListener('keydown', handleKeyDown);
        };
    }, [isFocused]);
    const excludesSelected = (0, react_1.useMemo)(() => !value || options.every((option) => option.value !== value), [value, options]);
    const actualOnClickOption = (0, react_1.useMemo)(() => onClickOption
        ? (e) => onClickOption(e.currentTarget.value)
        : undefined, [onClickOption]);
    return ((0, jsx_runtime_1.jsx)("div", { ...props, className: classNames.container, onFocus: onFocus, onBlur: onBlur, ref: containerRef, role: "toolbar", children: (0, jsx_runtime_1.jsx)("div", { role: "radiogroup", className: classNames.buttonGroup, children: options.map((option, index) => ((0, jsx_runtime_1.jsx)(SegmentedControlButton, { option: option, index: index, onClick: actualOnClickOption, size: size, value: value, isFocused: isFocused, excludesSelected: excludesSelected, className: classNames.button }, option.value))) }) }));
};
exports.SegmentedControl = SegmentedControl;
const SegmentedControlButton = ({ onClick, size, value, option, index, isFocused, excludesSelected, className }) => {
    const attrs = (0, react_1.useMemo)(() => {
        const checked = value === option.value;
        return {
            checked,
            ariaChecked: checked && !!value,
            variant: checked ? 'primary' : 'secondary',
        };
    }, [value, option.value]);
    const tabIndex = (0, react_1.useMemo)(() => {
        if (isFocused) {
            return -1;
        }
        if (excludesSelected) {
            return index === 0 ? 0 : -1;
        }
        return attrs.checked ? 0 : -1;
    }, [excludesSelected, isFocused, attrs.checked, index]);
    return ((0, jsx_runtime_1.jsx)(Button_1.Button, { value: option.value, disabled: option.disabled, tabIndex: tabIndex, role: "radio", "aria-label": option.ariaLabel, "aria-checked": attrs.ariaChecked, onClick: onClick, variant: attrs.variant, size: size, className: className, children: option.content }));
};
//# sourceMappingURL=SegmentedControl.js.map