import { type ComponentPropsWithoutRef, type OptgroupHTMLAttributes, type OptionHTMLAttributes } from 'react';
import { type DecoratorsType } from '../../hooks/useDecorators';
type Option<T extends string> = {
    value: T;
} & Omit<OptionHTMLAttributes<HTMLOptionElement>, 'value'>;
type Optgroup<T extends string> = {
    label: string;
    options: Array<Option<T>>;
} & OptgroupHTMLAttributes<HTMLOptGroupElement>;
type Props<T extends string> = {
    /** 選択肢のデータの配列 */
    options: Array<Option<T> | Optgroup<T>>;
    /** フォームの値が変わったときに発火するコールバック関数 */
    onChangeValue?: (value: T) => void;
    /** フォームの値にエラーがあるかどうか */
    error?: boolean;
    /** コンポーネントの幅 */
    width?: number | string;
    /** コンポーネントの大きさ */
    size?: 'default' | 's';
    /** 空の選択肢を表示するかどうか */
    hasBlank?: boolean;
    /** コンポーネント内の文言を変更するための関数を設定 */
    decorators?: DecoratorsType<DecoratorKeyTypes>;
};
type ElementProps = Omit<ComponentPropsWithoutRef<'select'>, keyof Props<string> | 'children'>;
declare const DECORATOR_DEFAULT_TEXTS: {
    readonly blankLabel: "選択してください";
};
type DecoratorKeyTypes = keyof typeof DECORATOR_DEFAULT_TEXTS;
declare const Option: import("react").NamedExoticComponent<Option<string> | Optgroup<string>>;
export declare const Select: <T extends string>(props: Props<T> & ElementProps & import("react").RefAttributes<HTMLSelectElement>) => import("react").ReactNode;
export {};
