"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Select = void 0;
const react_1 = require("react");
const jsx_runtime_1 = require("react/jsx-runtime");
const react_2 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../hooks/useDecorators");
const ua_1 = require("../../libs/ua");
const util_1 = require("../../libs/util");
const Icon_1 = require("../Icon");
const DECORATOR_DEFAULT_TEXTS = {
    blankLabel: '選択してください',
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Select shr-relative shr-inline-block',
        select: [
            'shr-peer shr-border-shorthand shr-w-full shr-cursor-pointer shr-appearance-none shr-rounded-m shr-bg-white shr-text-base shr-leading-tight shr-text-black shr-outline-none',
            'hover:shr-bg-white-darken',
            'focus-visible:shr-focus-indicator',
            'disabled:shr-pointer-events-none disabled:shr-bg-white-darken disabled:shr-text-disabled disabled:shr-opacity-100',
            'contrast-more:shr-border-high-contrast',
            /* padding に依る積み上げでは文字が見切れてしまうため */
            'shr-min-h-[calc(theme(fontSize.base)_+_theme(spacing[0.75])_*_2_+_theme(spacing.px)_*_2)]',
            'shr-border-default disabled:shr-border-disabled',
            'aria-[invalid]:shr-border-danger',
        ],
        iconWrap: [
            'shr-pointer-events-none shr-absolute shr-inset-y-0 shr-inline-flex shr-items-center shr-text-grey',
            'peer-focus-visible:shr-text-black peer-disabled:shr-text-disabled',
        ],
        blankOptgroup: 'shr-hidden',
    },
    variants: {
        size: {
            default: {
                select: 'shr-py-0.5 shr-pe-2 shr-ps-0.5',
                // ((右 padding - アイコン幅) / 2) + 右 border
                iconWrap: 'shr-end-[calc(theme(spacing[0.5])_+_theme(spacing.px))]',
            },
            s: {
                select: [
                    'shr-px-0.5 shr-py-0.25 shr-pe-1.5 shr-text-sm',
                    /* padding に依る積み上げでは文字が見切れてしまうため */
                    'shr-min-h-[calc(theme(fontSize.sm)_+_theme(spacing[0.5])_*_2_+_theme(spacing.px)_*_2)]',
                ],
                iconWrap: 'shr-end-0.5 shr-text-sm',
            },
        },
    },
});
const ActualSelect = ({ options, onChange, onChangeValue, error, width, hasBlank, decorators, size, className, disabled, required, ...props }, ref) => {
    const handleChange = (0, react_2.useCallback)((e) => {
        if (onChange)
            onChange(e);
        if (onChangeValue) {
            const flattenOptions = options.reduce((pre, cur) => pre.concat('value' in cur ? cur : cur.options), []);
            const selectedOption = flattenOptions.find((option) => option.value === e.target.value);
            if (selectedOption) {
                onChangeValue(selectedOption.value);
            }
        }
    }, [onChange, onChangeValue, options]);
    const classNames = (0, react_2.useMemo)(() => {
        const { wrapper, select, iconWrap, blankOptgroup } = classNameGenerator();
        const sizeProps = {
            size: size || 'default',
        };
        return {
            wrapper: wrapper({ className }),
            select: select(sizeProps),
            iconWrap: iconWrap(sizeProps),
            blankOptGroup: blankOptgroup(),
        };
    }, [className, size]);
    const wrapperStyle = (0, react_2.useMemo)(() => ({
        width: typeof width === 'number' ? `${width}px` : width,
    }), [width]);
    const decorated = (0, useDecorators_1.useDecorators)(DECORATOR_DEFAULT_TEXTS, decorators);
    return ((0, jsx_runtime_1.jsxs)("span", { className: classNames.wrapper, style: wrapperStyle, children: [(0, jsx_runtime_1.jsxs)("select", { ...props, "data-smarthr-ui-input": "true", onChange: handleChange, "aria-invalid": error || undefined, disabled: disabled, 
                // HINT: required属性を設定すると、iOS端末で以下の問題が発生します
                //  - フォームのsubmit時にバリデーションは行われるが、ユーザーにフィードバックがない
                //    - エラーメッセージが表示されない
                //    - 問題のある入力フィールドまでスクロールしない
                // 歴史的に一部の端末ではrequired属性が無視されることがあるため、HTMLのバリデーションのみとすることは少ないです
                // そのため、iOS端末ではrequired属性を設定しない方がユーザーがsubmitできない理由をエラーメッセージなどで正しく理解できるようになります
                required: ua_1.isIOS ? undefined : required, ref: ref, className: classNames.select, children: [(0, jsx_runtime_1.jsx)(BlankOption, { hasBlank: hasBlank, children: decorated.blankLabel }), options.map((option, index) => ((0, react_1.createElement)(Option, { ...option, key: index }))), (0, jsx_runtime_1.jsx)(NotOmittingLabelsInMobileSafari, { className: classNames.blankOptGroup })] }), (0, jsx_runtime_1.jsx)("span", { className: classNames.iconWrap, children: (0, jsx_runtime_1.jsx)(Icon_1.FaAngleDownIcon, {}) })] }));
};
const BlankOption = (0, react_2.memo)(({ hasBlank, children }) => hasBlank && (0, jsx_runtime_1.jsx)("option", { value: "", children: children }));
const Option = (0, react_2.memo)((option) => {
    if ('value' in option) {
        return (0, jsx_runtime_1.jsx)("option", { ...option, children: option.label });
    }
    const { options: groupedOptions, ...optgroup } = option;
    return ((0, react_1.createElement)("optgroup", { ...optgroup, key: optgroup.label }, groupedOptions.map((groupedOption) => ((0, react_1.createElement)("option", { ...groupedOption, key: groupedOption.value }, groupedOption.label)))));
});
// Support for not omitting labels in Mobile Safari
const NotOmittingLabelsInMobileSafari = (0, react_2.memo)(({ className }) => ua_1.isMobileSafari && (0, jsx_runtime_1.jsx)("optgroup", { className: className }));
exports.Select = (0, util_1.genericsForwardRef)(ActualSelect);
//# sourceMappingURL=Select.js.map