"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusLabel = exports.classNameGenerator = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Icon_1 = require("../Icon");
exports.classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-StatusLabel',
        'shr-border-shorthand shr-box-content shr-inline-flex shr-min-h-em shr-min-w-[3.5em] shr-items-center shr-justify-center shr-gap-0.25 shr-whitespace-nowrap shr-border-current shr-bg-white shr-px-0.5 shr-py-0.25 shr-text-sm shr-font-bold',
        // ラベルが天地中央に揃わないため暫定対応
        'shr-leading-[0]',
    ],
    variants: {
        type: {
            grey: ['shr-border-grey-20 shr-text-grey', 'contrast-more:shr-border-high-contrast'],
            blue: 'shr-text-main',
            /* SmartHR 基本色の Aqua04。StatusLabel 以外では使いません。
             * https://smarthr.design/basics/colors/#h4-1 */
            green: 'shr-text-green',
            red: 'shr-text-danger',
            warning: 'shr-border-warning-yellow shr-bg-warning-yellow shr-text-black',
            error: 'shr-border-danger shr-bg-danger shr-text-white',
        },
        bold: {
            true: 'shr-text-white',
        },
    },
    compoundVariants: [
        {
            type: 'grey',
            bold: true,
            class: 'shr-border-grey-65 shr-bg-[theme(colors.grey.65)]',
        },
        {
            type: 'blue',
            bold: true,
            class: 'shr-border-main shr-bg-main',
        },
        {
            type: 'green',
            bold: true,
            /* SmartHR 基本色の Aqua04。StatusLabel 以外では使いません。
             * https://smarthr.design/basics/colors/#h4-1 */
            class: 'shr-border-green shr-bg-green',
        },
        {
            type: 'red',
            bold: true,
            class: 'shr-border-danger shr-bg-danger',
        },
        {
            type: 'warning',
            bold: true,
            class: 'shr-border-current shr-text-black',
        },
    ],
});
exports.StatusLabel = (0, react_1.memo)(({ type = 'grey', bold = false, className, children, ...props }) => {
    const actualClassName = (0, react_1.useMemo)(() => (0, exports.classNameGenerator)({
        className,
        type,
        bold,
    }), [type, bold, className]);
    return ((0, jsx_runtime_1.jsxs)("span", { ...props, className: actualClassName, children: [(0, jsx_runtime_1.jsx)(Icon, { type: type, bold: bold }), children] }));
});
const Icon = ({ type, bold }) => {
    if (bold) {
        switch (type) {
            case 'warning':
                return (0, jsx_runtime_1.jsx)(Icon_1.FaTriangleExclamationIcon, {});
            case 'error':
                return (0, jsx_runtime_1.jsx)(Icon_1.FaCircleExclamationIcon, {});
        }
    }
    return null;
};
//# sourceMappingURL=StatusLabel.js.map