"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HorizontalStepItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Text_1 = require("../Text");
const StepCounter_1 = require("./StepCounter");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'shr-group/stepItem',
            // 長いステップ名が来ても等幅にする
            'shr-flex-1',
        ],
        labelWrapper: 'shr-flex shr-flex-col shr-items-center shr-gap-0.5',
        stepCounterWrapper: 'shr-flex shr-items-center shr-self-stretch',
        beforeLine: [
            'group-first/stepItem:shr-bg-transparent',
            'shr-h-[theme(borderWidth.2)] shr-grow shr-bg-border',
            'forced-colors:shr-bg-[ButtonBorder]',
        ],
        afterLine: [
            'group-last/stepItem:shr-bg-transparent',
            // compoundSlots で書けるが、variants の上書きが複雑になるため切り出していない
            'shr-h-[theme(borderWidth.2)] shr-grow shr-bg-border',
            'forced-colors:shr-bg-[ButtonBorder]',
        ],
        label: 'shr-px-0.25 shr-text-center shr-text-sm',
    },
    variants: {
        status: {
            completed: {
                afterLine: ['shr-bg-main', 'forced-colors:shr-bg-[Highlight]'],
            },
            closed: {},
        },
        current: {
            true: {
                label: 'shr-font-bold',
            },
            false: {},
        },
        isPrevStepCompleted: {
            true: {
                beforeLine: ['shr-bg-main', 'forced-colors:shr-bg-[Highlight]'],
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            status: ['completed', 'closed'],
            current: false,
            className: {
                label: 'shr-text-grey',
            },
        },
    ],
});
exports.HorizontalStepItem = (0, react_1.memo)(({ stepNumber, label, status, current, isPrevStepCompleted }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, labelWrapper, stepCounterWrapper, beforeLine, afterLine, label: labelText, } = classNameGenerator({
            status: typeof status === 'object' ? status.type : status,
            current,
            isPrevStepCompleted,
        });
        return {
            wrapper: wrapper(),
            labelWrapper: labelWrapper(),
            stepCounterWrapper: stepCounterWrapper(),
            beforeLine: beforeLine(),
            afterLine: afterLine(),
            label: labelText(),
        };
    }, [current, isPrevStepCompleted, status]);
    return ((0, jsx_runtime_1.jsx)("li", { "aria-current": current ? 'step' : undefined, className: classNames.wrapper, children: (0, jsx_runtime_1.jsxs)("div", { className: classNames.labelWrapper, children: [(0, jsx_runtime_1.jsxs)("div", { className: classNames.stepCounterWrapper, children: [(0, jsx_runtime_1.jsx)("span", { className: classNames.beforeLine }), (0, jsx_runtime_1.jsx)(StepCounter_1.StepCounter, { status: status, current: current, stepNumber: stepNumber }), (0, jsx_runtime_1.jsx)("span", { className: classNames.afterLine })] }), (0, jsx_runtime_1.jsx)(Text_1.Text, { styleType: "sectionTitle", className: classNames.label, children: label })] }) }));
});
//# sourceMappingURL=HorizontalStepItem.js.map