"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepStatusIcon = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const intl_1 = require("../../intl");
const Icon_1 = require("../Icon");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'shr-rounded-full shr-bg-white shr-shadow-[0_0_0_theme(borderWidth.2)_theme(colors.white)]',
        'forced-colors:shr-bg-[CanvasText] forced-colors:shr-fill-[Canvas] forced-colors:shr-shadow-[0_0_0_theme(borderWidth.2)_Canvas]',
    ],
    variants: {
        status: {
            completed: [
                'shr-text-main',
                'forced-colors:shr-bg-[Canvas] forced-colors:shr-fill-[Highlight]',
            ],
            closed: ['shr-text-grey', 'forced-colors:shr-bg-[Canvas] forced-colors:shr-fill-[GrayText]'],
        },
    },
});
const StepStatusIcon = (props) => props.status ? (0, jsx_runtime_1.jsx)(ActualStepStatusIcon, { ...props }) : null;
exports.StepStatusIcon = StepStatusIcon;
const ICON_MAPPER = {
    completed: {
        alt: (0, jsx_runtime_1.jsx)(intl_1.Localizer, { id: "smarthr-ui/StepStatusIcon/completedAlt", defaultText: "\u5B8C\u4E86" }),
        Component: Icon_1.FaCircleCheckIcon,
    },
    closed: {
        alt: (0, jsx_runtime_1.jsx)(intl_1.Localizer, { id: "smarthr-ui/StepStatusIcon/closedAlt", defaultText: "\u4E2D\u65AD" }),
        Component: Icon_1.FaCircleXmarkIcon,
    },
};
const ActualStepStatusIcon = ({ status, className, ...rest }) => {
    const actualStatus = (0, react_1.useMemo)(() => {
        const isObject = typeof status === 'object';
        const statusType = isObject ? status.type : status;
        const { alt, Component } = ICON_MAPPER[statusType];
        return {
            type: statusType,
            text: isObject ? status.text || alt : alt,
            Component,
        };
    }, [status]);
    const actualClassName = (0, react_1.useMemo)(() => classNameGenerator({ status: actualStatus.type, className }), [actualStatus.type, className]);
    const Component = actualStatus.Component;
    return (0, jsx_runtime_1.jsx)(Component, { ...rest, alt: actualStatus.text, className: actualClassName });
};
//# sourceMappingURL=StepStatusIcon.js.map