"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VerticalStepItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Heading_1 = require("../Heading");
const SectioningContent_1 = require("../SectioningContent/SectioningContent");
const StepCounter_1 = require("./StepCounter");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'shr-group/stepItem',
        section: 'shr-flex shr-gap-1',
        // StepCounterの中心に揃えるため、0.25remとborder分の1px paddingを追加している
        headingWrapper: 'shr-flex shr-items-center shr-gap-1 shr-py-[calc(0.25rem_+_1px)]',
        heading: 'shr-inline-block',
        body: [
            // (stepCounter + :after) + (body > inner) という構造
            'shr-flex shr-grow shr-flex-col',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
        inner: 'shr-grow shr-pb-1.5 shr-pt-0.5',
        stepCounter: [
            // stepCounter の after 疑似要素がステップを繋ぐ線
            'after:shr-relative after:shr-mx-1 after:shr-block after:shr-h-full after:shr-w-[theme(borderWidth.2)] after:shr-bg-border after:shr-content-[""]',
            // 最後のステップの線を消す
            'group-last/stepItem:after:shr-bg-transparent',
        ],
    },
    variants: {
        status: {
            completed: {
                stepCounter: ['after:shr-bg-main', 'forced-colors:after:shr-bg-[Highlight]'],
            },
            closed: {},
        },
        current: {
            true: {
                heading: 'shr-font-bold',
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            status: ['completed', 'closed'],
            current: false,
            className: {
                heading: 'shr-text-grey',
            },
        },
    ],
});
const VerticalStepItem = ({ stepNumber, label, status, children, current }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, section, headingWrapper, heading, body, inner, stepCounter } = classNameGenerator({
            status: typeof status === 'object' ? status.type : status,
            current,
        });
        return {
            wrapper: wrapper(),
            section: section(),
            headingWrapper: headingWrapper(),
            heading: heading(),
            body: body(),
            inner: inner(),
            stepCounter: stepCounter(),
        };
    }, [current, status]);
    return ((0, jsx_runtime_1.jsx)("li", { "aria-current": current ? 'step' : undefined, className: classNames.wrapper, children: (0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { className: classNames.section, children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.stepCounter, children: (0, jsx_runtime_1.jsx)(StepCounter_1.StepCounter, { status: status, current: current, stepNumber: stepNumber }) }), (0, jsx_runtime_1.jsxs)("div", { className: classNames.body, children: [(0, jsx_runtime_1.jsx)("div", { className: classNames.headingWrapper, children: (0, jsx_runtime_1.jsx)(Heading_1.Heading, { type: "sectionTitle", className: classNames.heading, children: label }) }), (0, jsx_runtime_1.jsx)("div", { className: classNames.inner, children: children })] })] }) }));
};
exports.VerticalStepItem = VerticalStepItem;
//# sourceMappingURL=VerticalStepItem.js.map