"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Switch = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Icon_1 = require("../Icon");
const Layout_1 = require("../Layout");
const Text_1 = require("../Text");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            // Switch 本体
            'shr-border-shorthand shr-relative shr-inline-flex shr-h-fit shr-w-[calc(theme(fontSize.base)*2)] shr-items-center shr-rounded-full shr-bg-white',
            // 理想的には padding: 2px; だが、box-shadow を outline で使用しているため、border と padding で2pxの疑似余白を作っている。
            'shr-p-px',
            // :focus-visible-within の代替, なぜかhasが機能しないので以下の書き方で代用している
            'has-[:focus-visible]:shr-focus-indicator [&:has(:focus-visible)]:shr-focus-indicator',
            'has-[:checked]:shr-border-[theme(colors.main)] has-[:checked]:shr-bg-main',
            'has-[:disabled]:shr-border-[theme(borderColor.default)] has-[:disabled]:shr-bg-border',
            'forced-colors:has-[:disabled]:shr-border-[GrayText]',
            'supports-[not_selector(:has(+_*))]:shr-border-[revert] supports-[not_selector(:has(+_*))]:shr-bg-[revert]',
            // Switch ツマミ
            'before:shr-box-border before:shr-inline-block before:shr-size-[theme(fontSize.base)] before:shr-scale-[calc(2/3)] before:shr-rounded-full before:shr-border before:shr-border-solid before:shr-border-[theme(textColor.grey)] before:shr-bg-[theme(textColor.grey)] before:shr-transition-[transform,margin] before:shr-duration-150 before:shr-ease-out before:shr-content-[""]',
            'has-[input:disabled:not(:checked)]:before:shr-border-[theme(textColor.disabled)] has-[input:disabled:not(:checked)]:before:shr-bg-[theme(textColor.disabled)]',
            'has-[:checked]:before:shr-border-shorthand has-[:checked]:before:shr-ms-[theme(fontSize.base)] has-[:checked]:before:shr-scale-100 has-[:checked]:before:shr-bg-white',
            'forced-colors:has-[input:not(:disabled)]:before:shr-bg-[ButtonBorder]',
            'forced-colors:has-[:disabled:not(:checked)]:before:shr-border-solid forced-colors:has-[:disabled:not(:checked)]:before:shr-border-[GrayText]',
            'forced-colors:has-[:disabled:checked]:before:shr-border-[GrayText]',
            'supports-[not_selector(:has(+_*))]:before:hidden',
        ],
        input: [
            'shr-absolute shr-inset-0 shr-m-0 shr-h-full shr-w-full shr-cursor-pointer shr-appearance-none shr-rounded-full shr-opacity-0',
            'disabled:shr-cursor-[revert]',
            'supports-[not_selector(:has(+_*))]:shr-static supports-[not_selector(:has(+_*))]:shr-appearance-auto supports-[not_selector(:has(+_*))]:shr-opacity-100 supports-[not_selector(:has(+_*))]:shr-outline-[revert]',
        ],
        iconWrapper: [
            'smarthr-ui-Switch-iconWrapper',
            'shr-pointer-events-none shr-absolute shr-hidden shr-size-[theme(fontSize.base)] shr-items-center shr-justify-center',
            '[:checked~&]:shr-flex',
        ],
        icon: [
            'shr-fill-white',
            'forced-colors:shr-fill-[ButtonText]',
            'forced-colors:[:disabled~.smarthr-ui-Switch-iconWrapper_&]:shr-fill-[GrayText]',
        ],
    },
});
exports.Switch = (0, react_1.forwardRef)(({ children, dangerouslyLabelHidden, className, id, ...props }, ref) => {
    const defaultId = (0, react_1.useId)();
    const inputId = id || defaultId;
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, input, icon, iconWrapper } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            input: input(),
            icon: icon(),
            iconWrapper: iconWrapper(),
        };
    }, [className]);
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", children: [(0, jsx_runtime_1.jsx)(MemoizedLabel, { htmlFor: inputId, dangerouslyLabelHidden: dangerouslyLabelHidden, children: children }), (0, jsx_runtime_1.jsxs)("span", { className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)("input", { ...props, type: "checkbox", role: "switch", id: inputId, className: classNames.input, ref: ref }), (0, jsx_runtime_1.jsx)(MemoizedSuffixIcon, { className: classNames.iconWrapper, iconClassName: classNames.icon })] })] }));
});
const MemoizedLabel = (0, react_1.memo)(({ dangerouslyLabelHidden, htmlFor, children }) => {
    const Component = dangerouslyLabelHidden ? VisuallyHiddenText_1.VisuallyHiddenText : Text_1.Text;
    return ((0, jsx_runtime_1.jsx)(Component, { as: "label", htmlFor: htmlFor, children: children }));
});
const MemoizedSuffixIcon = (0, react_1.memo)(({ className, iconClassName }) => ((0, jsx_runtime_1.jsx)("span", { className: className, children: (0, jsx_runtime_1.jsx)(Icon_1.FaCheckIcon, { className: iconClassName, size: "XXS" }) })));
//# sourceMappingURL=Switch.js.map