"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TabItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const ua_1 = require("../../libs/ua");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const Tooltip_1 = require("../Tooltip");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-TabItem',
            'shr-group/tabitem',
            'shr-relative shr-inline-flex shr-items-center shr-gap-0.5 shr-px-1 shr-py-0.75',
            'hover:shr-bg-white-darken',
            'focus-visible:shr-focus-indicator--inner focus-visible:shr-z-1',
            'disabled:shr-cursor-not-allowed disabled:shr-bg-transparent',
            'aria-selected:before:shr-absolute aria-selected:before:shr-inset-x-0 aria-selected:before:shr-bottom-0 aria-selected:before:shr-z-1 aria-selected:before:shr-block aria-selected:before:shr-h-0.25 aria-selected:before:shr-bg-main aria-selected:before:shr-content-[""]',
            'forced-colors:aria-selected:before:shr-bg-[Highlight]',
        ],
        label: [
            'shr-font-bold shr-leading-none shr-text-grey',
            'group-hover/tabitem:shr-text-black',
            'group-disabled/tabitem:shr-text-grey/50',
            'group-aria-selected/tabitem:shr-text-black',
        ],
        suffixWrapper: [
            // Badge など内包要素に依って高さが変わらないようにするため、ネガティブマージンを指定
            '-shr-my-0.25',
            // 内包アイコンの leading を詰める
            '[&_.smarthr-ui-Icon]:shr-block',
        ],
    },
    variants: {
        isTouchDevice: {
            false: {
                wrapper: 'shr-transition-colors',
            },
        },
    },
});
const TabItem = ({ selected = false, disabledDetail, ...rest }) => {
    const tabAttrs = {
        role: 'tab',
        'aria-selected': selected,
    };
    if (rest.disabled && disabledDetail) {
        const Icon = disabledDetail.icon || (0, jsx_runtime_1.jsx)(Icon_1.FaCircleInfoIcon, { color: "TEXT_GREY" });
        return ((0, jsx_runtime_1.jsx)(Tooltip_1.Tooltip, { ...tabAttrs, message: disabledDetail.message, ariaDescribedbyTarget: "inner", "aria-disabled": rest.disabled, className: "focus-visible:shr-focus-indicator--inner", children: (0, jsx_runtime_1.jsx)(TabButton, { ...rest, suffix: Icon }) }));
    }
    return (0, jsx_runtime_1.jsx)(TabButton, { ...rest, ...tabAttrs });
};
exports.TabItem = TabItem;
const TabButton = ({ id, children, suffix, onClick, className, ...rest }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, label, suffixWrapper } = classNameGenerator({ isTouchDevice: ua_1.isTouchDevice });
        return {
            wrapper: wrapper({ className }),
            label: label(),
            suffixWrapper: suffixWrapper(),
        };
    }, [className]);
    const actualOnClick = (0, react_1.useCallback)((e) => onClick(e.currentTarget.value), [onClick]);
    return ((0, jsx_runtime_1.jsxs)(Button_1.UnstyledButton, { ...rest, type: "button", value: id, id: id, className: classNames.wrapper, onClick: actualOnClick, children: [(0, jsx_runtime_1.jsx)(TabLabel, { className: classNames.label, children: children }), (0, jsx_runtime_1.jsx)(TabButtonSuffix, { className: classNames.suffixWrapper, children: suffix })] }));
};
const TabLabel = (0, react_1.memo)(({ children, className }) => ((0, jsx_runtime_1.jsx)("span", { className: className, children: children })));
const TabButtonSuffix = (0, react_1.memo)(({ children, className }) => children && (0, jsx_runtime_1.jsx)("span", { className: className, children: children }));
//# sourceMappingURL=TabItem.js.map