"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThCheckbox = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const useDecorators_1 = require("../../hooks/useDecorators");
const intl_1 = require("../../intl");
const Balloon_1 = require("../Balloon");
const Checkbox_1 = require("../Checkbox");
const Th_1 = require("./Th");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        inner: [
            'shr-group/label',
            'shr-relative shr-flex shr-justify-center shr-px-1 shr-py-0.75',
            '[&:not(:has([disabled]))]:shr-cursor-pointer',
        ],
        wrapper: 'shr-w-[theme(fontSize.base)] shr-p-0',
        checkbox: ['shr-leading-[0]', '[&>span]:shr-translate-y-[unset]'],
        balloon: [
            // 位置はセルの真ん中(50%)+checkboxの幅の半分(8px)+outlineの幅(4px)+Balloonの矢印の幅(5px), sr-onlyで隠す
            'shr-sr-only shr-absolute shr-left-[calc(50%+(theme(fontSize.base)/2)+4px+5px)]',
            // labelの中の要素に hover or focus-visible がある時のスタイル。shr-absoluteはshr-not-sr-onlyのpositionをabsoluteに上書きしている
            'group-has-[:hover,:focus-visible]/label:shr-not-sr-only group-has-[:hover,:focus-visible]/label:shr-absolute group-has-[:hover,:focus-visible]/label:shr-whitespace-nowrap',
        ],
    },
});
exports.ThCheckbox = (0, react_1.forwardRef)(({ vAlign, fixed, decorators, className, ...others }, ref) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        checkAllInvisibleLabel: localize({
            id: 'smarthr-ui/ThCheckbox/checkAllInvisibleLabel',
            defaultText: 'すべての項目を選択/解除',
        }),
        checkColumnName: localize({
            id: 'smarthr-ui/ThCheckbox/checkColumnName',
            defaultText: '選択',
        }),
    }), [localize]);
    const decorated = (0, useDecorators_1.useDecorators)(decoratorDefaultTexts, decorators);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, inner, balloon, checkbox } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            inner: inner(),
            balloon: balloon(),
            checkbox: checkbox(),
        };
    }, [className]);
    return (
    // Th に必要な属性やイベントは不要
    (0, jsx_runtime_1.jsx)(Th_1.Th, { vAlign: vAlign, fixed: fixed, className: classNames.wrapper, "aria-label": decorated.checkColumnName, children: (0, jsx_runtime_1.jsxs)("label", { className: classNames.inner, children: [(0, jsx_runtime_1.jsx)(Balloon_1.Balloon, { as: "span", horizontal: "left", vertical: "middle", className: classNames.balloon, children: (0, jsx_runtime_1.jsx)("span", { className: "shr-block shr-p-0.5", children: decorated.checkAllInvisibleLabel }) }), (0, jsx_runtime_1.jsx)(Checkbox_1.Checkbox, { ...others, ref: ref, className: classNames.checkbox })] }) }));
});
//# sourceMappingURL=ThCheckbox.js.map