"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThSortButton = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const intl_1 = require("../../intl");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const sortButtonClassNameGenerator = (0, tailwind_variants_1.tv)({
    base: '-shr-mx-1 -shr-my-0.75 shr-inline-flex shr-w-full shr-items-center shr-justify-between shr-gap-x-0.5 shr-px-1 shr-py-0.75 shr-font-bold',
    variants: {
        align: {
            left: '',
            right: 'shr-justify-end',
        },
    },
});
exports.ThSortButton = (0, react_1.memo)(({ align, sort, decorators, onSort, children }) => {
    const { localize } = (0, intl_1.useIntl)();
    const decoratorDefaultTexts = (0, react_1.useMemo)(() => ({
        asc: localize({
            id: 'smarthr-ui/Th/sortDirectionAsc',
            defaultText: '昇順',
        }),
        desc: localize({
            id: 'smarthr-ui/Th/sortDirectionDesc',
            defaultText: '降順',
        }),
        none: localize({
            id: 'smarthr-ui/Th/sortDirectionNone',
            defaultText: '並び替えなし',
        }),
    }), [localize]);
    const sortLabel = (0, react_1.useMemo)(() => {
        if (!sort)
            return undefined;
        return (decorators?.sortDirectionIconAlt?.(decoratorDefaultTexts[sort], { sort }) ??
            decoratorDefaultTexts[sort]);
    }, [decorators, sort, decoratorDefaultTexts]);
    const className = (0, react_1.useMemo)(() => sortButtonClassNameGenerator({ align }), [align]);
    return ((0, jsx_runtime_1.jsxs)(Button_1.UnstyledButton, { onClick: onSort, className: className, children: [children, (0, jsx_runtime_1.jsx)(SortIcon, {}), (0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { children: sortLabel })] }));
});
const sortIconClassNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Icon-extended shr-relative shr-h-1 shr-w-1',
        upIcon: [
            'shr-absolute shr-left-0 shr-top-0',
            'shr-text-base',
            '[[aria-sort="none"]_&]:shr-text-disabled',
            '[[aria-sort="ascending"]_&]:shr-text-black',
            '[[aria-sort="descending"]_&]:shr-text-disabled',
        ],
        downIcon: [
            'shr-absolute shr-left-0 shr-top-0',
            'shr-text-base',
            '[[aria-sort="none"]_&]:shr-text-disabled',
            '[[aria-sort="ascending"]_&]:shr-text-disabled',
            '[[aria-sort="descending"]_&]:shr-text-black',
        ],
    },
});
const SortIcon = (0, react_1.memo)(() => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, upIcon, downIcon } = sortIconClassNameGenerator();
        return {
            wrapper: wrapper(),
            upIcon: upIcon(),
            downIcon: downIcon(),
        };
    }, []);
    return ((0, jsx_runtime_1.jsxs)("span", { className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)(Icon_1.FaSortUpIcon, { className: classNames.upIcon }), (0, jsx_runtime_1.jsx)(Icon_1.FaSortDownIcon, { className: classNames.downIcon })] }));
});
//# sourceMappingURL=ThSortButton.js.map