"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Text = exports.STYLE_TYPE_MAP = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
exports.STYLE_TYPE_MAP = {
    screenTitle: {
        size: 'XL',
        leading: 'TIGHT',
        weight: 'normal',
    },
    sectionTitle: {
        size: 'L',
        leading: 'TIGHT',
        weight: 'normal',
    },
    blockTitle: {
        size: 'M',
        leading: 'TIGHT',
        weight: 'bold',
    },
    subBlockTitle: {
        size: 'M',
        leading: 'TIGHT',
        weight: 'bold',
        color: 'TEXT_GREY',
    },
    subSubBlockTitle: {
        size: 'S',
        leading: 'TIGHT',
        weight: 'bold',
        color: 'TEXT_GREY',
    },
};
const UNDEFINED_STYLE_VALUES = {
    size: undefined,
    leading: undefined,
    weight: undefined,
    color: undefined,
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    variants: {
        size: {
            XXS: 'shr-text-2xs',
            XS: 'shr-text-xs',
            S: 'shr-text-sm',
            M: 'shr-text-base',
            L: 'shr-text-lg',
            XL: 'shr-text-xl',
            XXL: 'shr-text-2xl',
        },
        weight: {
            normal: 'shr-font-normal',
            bold: 'shr-font-bold',
        },
        italic: {
            true: 'shr-italic',
        },
        color: {
            TEXT_BLACK: 'shr-text-black',
            TEXT_WHITE: 'shr-text-white',
            TEXT_GREY: 'shr-text-grey',
            TEXT_DISABLED: 'shr-text-disabled',
            TEXT_LINK: 'shr-text-link',
            inherit: 'shr-text-color-inherit',
        },
        leading: {
            NONE: 'shr-leading-none',
            TIGHT: 'shr-leading-tight',
            NORMAL: 'shr-leading-normal',
            LOOSE: 'shr-leading-loose',
        },
        whiteSpace: {
            normal: 'shr-whitespace-normal',
            nowrap: 'shr-whitespace-nowrap',
            pre: 'shr-whitespace-pre',
            'pre-line': 'shr-whitespace-pre-line',
            'pre-wrap': 'shr-whitespace-pre-wrap',
        },
    },
});
const ActualText = ({ emphasis, styleType, weight = emphasis ? 'bold' : undefined, as: Component = emphasis ? 'em' : 'span', size, italic, color, leading, whiteSpace, className, ...props }) => {
    const actualClassName = (0, react_1.useMemo)(() => {
        const styleTypeValues = styleType
            ? exports.STYLE_TYPE_MAP[styleType]
            : UNDEFINED_STYLE_VALUES;
        return classNameGenerator({
            size: size || styleTypeValues.size,
            weight: weight || styleTypeValues.weight,
            color: color || styleTypeValues.color,
            leading: leading || styleTypeValues.leading,
            italic,
            whiteSpace,
            className,
        });
    }, [size, weight, italic, color, leading, whiteSpace, className, styleType]);
    return (0, jsx_runtime_1.jsx)(Component, { ...props, className: actualClassName });
};
exports.Text = (0, react_1.memo)(ActualText);
//# sourceMappingURL=Text.js.map