"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextLink = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const OpenInNewTabIcon_1 = require("./OpenInNewTabIcon");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        anchor: [
            'shr-text-link shr-no-underline shr-shadow-underline',
            'forced-colors:shr-underline',
            '[&:not([href])]:shr-shadow-none [&:not([href])]:forced-colors:shr-no-underline',
            '[.smarthr-ui-Th_&]:shr-text-link-darken',
        ],
        prefixWrapper: 'shr-me-0.25 shr-align-middle',
        suffixWrapper: 'shr-ms-0.25 shr-align-middle',
    },
    variants: {
        size: {
            S: {
                anchor: 'shr-text-sm',
            },
            M: {
                anchor: 'shr-text-base',
            },
        },
    },
});
const { anchor, prefixWrapper, suffixWrapper } = classNameGenerator();
const prefixWrapperClassName = prefixWrapper();
const suffixWrapperClassName = suffixWrapper();
const ActualTextLink = (0, react_1.forwardRef)(({ elementAs, href, target, rel, onClick, children, prefix, suffix, className, size, ...others }, ref) => {
    const Anchor = elementAs || 'a';
    const actualSuffix = (0, react_1.useMemo)(() => {
        if (target === '_blank' && suffix === undefined) {
            return (0, jsx_runtime_1.jsx)(OpenInNewTabIcon_1.OpenInNewTabIcon, {});
        }
        return suffix;
    }, [suffix, target]);
    const actualHref = (0, react_1.useMemo)(() => {
        if (href) {
            return href;
        }
        if (onClick) {
            return '';
        }
        return undefined;
    }, [href, onClick]);
    const actualRel = (0, react_1.useMemo)(() => (rel === undefined && target === '_blank' ? 'noopener noreferrer' : rel), [rel, target]);
    const anchorClassName = (0, react_1.useMemo)(() => anchor({ size, className }), [size, className]);
    const actualOnClick = (0, react_1.useMemo)(() => {
        if (!onClick) {
            return undefined;
        }
        if (href) {
            return onClick;
        }
        return (e) => {
            e.preventDefault();
            onClick(e);
        };
    }, [onClick, href]);
    return ((0, jsx_runtime_1.jsxs)(Anchor, { ...others, ref: ref, href: actualHref, target: target, rel: actualRel, onClick: actualOnClick, className: anchorClassName, children: [prefix && (0, jsx_runtime_1.jsx)("span", { className: prefixWrapperClassName, children: prefix }), children, actualSuffix && (0, jsx_runtime_1.jsx)("span", { className: suffixWrapperClassName, children: actualSuffix })] }));
});
exports.TextLink = (0, react_1.memo)(ActualTextLink);
//# sourceMappingURL=TextLink.js.map