"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimelineItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const dayjs_1 = __importDefault(require("dayjs"));
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Layout_1 = require("../Layout");
const SectioningContent_1 = require("../SectioningContent");
const Text_1 = require("../Text");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-TimelineItem',
            // mark(1) + 余白(0.75) の分だけ padding
            'shr-relative shr-pl-[calc(theme(fontSize.sm)+theme(spacing[0.75]))]',
            'has-[+_&]:shr-pb-2',
            // 繋ぎ線: 欠けたりはみ出たりしないように bottom で調整
            'before:shr-absolute before:-shr-bottom-0.75 before:shr-left-[calc((theme(fontSize.sm)/2)-1px)] before:shr-h-full before:shr-w-[2px] before:shr-bg-border',
            // 最後のアイテムには線を引かない
            '[&:not(:last-child)]:before:shr-content-[""]',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
        dateArea: 'shr-grow',
        title: [
            // 日付と中央寄せにしやすくするために mark は title に生やす
            'before:shr-absolute before:shr-left-0 before:shr-size-[theme(fontSize.sm)] before:shr-rounded-full before:shr-bg-border before:shr-content-[""]',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
    },
    variants: {
        current: {
            true: {
                title: [
                    'before:shr-left-[calc(theme(fontSize.sm)-theme(spacing[0.75]))] before:shr-z-1 before:shr-size-0.75 before:shr-bg-main before:shr-shadow-[0_0_0_2px_white,0_0_0_4px_theme(colors.main)]',
                    'forced-colors:before:shr-bg-[Mark]',
                ],
            },
        },
    },
});
const TimelineItem = ({ datetime, dateLabel, timeFormat = 'HH:mm', dateSuffixArea, sideActionArea, children, current, className, ...rest }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, dateArea, title } = classNameGenerator({
            current: !!current,
        });
        return {
            wrapper: wrapper({ className }),
            dateArea: dateArea(),
            title: title(),
        };
    }, [current, className]);
    const { date, time, isoString } = (0, react_1.useMemo)(() => {
        const d = (0, dayjs_1.default)(datetime);
        return {
            date: d.format('YYYY/MM/DD'),
            time: timeFormat !== 'none' && d.format(timeFormat),
            isoString: d.toISOString(),
        };
    }, [datetime, timeFormat]);
    const id = (0, react_1.useId)();
    return ((0, jsx_runtime_1.jsxs)(Layout_1.Stack, { ...rest, as: "li", gap: 0.5, "aria-current": current, className: classNames.wrapper, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", justify: "space-between", children: [(0, jsx_runtime_1.jsxs)(Layout_1.Sidebar, { align: "center", gap: 0.5, className: classNames.dateArea, children: [(0, jsx_runtime_1.jsxs)(Layout_1.Cluster, { align: "center", as: "time", dateTime: isoString, id: id, className: classNames.title, children: [(0, jsx_runtime_1.jsx)(Text_1.Text, { styleType: "blockTitle", leading: "NONE", children: dateLabel || date }), time && (0, jsx_runtime_1.jsx)(Text_1.Text, { leading: "NONE", children: time })] }), dateSuffixArea && (0, jsx_runtime_1.jsx)("div", { children: dateSuffixArea })] }), sideActionArea] }), children && (
            // eslint-disable-next-line smarthr/a11y-heading-in-sectioning-content
            (0, jsx_runtime_1.jsx)(SectioningContent_1.Section, { "aria-labelledby": id, children: children }))] }));
};
exports.TimelineItem = TimelineItem;
//# sourceMappingURL=TimelineItem.js.map