"use strict";
'use client';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tooltip = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_dom_1 = require("react-dom");
const react_innertext_1 = __importDefault(require("react-innertext"));
const tailwind_variants_1 = require("tailwind-variants");
const useEnhancedEffect_1 = require("../../hooks/useEnhancedEffect");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const TooltipPortal_1 = require("./TooltipPortal");
const subscribeFullscreenChange = (callback) => {
    window.addEventListener('fullscreenchange', callback);
    return () => {
        window.removeEventListener('fullscreenchange', callback);
    };
};
const getFullscreenElement = () => document.fullscreenElement;
const getFullscreenElementOnSSR = () => null;
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-Tooltip',
        'shr-inline-block shr-max-w-full shr-align-bottom',
        'focus-visible:shr-focus-indicator',
    ],
    variants: {
        isIcon: {
            true: 'shr-leading-[0]',
        },
    },
});
const Tooltip = ({ message, children, triggerType, ellipsisOnly, tabIndex = 0, ariaDescribedbyTarget = 'wrapper', className, onPointerEnter, onPointerLeave, onTouchStart, onTouchEnd, onFocus, onBlur, ...props }) => {
    const [portalRoot, setPortalRoot] = (0, react_1.useState)(null);
    const [isVisible, setIsVisible] = (0, react_1.useState)(false);
    const [rect, setRect] = (0, react_1.useState)(null);
    const ref = (0, react_1.useRef)(null);
    const messageId = (0, react_1.useId)();
    const fullscreenElement = (0, react_1.useSyncExternalStore)(subscribeFullscreenChange, getFullscreenElement, getFullscreenElementOnSSR);
    (0, useEnhancedEffect_1.useEnhancedEffect)(() => {
        setPortalRoot(fullscreenElement ?? document.body);
    }, [fullscreenElement]);
    const toShowAction = (0, react_1.useCallback)((e) => {
        // Tooltipのtriggerの他の要素(Dropwdown menu buttonで開いたmenu contentとか)に移動されたらtooltipを表示しない
        if (!ref.current?.contains(e.target)) {
            return;
        }
        if (ellipsisOnly) {
            const outerWidth = parseInt(window
                .getComputedStyle(ref.current.parentNode, null)
                .width.match(/\d+/)[0], 10);
            if (outerWidth < 0 || outerWidth > ref.current.clientWidth) {
                return;
            }
        }
        setRect(ref.current.getBoundingClientRect());
        setIsVisible(true);
    }, [ellipsisOnly]);
    const actualOnPointerEnter = (0, react_1.useMemo)(() => onPointerEnter
        ? (e) => {
            onPointerEnter(e);
            toShowAction(e);
        }
        : toShowAction, [onPointerEnter, toShowAction]);
    const actualOnTouchStart = (0, react_1.useMemo)(() => onTouchStart
        ? (e) => {
            onTouchStart(e);
            toShowAction(e);
        }
        : toShowAction, [onTouchStart, toShowAction]);
    const actualOnFocus = (0, react_1.useMemo)(() => onFocus
        ? (e) => {
            onFocus(e);
            toShowAction(e);
        }
        : toShowAction, [onFocus, toShowAction]);
    const toCloseAction = (0, react_1.useCallback)(() => setIsVisible(false), []);
    const actualOnPointerLeave = (0, react_1.useMemo)(() => onPointerLeave
        ? (e) => {
            onPointerLeave(e);
            toCloseAction();
        }
        : toCloseAction, [onPointerLeave, toCloseAction]);
    const actualOnTouchEnd = (0, react_1.useMemo)(() => onTouchEnd
        ? (e) => {
            onTouchEnd(e);
            toCloseAction();
        }
        : toCloseAction, [onTouchEnd, toCloseAction]);
    const actualOnBlur = (0, react_1.useMemo)(() => onBlur
        ? (e) => {
            onBlur(e);
            toCloseAction();
        }
        : toCloseAction, [onBlur, toCloseAction]);
    const isIcon = triggerType === 'icon';
    const actualClassName = (0, react_1.useMemo)(() => classNameGenerator({ isIcon, className }), [isIcon, className]);
    const isInnerTarget = ariaDescribedbyTarget === 'inner';
    const childrenWithProps = (0, react_1.useMemo)(() => isInnerTarget
        ? (0, react_1.cloneElement)(children, { 'aria-describedby': messageId })
        : children, [children, isInnerTarget, messageId]);
    return (
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions,smarthr/a11y-delegate-element-has-role-presentation
    (0, jsx_runtime_1.jsxs)("span", { ...props, ref: ref, tabIndex: tabIndex, "aria-describedby": isInnerTarget ? undefined : messageId, onPointerEnter: actualOnPointerEnter, onTouchStart: actualOnTouchStart, onFocus: actualOnFocus, onPointerLeave: actualOnPointerLeave, onTouchEnd: actualOnTouchEnd, onBlur: actualOnBlur, className: actualClassName, children: [portalRoot &&
                (0, react_dom_1.createPortal)((0, jsx_runtime_1.jsx)(TooltipPortal_1.TooltipPortal, { message: message, isVisible: isVisible, parentRect: rect, isIcon: isIcon }), portalRoot), childrenWithProps, (0, jsx_runtime_1.jsx)(MemoizedVisuallyHiddenText, { id: messageId, visible: isVisible, children: message })] }));
};
exports.Tooltip = Tooltip;
const MemoizedVisuallyHiddenText = (0, react_1.memo)(({ id, visible, children }) => {
    const hiddenText = (0, react_1.useMemo)(() => (0, react_innertext_1.default)(children), [children]);
    return ((0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { id: id, "aria-hidden": !visible, children: hiddenText }));
});
//# sourceMappingURL=Tooltip.js.map