"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useClick = useClick;
const react_1 = require("react");
function useClick(innerRefs, innerCallback, outerCallback) {
    (0, react_1.useEffect)(() => {
        const handleClick = (e) => {
            if (innerRefs.some((target) => isEventIncludedParent(e, target.current))) {
                innerCallback(e);
                return;
            }
            outerCallback(e);
        };
        window.addEventListener('click', handleClick);
        return () => {
            window.removeEventListener('click', handleClick);
        };
    }, [innerRefs, innerCallback, outerCallback]);
}
function isEventIncludedParent(e, parent) {
    if (!parent)
        return false;
    const path = e.composedPath();
    if (path.length === 0)
        return false;
    return path.includes(parent);
}
//# sourceMappingURL=useClick.js.map