"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useOuterClick = useOuterClick;
const react_1 = require("react");
function useOuterClick(targets, callback) {
    (0, react_1.useEffect)(() => {
        const handleOuterClick = (e) => {
            if (targets.every((target) => isEventExcludedParent(e, target.current))) {
                callback(e);
            }
        };
        window.addEventListener('click', handleOuterClick);
        return () => {
            window.removeEventListener('click', handleOuterClick);
        };
    }, [callback, targets]);
}
function isEventExcludedParent(e, parent) {
    if (!parent)
        return false;
    const path = e.composedPath();
    if (path.length === 0)
        return false;
    return !path.includes(parent);
}
//# sourceMappingURL=useOuterClick.js.map