"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePortal = usePortal;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_dom_1 = require("react-dom");
const useEnhancedEffect_1 = require("./useEnhancedEffect");
const ParentContext = (0, react_1.createContext)({
    seqs: [],
});
let portalSeq = 0;
function usePortal() {
    const [portalRoot, setPortalRoot] = (0, react_1.useState)(null);
    const currentSeq = (0, react_1.useMemo)(() => ++portalSeq, []);
    const parent = (0, react_1.useContext)(ParentContext);
    const calculatedSeqs = (0, react_1.useMemo)(() => {
        const parentSeqs = parent.seqs.concat(currentSeq);
        return {
            parentSeqs,
            portalChildOf: parentSeqs.join(','),
        };
    }, [currentSeq, parent.seqs]);
    (0, useEnhancedEffect_1.useEnhancedEffect)(() => {
        // Next.jsのhydration error回避のため、初回レンダリング時にdivを作成する
        setPortalRoot(document.createElement('div'));
    }, []);
    (0, useEnhancedEffect_1.useEnhancedEffect)(() => {
        if (!portalRoot) {
            return;
        }
        portalRoot.dataset.portalChildOf = calculatedSeqs.portalChildOf;
        document.body.appendChild(portalRoot);
        return () => {
            document.body.removeChild(portalRoot);
        };
    }, [portalRoot, calculatedSeqs.portalChildOf]);
    const isChildPortal = (0, react_1.useCallback)((element) => _isChildPortal(element, new RegExp(`(^|,)${currentSeq}(,|$)`)), [currentSeq]);
    const PortalParentProvider = (0, react_1.useCallback)(({ children }) => {
        const value = {
            seqs: calculatedSeqs.parentSeqs,
        };
        return (0, jsx_runtime_1.jsx)(ParentContext.Provider, { value: value, children: children });
    }, [calculatedSeqs.parentSeqs]);
    const wrappedCreatePortal = (0, react_1.useCallback)((children) => {
        if (portalRoot === null) {
            return null;
        }
        return (0, react_dom_1.createPortal)(children, portalRoot);
    }, [portalRoot]);
    const isPortalRootMounted = (0, react_1.useCallback)(() => portalRoot !== null, [portalRoot]);
    return {
        portalRoot,
        isPortalRootMounted,
        isChildPortal,
        PortalParentProvider,
        createPortal: wrappedCreatePortal,
    };
}
function _isChildPortal(element, seqRegex) {
    if (!element)
        return false;
    let includesSeq = false;
    const childOf = element.dataset?.portalChildOf;
    if (childOf) {
        includesSeq = seqRegex.test(childOf);
    }
    return includesSeq || _isChildPortal(element.parentElement, seqRegex);
}
//# sourceMappingURL=usePortal.js.map