"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.debounce = void 0;
/**
 * 関数の呼び出しを指定された待機時間 (wait) だけ遅延させるデバウンス関数。
 * 直前に同じ関数が呼び出された場合、タイマーをリセットして再び遅延させます。
 *
 * @param {T} func - 実行する関数
 * @param {number} wait - デバウンスの待機時間（ミリ秒）
 * @returns {(...args: Parameters<T>) => void} デバウンスされた関数
 *
 * @example
 * const debouncedFunction = debounce(() => console.log('Called!'), 200);
 */
const debounce = (func, wait) => {
    let timeoutId = null;
    return function (...args) {
        if (timeoutId !== null) {
            clearTimeout(timeoutId);
        }
        timeoutId = setTimeout(() => {
            func(...args);
        }, wait);
    };
};
exports.debounce = debounce;
//# sourceMappingURL=debounce.js.map