"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTheme = void 0;
const createBorder_1 = require("./createBorder");
const createBreakpoint_1 = require("./createBreakpoint");
const createColor_1 = require("./createColor");
const createFontSize_1 = require("./createFontSize");
const createInteraction_1 = require("./createInteraction");
const createLeading_1 = require("./createLeading");
const createRadius_1 = require("./createRadius");
const createShadow_1 = require("./createShadow");
const createSpacing_1 = require("./createSpacing");
const createZIndex_1 = require("./createZIndex");
const createTheme = (theme = {}) => {
    const colorProperty = theme.color;
    const baseSize = theme.spacing?.baseSize;
    const spacingByChar = (0, createSpacing_1.createSpacingByChar)(baseSize);
    return {
        color: (0, createColor_1.createColor)(colorProperty),
        fontSize: (0, createFontSize_1.createFontSize)(theme.fontSize),
        spacing: (0, createSpacing_1.createSpacing)(baseSize),
        spacingByChar,
        space: spacingByChar,
        leading: (0, createLeading_1.createLeading)(theme.leading),
        breakpoint: (0, createBreakpoint_1.createBreakpoint)(theme.breakpoint),
        border: (0, createBorder_1.createBorder)(theme.border, colorProperty),
        radius: (0, createRadius_1.createRadius)(theme.radius),
        interaction: (0, createInteraction_1.createInteraction)(theme.interaction),
        shadow: (0, createShadow_1.createShadow)(theme.shadow, colorProperty),
        zIndex: (0, createZIndex_1.createZIndex)(theme.zIndex),
    };
};
exports.createTheme = createTheme;
//# sourceMappingURL=createTheme.js.map